package com.bumptech.glide.load.engine;

import com.bumptech.glide.load.Encoder;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.ResourceDecoder;
import com.bumptech.glide.load.ResourceEncoder;
import com.bumptech.glide.load.Transformation;
import com.bumptech.glide.load.resource.transcode.ResourceTranscoder;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.security.MessageDigest;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes14.dex */
public class EngineKey implements Key {
    private static final String EMPTY_LOG_STRING = "";
    private final ResourceDecoder cacheDecoder;
    private final ResourceDecoder decoder;
    private final ResourceEncoder encoder;
    private int hashCode;
    private final int height;
    private final String id;
    private Key originalKey;
    private final Key signature;
    private final Encoder sourceEncoder;
    private String stringKey;
    private final ResourceTranscoder transcoder;
    private final Transformation transformation;
    private final int width;

    public EngineKey(String str, Key key, int i2, int i3, ResourceDecoder resourceDecoder, ResourceDecoder resourceDecoder2, Transformation transformation, ResourceEncoder resourceEncoder, ResourceTranscoder resourceTranscoder, Encoder encoder) {
        this.id = str;
        this.signature = key;
        this.width = i2;
        this.height = i3;
        this.cacheDecoder = resourceDecoder;
        this.decoder = resourceDecoder2;
        this.transformation = transformation;
        this.encoder = resourceEncoder;
        this.transcoder = resourceTranscoder;
        this.sourceEncoder = encoder;
    }

    public Key getOriginalKey() {
        if (this.originalKey == null) {
            this.originalKey = new OriginalKey(this.id, this.signature);
        }
        return this.originalKey;
    }

    @Override // com.bumptech.glide.load.Key
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        EngineKey engineKey = (EngineKey) obj;
        if (this.id.equals(engineKey.id) && this.signature.equals(engineKey.signature) && this.height == engineKey.height && this.width == engineKey.width) {
            Transformation transformation = this.transformation;
            if ((transformation == null) ^ (engineKey.transformation == null)) {
                return false;
            }
            if (transformation == null || transformation.getId().equals(engineKey.transformation.getId())) {
                ResourceDecoder resourceDecoder = this.decoder;
                if ((resourceDecoder == null) ^ (engineKey.decoder == null)) {
                    return false;
                }
                if (resourceDecoder == null || resourceDecoder.getId().equals(engineKey.decoder.getId())) {
                    ResourceDecoder resourceDecoder2 = this.cacheDecoder;
                    if ((resourceDecoder2 == null) ^ (engineKey.cacheDecoder == null)) {
                        return false;
                    }
                    if (resourceDecoder2 == null || resourceDecoder2.getId().equals(engineKey.cacheDecoder.getId())) {
                        ResourceEncoder resourceEncoder = this.encoder;
                        if ((resourceEncoder == null) ^ (engineKey.encoder == null)) {
                            return false;
                        }
                        if (resourceEncoder == null || resourceEncoder.getId().equals(engineKey.encoder.getId())) {
                            ResourceTranscoder resourceTranscoder = this.transcoder;
                            if ((resourceTranscoder == null) ^ (engineKey.transcoder == null)) {
                                return false;
                            }
                            if (resourceTranscoder == null || resourceTranscoder.getId().equals(engineKey.transcoder.getId())) {
                                Encoder encoder = this.sourceEncoder;
                                if ((encoder == null) ^ (engineKey.sourceEncoder == null)) {
                                    return false;
                                }
                                return encoder == null || encoder.getId().equals(engineKey.sourceEncoder.getId());
                            }
                            return false;
                        }
                        return false;
                    }
                    return false;
                }
                return false;
            }
            return false;
        }
        return false;
    }

    @Override // com.bumptech.glide.load.Key
    public int hashCode() {
        if (this.hashCode == 0) {
            int hashCode = this.id.hashCode();
            this.hashCode = hashCode;
            int hashCode2 = (hashCode * 31) + this.signature.hashCode();
            this.hashCode = hashCode2;
            int i2 = (hashCode2 * 31) + this.width;
            this.hashCode = i2;
            int i3 = (i2 * 31) + this.height;
            this.hashCode = i3;
            int i4 = i3 * 31;
            ResourceDecoder resourceDecoder = this.cacheDecoder;
            int hashCode3 = i4 + (resourceDecoder != null ? resourceDecoder.getId().hashCode() : 0);
            this.hashCode = hashCode3;
            int i5 = hashCode3 * 31;
            ResourceDecoder resourceDecoder2 = this.decoder;
            int hashCode4 = i5 + (resourceDecoder2 != null ? resourceDecoder2.getId().hashCode() : 0);
            this.hashCode = hashCode4;
            int i6 = hashCode4 * 31;
            Transformation transformation = this.transformation;
            int hashCode5 = i6 + (transformation != null ? transformation.getId().hashCode() : 0);
            this.hashCode = hashCode5;
            int i7 = hashCode5 * 31;
            ResourceEncoder resourceEncoder = this.encoder;
            int hashCode6 = i7 + (resourceEncoder != null ? resourceEncoder.getId().hashCode() : 0);
            this.hashCode = hashCode6;
            int i8 = hashCode6 * 31;
            ResourceTranscoder resourceTranscoder = this.transcoder;
            int hashCode7 = i8 + (resourceTranscoder != null ? resourceTranscoder.getId().hashCode() : 0);
            this.hashCode = hashCode7;
            int i9 = hashCode7 * 31;
            Encoder encoder = this.sourceEncoder;
            this.hashCode = i9 + (encoder != null ? encoder.getId().hashCode() : 0);
        }
        return this.hashCode;
    }

    public String toString() {
        if (this.stringKey == null) {
            StringBuilder append = new StringBuilder().append("EngineKey{").append(this.id).append('+').append(this.signature).append("+[").append(this.width).append('x').append(this.height).append("]+").append('\'');
            ResourceDecoder resourceDecoder = this.cacheDecoder;
            StringBuilder append2 = append.append(resourceDecoder != null ? resourceDecoder.getId() : "").append('\'').append('+').append('\'');
            ResourceDecoder resourceDecoder2 = this.decoder;
            StringBuilder append3 = append2.append(resourceDecoder2 != null ? resourceDecoder2.getId() : "").append('\'').append('+').append('\'');
            Transformation transformation = this.transformation;
            StringBuilder append4 = append3.append(transformation != null ? transformation.getId() : "").append('\'').append('+').append('\'');
            ResourceEncoder resourceEncoder = this.encoder;
            StringBuilder append5 = append4.append(resourceEncoder != null ? resourceEncoder.getId() : "").append('\'').append('+').append('\'');
            ResourceTranscoder resourceTranscoder = this.transcoder;
            StringBuilder append6 = append5.append(resourceTranscoder != null ? resourceTranscoder.getId() : "").append('\'').append('+').append('\'');
            Encoder encoder = this.sourceEncoder;
            this.stringKey = append6.append(encoder != null ? encoder.getId() : "").append('\'').append('}').toString();
        }
        return this.stringKey;
    }

    @Override // com.bumptech.glide.load.Key
    public void updateDiskCacheKey(MessageDigest messageDigest) throws UnsupportedEncodingException {
        byte[] array = ByteBuffer.allocate(8).putInt(this.width).putInt(this.height).array();
        this.signature.updateDiskCacheKey(messageDigest);
        messageDigest.update(this.id.getBytes(Key.STRING_CHARSET_NAME));
        messageDigest.update(array);
        ResourceDecoder resourceDecoder = this.cacheDecoder;
        messageDigest.update((resourceDecoder != null ? resourceDecoder.getId() : "").getBytes(Key.STRING_CHARSET_NAME));
        ResourceDecoder resourceDecoder2 = this.decoder;
        messageDigest.update((resourceDecoder2 != null ? resourceDecoder2.getId() : "").getBytes(Key.STRING_CHARSET_NAME));
        Transformation transformation = this.transformation;
        messageDigest.update((transformation != null ? transformation.getId() : "").getBytes(Key.STRING_CHARSET_NAME));
        ResourceEncoder resourceEncoder = this.encoder;
        messageDigest.update((resourceEncoder != null ? resourceEncoder.getId() : "").getBytes(Key.STRING_CHARSET_NAME));
        Encoder encoder = this.sourceEncoder;
        messageDigest.update((encoder != null ? encoder.getId() : "").getBytes(Key.STRING_CHARSET_NAME));
    }
}
