package com.kongzue.dialogx.dialogs;

import android.animation.ObjectAnimator;
import android.animation.ValueAnimator;
import android.app.Activity;
import android.graphics.Outline;
import android.graphics.Rect;
import android.graphics.drawable.GradientDrawable;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.view.animation.DecelerateInterpolator;
import android.widget.RelativeLayout;
import androidx.lifecycle.Lifecycle;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.DialogConvertViewInterface;
import com.kongzue.dialogx.interfaces.DialogLifecycleCallback;
import com.kongzue.dialogx.interfaces.DialogXAnimInterface;
import com.kongzue.dialogx.interfaces.DialogXStyle;
import com.kongzue.dialogx.interfaces.OnBackPressedListener;
import com.kongzue.dialogx.interfaces.OnBackgroundMaskClickListener;
import com.kongzue.dialogx.interfaces.OnBindView;
import com.kongzue.dialogx.interfaces.OnSafeInsetsChangeListener;
import com.kongzue.dialogx.interfaces.ScrollController;
import com.kongzue.dialogx.util.FullScreenDialogTouchEventInterceptor;
import com.kongzue.dialogx.util.ObjectRunnable;
import com.kongzue.dialogx.util.views.ActivityScreenShotImageView;
import com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout;
import com.kongzue.dialogx.util.views.MaxRelativeLayout;
/* loaded from: classes10.dex */
public class FullScreenDialog extends BaseDialog {
    public static BaseDialog.BOOLEAN overrideCancelable = null;
    public static int overrideEnterDuration = -1;
    public static int overrideExitDuration = -1;
    protected DialogImpl dialogImpl;
    protected DialogLifecycleCallback<FullScreenDialog> dialogLifecycleCallback;
    private View dialogView;
    protected DialogXAnimInterface<FullScreenDialog> dialogXAnimImpl;
    protected boolean hideWithExitAnim;
    protected boolean hideZoomBackground;
    private boolean isHide;
    protected OnBackPressedListener<FullScreenDialog> onBackPressedListener;
    protected OnBackgroundMaskClickListener<FullScreenDialog> onBackgroundMaskClickListener;
    protected OnBindView<FullScreenDialog> onBindView;
    protected BaseDialog.BOOLEAN privateCancelable;
    protected float backgroundRadius = -1.0f;
    protected boolean allowInterceptTouch = true;

    /* renamed from: me  reason: collision with root package name */
    protected FullScreenDialog f974me = this;

    protected FullScreenDialog() {
    }

    public static FullScreenDialog build() {
        return new FullScreenDialog();
    }

    public static FullScreenDialog build(OnBindView<FullScreenDialog> onBindView) {
        return new FullScreenDialog(onBindView);
    }

    public FullScreenDialog(OnBindView<FullScreenDialog> onBindView) {
        this.onBindView = onBindView;
    }

    public static FullScreenDialog show(OnBindView<FullScreenDialog> onBindView) {
        FullScreenDialog fullScreenDialog = new FullScreenDialog(onBindView);
        fullScreenDialog.show();
        return fullScreenDialog;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public FullScreenDialog show() {
        if (this.isHide && getDialogView() != null && this.isShow) {
            if (this.hideWithExitAnim && getDialogImpl() != null) {
                getDialogView().setVisibility(0);
                getDialogImpl().getDialogXAnimImpl().doShowAnim(this.f974me, null);
            } else {
                getDialogView().setVisibility(0);
            }
            return this;
        }
        super.beforeShow();
        if (getDialogView() == null) {
            this.dialogView = createView(isLightTheme() ? R.layout.layout_dialogx_fullscreen : R.layout.layout_dialogx_fullscreen_dark);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f974me);
            }
        }
        show(this.dialogView);
        return this;
    }

    public void show(Activity activity) {
        super.beforeShow();
        if (getDialogView() == null) {
            this.dialogView = createView(isLightTheme() ? R.layout.layout_dialogx_fullscreen : R.layout.layout_dialogx_fullscreen_dark);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f974me);
            }
        }
        show(activity, this.dialogView);
    }

    /* loaded from: classes10.dex */
    public class DialogImpl implements DialogConvertViewInterface {
        public MaxRelativeLayout bkg;
        public RelativeLayout boxBkg;
        public RelativeLayout boxCustom;
        public DialogXBaseRelativeLayout boxRoot;
        private FullScreenDialogTouchEventInterceptor fullScreenDialogTouchEventInterceptor;
        public ActivityScreenShotImageView imgZoomActivity;
        public ScrollController scrollView;
        public float bkgEnterAimY = -1.0f;
        private long enterAnimDurationTemp = 300;

        public DialogImpl setScrollView(ScrollController scrollView) {
            this.scrollView = scrollView;
            return this;
        }

        public DialogImpl(View convertView) {
            if (convertView == null) {
                return;
            }
            this.imgZoomActivity = (ActivityScreenShotImageView) convertView.findViewById(R.id.img_zoom_activity);
            this.boxRoot = (DialogXBaseRelativeLayout) convertView.findViewById(R.id.box_root);
            this.boxBkg = (RelativeLayout) convertView.findViewById(R.id.box_bkg);
            this.bkg = (MaxRelativeLayout) convertView.findViewById(R.id.bkg);
            this.boxCustom = (RelativeLayout) convertView.findViewById(R.id.box_custom);
            if (FullScreenDialog.this.hideZoomBackground) {
                FullScreenDialog.this.dialogView.setBackgroundResource(R.color.black20);
                this.imgZoomActivity.setVisibility(8);
            } else {
                FullScreenDialog.this.dialogView.setBackgroundResource(R.color.black);
                this.imgZoomActivity.setVisibility(0);
            }
            init();
            FullScreenDialog.this.dialogImpl = this;
            refreshView();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void init() {
            this.boxRoot.setParentDialog(FullScreenDialog.this.f974me);
            this.boxRoot.setOnLifecycleCallBack(new DialogXBaseRelativeLayout.OnLifecycleCallBack() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.1
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onShow() {
                    FullScreenDialog.this.isShow = true;
                    FullScreenDialog.this.preShow = false;
                    FullScreenDialog.this.lifecycle.setCurrentState(Lifecycle.State.CREATED);
                    FullScreenDialog.this.onDialogShow();
                    FullScreenDialog.this.getDialogLifecycleCallback().onShow(FullScreenDialog.this.f974me);
                }

                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onDismiss() {
                    FullScreenDialog.this.isShow = false;
                    FullScreenDialog.this.getDialogLifecycleCallback().onDismiss(FullScreenDialog.this.f974me);
                    DialogImpl.this.fullScreenDialogTouchEventInterceptor = null;
                    FullScreenDialog.this.dialogImpl = null;
                    FullScreenDialog.this.dialogLifecycleCallback = null;
                    FullScreenDialog.this.lifecycle.setCurrentState(Lifecycle.State.DESTROYED);
                    System.gc();
                }
            });
            this.boxRoot.setOnBackPressedListener(new DialogXBaseRelativeLayout.PrivateBackPressedListener() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.2
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.PrivateBackPressedListener
                public boolean onBackPressed() {
                    if (FullScreenDialog.this.onBackPressedListener != null) {
                        if (FullScreenDialog.this.onBackPressedListener.onBackPressed(FullScreenDialog.this.f974me)) {
                            FullScreenDialog.this.dismiss();
                            return true;
                        }
                        return true;
                    } else if (FullScreenDialog.this.isCancelable()) {
                        FullScreenDialog.this.dismiss();
                        return true;
                    } else {
                        return true;
                    }
                }
            });
            this.fullScreenDialogTouchEventInterceptor = new FullScreenDialogTouchEventInterceptor(FullScreenDialog.this.f974me, FullScreenDialog.this.dialogImpl);
            this.enterAnimDurationTemp = 300L;
            if (FullScreenDialog.overrideEnterDuration >= 0) {
                this.enterAnimDurationTemp = FullScreenDialog.overrideEnterDuration;
            }
            if (FullScreenDialog.this.enterAnimDuration >= 0) {
                this.enterAnimDurationTemp = FullScreenDialog.this.enterAnimDuration;
            }
            this.boxRoot.setBkgAlpha(0.0f);
            this.bkg.setY(this.boxRoot.getHeight());
            this.boxRoot.post(new Runnable() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.3
                @Override // java.lang.Runnable
                public void run() {
                    DialogImpl.this.getDialogXAnimImpl().doShowAnim(FullScreenDialog.this.f974me, null);
                    FullScreenDialog.this.lifecycle.setCurrentState(Lifecycle.State.RESUMED);
                }
            });
            this.boxRoot.setOnSafeInsetsChangeListener(new OnSafeInsetsChangeListener() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.4
                @Override // com.kongzue.dialogx.interfaces.OnSafeInsetsChangeListener
                public void onChange(Rect unsafeRect) {
                    if (unsafeRect.bottom > FullScreenDialog.this.dip2px(100.0f)) {
                        ObjectAnimator ofFloat = ObjectAnimator.ofFloat(DialogImpl.this.bkg, "y", DialogImpl.this.bkg.getY(), 0.0f);
                        ofFloat.setDuration(DialogImpl.this.enterAnimDurationTemp);
                        ofFloat.start();
                    }
                }
            });
            this.bkg.setOnYChanged(new MaxRelativeLayout.OnYChanged() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.5
                @Override // com.kongzue.dialogx.util.views.MaxRelativeLayout.OnYChanged
                public void y(float y) {
                    float height = 1.0f - ((DialogImpl.this.boxRoot.getHeight() - y) * 2.0E-5f);
                    float f = height <= 1.0f ? height : 1.0f;
                    if (FullScreenDialog.this.hideZoomBackground) {
                        return;
                    }
                    DialogImpl.this.imgZoomActivity.setScaleX(f);
                    DialogImpl.this.imgZoomActivity.setScaleY(f);
                    DialogImpl.this.imgZoomActivity.setRadius(FullScreenDialog.this.dip2px(15.0f) * ((DialogImpl.this.boxRoot.getHeight() - y) / DialogImpl.this.boxRoot.getHeight()));
                }
            });
            FullScreenDialog.this.onDialogInit();
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void showEnterAnim(int customViewHeight) {
            float safeHeight = this.boxRoot.getSafeHeight() - customViewHeight;
            this.bkgEnterAimY = safeHeight;
            if (safeHeight < 0.0f) {
                this.bkgEnterAimY = 0.0f;
            }
            ObjectAnimator ofFloat = ObjectAnimator.ofFloat(this.bkg, "y", this.boxRoot.getHeight(), this.bkgEnterAimY);
            ofFloat.setDuration(this.enterAnimDurationTemp);
            ofFloat.setInterpolator(new DecelerateInterpolator());
            ofFloat.start();
            this.bkg.setVisibility(0);
            ValueAnimator ofFloat2 = ValueAnimator.ofFloat(0.0f, 1.0f);
            ofFloat2.setDuration(this.enterAnimDurationTemp);
            ofFloat2.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.6
                @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                public void onAnimationUpdate(ValueAnimator animation) {
                    DialogImpl.this.boxRoot.setBkgAlpha(((Float) animation.getAnimatedValue()).floatValue());
                }
            });
            ofFloat2.start();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void refreshView() {
            if (this.boxRoot == null || BaseDialog.getTopActivity() == null) {
                return;
            }
            if (FullScreenDialog.this.backgroundColor != -1) {
                FullScreenDialog fullScreenDialog = FullScreenDialog.this;
                fullScreenDialog.tintColor(this.bkg, fullScreenDialog.backgroundColor);
            }
            this.bkg.setMaxWidth(FullScreenDialog.this.getMaxWidth());
            if (FullScreenDialog.this.isCancelable()) {
                this.boxRoot.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.7
                    @Override // android.view.View.OnClickListener
                    public void onClick(View v) {
                        if (FullScreenDialog.this.onBackgroundMaskClickListener == null || !FullScreenDialog.this.onBackgroundMaskClickListener.onClick(FullScreenDialog.this.f974me, v)) {
                            DialogImpl.this.doDismiss(v);
                        }
                    }
                });
            } else {
                this.boxRoot.setOnClickListener(null);
            }
            if (FullScreenDialog.this.backgroundRadius > -1.0f) {
                GradientDrawable gradientDrawable = (GradientDrawable) this.bkg.getBackground();
                if (gradientDrawable != null) {
                    gradientDrawable.setCornerRadii(new float[]{FullScreenDialog.this.backgroundRadius, FullScreenDialog.this.backgroundRadius, FullScreenDialog.this.backgroundRadius, FullScreenDialog.this.backgroundRadius, 0.0f, 0.0f, 0.0f, 0.0f});
                }
                if (Build.VERSION.SDK_INT >= 21) {
                    this.bkg.setOutlineProvider(new ViewOutlineProvider() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.8
                        @Override // android.view.ViewOutlineProvider
                        public void getOutline(View view, Outline outline) {
                            outline.setRoundRect(0, 0, view.getWidth(), (int) (view.getHeight() + FullScreenDialog.this.backgroundRadius), FullScreenDialog.this.backgroundRadius);
                        }
                    });
                    this.bkg.setClipToOutline(true);
                }
            }
            if (FullScreenDialog.this.onBindView != null) {
                FullScreenDialog.this.onBindView.bindParent(this.boxCustom, FullScreenDialog.this.f974me);
                if (FullScreenDialog.this.onBindView.getCustomView() instanceof ScrollController) {
                    this.scrollView = (ScrollController) FullScreenDialog.this.onBindView.getCustomView();
                } else {
                    View findViewWithTag = FullScreenDialog.this.onBindView.getCustomView().findViewWithTag("ScrollController");
                    if (findViewWithTag instanceof ScrollController) {
                        this.scrollView = (ScrollController) findViewWithTag;
                    }
                }
            }
            if (FullScreenDialog.this.hideZoomBackground) {
                FullScreenDialog.this.dialogView.setBackgroundResource(R.color.black20);
                this.imgZoomActivity.setVisibility(8);
            } else {
                FullScreenDialog.this.dialogView.setBackgroundResource(R.color.black);
                this.imgZoomActivity.setVisibility(0);
            }
            this.fullScreenDialogTouchEventInterceptor.refresh(FullScreenDialog.this.f974me, this);
            FullScreenDialog.this.onDialogRefreshUI();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void doDismiss(View v) {
            if (v != null) {
                v.setEnabled(false);
            }
            if (BaseDialog.getTopActivity() == null || FullScreenDialog.this.dismissAnimFlag) {
                return;
            }
            FullScreenDialog.this.dismissAnimFlag = true;
            getDialogXAnimImpl().doExitAnim(FullScreenDialog.this.f974me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.9
                @Override // com.kongzue.dialogx.util.ObjectRunnable
                public void run(Float value) {
                    if (DialogImpl.this.boxRoot != null) {
                        DialogImpl.this.boxRoot.setBkgAlpha(value.floatValue());
                    }
                    if (value.floatValue() == 0.0f) {
                        if (DialogImpl.this.boxRoot != null) {
                            DialogImpl.this.boxRoot.setVisibility(8);
                        }
                        FullScreenDialog.dismiss(FullScreenDialog.this.dialogView);
                    }
                }
            });
        }

        public void preDismiss() {
            if (FullScreenDialog.this.isCancelable()) {
                doDismiss(this.boxRoot);
                return;
            }
            long j = FullScreenDialog.overrideExitDuration >= 0 ? FullScreenDialog.overrideExitDuration : 300L;
            if (FullScreenDialog.this.exitAnimDuration >= 0) {
                j = FullScreenDialog.this.exitAnimDuration;
            }
            MaxRelativeLayout maxRelativeLayout = this.bkg;
            ObjectAnimator ofFloat = ObjectAnimator.ofFloat(maxRelativeLayout, "y", maxRelativeLayout.getY(), this.bkgEnterAimY);
            ofFloat.setDuration(j);
            ofFloat.start();
        }

        protected DialogXAnimInterface<FullScreenDialog> getDialogXAnimImpl() {
            if (FullScreenDialog.this.dialogXAnimImpl == null) {
                FullScreenDialog.this.dialogXAnimImpl = new DialogXAnimInterface<FullScreenDialog>() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.10
                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doExitAnim(FullScreenDialog dialog, ObjectRunnable animProgress) {
                        doExitAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doShowAnim(FullScreenDialog dialog, ObjectRunnable animProgress) {
                        doShowAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    /* renamed from: doShowAnim  reason: avoid collision after fix types in other method */
                    public void doShowAnim2(FullScreenDialog dialog, ObjectRunnable<Float> animProgress) {
                        int height = DialogImpl.this.boxCustom.getHeight();
                        if (height != 0 && !isMatchParentHeightCustomView()) {
                            DialogImpl.this.showEnterAnim(height);
                            return;
                        }
                        DialogImpl dialogImpl = DialogImpl.this;
                        dialogImpl.showEnterAnim((int) dialogImpl.boxRoot.getSafeHeight());
                    }

                    private boolean isMatchParentHeightCustomView() {
                        ViewGroup.LayoutParams layoutParams;
                        return (FullScreenDialog.this.onBindView == null || FullScreenDialog.this.onBindView.getCustomView() == null || (layoutParams = FullScreenDialog.this.onBindView.getCustomView().getLayoutParams()) == null || layoutParams.height != -1) ? false : true;
                    }

                    /* renamed from: doExitAnim  reason: avoid collision after fix types in other method */
                    public void doExitAnim2(FullScreenDialog dialog, final ObjectRunnable<Float> animProgress) {
                        long j = FullScreenDialog.overrideExitDuration >= 0 ? FullScreenDialog.overrideExitDuration : 300L;
                        if (FullScreenDialog.this.exitAnimDuration >= 0) {
                            j = FullScreenDialog.this.exitAnimDuration;
                        }
                        ObjectAnimator ofFloat = ObjectAnimator.ofFloat(DialogImpl.this.bkg, "y", DialogImpl.this.bkg.getY(), DialogImpl.this.boxBkg.getHeight());
                        ofFloat.setDuration(j);
                        ofFloat.start();
                        ValueAnimator ofFloat2 = ValueAnimator.ofFloat(1.0f, 0.0f);
                        ofFloat2.setDuration(j);
                        ofFloat2.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.DialogImpl.10.1
                            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                            public void onAnimationUpdate(ValueAnimator animation) {
                                animProgress.run((Float) animation.getAnimatedValue());
                            }
                        });
                        ofFloat2.start();
                    }
                };
            }
            return FullScreenDialog.this.dialogXAnimImpl;
        }
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public String dialogKey() {
        return getClass().getSimpleName() + "(" + Integer.toHexString(hashCode()) + ")";
    }

    public void refreshUI() {
        if (getDialogImpl() == null) {
            return;
        }
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.1
            @Override // java.lang.Runnable
            public void run() {
                if (FullScreenDialog.this.dialogImpl != null) {
                    FullScreenDialog.this.dialogImpl.refreshView();
                }
            }
        });
    }

    public void dismiss() {
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.2
            @Override // java.lang.Runnable
            public void run() {
                if (FullScreenDialog.this.dialogImpl == null) {
                    return;
                }
                FullScreenDialog.this.dialogImpl.doDismiss(null);
            }
        });
    }

    public DialogLifecycleCallback<FullScreenDialog> getDialogLifecycleCallback() {
        DialogLifecycleCallback<FullScreenDialog> dialogLifecycleCallback = this.dialogLifecycleCallback;
        return dialogLifecycleCallback == null ? new DialogLifecycleCallback<FullScreenDialog>() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.3
        } : dialogLifecycleCallback;
    }

    public FullScreenDialog setDialogLifecycleCallback(DialogLifecycleCallback<FullScreenDialog> dialogLifecycleCallback) {
        this.dialogLifecycleCallback = dialogLifecycleCallback;
        if (this.isShow) {
            dialogLifecycleCallback.onShow(this.f974me);
        }
        return this;
    }

    public OnBackPressedListener<FullScreenDialog> getOnBackPressedListener() {
        return this.onBackPressedListener;
    }

    public FullScreenDialog setOnBackPressedListener(OnBackPressedListener<FullScreenDialog> onBackPressedListener) {
        this.onBackPressedListener = onBackPressedListener;
        refreshUI();
        return this;
    }

    public FullScreenDialog setStyle(DialogXStyle style) {
        this.style = style;
        return this;
    }

    public FullScreenDialog setTheme(DialogX.THEME theme) {
        this.theme = theme;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public boolean isCancelable() {
        BaseDialog.BOOLEAN r0 = this.privateCancelable;
        if (r0 != null) {
            return r0 == BaseDialog.BOOLEAN.TRUE;
        }
        BaseDialog.BOOLEAN r02 = overrideCancelable;
        if (r02 != null) {
            return r02 == BaseDialog.BOOLEAN.TRUE;
        }
        return this.cancelable;
    }

    public FullScreenDialog setCancelable(boolean cancelable) {
        this.privateCancelable = cancelable ? BaseDialog.BOOLEAN.TRUE : BaseDialog.BOOLEAN.FALSE;
        refreshUI();
        return this;
    }

    public DialogImpl getDialogImpl() {
        return this.dialogImpl;
    }

    public FullScreenDialog setCustomView(OnBindView<FullScreenDialog> onBindView) {
        this.onBindView = onBindView;
        refreshUI();
        return this;
    }

    public View getCustomView() {
        OnBindView<FullScreenDialog> onBindView = this.onBindView;
        if (onBindView == null) {
            return null;
        }
        return onBindView.getCustomView();
    }

    public FullScreenDialog removeCustomView() {
        this.onBindView.clean();
        refreshUI();
        return this;
    }

    public int getBackgroundColor() {
        return this.backgroundColor;
    }

    public FullScreenDialog setBackgroundColor(int backgroundColor) {
        this.backgroundColor = backgroundColor;
        refreshUI();
        return this;
    }

    public FullScreenDialog setBackgroundColorRes(int backgroundColorRes) {
        this.backgroundColor = getColor(backgroundColorRes);
        refreshUI();
        return this;
    }

    public long getEnterAnimDuration() {
        return this.enterAnimDuration;
    }

    public FullScreenDialog setEnterAnimDuration(long enterAnimDuration) {
        this.enterAnimDuration = enterAnimDuration;
        return this;
    }

    public long getExitAnimDuration() {
        return this.exitAnimDuration;
    }

    public FullScreenDialog setExitAnimDuration(long exitAnimDuration) {
        this.exitAnimDuration = exitAnimDuration;
        return this;
    }

    public boolean isHideZoomBackground() {
        return this.hideZoomBackground;
    }

    public FullScreenDialog setHideZoomBackground(boolean hideZoomBackground) {
        this.hideZoomBackground = hideZoomBackground;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public void restartDialog() {
        View view = this.dialogView;
        if (view != null) {
            dismiss(view);
            this.isShow = false;
        }
        if (getDialogImpl().boxCustom != null) {
            getDialogImpl().boxCustom.removeAllViews();
        }
        this.enterAnimDuration = 0L;
        this.dialogView = createView(isLightTheme() ? R.layout.layout_dialogx_fullscreen : R.layout.layout_dialogx_fullscreen_dark);
        this.dialogImpl = new DialogImpl(this.dialogView);
        View view2 = this.dialogView;
        if (view2 != null) {
            view2.setTag(this.f974me);
        }
        show(this.dialogView);
    }

    public void hide() {
        this.isHide = true;
        this.hideWithExitAnim = false;
        if (getDialogView() != null) {
            getDialogView().setVisibility(8);
        }
    }

    public void hideWithExitAnim() {
        this.hideWithExitAnim = true;
        this.isHide = true;
        if (getDialogImpl() != null) {
            getDialogImpl().getDialogXAnimImpl().doExitAnim(this.f974me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.FullScreenDialog.4
                @Override // com.kongzue.dialogx.util.ObjectRunnable
                public void run(Float value) {
                    FullScreenDialog.this.getDialogImpl().boxRoot.setBkgAlpha(value.floatValue());
                    if (value.floatValue() != 0.0f || FullScreenDialog.this.getDialogView() == null) {
                        return;
                    }
                    FullScreenDialog.this.getDialogView().setVisibility(8);
                }
            });
        }
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    protected void shutdown() {
        dismiss();
    }

    public FullScreenDialog setMaxWidth(int maxWidth) {
        this.maxWidth = maxWidth;
        refreshUI();
        return this;
    }

    public FullScreenDialog setDialogImplMode(DialogX.IMPL_MODE dialogImplMode) {
        this.dialogImplMode = dialogImplMode;
        return this;
    }

    public OnBackgroundMaskClickListener<FullScreenDialog> getOnBackgroundMaskClickListener() {
        return this.onBackgroundMaskClickListener;
    }

    public FullScreenDialog setOnBackgroundMaskClickListener(OnBackgroundMaskClickListener<FullScreenDialog> onBackgroundMaskClickListener) {
        this.onBackgroundMaskClickListener = onBackgroundMaskClickListener;
        return this;
    }

    public FullScreenDialog setRadius(float radiusPx) {
        this.backgroundRadius = radiusPx;
        refreshUI();
        return this;
    }

    public float getRadius() {
        return this.backgroundRadius;
    }

    public boolean isAllowInterceptTouch() {
        return this.allowInterceptTouch;
    }

    public FullScreenDialog setAllowInterceptTouch(boolean allowInterceptTouch) {
        this.allowInterceptTouch = allowInterceptTouch;
        refreshUI();
        return this;
    }

    public DialogXAnimInterface<FullScreenDialog> getDialogXAnimImpl() {
        return this.dialogXAnimImpl;
    }

    public FullScreenDialog setDialogXAnimImpl(DialogXAnimInterface<FullScreenDialog> dialogXAnimImpl) {
        this.dialogXAnimImpl = dialogXAnimImpl;
        return this;
    }
}
