package com.kongzue.dialogx.dialogs;

import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.RectF;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import androidx.core.internal.view.SupportMenu;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.dialogs.CustomDialog;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.DialogLifecycleCallback;
import com.kongzue.dialogx.interfaces.DialogXAnimInterface;
import com.kongzue.dialogx.interfaces.DialogXStyle;
import com.kongzue.dialogx.interfaces.OnBackPressedListener;
import com.kongzue.dialogx.interfaces.OnBackgroundMaskClickListener;
import com.kongzue.dialogx.interfaces.OnBindView;
import com.kongzue.dialogx.interfaces.OnDialogButtonClickListener;
/* loaded from: classes10.dex */
public class GuideDialog extends CustomDialog {
    protected int maskColor;
    protected OnDialogButtonClickListener<GuideDialog> onStageLightPathClickListener;
    protected float stageLightFilletRadius;
    Paint stageLightPaint;
    View stageLightPathStub;
    protected STAGE_LIGHT_TYPE stageLightType;
    protected Drawable tipImage;

    /* loaded from: classes10.dex */
    public enum STAGE_LIGHT_TYPE {
        RECTANGLE,
        SQUARE_OUTSIDE,
        SQUARE_INSIDE,
        CIRCLE_OUTSIDE,
        CIRCLE_INSIDE
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public /* bridge */ /* synthetic */ CustomDialog setCustomView(OnBindView onBindView) {
        return setCustomView((OnBindView<CustomDialog>) onBindView);
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public /* bridge */ /* synthetic */ CustomDialog setDialogLifecycleCallback(DialogLifecycleCallback dialogLifecycleCallback) {
        return setDialogLifecycleCallback((DialogLifecycleCallback<CustomDialog>) dialogLifecycleCallback);
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public /* bridge */ /* synthetic */ CustomDialog setDialogXAnimImpl(DialogXAnimInterface dialogXAnimImpl) {
        return setDialogXAnimImpl((DialogXAnimInterface<CustomDialog>) dialogXAnimImpl);
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public /* bridge */ /* synthetic */ CustomDialog setOnBackPressedListener(OnBackPressedListener onBackPressedListener) {
        return setOnBackPressedListener((OnBackPressedListener<CustomDialog>) onBackPressedListener);
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public /* bridge */ /* synthetic */ CustomDialog setOnBackgroundMaskClickListener(OnBackgroundMaskClickListener onBackgroundMaskClickListener) {
        return setOnBackgroundMaskClickListener((OnBackgroundMaskClickListener<CustomDialog>) onBackgroundMaskClickListener);
    }

    protected GuideDialog() {
        this.stageLightType = STAGE_LIGHT_TYPE.CIRCLE_OUTSIDE;
        this.maskColor = -1;
        this.enterAnimResId = R.anim.anim_dialogx_alpha_enter;
        this.exitAnimResId = R.anim.anim_dialogx_default_exit;
        this.alignViewGravity = 81;
    }

    public static GuideDialog build() {
        return new GuideDialog();
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType) {
        this();
        this.baseView = baseView;
        this.stageLightType = stageLightType;
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, OnBindView<CustomDialog> onBindView, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.stageLightType = stageLightType;
        this.onBindView = onBindView;
        this.alignViewGravity = alignBaseViewGravity;
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, int tipImageResId, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.tipImage = getResources().getDrawable(tipImageResId);
        this.stageLightType = stageLightType;
        this.alignViewGravity = alignBaseViewGravity;
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, Bitmap tipImage, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
        this.stageLightType = stageLightType;
        this.alignViewGravity = alignBaseViewGravity;
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, Drawable tipImage, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.tipImage = tipImage;
        this.stageLightType = stageLightType;
        this.alignViewGravity = alignBaseViewGravity;
    }

    public GuideDialog(int tipImageResId) {
        this();
        this.tipImage = getResources().getDrawable(tipImageResId);
    }

    public GuideDialog(Bitmap tipImage) {
        this();
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
    }

    public GuideDialog(Drawable tipImage) {
        this();
        this.tipImage = tipImage;
    }

    public GuideDialog(int tipImageResId, CustomDialog.ALIGN align) {
        this();
        this.tipImage = getResources().getDrawable(tipImageResId);
        this.align = align;
    }

    public GuideDialog(Bitmap tipImage, CustomDialog.ALIGN align) {
        this();
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
        this.align = align;
    }

    public GuideDialog(Drawable tipImage, CustomDialog.ALIGN align) {
        this();
        this.tipImage = tipImage;
        this.align = align;
    }

    public GuideDialog(OnBindView<CustomDialog> onBindView) {
        this();
        this.onBindView = onBindView;
    }

    public GuideDialog(OnBindView<CustomDialog> onBindView, CustomDialog.ALIGN align) {
        this();
        this.onBindView = onBindView;
        this.align = align;
    }

    public GuideDialog(View baseView, int tipImageResId) {
        this();
        this.baseView = baseView;
        this.tipImage = getResources().getDrawable(tipImageResId);
    }

    public GuideDialog(View baseView, Bitmap tipImage) {
        this();
        this.baseView = baseView;
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
    }

    public GuideDialog(View baseView, Drawable tipImage) {
        this();
        this.baseView = baseView;
        this.tipImage = tipImage;
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, int tipImageResId) {
        this();
        this.baseView = baseView;
        this.stageLightType = stageLightType;
        this.tipImage = getResources().getDrawable(tipImageResId);
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, Bitmap tipImage) {
        this();
        this.baseView = baseView;
        this.stageLightType = stageLightType;
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
    }

    public GuideDialog(View baseView, STAGE_LIGHT_TYPE stageLightType, Drawable tipImage) {
        this();
        this.baseView = baseView;
        this.stageLightType = stageLightType;
        this.tipImage = tipImage;
    }

    public GuideDialog(View baseView, int tipImageResId, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.alignViewGravity = alignBaseViewGravity;
        this.tipImage = getResources().getDrawable(tipImageResId);
    }

    public GuideDialog(View baseView, Bitmap tipImage, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.alignViewGravity = alignBaseViewGravity;
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
    }

    public GuideDialog(View baseView, Drawable tipImage, int alignBaseViewGravity) {
        this();
        this.baseView = baseView;
        this.alignViewGravity = alignBaseViewGravity;
        this.tipImage = tipImage;
    }

    public static GuideDialog show(OnBindView<CustomDialog> onBindView) {
        GuideDialog guideDialog = new GuideDialog(onBindView);
        guideDialog.show();
        return guideDialog;
    }

    public static GuideDialog show(OnBindView<CustomDialog> onBindView, CustomDialog.ALIGN align) {
        GuideDialog guideDialog = new GuideDialog(onBindView);
        guideDialog.align = align;
        guideDialog.show();
        return guideDialog;
    }

    public static GuideDialog show(int tipImageResId) {
        return new GuideDialog(tipImageResId).show();
    }

    public static GuideDialog show(Bitmap tipImage) {
        return new GuideDialog(tipImage).show();
    }

    public static GuideDialog show(Drawable tipImage) {
        return new GuideDialog(tipImage).show();
    }

    public static GuideDialog show(int tipImageResId, CustomDialog.ALIGN align) {
        GuideDialog guideDialog = new GuideDialog(tipImageResId, align);
        guideDialog.align = align;
        return guideDialog.show();
    }

    public static GuideDialog show(Bitmap tipImage, CustomDialog.ALIGN align) {
        GuideDialog guideDialog = new GuideDialog(tipImage, align);
        guideDialog.align = align;
        return guideDialog.show();
    }

    public static GuideDialog show(Drawable tipImage, CustomDialog.ALIGN align) {
        return new GuideDialog(tipImage, align).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType) {
        return new GuideDialog(baseView, stageLightType).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, OnBindView<CustomDialog> onBindView, int alignBaseViewGravity) {
        return new GuideDialog(baseView, stageLightType, onBindView, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, int tipImageResId, int alignBaseViewGravity) {
        return new GuideDialog(baseView, stageLightType, tipImageResId, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, Bitmap tipImage, int alignBaseViewGravity) {
        return new GuideDialog(baseView, stageLightType, tipImage, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, Drawable tipImage, int alignBaseViewGravity) {
        return new GuideDialog(baseView, stageLightType, tipImage, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, int tipImageResId) {
        return new GuideDialog(baseView, tipImageResId).show();
    }

    public static GuideDialog show(View baseView, Bitmap tipImage) {
        return new GuideDialog(baseView, tipImage).show();
    }

    public static GuideDialog show(View baseView, Drawable tipImage) {
        return new GuideDialog(baseView, tipImage).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, int tipImageResId) {
        return new GuideDialog(baseView, stageLightType, tipImageResId).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, Bitmap tipImage) {
        return new GuideDialog(baseView, stageLightType, tipImage).show();
    }

    public static GuideDialog show(View baseView, STAGE_LIGHT_TYPE stageLightType, Drawable tipImage) {
        return new GuideDialog(baseView, stageLightType, tipImage).show();
    }

    public static GuideDialog show(View baseView, int tipImageResId, int alignBaseViewGravity) {
        return new GuideDialog(baseView, tipImageResId, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, Bitmap tipImage, int alignBaseViewGravity) {
        return new GuideDialog(baseView, tipImage, alignBaseViewGravity).show();
    }

    public static GuideDialog show(View baseView, Drawable tipImage, int alignBaseViewGravity) {
        return new GuideDialog(baseView, tipImage, alignBaseViewGravity).show();
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog, com.kongzue.dialogx.interfaces.BaseDialog
    public GuideDialog show() {
        super.show();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog show(Activity activity) {
        super.show(activity);
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog, com.kongzue.dialogx.interfaces.BaseDialog
    public String dialogKey() {
        return getClass().getSimpleName() + "(" + Integer.toHexString(hashCode()) + ")";
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setDialogLifecycleCallback(DialogLifecycleCallback<CustomDialog> dialogLifecycleCallback) {
        this.dialogLifecycleCallback = dialogLifecycleCallback;
        if (this.isShow) {
            dialogLifecycleCallback.onShow(this.f973me);
        }
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setOnBackPressedListener(OnBackPressedListener<CustomDialog> onBackPressedListener) {
        this.onBackPressedListener = onBackPressedListener;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setStyle(DialogXStyle style) {
        this.style = style;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setTheme(DialogX.THEME theme) {
        this.theme = theme;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setCancelable(boolean cancelable) {
        this.privateCancelable = cancelable ? BaseDialog.BOOLEAN.TRUE : BaseDialog.BOOLEAN.FALSE;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public CustomDialog.DialogImpl getDialogImpl() {
        return this.dialogImpl;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setCustomView(OnBindView<CustomDialog> onBindView) {
        this.onBindView = onBindView;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog removeCustomView() {
        this.onBindView.clean();
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setEnterAnimResId(int enterAnimResId) {
        this.enterAnimResId = enterAnimResId;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setExitAnimResId(int exitAnimResId) {
        this.exitAnimResId = exitAnimResId;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAnimResId(int enterAnimResId, int exitAnimResId) {
        this.enterAnimResId = enterAnimResId;
        this.exitAnimResId = exitAnimResId;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAlign(CustomDialog.ALIGN align) {
        this.align = align;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAutoUnsafePlacePadding(boolean autoUnsafePlacePadding) {
        this.autoUnsafePlacePadding = autoUnsafePlacePadding;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setFullScreen(boolean fullscreen) {
        this.autoUnsafePlacePadding = !this.autoUnsafePlacePadding;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setMaskColor(int maskColor) {
        this.maskColor = maskColor;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setEnterAnimDuration(long enterAnimDuration) {
        this.enterAnimDuration = enterAnimDuration;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setExitAnimDuration(long exitAnimDuration) {
        this.exitAnimDuration = exitAnimDuration;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setDialogImplMode(DialogX.IMPL_MODE dialogImplMode) {
        this.dialogImplMode = dialogImplMode;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBkgInterceptTouch(boolean bkgInterceptTouch) {
        this.bkgInterceptTouch = bkgInterceptTouch;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAlignBaseViewGravity(View baseView, int alignGravity) {
        this.baseView = baseView;
        this.alignViewGravity = alignGravity;
        this.baseViewLoc = new int[4];
        baseView.getLocationOnScreen(this.baseViewLoc);
        setFullScreen(true);
        return this;
    }

    public GuideDialog setAlignBaseViewGravity(View baseView) {
        this.baseView = baseView;
        this.baseViewLoc = new int[4];
        baseView.getLocationOnScreen(this.baseViewLoc);
        setFullScreen(true);
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAlignBaseViewGravity(int alignGravity) {
        this.alignViewGravity = alignGravity;
        if (this.baseView != null) {
            this.baseViewLoc = new int[4];
            this.baseView.getLocationOnScreen(this.baseViewLoc);
        }
        setFullScreen(true);
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setAlignBaseViewGravity(View baseView, int alignGravity, int marginLeft, int marginTop, int marginRight, int marginBottom) {
        this.marginRelativeBaseView = new int[]{marginLeft, marginTop, marginRight, marginBottom};
        return setAlignBaseViewGravity(baseView, alignGravity);
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMargin(int[] marginRelativeBaseView) {
        this.marginRelativeBaseView = marginRelativeBaseView;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMargin(int marginLeft, int marginTop, int marginRight, int marginBottom) {
        this.marginRelativeBaseView = new int[]{marginLeft, marginTop, marginRight, marginBottom};
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMarginLeft(int marginLeft) {
        this.marginRelativeBaseView[0] = marginLeft;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMarginTop(int marginTop) {
        this.marginRelativeBaseView[1] = marginTop;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMarginRight(int marginRight) {
        this.marginRelativeBaseView[2] = marginRight;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setBaseViewMarginBottom(int marginBottom) {
        this.marginRelativeBaseView[3] = marginBottom;
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setWidth(int width) {
        this.width = width;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setHeight(int height) {
        this.height = height;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setOnBackgroundMaskClickListener(OnBackgroundMaskClickListener<CustomDialog> onBackgroundMaskClickListener) {
        this.onBackgroundMaskClickListener = onBackgroundMaskClickListener;
        return this;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public void onDialogShow() {
        super.onDialogShow();
        if (this.baseView == null) {
            int i2 = this.maskColor;
            if (i2 == -1) {
                i2 = getColor(R.color.black50);
            }
            super.setMaskColor(i2);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public void onDialogRefreshUI() {
        super.onDialogRefreshUI();
        if (this.onBindView == null && this.tipImage != null) {
            getDialogImpl().boxCustom.setFocusable(false);
            getDialogImpl().boxCustom.setFocusableInTouchMode(false);
            getDialogImpl().boxCustom.setOnClickListener(null);
            getDialogImpl().boxCustom.setClickable(false);
            ImageView imageView = new ImageView(getContext());
            imageView.setImageDrawable(this.tipImage);
            imageView.setAdjustViewBounds(true);
            imageView.setLayoutParams(new RelativeLayout.LayoutParams(-2, -2));
            this.onBindView = new OnBindView<CustomDialog>(imageView) { // from class: com.kongzue.dialogx.dialogs.GuideDialog.1
                @Override // com.kongzue.dialogx.interfaces.OnBindView
                public void onBind(CustomDialog dialog, View v) {
                }
            };
            this.onBindView.bindParent(getDialogImpl().boxCustom, this.f973me);
        }
        if (getOnStageLightPathClickListener() != null && this.baseView != null) {
            View view = new View(getContext());
            this.stageLightPathStub = view;
            view.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.GuideDialog.2
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (GuideDialog.this.getOnStageLightPathClickListener().onClick(GuideDialog.this, v)) {
                        return;
                    }
                    GuideDialog.this.dismiss();
                }
            });
            getDialogImpl().boxRoot.addView(this.stageLightPathStub);
            return;
        }
        View view2 = this.stageLightPathStub;
        if (view2 == null || !(view2.getParent() instanceof ViewGroup)) {
            return;
        }
        ((ViewGroup) this.stageLightPathStub.getParent()).removeView(this.stageLightPathStub);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public void onGetBaseViewLoc(int[] baseViewLoc) {
        int min;
        int i2;
        int i3;
        int max;
        int i4;
        int i5;
        super.onGetBaseViewLoc(baseViewLoc);
        if (getDialogImpl() == null) {
            return;
        }
        Bitmap createBitmap = Bitmap.createBitmap(getDialogImpl().boxRoot.getWidth(), getDialogImpl().boxRoot.getHeight(), Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        int i6 = baseViewLoc[0];
        int i7 = baseViewLoc[1];
        int i8 = baseViewLoc[2];
        int i9 = baseViewLoc[3];
        int i10 = i8 / 2;
        int i11 = i9 / 2;
        View view = this.stageLightPathStub;
        if (view != null) {
            float f = i6;
            if (view.getX() != f || this.stageLightPathStub.getY() != i7) {
                RelativeLayout.LayoutParams layoutParams = (RelativeLayout.LayoutParams) this.stageLightPathStub.getLayoutParams();
                if (layoutParams == null) {
                    layoutParams = new RelativeLayout.LayoutParams(i8, i9);
                } else {
                    layoutParams.width = i8;
                    layoutParams.height = i9;
                }
                this.stageLightPathStub.setLayoutParams(layoutParams);
                this.stageLightPathStub.setX(f);
                this.stageLightPathStub.setY(i7);
            }
        }
        int i12 = AnonymousClass3.$SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE[this.stageLightType.ordinal()];
        if (i12 == 1) {
            canvas.drawCircle(i6 + i10, i7 + i11, (int) Math.sqrt((i10 * i10) + (i11 * i11)), getStageLightPaint());
        } else if (i12 == 2) {
            canvas.drawCircle(i6 + i10, i7 + i11, Math.min(i8, i9) / 2, getStageLightPaint());
        } else if (i12 == 3) {
            RectF rectF = new RectF(i6, i7, i6 + i8, i7 + i9);
            float f2 = this.stageLightFilletRadius;
            canvas.drawRoundRect(rectF, f2, f2, getStageLightPaint());
        } else if (i12 == 4) {
            int min2 = Math.min(i8, i9) / 2;
            RectF rectF2 = new RectF((i6 + i10) - min2, (i7 + i11) - min2, i2 + min, i3 + min);
            float f3 = this.stageLightFilletRadius;
            canvas.drawRoundRect(rectF2, f3, f3, getStageLightPaint());
        } else if (i12 == 5) {
            int max2 = Math.max(i8, i9) / 2;
            RectF rectF3 = new RectF((i6 + i10) - max2, (i7 + i11) - max2, i4 + max, i5 + max);
            float f4 = this.stageLightFilletRadius;
            canvas.drawRoundRect(rectF3, f4, f4, getStageLightPaint());
        }
        this.stageLightPaint.setXfermode(null);
        int i13 = this.maskColor;
        if (i13 == -1) {
            i13 = getColor(R.color.black50);
        }
        canvas.drawColor(i13, PorterDuff.Mode.SRC_OUT);
        getDialogImpl().boxRoot.setBackground(new BitmapDrawable(getResources(), createBitmap));
    }

    /* renamed from: com.kongzue.dialogx.dialogs.GuideDialog$3  reason: invalid class name */
    /* loaded from: classes10.dex */
    static /* synthetic */ class AnonymousClass3 {
        static final /* synthetic */ int[] $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE;

        static {
            int[] iArr = new int[STAGE_LIGHT_TYPE.values().length];
            $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE = iArr;
            try {
                iArr[STAGE_LIGHT_TYPE.CIRCLE_OUTSIDE.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE[STAGE_LIGHT_TYPE.CIRCLE_INSIDE.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE[STAGE_LIGHT_TYPE.RECTANGLE.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE[STAGE_LIGHT_TYPE.SQUARE_INSIDE.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$dialogs$GuideDialog$STAGE_LIGHT_TYPE[STAGE_LIGHT_TYPE.SQUARE_OUTSIDE.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    private Paint getStageLightPaint() {
        if (this.stageLightPaint == null) {
            Paint paint = new Paint();
            this.stageLightPaint = paint;
            paint.setColor(SupportMenu.CATEGORY_MASK);
            this.stageLightPaint.setStyle(Paint.Style.FILL);
            this.stageLightPaint.setAntiAlias(true);
        }
        return this.stageLightPaint;
    }

    public STAGE_LIGHT_TYPE getStageLightType() {
        return this.stageLightType;
    }

    public GuideDialog setStageLightType(STAGE_LIGHT_TYPE stageLightType) {
        this.stageLightType = stageLightType;
        refreshUI();
        return this;
    }

    public Drawable getTipImage() {
        return this.tipImage;
    }

    public GuideDialog setTipImage(int tipImageResId) {
        this.tipImage = getResources().getDrawable(tipImageResId);
        refreshUI();
        return this;
    }

    public GuideDialog setTipImage(Bitmap tipImage) {
        this.tipImage = new BitmapDrawable(getResources(), tipImage);
        refreshUI();
        return this;
    }

    public GuideDialog setTipImage(Drawable tipImage) {
        this.tipImage = tipImage;
        refreshUI();
        return this;
    }

    public float getStageLightFilletRadius() {
        return this.stageLightFilletRadius;
    }

    public GuideDialog setStageLightFilletRadius(float stageLightFilletRadius) {
        this.stageLightFilletRadius = stageLightFilletRadius;
        refreshUI();
        return this;
    }

    public OnDialogButtonClickListener<GuideDialog> getOnStageLightPathClickListener() {
        return this.onStageLightPathClickListener;
    }

    public GuideDialog setOnStageLightPathClickListener(OnDialogButtonClickListener<GuideDialog> onStageLightPathClickListener) {
        this.onStageLightPathClickListener = onStageLightPathClickListener;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public DialogXAnimInterface<CustomDialog> getDialogXAnimImpl() {
        return this.dialogXAnimImpl;
    }

    @Override // com.kongzue.dialogx.dialogs.CustomDialog
    public GuideDialog setDialogXAnimImpl(DialogXAnimInterface<CustomDialog> dialogXAnimImpl) {
        this.dialogXAnimImpl = dialogXAnimImpl;
        return this;
    }
}
