package com.kongzue.dialogx.dialogs;

import android.animation.ValueAnimator;
import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.Outline;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.os.Build;
import android.text.InputFilter;
import android.text.method.LinkMovementMethod;
import android.view.View;
import android.view.ViewOutlineProvider;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.view.animation.DecelerateInterpolator;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.Space;
import android.widget.TextView;
import androidx.lifecycle.Lifecycle;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.BaseOnDialogClickCallback;
import com.kongzue.dialogx.interfaces.DialogConvertViewInterface;
import com.kongzue.dialogx.interfaces.DialogLifecycleCallback;
import com.kongzue.dialogx.interfaces.DialogXAnimInterface;
import com.kongzue.dialogx.interfaces.DialogXStyle;
import com.kongzue.dialogx.interfaces.OnBackPressedListener;
import com.kongzue.dialogx.interfaces.OnBackgroundMaskClickListener;
import com.kongzue.dialogx.interfaces.OnBindView;
import com.kongzue.dialogx.interfaces.OnDialogButtonClickListener;
import com.kongzue.dialogx.interfaces.OnInputDialogButtonClickListener;
import com.kongzue.dialogx.style.MaterialStyle;
import com.kongzue.dialogx.util.InputInfo;
import com.kongzue.dialogx.util.ObjectRunnable;
import com.kongzue.dialogx.util.TextInfo;
import com.kongzue.dialogx.util.views.BlurView;
import com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout;
import com.kongzue.dialogx.util.views.MaxRelativeLayout;
/* loaded from: classes10.dex */
public class MessageDialog extends BaseDialog {
    public static BaseDialog.BOOLEAN overrideCancelable = null;
    public static int overrideEnterAnimRes = 0;
    public static int overrideEnterDuration = -1;
    public static int overrideExitAnimRes = 0;
    public static int overrideExitDuration = -1;
    protected int buttonOrientation;
    protected BaseOnDialogClickCallback cancelButtonClickListener;
    protected CharSequence cancelText;
    protected TextInfo cancelTextInfo;
    protected int customEnterAnimResId;
    protected int customExitAnimResId;
    protected DialogImpl dialogImpl;
    protected DialogLifecycleCallback<MessageDialog> dialogLifecycleCallback;
    protected View dialogView;
    protected DialogXAnimInterface<MessageDialog> dialogXAnimImpl;
    protected boolean hideWithExitAnim;
    protected String inputHintText;
    protected InputInfo inputInfo;
    protected String inputText;
    private boolean isHide;
    protected CharSequence message;
    protected TextInfo messageTextInfo;
    protected BaseOnDialogClickCallback okButtonClickListener;
    protected CharSequence okText;
    protected TextInfo okTextInfo;
    protected OnBackPressedListener<MessageDialog> onBackPressedListener;
    protected OnBackgroundMaskClickListener<MessageDialog> onBackgroundMaskClickListener;
    protected OnBindView<MessageDialog> onBindView;
    protected BaseOnDialogClickCallback otherButtonClickListener;
    protected CharSequence otherText;
    protected TextInfo otherTextInfo;
    protected BaseDialog.BOOLEAN privateCancelable;
    protected CharSequence title;
    protected Drawable titleIcon;
    protected TextInfo titleTextInfo;
    protected boolean bkgInterceptTouch = true;

    /* renamed from: me  reason: collision with root package name */
    protected MessageDialog f975me = this;
    protected int maskColor = -1;
    protected float backgroundRadius = -1.0f;

    /* JADX INFO: Access modifiers changed from: protected */
    public MessageDialog() {
    }

    public static MessageDialog build() {
        return new MessageDialog();
    }

    public static MessageDialog build(DialogXStyle style) {
        return new MessageDialog().setStyle(style);
    }

    public static MessageDialog build(OnBindView<MessageDialog> onBindView) {
        return new MessageDialog().setCustomView(onBindView);
    }

    public MessageDialog(CharSequence title, CharSequence message) {
        this.title = title;
        this.message = message;
    }

    public MessageDialog(CharSequence title, CharSequence message, CharSequence okText) {
        this.title = title;
        this.message = message;
        this.okText = okText;
    }

    public MessageDialog(int titleResId, int messageResId, int okTextResId) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.okText = getString(okTextResId);
    }

    public MessageDialog(int titleResId, int messageResId) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
    }

    public static MessageDialog show(CharSequence title, CharSequence message, CharSequence okText) {
        MessageDialog messageDialog = new MessageDialog(title, message, okText);
        messageDialog.show();
        return messageDialog;
    }

    public static MessageDialog show(int titleResId, int messageResId, int okTextResId) {
        MessageDialog messageDialog = new MessageDialog(titleResId, messageResId, okTextResId);
        messageDialog.show();
        return messageDialog;
    }

    public static MessageDialog show(CharSequence title, CharSequence message) {
        MessageDialog messageDialog = new MessageDialog(title, message);
        messageDialog.show();
        return messageDialog;
    }

    public static MessageDialog show(int titleResId, int messageResId) {
        MessageDialog messageDialog = new MessageDialog(titleResId, messageResId);
        messageDialog.show();
        return messageDialog;
    }

    public MessageDialog(CharSequence title, CharSequence message, CharSequence okText, CharSequence cancelText) {
        this.title = title;
        this.message = message;
        this.okText = okText;
        this.cancelText = cancelText;
    }

    public MessageDialog(int titleResId, int messageResId, int okTextResId, int cancelTextResId) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.okText = getString(okTextResId);
        this.cancelText = getString(cancelTextResId);
    }

    public static MessageDialog show(CharSequence title, CharSequence message, CharSequence okText, CharSequence cancelText) {
        MessageDialog messageDialog = new MessageDialog(title, message, okText, cancelText);
        messageDialog.show();
        return messageDialog;
    }

    public static MessageDialog show(int titleResId, int messageResId, int okTextResId, int cancelTextResId) {
        MessageDialog messageDialog = new MessageDialog(titleResId, messageResId, okTextResId, cancelTextResId);
        messageDialog.show();
        return messageDialog;
    }

    public MessageDialog(CharSequence title, CharSequence message, CharSequence okText, CharSequence cancelText, CharSequence otherText) {
        this.title = title;
        this.message = message;
        this.okText = okText;
        this.cancelText = cancelText;
        this.otherText = otherText;
    }

    public MessageDialog(int titleResId, int messageResId, int okTextResId, int cancelTextResId, int otherTextResId) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.okText = getString(okTextResId);
        this.cancelText = getString(cancelTextResId);
        this.otherText = getString(otherTextResId);
    }

    public static MessageDialog show(CharSequence title, CharSequence message, CharSequence okText, CharSequence cancelText, CharSequence otherText) {
        MessageDialog messageDialog = new MessageDialog(title, message, okText, cancelText, otherText);
        messageDialog.show();
        return messageDialog;
    }

    public static MessageDialog show(int titleResId, int messageResId, int okTextResId, int cancelTextResId, int otherTextResId) {
        MessageDialog messageDialog = new MessageDialog(titleResId, messageResId, okTextResId, cancelTextResId, otherTextResId);
        messageDialog.show();
        return messageDialog;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public MessageDialog show() {
        if (this.isHide && getDialogView() != null && this.isShow) {
            if (this.hideWithExitAnim && getDialogImpl() != null) {
                getDialogView().setVisibility(0);
                getDialogImpl().getDialogXAnimImpl().doShowAnim(this.f975me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.1
                    @Override // com.kongzue.dialogx.util.ObjectRunnable
                    public void run(Float value) {
                        MessageDialog.this.getDialogImpl().boxRoot.setBkgAlpha(value.floatValue());
                    }
                });
            } else {
                getDialogView().setVisibility(0);
            }
            return this;
        }
        super.beforeShow();
        if (getDialogView() == null) {
            int layout = this.style.layout(isLightTheme());
            if (layout == 0) {
                layout = isLightTheme() ? R.layout.layout_dialogx_material : R.layout.layout_dialogx_material_dark;
            }
            this.dialogView = createView(layout);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f975me);
            }
        }
        show(this.dialogView);
        return this;
    }

    public void show(Activity activity) {
        super.beforeShow();
        if (getDialogView() == null) {
            int layout = this.style.layout(isLightTheme());
            if (layout == 0) {
                layout = isLightTheme() ? R.layout.layout_dialogx_material : R.layout.layout_dialogx_material_dark;
            }
            this.dialogView = createView(layout);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f975me);
            }
        }
        show(activity, this.dialogView);
    }

    public void refreshUI() {
        if (getDialogImpl() == null) {
            return;
        }
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.2
            @Override // java.lang.Runnable
            public void run() {
                if (MessageDialog.this.dialogImpl != null) {
                    MessageDialog.this.dialogImpl.refreshView();
                }
            }
        });
    }

    /* loaded from: classes10.dex */
    public class DialogImpl implements DialogConvertViewInterface {
        public MaxRelativeLayout bkg;
        BlurView blurView;
        public LinearLayout boxButton;
        public RelativeLayout boxCustom;
        public DialogXBaseRelativeLayout boxRoot;
        public TextView btnSelectNegative;
        public TextView btnSelectOther;
        public TextView btnSelectPositive;
        public View spaceOtherButton;
        public View splitHorizontal;
        public TextView txtDialogTip;
        public TextView txtDialogTitle;
        public EditText txtInput;

        public DialogImpl(View convertView) {
            if (convertView == null) {
                return;
            }
            this.boxRoot = (DialogXBaseRelativeLayout) convertView.findViewById(R.id.box_root);
            this.bkg = (MaxRelativeLayout) convertView.findViewById(R.id.bkg);
            this.txtDialogTitle = (TextView) convertView.findViewById(R.id.txt_dialog_title);
            this.txtDialogTip = (TextView) convertView.findViewById(R.id.txt_dialog_tip);
            this.boxCustom = (RelativeLayout) convertView.findViewById(R.id.box_custom);
            this.txtInput = (EditText) convertView.findViewById(R.id.txt_input);
            this.boxButton = (LinearLayout) convertView.findViewById(R.id.box_button);
            this.btnSelectOther = (TextView) convertView.findViewById(R.id.btn_selectOther);
            this.spaceOtherButton = convertView.findViewById(R.id.space_other_button);
            this.splitHorizontal = convertView.findViewWithTag("split");
            this.btnSelectNegative = (TextView) convertView.findViewById(R.id.btn_selectNegative);
            this.btnSelectPositive = (TextView) convertView.findViewById(R.id.btn_selectPositive);
            init();
            MessageDialog.this.dialogImpl = this;
            refreshView();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void init() {
            if (MessageDialog.this.titleTextInfo == null) {
                MessageDialog.this.titleTextInfo = DialogX.titleTextInfo;
            }
            if (MessageDialog.this.messageTextInfo == null) {
                MessageDialog.this.messageTextInfo = DialogX.messageTextInfo;
            }
            if (MessageDialog.this.okTextInfo == null) {
                MessageDialog.this.okTextInfo = DialogX.okButtonTextInfo;
            }
            if (MessageDialog.this.okTextInfo == null) {
                MessageDialog.this.okTextInfo = DialogX.buttonTextInfo;
            }
            if (MessageDialog.this.cancelTextInfo == null) {
                MessageDialog.this.cancelTextInfo = DialogX.buttonTextInfo;
            }
            if (MessageDialog.this.otherTextInfo == null) {
                MessageDialog.this.otherTextInfo = DialogX.buttonTextInfo;
            }
            if (MessageDialog.this.inputInfo == null) {
                MessageDialog.this.inputInfo = DialogX.inputInfo;
            }
            if (MessageDialog.this.backgroundColor == -1) {
                MessageDialog.this.backgroundColor = DialogX.backgroundColor;
            }
            this.txtDialogTitle.getPaint().setFakeBoldText(true);
            this.btnSelectNegative.getPaint().setFakeBoldText(true);
            this.btnSelectPositive.getPaint().setFakeBoldText(true);
            this.btnSelectOther.getPaint().setFakeBoldText(true);
            this.txtDialogTip.setMovementMethod(LinkMovementMethod.getInstance());
            this.boxRoot.setBkgAlpha(0.0f);
            this.boxRoot.setParentDialog(MessageDialog.this.f975me);
            this.boxRoot.setOnLifecycleCallBack(new DialogXBaseRelativeLayout.OnLifecycleCallBack() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.1
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onShow() {
                    MessageDialog.this.isShow = true;
                    MessageDialog.this.preShow = false;
                    MessageDialog.this.lifecycle.setCurrentState(Lifecycle.State.CREATED);
                    MessageDialog.this.onDialogShow();
                    MessageDialog.this.getDialogLifecycleCallback().onShow(MessageDialog.this.f975me);
                    DialogImpl.this.getDialogXAnimImpl().doShowAnim(MessageDialog.this.f975me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.1.1
                        @Override // com.kongzue.dialogx.util.ObjectRunnable
                        public void run(Float value) {
                            DialogImpl.this.boxRoot.setBkgAlpha(value.floatValue());
                        }
                    });
                    if (MessageDialog.this.style.messageDialogBlurSettings() != null && MessageDialog.this.style.messageDialogBlurSettings().blurBackground()) {
                        DialogImpl.this.bkg.post(new Runnable() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.1.2
                            @Override // java.lang.Runnable
                            public void run() {
                                int color = MessageDialog.this.getResources().getColor(MessageDialog.this.style.messageDialogBlurSettings().blurForwardColorRes(MessageDialog.this.isLightTheme()));
                                DialogImpl.this.blurView = new BlurView(DialogImpl.this.bkg.getContext(), null);
                                RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(DialogImpl.this.bkg.getWidth(), DialogImpl.this.bkg.getHeight());
                                layoutParams.addRule(13);
                                BlurView blurView = DialogImpl.this.blurView;
                                if (MessageDialog.this.backgroundColor != -1) {
                                    color = MessageDialog.this.backgroundColor;
                                }
                                blurView.setOverlayColor(color);
                                DialogImpl.this.blurView.setTag("blurView");
                                DialogImpl.this.blurView.setRadiusPx(MessageDialog.this.style.messageDialogBlurSettings().blurBackgroundRoundRadiusPx());
                                DialogImpl.this.bkg.addView(DialogImpl.this.blurView, 0, layoutParams);
                                MessageDialog.this.lifecycle.setCurrentState(Lifecycle.State.RESUMED);
                            }
                        });
                    }
                    if (MessageDialog.this.autoShowInputKeyboard) {
                        DialogImpl.this.txtInput.postDelayed(new Runnable() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.1.3
                            @Override // java.lang.Runnable
                            public void run() {
                                if (DialogImpl.this.txtInput == null) {
                                    return;
                                }
                                DialogImpl.this.txtInput.requestFocus();
                                DialogImpl.this.txtInput.setFocusableInTouchMode(true);
                                MessageDialog.this.imeShow(DialogImpl.this.txtInput, true);
                                DialogImpl.this.txtInput.setSelection(DialogImpl.this.txtInput.getText().length());
                                if (MessageDialog.this.inputInfo == null || !MessageDialog.this.inputInfo.isSelectAllText()) {
                                    return;
                                }
                                DialogImpl.this.txtInput.selectAll();
                            }
                        }, 300L);
                    } else if (MessageDialog.this.inputInfo == null || !MessageDialog.this.inputInfo.isSelectAllText()) {
                    } else {
                        DialogImpl.this.txtInput.clearFocus();
                        DialogImpl.this.txtInput.requestFocus();
                        DialogImpl.this.txtInput.selectAll();
                    }
                }

                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onDismiss() {
                    MessageDialog.this.isShow = false;
                    MessageDialog.this.getDialogLifecycleCallback().onDismiss(MessageDialog.this.f975me);
                    MessageDialog.this.dialogView = null;
                    MessageDialog.this.dialogLifecycleCallback = null;
                    MessageDialog.this.lifecycle.setCurrentState(Lifecycle.State.DESTROYED);
                    System.gc();
                }
            });
            this.boxRoot.setOnBackPressedListener(new DialogXBaseRelativeLayout.PrivateBackPressedListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.2
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.PrivateBackPressedListener
                public boolean onBackPressed() {
                    if (MessageDialog.this.onBackPressedListener != null) {
                        if (MessageDialog.this.onBackPressedListener.onBackPressed(MessageDialog.this.f975me)) {
                            MessageDialog.this.dismiss();
                            return true;
                        }
                        return true;
                    } else if (MessageDialog.this.isCancelable()) {
                        MessageDialog.this.dismiss();
                        return true;
                    } else {
                        return true;
                    }
                }
            });
            this.btnSelectPositive.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.3
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (DialogImpl.this.txtInput != null) {
                        MessageDialog.this.imeShow(DialogImpl.this.txtInput, false);
                    }
                    if (MessageDialog.this.okButtonClickListener != null) {
                        if (MessageDialog.this.okButtonClickListener instanceof OnInputDialogButtonClickListener) {
                            if (((OnInputDialogButtonClickListener) MessageDialog.this.okButtonClickListener).onClick(MessageDialog.this.f975me, v, DialogImpl.this.txtInput == null ? "" : DialogImpl.this.txtInput.getText().toString())) {
                                return;
                            }
                            DialogImpl.this.doDismiss(v);
                            return;
                        } else if (!(MessageDialog.this.okButtonClickListener instanceof OnDialogButtonClickListener) || ((OnDialogButtonClickListener) MessageDialog.this.okButtonClickListener).onClick(MessageDialog.this.f975me, v)) {
                            return;
                        } else {
                            DialogImpl.this.doDismiss(v);
                            return;
                        }
                    }
                    DialogImpl.this.doDismiss(v);
                }
            });
            this.btnSelectNegative.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.4
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (DialogImpl.this.txtInput != null) {
                        MessageDialog.this.imeShow(DialogImpl.this.txtInput, false);
                    }
                    if (MessageDialog.this.cancelButtonClickListener != null) {
                        if (MessageDialog.this.cancelButtonClickListener instanceof OnInputDialogButtonClickListener) {
                            if (((OnInputDialogButtonClickListener) MessageDialog.this.cancelButtonClickListener).onClick(MessageDialog.this.f975me, v, DialogImpl.this.txtInput == null ? "" : DialogImpl.this.txtInput.getText().toString())) {
                                return;
                            }
                            DialogImpl.this.doDismiss(v);
                            return;
                        } else if (((OnDialogButtonClickListener) MessageDialog.this.cancelButtonClickListener).onClick(MessageDialog.this.f975me, v)) {
                            return;
                        } else {
                            DialogImpl.this.doDismiss(v);
                            return;
                        }
                    }
                    DialogImpl.this.doDismiss(v);
                }
            });
            this.btnSelectOther.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.5
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (DialogImpl.this.txtInput != null) {
                        MessageDialog.this.imeShow(DialogImpl.this.txtInput, false);
                    }
                    if (MessageDialog.this.otherButtonClickListener != null) {
                        if (MessageDialog.this.otherButtonClickListener instanceof OnInputDialogButtonClickListener) {
                            if (((OnInputDialogButtonClickListener) MessageDialog.this.otherButtonClickListener).onClick(MessageDialog.this.f975me, v, DialogImpl.this.txtInput == null ? "" : DialogImpl.this.txtInput.getText().toString())) {
                                return;
                            }
                            DialogImpl.this.doDismiss(v);
                            return;
                        } else if (((OnDialogButtonClickListener) MessageDialog.this.otherButtonClickListener).onClick(MessageDialog.this.f975me, v)) {
                            return;
                        } else {
                            DialogImpl.this.doDismiss(v);
                            return;
                        }
                    }
                    DialogImpl.this.doDismiss(v);
                }
            });
            MessageDialog.this.onDialogInit();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void refreshView() {
            int[] horizontalButtonOrder;
            int[] verticalButtonOrder;
            MessageDialog.log("#refreshView");
            if (this.boxRoot == null || BaseDialog.getTopActivity() == null) {
                return;
            }
            if (MessageDialog.this.backgroundColor != -1) {
                MessageDialog messageDialog = MessageDialog.this;
                messageDialog.tintColor(this.bkg, messageDialog.backgroundColor);
                if (MessageDialog.this.style instanceof MaterialStyle) {
                    MessageDialog messageDialog2 = MessageDialog.this;
                    messageDialog2.tintColor(this.btnSelectOther, messageDialog2.backgroundColor);
                    MessageDialog messageDialog3 = MessageDialog.this;
                    messageDialog3.tintColor(this.btnSelectNegative, messageDialog3.backgroundColor);
                    MessageDialog messageDialog4 = MessageDialog.this;
                    messageDialog4.tintColor(this.btnSelectPositive, messageDialog4.backgroundColor);
                }
            }
            this.bkg.setMaxWidth(MessageDialog.this.getMaxWidth());
            View findViewWithTag = this.boxRoot.findViewWithTag("dialogx_editbox");
            if (MessageDialog.this.f975me instanceof InputDialog) {
                if (findViewWithTag != null) {
                    findViewWithTag.setVisibility(0);
                }
                this.txtInput.setVisibility(0);
                this.boxRoot.bindFocusView(this.txtInput);
            } else {
                if (findViewWithTag != null) {
                    findViewWithTag.setVisibility(8);
                }
                this.txtInput.setVisibility(8);
            }
            this.boxRoot.setClickable(true);
            if (MessageDialog.this.maskColor != -1) {
                this.boxRoot.setBackgroundColor(MessageDialog.this.maskColor);
            }
            if (MessageDialog.this.backgroundRadius > -1.0f) {
                GradientDrawable gradientDrawable = (GradientDrawable) this.bkg.getBackground();
                if (gradientDrawable != null) {
                    gradientDrawable.setCornerRadius(MessageDialog.this.backgroundRadius);
                }
                if (Build.VERSION.SDK_INT >= 21) {
                    this.bkg.setOutlineProvider(new ViewOutlineProvider() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.6
                        @Override // android.view.ViewOutlineProvider
                        public void getOutline(View view, Outline outline) {
                            outline.setRoundRect(0, 0, view.getWidth(), view.getHeight(), MessageDialog.this.backgroundRadius);
                        }
                    });
                    this.bkg.setClipToOutline(true);
                }
            }
            MessageDialog messageDialog5 = MessageDialog.this;
            messageDialog5.showText(this.txtDialogTitle, messageDialog5.title);
            MessageDialog messageDialog6 = MessageDialog.this;
            messageDialog6.showText(this.txtDialogTip, messageDialog6.message);
            MessageDialog messageDialog7 = MessageDialog.this;
            messageDialog7.showText(this.btnSelectPositive, messageDialog7.okText);
            MessageDialog messageDialog8 = MessageDialog.this;
            messageDialog8.showText(this.btnSelectNegative, messageDialog8.cancelText);
            MessageDialog messageDialog9 = MessageDialog.this;
            messageDialog9.showText(this.btnSelectOther, messageDialog9.otherText);
            this.txtInput.setText(MessageDialog.this.inputText);
            this.txtInput.setHint(MessageDialog.this.inputHintText);
            if (this.spaceOtherButton != null) {
                if (MessageDialog.this.otherText == null) {
                    this.spaceOtherButton.setVisibility(8);
                } else {
                    this.spaceOtherButton.setVisibility(0);
                }
            }
            BaseDialog.useTextInfo(this.txtDialogTitle, MessageDialog.this.titleTextInfo);
            BaseDialog.useTextInfo(this.txtDialogTip, MessageDialog.this.messageTextInfo);
            BaseDialog.useTextInfo(this.btnSelectPositive, MessageDialog.this.okTextInfo);
            BaseDialog.useTextInfo(this.btnSelectNegative, MessageDialog.this.cancelTextInfo);
            BaseDialog.useTextInfo(this.btnSelectOther, MessageDialog.this.otherTextInfo);
            if (MessageDialog.this.titleIcon != null) {
                int textSize = (int) this.txtDialogTitle.getTextSize();
                MessageDialog.this.titleIcon.setBounds(0, 0, textSize, textSize);
                this.txtDialogTitle.setCompoundDrawablePadding(MessageDialog.this.dip2px(10.0f));
                this.txtDialogTitle.setCompoundDrawables(MessageDialog.this.titleIcon, null, null, null);
            }
            if (MessageDialog.this.inputInfo != null) {
                if (MessageDialog.this.inputInfo.getMAX_LENGTH() != -1) {
                    this.txtInput.setFilters(new InputFilter[]{new InputFilter.LengthFilter(MessageDialog.this.inputInfo.getMAX_LENGTH())});
                }
                int inputType = MessageDialog.this.inputInfo.getInputType() | 1;
                if (MessageDialog.this.inputInfo.isMultipleLines()) {
                    inputType |= 131072;
                }
                this.txtInput.setInputType(inputType);
                if (MessageDialog.this.inputInfo.getTextInfo() != null) {
                    BaseDialog.useTextInfo(this.txtInput, MessageDialog.this.inputInfo.getTextInfo());
                }
            }
            int i2 = !BaseDialog.isNull(MessageDialog.this.okText) ? 1 : 0;
            if (!BaseDialog.isNull(MessageDialog.this.cancelText)) {
                i2++;
            }
            if (!BaseDialog.isNull(MessageDialog.this.otherText)) {
                i2++;
            }
            View view = this.splitHorizontal;
            if (view != null) {
                MessageDialog messageDialog10 = MessageDialog.this;
                view.setBackgroundColor(messageDialog10.getColor(messageDialog10.style.splitColorRes(MessageDialog.this.isLightTheme())));
            }
            this.boxButton.setOrientation(MessageDialog.this.buttonOrientation);
            if (MessageDialog.this.buttonOrientation == 1) {
                if (MessageDialog.this.style.verticalButtonOrder() != null && MessageDialog.this.style.verticalButtonOrder().length != 0) {
                    this.boxButton.removeAllViews();
                    for (int i3 : MessageDialog.this.style.verticalButtonOrder()) {
                        if (i3 == 1) {
                            this.boxButton.addView(this.btnSelectPositive);
                            if (MessageDialog.this.style.overrideVerticalButtonRes() != null) {
                                this.btnSelectPositive.setBackgroundResource(MessageDialog.this.style.overrideVerticalButtonRes().overrideVerticalOkButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                            }
                        } else if (i3 == 2) {
                            this.boxButton.addView(this.btnSelectNegative);
                            if (MessageDialog.this.style.overrideVerticalButtonRes() != null) {
                                this.btnSelectNegative.setBackgroundResource(MessageDialog.this.style.overrideVerticalButtonRes().overrideVerticalCancelButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                            }
                        } else if (i3 == 3) {
                            this.boxButton.addView(this.btnSelectOther);
                            if (MessageDialog.this.style.overrideVerticalButtonRes() != null) {
                                this.btnSelectOther.setBackgroundResource(MessageDialog.this.style.overrideVerticalButtonRes().overrideVerticalOtherButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                            }
                        } else if (i3 == 4) {
                            Space space = new Space(BaseDialog.getTopActivity());
                            LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -1);
                            layoutParams.weight = 1.0f;
                            this.boxButton.addView(space, layoutParams);
                        } else if (i3 == 5) {
                            View view2 = new View(BaseDialog.getTopActivity());
                            view2.setBackgroundColor(MessageDialog.this.getResources().getColor(MessageDialog.this.style.splitColorRes(MessageDialog.this.isLightTheme())));
                            this.boxButton.addView(view2, new LinearLayout.LayoutParams(-1, MessageDialog.this.style.splitWidthPx()));
                        }
                    }
                }
            } else if (MessageDialog.this.style.horizontalButtonOrder() != null && MessageDialog.this.style.horizontalButtonOrder().length != 0) {
                this.boxButton.removeAllViews();
                for (int i4 : MessageDialog.this.style.horizontalButtonOrder()) {
                    if (i4 == 1) {
                        this.boxButton.addView(this.btnSelectPositive);
                        if (MessageDialog.this.style.overrideHorizontalButtonRes() != null) {
                            this.btnSelectPositive.setBackgroundResource(MessageDialog.this.style.overrideHorizontalButtonRes().overrideHorizontalOkButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                        }
                    } else if (i4 == 2) {
                        this.boxButton.addView(this.btnSelectNegative);
                        if (MessageDialog.this.style.overrideHorizontalButtonRes() != null) {
                            this.btnSelectNegative.setBackgroundResource(MessageDialog.this.style.overrideHorizontalButtonRes().overrideHorizontalCancelButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                        }
                    } else if (i4 == 3) {
                        this.boxButton.addView(this.btnSelectOther);
                        if (MessageDialog.this.style.overrideHorizontalButtonRes() != null) {
                            this.btnSelectOther.setBackgroundResource(MessageDialog.this.style.overrideHorizontalButtonRes().overrideHorizontalOtherButtonBackgroundRes(i2, MessageDialog.this.isLightTheme()));
                        }
                    } else if (i4 == 4) {
                        if (this.boxButton.getChildCount() >= 1) {
                            LinearLayout linearLayout = this.boxButton;
                            if (linearLayout.getChildAt(linearLayout.getChildCount() - 1).getVisibility() != 8) {
                                Space space2 = new Space(BaseDialog.getTopActivity());
                                LinearLayout.LayoutParams layoutParams2 = new LinearLayout.LayoutParams(-1, -2);
                                layoutParams2.weight = 1.0f;
                                this.boxButton.addView(space2, layoutParams2);
                            }
                        }
                    } else if (i4 == 5 && this.boxButton.getChildCount() >= 1) {
                        LinearLayout linearLayout2 = this.boxButton;
                        if (linearLayout2.getChildAt(linearLayout2.getChildCount() - 1).getVisibility() != 8) {
                            View view3 = new View(BaseDialog.getTopActivity());
                            view3.setBackgroundColor(MessageDialog.this.getResources().getColor(MessageDialog.this.style.splitColorRes(MessageDialog.this.isLightTheme())));
                            this.boxButton.addView(view3, new LinearLayout.LayoutParams(MessageDialog.this.style.splitWidthPx(), -1));
                        }
                    }
                }
            }
            if (MessageDialog.this.bkgInterceptTouch) {
                if (MessageDialog.this.isCancelable()) {
                    this.boxRoot.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.7
                        @Override // android.view.View.OnClickListener
                        public void onClick(View v) {
                            if (MessageDialog.this.onBackgroundMaskClickListener == null || !MessageDialog.this.onBackgroundMaskClickListener.onClick(MessageDialog.this.f975me, v)) {
                                DialogImpl.this.doDismiss(v);
                            }
                        }
                    });
                } else {
                    this.boxRoot.setOnClickListener(null);
                }
            } else {
                this.boxRoot.setClickable(false);
            }
            if (MessageDialog.this.onBindView != null && MessageDialog.this.onBindView.getCustomView() != null) {
                MessageDialog.this.onBindView.bindParent(this.boxCustom, MessageDialog.this.f975me);
                this.boxCustom.setVisibility(0);
            } else {
                this.boxCustom.setVisibility(8);
            }
            MessageDialog.this.onDialogRefreshUI();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void doDismiss(View v) {
            if (v != null) {
                v.setEnabled(false);
            }
            if (BaseDialog.getTopActivity() == null || MessageDialog.this.dismissAnimFlag) {
                return;
            }
            MessageDialog.this.dismissAnimFlag = true;
            getDialogXAnimImpl().doExitAnim(MessageDialog.this.f975me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.8
                @Override // com.kongzue.dialogx.util.ObjectRunnable
                public void run(Float value) {
                    if (DialogImpl.this.boxRoot != null) {
                        DialogImpl.this.boxRoot.setBkgAlpha(value.floatValue());
                    }
                    if (value.floatValue() == 0.0f) {
                        if (DialogImpl.this.boxRoot != null) {
                            DialogImpl.this.boxRoot.setVisibility(8);
                        }
                        MessageDialog.dismiss(MessageDialog.this.dialogView);
                    }
                }
            });
        }

        protected DialogXAnimInterface<MessageDialog> getDialogXAnimImpl() {
            if (MessageDialog.this.dialogXAnimImpl == null) {
                MessageDialog.this.dialogXAnimImpl = new DialogXAnimInterface<MessageDialog>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.9
                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doExitAnim(MessageDialog dialog, ObjectRunnable animProgress) {
                        doExitAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doShowAnim(MessageDialog dialog, ObjectRunnable animProgress) {
                        doShowAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    /* renamed from: doShowAnim  reason: avoid collision after fix types in other method */
                    public void doShowAnim2(MessageDialog dialog, final ObjectRunnable<Float> animProgress) {
                        int enterAnimResId = MessageDialog.this.style.enterAnimResId() == 0 ? R.anim.anim_dialogx_default_enter : MessageDialog.this.style.enterAnimResId();
                        if (MessageDialog.overrideEnterAnimRes != 0) {
                            enterAnimResId = MessageDialog.overrideEnterAnimRes;
                        }
                        if (MessageDialog.this.customEnterAnimResId != 0) {
                            enterAnimResId = MessageDialog.this.customEnterAnimResId;
                        }
                        Animation loadAnimation = AnimationUtils.loadAnimation(BaseDialog.getTopActivity(), enterAnimResId);
                        long duration = loadAnimation.getDuration();
                        if (MessageDialog.overrideEnterDuration >= 0) {
                            duration = MessageDialog.overrideEnterDuration;
                        }
                        if (MessageDialog.this.enterAnimDuration >= 0) {
                            duration = MessageDialog.this.enterAnimDuration;
                        }
                        loadAnimation.setDuration(duration);
                        loadAnimation.setInterpolator(new DecelerateInterpolator());
                        DialogImpl.this.bkg.startAnimation(loadAnimation);
                        ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 1.0f);
                        ofFloat.setDuration(duration);
                        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.9.1
                            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                            public void onAnimationUpdate(ValueAnimator animation) {
                                animProgress.run((Float) animation.getAnimatedValue());
                            }
                        });
                        ofFloat.start();
                    }

                    /* renamed from: doExitAnim  reason: avoid collision after fix types in other method */
                    public void doExitAnim2(MessageDialog dialog, final ObjectRunnable<Float> animProgress) {
                        int exitAnimResId = MessageDialog.this.style.exitAnimResId() == 0 ? R.anim.anim_dialogx_default_exit : MessageDialog.this.style.exitAnimResId();
                        if (MessageDialog.overrideExitAnimRes != 0) {
                            exitAnimResId = MessageDialog.overrideExitAnimRes;
                        }
                        if (MessageDialog.this.customExitAnimResId != 0) {
                            exitAnimResId = MessageDialog.this.customExitAnimResId;
                        }
                        Animation loadAnimation = AnimationUtils.loadAnimation(BaseDialog.getTopActivity(), exitAnimResId);
                        long duration = loadAnimation.getDuration();
                        loadAnimation.setInterpolator(new AccelerateInterpolator());
                        if (MessageDialog.overrideExitDuration >= 0) {
                            duration = MessageDialog.overrideExitDuration;
                        }
                        if (MessageDialog.this.exitAnimDuration >= 0) {
                            duration = MessageDialog.this.exitAnimDuration;
                        }
                        loadAnimation.setDuration(duration);
                        DialogImpl.this.bkg.startAnimation(loadAnimation);
                        ValueAnimator ofFloat = ValueAnimator.ofFloat(1.0f, 0.0f);
                        ofFloat.setDuration(duration);
                        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.DialogImpl.9.2
                            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                            public void onAnimationUpdate(ValueAnimator animation) {
                                animProgress.run((Float) animation.getAnimatedValue());
                            }
                        });
                        ofFloat.start();
                    }
                };
            }
            return MessageDialog.this.dialogXAnimImpl;
        }
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public String dialogKey() {
        return getClass().getSimpleName() + "(" + Integer.toHexString(hashCode()) + ")";
    }

    public void dismiss() {
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.3
            @Override // java.lang.Runnable
            public void run() {
                if (MessageDialog.this.dialogImpl == null) {
                    return;
                }
                MessageDialog.this.dialogImpl.doDismiss(MessageDialog.this.dialogImpl.bkg);
            }
        });
    }

    public DialogLifecycleCallback<MessageDialog> getDialogLifecycleCallback() {
        DialogLifecycleCallback<MessageDialog> dialogLifecycleCallback = this.dialogLifecycleCallback;
        return dialogLifecycleCallback == null ? new DialogLifecycleCallback<MessageDialog>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.4
        } : dialogLifecycleCallback;
    }

    public MessageDialog setDialogLifecycleCallback(DialogLifecycleCallback<MessageDialog> dialogLifecycleCallback) {
        this.dialogLifecycleCallback = dialogLifecycleCallback;
        if (this.isShow) {
            dialogLifecycleCallback.onShow(this.f975me);
        }
        return this;
    }

    public MessageDialog setStyle(DialogXStyle style) {
        this.style = style;
        return this;
    }

    public MessageDialog setTheme(DialogX.THEME theme) {
        this.theme = theme;
        return this;
    }

    public CharSequence getOkButton() {
        return this.okText;
    }

    public MessageDialog setOkButton(CharSequence okText) {
        this.okText = okText;
        refreshUI();
        return this;
    }

    public MessageDialog setOkButton(int okTextRedId) {
        this.okText = getString(okTextRedId);
        refreshUI();
        return this;
    }

    public MessageDialog setOkButton(OnDialogButtonClickListener<MessageDialog> okButtonClickListener) {
        this.okButtonClickListener = okButtonClickListener;
        return this;
    }

    public MessageDialog setOkButton(CharSequence okText, OnDialogButtonClickListener<MessageDialog> okButtonClickListener) {
        this.okText = okText;
        this.okButtonClickListener = okButtonClickListener;
        refreshUI();
        return this;
    }

    public MessageDialog setOkButton(int okTextRedId, OnDialogButtonClickListener<MessageDialog> okButtonClickListener) {
        this.okText = getString(okTextRedId);
        this.okButtonClickListener = okButtonClickListener;
        refreshUI();
        return this;
    }

    public CharSequence getCancelButton() {
        return this.cancelText;
    }

    public MessageDialog setCancelButton(CharSequence cancelText) {
        this.cancelText = cancelText;
        refreshUI();
        return this;
    }

    public MessageDialog setCancelButton(int cancelTextResId) {
        this.cancelText = getString(cancelTextResId);
        refreshUI();
        return this;
    }

    public MessageDialog setCancelButton(OnDialogButtonClickListener<MessageDialog> cancelButtonClickListener) {
        this.cancelButtonClickListener = cancelButtonClickListener;
        return this;
    }

    public MessageDialog setCancelButton(CharSequence cancelText, OnDialogButtonClickListener<MessageDialog> cancelButtonClickListener) {
        this.cancelText = cancelText;
        this.cancelButtonClickListener = cancelButtonClickListener;
        refreshUI();
        return this;
    }

    public MessageDialog setCancelButton(int cancelTextResId, OnDialogButtonClickListener<MessageDialog> cancelButtonClickListener) {
        this.cancelText = getString(cancelTextResId);
        this.cancelButtonClickListener = cancelButtonClickListener;
        refreshUI();
        return this;
    }

    public CharSequence getOtherButton() {
        return this.otherText;
    }

    public MessageDialog setOtherButton(CharSequence otherText) {
        this.otherText = otherText;
        refreshUI();
        return this;
    }

    public MessageDialog setOtherButton(int otherTextResId) {
        this.otherText = getString(otherTextResId);
        refreshUI();
        return this;
    }

    public MessageDialog setOtherButton(OnDialogButtonClickListener<MessageDialog> otherButtonClickListener) {
        this.otherButtonClickListener = otherButtonClickListener;
        return this;
    }

    public MessageDialog setOtherButton(CharSequence otherText, OnDialogButtonClickListener<MessageDialog> otherButtonClickListener) {
        this.otherText = otherText;
        this.otherButtonClickListener = otherButtonClickListener;
        refreshUI();
        return this;
    }

    public MessageDialog setOtherButton(int otherTextResId, OnDialogButtonClickListener<MessageDialog> otherButtonClickListener) {
        this.otherText = getString(otherTextResId);
        this.otherButtonClickListener = otherButtonClickListener;
        refreshUI();
        return this;
    }

    public OnDialogButtonClickListener<MessageDialog> getOkButtonClickListener() {
        return (OnDialogButtonClickListener) this.okButtonClickListener;
    }

    public MessageDialog setOkButtonClickListener(OnDialogButtonClickListener<MessageDialog> okButtonClickListener) {
        this.okButtonClickListener = okButtonClickListener;
        return this;
    }

    public OnDialogButtonClickListener<MessageDialog> getCancelButtonClickListener() {
        return (OnDialogButtonClickListener) this.cancelButtonClickListener;
    }

    public MessageDialog setCancelButtonClickListener(OnDialogButtonClickListener<MessageDialog> cancelButtonClickListener) {
        this.cancelButtonClickListener = cancelButtonClickListener;
        return this;
    }

    public OnDialogButtonClickListener<MessageDialog> getOtherButtonClickListener() {
        return (OnDialogButtonClickListener) this.otherButtonClickListener;
    }

    public MessageDialog setOtherButtonClickListener(OnDialogButtonClickListener<MessageDialog> otherButtonClickListener) {
        this.otherButtonClickListener = otherButtonClickListener;
        return this;
    }

    public CharSequence getTitle() {
        return this.title;
    }

    public MessageDialog setTitle(CharSequence title) {
        this.title = title;
        refreshUI();
        return this;
    }

    public MessageDialog setTitle(int titleResId) {
        this.title = getString(titleResId);
        refreshUI();
        return this;
    }

    public CharSequence getMessage() {
        return this.message;
    }

    public MessageDialog setMessage(CharSequence message) {
        this.message = message;
        refreshUI();
        return this;
    }

    public MessageDialog setMessage(int messageResId) {
        this.message = getString(messageResId);
        refreshUI();
        return this;
    }

    public TextInfo getTitleTextInfo() {
        return this.titleTextInfo;
    }

    public MessageDialog setTitleTextInfo(TextInfo titleTextInfo) {
        this.titleTextInfo = titleTextInfo;
        refreshUI();
        return this;
    }

    public TextInfo getMessageTextInfo() {
        return this.messageTextInfo;
    }

    public MessageDialog setMessageTextInfo(TextInfo messageTextInfo) {
        this.messageTextInfo = messageTextInfo;
        refreshUI();
        return this;
    }

    public TextInfo getOkTextInfo() {
        return this.okTextInfo;
    }

    public MessageDialog setOkTextInfo(TextInfo okTextInfo) {
        this.okTextInfo = okTextInfo;
        refreshUI();
        return this;
    }

    public TextInfo getCancelTextInfo() {
        return this.cancelTextInfo;
    }

    public MessageDialog setCancelTextInfo(TextInfo cancelTextInfo) {
        this.cancelTextInfo = cancelTextInfo;
        refreshUI();
        return this;
    }

    public TextInfo getOtherTextInfo() {
        return this.otherTextInfo;
    }

    public MessageDialog setOtherTextInfo(TextInfo otherTextInfo) {
        this.otherTextInfo = otherTextInfo;
        refreshUI();
        return this;
    }

    public int getButtonOrientation() {
        return this.buttonOrientation;
    }

    public MessageDialog setButtonOrientation(int buttonOrientation) {
        this.buttonOrientation = buttonOrientation;
        refreshUI();
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public boolean isCancelable() {
        BaseDialog.BOOLEAN r0 = this.privateCancelable;
        if (r0 != null) {
            return r0 == BaseDialog.BOOLEAN.TRUE;
        }
        BaseDialog.BOOLEAN r02 = overrideCancelable;
        if (r02 != null) {
            return r02 == BaseDialog.BOOLEAN.TRUE;
        }
        return this.cancelable;
    }

    public MessageDialog setCancelable(boolean cancelable) {
        this.privateCancelable = cancelable ? BaseDialog.BOOLEAN.TRUE : BaseDialog.BOOLEAN.FALSE;
        refreshUI();
        return this;
    }

    public OnBackPressedListener<MessageDialog> getOnBackPressedListener() {
        return this.onBackPressedListener;
    }

    public MessageDialog setOnBackPressedListener(OnBackPressedListener<MessageDialog> onBackPressedListener) {
        this.onBackPressedListener = onBackPressedListener;
        return this;
    }

    public DialogImpl getDialogImpl() {
        return this.dialogImpl;
    }

    public MessageDialog setCustomView(OnBindView<MessageDialog> onBindView) {
        this.onBindView = onBindView;
        refreshUI();
        return this;
    }

    public View getCustomView() {
        OnBindView<MessageDialog> onBindView = this.onBindView;
        if (onBindView == null) {
            return null;
        }
        return onBindView.getCustomView();
    }

    public MessageDialog removeCustomView() {
        this.onBindView.clean();
        refreshUI();
        return this;
    }

    public int getBackgroundColor() {
        return this.backgroundColor;
    }

    public MessageDialog setBackgroundColor(int backgroundColor) {
        this.backgroundColor = backgroundColor;
        refreshUI();
        return this;
    }

    public String getInputText() {
        return this.dialogImpl.txtInput != null ? this.dialogImpl.txtInput.getText().toString() : "";
    }

    public MessageDialog setBackgroundColorRes(int backgroundColorResId) {
        this.backgroundColor = getColor(backgroundColorResId);
        refreshUI();
        return this;
    }

    public MessageDialog setMaskColor(int maskColor) {
        this.maskColor = maskColor;
        refreshUI();
        return this;
    }

    public long getEnterAnimDuration() {
        return this.enterAnimDuration;
    }

    public MessageDialog setEnterAnimDuration(long enterAnimDuration) {
        this.enterAnimDuration = enterAnimDuration;
        return this;
    }

    public long getExitAnimDuration() {
        return this.exitAnimDuration;
    }

    public MessageDialog setExitAnimDuration(long exitAnimDuration) {
        this.exitAnimDuration = exitAnimDuration;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public void restartDialog() {
        View view = this.dialogView;
        if (view != null) {
            dismiss(view);
            this.isShow = false;
        }
        if (getDialogImpl().boxCustom != null) {
            getDialogImpl().boxCustom.removeAllViews();
        }
        int layout = this.style.layout(isLightTheme());
        if (layout == 0) {
            layout = isLightTheme() ? R.layout.layout_dialogx_material : R.layout.layout_dialogx_material_dark;
        }
        this.enterAnimDuration = 0L;
        this.dialogView = createView(layout);
        this.dialogImpl = new DialogImpl(this.dialogView);
        View view2 = this.dialogView;
        if (view2 != null) {
            view2.setTag(this.f975me);
        }
        show(this.dialogView);
    }

    public void hide() {
        this.isHide = true;
        this.hideWithExitAnim = false;
        if (getDialogView() != null) {
            getDialogView().setVisibility(8);
        }
    }

    public void hideWithExitAnim() {
        this.hideWithExitAnim = true;
        this.isHide = true;
        if (getDialogImpl() != null) {
            getDialogImpl().getDialogXAnimImpl().doExitAnim(this.f975me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.MessageDialog.5
                @Override // com.kongzue.dialogx.util.ObjectRunnable
                public void run(Float value) {
                    MessageDialog.this.getDialogImpl().boxRoot.setBkgAlpha(value.floatValue());
                    if (value.floatValue() != 0.0f || MessageDialog.this.getDialogView() == null) {
                        return;
                    }
                    MessageDialog.this.getDialogView().setVisibility(8);
                }
            });
        }
    }

    public MessageDialog setAnimResId(int enterResId, int exitResId) {
        this.customEnterAnimResId = enterResId;
        this.customExitAnimResId = exitResId;
        return this;
    }

    public MessageDialog setEnterAnimResId(int enterResId) {
        this.customEnterAnimResId = enterResId;
        return this;
    }

    public MessageDialog setExitAnimResId(int exitResId) {
        this.customExitAnimResId = exitResId;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    protected void shutdown() {
        dismiss();
    }

    public MessageDialog setMaxWidth(int maxWidth) {
        this.maxWidth = maxWidth;
        refreshUI();
        return this;
    }

    public MessageDialog setDialogImplMode(DialogX.IMPL_MODE dialogImplMode) {
        this.dialogImplMode = dialogImplMode;
        return this;
    }

    public boolean isBkgInterceptTouch() {
        return this.bkgInterceptTouch;
    }

    public MessageDialog setBkgInterceptTouch(boolean bkgInterceptTouch) {
        this.bkgInterceptTouch = bkgInterceptTouch;
        return this;
    }

    public OnBackgroundMaskClickListener<MessageDialog> getOnBackgroundMaskClickListener() {
        return this.onBackgroundMaskClickListener;
    }

    public MessageDialog setOnBackgroundMaskClickListener(OnBackgroundMaskClickListener<MessageDialog> onBackgroundMaskClickListener) {
        this.onBackgroundMaskClickListener = onBackgroundMaskClickListener;
        return this;
    }

    public MessageDialog setRadius(float radiusPx) {
        this.backgroundRadius = radiusPx;
        refreshUI();
        return this;
    }

    public float getRadius() {
        return this.backgroundRadius;
    }

    public Drawable getTitleIcon() {
        return this.titleIcon;
    }

    public MessageDialog setTitleIcon(Bitmap titleIcon) {
        this.titleIcon = new BitmapDrawable(getResources(), titleIcon);
        refreshUI();
        return this;
    }

    public MessageDialog setTitleIcon(int titleIconResId) {
        this.titleIcon = getResources().getDrawable(titleIconResId);
        refreshUI();
        return this;
    }

    public MessageDialog setTitleIcon(Drawable titleIcon) {
        this.titleIcon = titleIcon;
        refreshUI();
        return this;
    }

    public DialogXAnimInterface<MessageDialog> getDialogXAnimImpl() {
        return this.dialogXAnimImpl;
    }

    public MessageDialog setDialogXAnimImpl(DialogXAnimInterface<MessageDialog> dialogXAnimImpl) {
        this.dialogXAnimImpl = dialogXAnimImpl;
        return this;
    }
}
