package com.kongzue.dialogx.dialogs;

import android.animation.ValueAnimator;
import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.Outline;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.view.animation.DecelerateInterpolator;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;
import androidx.lifecycle.Lifecycle;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.DialogConvertViewInterface;
import com.kongzue.dialogx.interfaces.DialogLifecycleCallback;
import com.kongzue.dialogx.interfaces.DialogXAnimInterface;
import com.kongzue.dialogx.interfaces.DialogXStyle;
import com.kongzue.dialogx.interfaces.NoTouchInterface;
import com.kongzue.dialogx.interfaces.OnBindView;
import com.kongzue.dialogx.interfaces.OnDialogButtonClickListener;
import com.kongzue.dialogx.interfaces.OnSafeInsetsChangeListener;
import com.kongzue.dialogx.util.ObjectRunnable;
import com.kongzue.dialogx.util.PopValueAnimator;
import com.kongzue.dialogx.util.TextInfo;
import com.kongzue.dialogx.util.views.BlurView;
import com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout;
import com.kongzue.dialogx.util.views.MaxRelativeLayout;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Timer;
import java.util.TimerTask;
import java.util.concurrent.CopyOnWriteArrayList;
/* loaded from: classes10.dex */
public class PopNotification extends BaseDialog implements NoTouchInterface {
    public static final int TIME_NO_AUTO_DISMISS_DELAY = -1;
    public static int overrideEnterAnimRes = 0;
    public static long overrideEnterDuration = -1;
    public static int overrideExitAnimRes = 0;
    public static long overrideExitDuration = -1;
    protected static List<PopNotification> popNotificationList;
    protected DialogXStyle.PopNotificationSettings.ALIGN align;
    protected long autoDismissDelay;
    protected Timer autoDismissTimer;
    protected CharSequence buttonText;
    protected DialogImpl dialogImpl;
    protected DialogLifecycleCallback<PopNotification> dialogLifecycleCallback;
    private View dialogView;
    protected DialogXAnimInterface<PopNotification> dialogXAnimImpl;
    protected Bitmap iconBitmap;
    protected Drawable iconDrawable;
    protected int iconResId;
    protected int iconSize;
    private boolean isHide;
    protected CharSequence message;
    protected TextInfo messageTextInfo;
    protected OnBindView<PopNotification> onBindView;
    protected OnDialogButtonClickListener<PopNotification> onButtonClickListener;
    protected OnDialogButtonClickListener<PopNotification> onPopNotificationClickListener;
    protected BaseDialog.BOOLEAN tintIcon;
    protected CharSequence title;
    protected TextInfo titleTextInfo;

    /* renamed from: me  reason: collision with root package name */
    protected PopNotification f977me = this;
    protected int enterAnimResId = 0;
    protected int exitAnimResId = 0;
    protected boolean autoTintIconInLightOrDarkMode = true;
    protected float backgroundRadius = -1.0f;
    protected TextInfo buttonTextInfo = new TextInfo().setBold(true);
    protected int[] bodyMargin = {-1, -1, -1, -1};
    protected boolean preRecycle = false;

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public boolean isCancelable() {
        return false;
    }

    protected PopNotification() {
    }

    public static PopNotification build() {
        return new PopNotification();
    }

    public static PopNotification build(DialogXStyle style) {
        return new PopNotification().setStyle(style);
    }

    public static PopNotification build(OnBindView<PopNotification> onBindView) {
        return new PopNotification().setCustomView(onBindView);
    }

    public PopNotification(OnBindView<PopNotification> onBindView) {
        this.onBindView = onBindView;
    }

    public PopNotification(CharSequence title) {
        this.title = title;
    }

    public PopNotification(CharSequence title, CharSequence message) {
        this.title = title;
        this.message = message;
    }

    public PopNotification(int titleResId) {
        this.title = getString(titleResId);
    }

    public PopNotification(int titleResId, int messageResId) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
    }

    public PopNotification(int iconResId, CharSequence title) {
        this.iconResId = iconResId;
        this.title = title;
    }

    public PopNotification(int iconResId, CharSequence title, CharSequence message) {
        this.iconResId = iconResId;
        this.title = title;
        this.message = message;
    }

    public PopNotification(int iconResId, int titleResId, int messageResId) {
        this.iconResId = iconResId;
        this.title = getString(titleResId);
        this.message = getString(messageResId);
    }

    public PopNotification(CharSequence title, OnBindView<PopNotification> onBindView) {
        this.title = title;
        this.onBindView = onBindView;
    }

    public PopNotification(CharSequence title, CharSequence message, OnBindView<PopNotification> onBindView) {
        this.title = title;
        this.message = message;
        this.onBindView = onBindView;
    }

    public PopNotification(int titleResId, OnBindView<PopNotification> onBindView) {
        this.title = getString(titleResId);
        this.onBindView = onBindView;
    }

    public PopNotification(int titleResId, int messageResId, OnBindView<PopNotification> onBindView) {
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.onBindView = onBindView;
    }

    public PopNotification(int iconResId, CharSequence title, OnBindView<PopNotification> onBindView) {
        this.iconResId = iconResId;
        this.title = title;
        this.onBindView = onBindView;
    }

    public PopNotification(int iconResId, CharSequence title, CharSequence message, OnBindView<PopNotification> onBindView) {
        this.iconResId = iconResId;
        this.title = title;
        this.message = message;
        this.onBindView = onBindView;
    }

    public PopNotification(int iconResId, int titleResId, int messageResId, OnBindView<PopNotification> onBindView) {
        this.iconResId = iconResId;
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.onBindView = onBindView;
    }

    public PopNotification(int iconResId, int titleResId, int messageResId, int buttonTextResId) {
        this.iconResId = iconResId;
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.buttonText = getString(buttonTextResId);
    }

    public PopNotification(int iconResId, int titleResId, int messageResId, int buttonTextResId, OnBindView<PopNotification> onBindView) {
        this.iconResId = iconResId;
        this.title = getString(titleResId);
        this.message = getString(messageResId);
        this.buttonText = getString(buttonTextResId);
        this.onBindView = onBindView;
    }

    public PopNotification(int iconResId, CharSequence title, CharSequence message, CharSequence buttonText) {
        this.iconResId = iconResId;
        this.title = title;
        this.message = message;
        this.buttonText = buttonText;
    }

    public PopNotification(int iconResId, CharSequence title, CharSequence message, CharSequence buttonText, OnBindView<PopNotification> onBindView) {
        this.iconResId = iconResId;
        this.title = title;
        this.message = message;
        this.buttonText = buttonText;
        this.onBindView = onBindView;
    }

    public static PopNotification show(OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(CharSequence title) {
        PopNotification popNotification = new PopNotification(title);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(CharSequence title, CharSequence message) {
        PopNotification popNotification = new PopNotification(title, message);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int titleResId) {
        PopNotification popNotification = new PopNotification(titleResId);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int titleResId, int messageResId) {
        PopNotification popNotification = new PopNotification(titleResId, messageResId);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(CharSequence title, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(title, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(CharSequence title, CharSequence message, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(title, message, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int titleResId, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(titleResId, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int titleResId, int messageResId, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(titleResId, messageResId, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(iconResId, title, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title, CharSequence message, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(iconResId, title, message, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title) {
        PopNotification popNotification = new PopNotification(iconResId, title);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title, CharSequence message) {
        PopNotification popNotification = new PopNotification(iconResId, title, message);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, int titleResId, int messageResId) {
        PopNotification popNotification = new PopNotification(iconResId, titleResId, messageResId);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, int titleResId, int messageResId, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(iconResId, titleResId, messageResId, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, int titleResId, int messageResId, int buttonTextResId) {
        PopNotification popNotification = new PopNotification(iconResId, titleResId, messageResId, buttonTextResId);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, int titleResId, int messageResId, int buttonTextResId, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(iconResId, titleResId, messageResId, buttonTextResId, onBindView);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title, CharSequence message, CharSequence buttonText) {
        PopNotification popNotification = new PopNotification(iconResId, title, message, buttonText);
        popNotification.show();
        return popNotification;
    }

    public static PopNotification show(int iconResId, CharSequence title, CharSequence message, CharSequence buttonText, OnBindView<PopNotification> onBindView) {
        PopNotification popNotification = new PopNotification(iconResId, title, message, buttonText, onBindView);
        popNotification.show();
        return popNotification;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public PopNotification show() {
        if (this.isHide && getDialogView() != null) {
            getDialogView().setVisibility(0);
            return this;
        }
        super.beforeShow();
        if (getDialogView() == null) {
            if (DialogX.onlyOnePopNotification) {
                PopNotification popNotification = null;
                List<PopNotification> list = popNotificationList;
                if (list != null && !list.isEmpty()) {
                    List<PopNotification> list2 = popNotificationList;
                    popNotification = list2.get(list2.size() - 1);
                }
                if (popNotification != null) {
                    popNotification.dismiss();
                }
            }
            if (popNotificationList == null) {
                popNotificationList = new ArrayList();
            }
            popNotificationList.add(this);
            int i2 = isLightTheme() ? R.layout.layout_dialogx_popnotification_material : R.layout.layout_dialogx_popnotification_material_dark;
            if (this.style.popNotificationSettings() != null) {
                if (this.style.popNotificationSettings().layout(isLightTheme()) != 0) {
                    i2 = this.style.popNotificationSettings().layout(isLightTheme());
                }
                DialogXStyle.PopNotificationSettings.ALIGN align = this.style.popNotificationSettings().align();
                this.align = align;
                if (align == null) {
                    this.align = DialogXStyle.PopNotificationSettings.ALIGN.TOP;
                }
                int enterAnimResId = this.style.popNotificationSettings().enterAnimResId(isLightTheme());
                int exitAnimResId = this.style.popNotificationSettings().exitAnimResId(isLightTheme());
                int i3 = this.enterAnimResId;
                if (i3 != 0 || (i3 = overrideEnterAnimRes) != 0) {
                    enterAnimResId = i3;
                } else if (enterAnimResId == 0) {
                    enterAnimResId = R.anim.anim_dialogx_notification_enter;
                }
                this.enterAnimResId = enterAnimResId;
                int i4 = this.exitAnimResId;
                if (i4 != 0 || (i4 = overrideExitAnimRes) != 0) {
                    exitAnimResId = i4;
                } else if (exitAnimResId == 0) {
                    exitAnimResId = R.anim.anim_dialogx_notification_exit;
                }
                this.exitAnimResId = exitAnimResId;
                this.enterAnimDuration = this.enterAnimDuration == -1 ? overrideEnterDuration : this.enterAnimDuration;
                this.exitAnimDuration = this.exitAnimDuration == -1 ? overrideExitDuration : this.exitAnimDuration;
            }
            this.dialogView = createView(i2);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f977me);
            }
        }
        show(this.dialogView);
        return this;
    }

    public PopNotification show(Activity activity) {
        super.beforeShow();
        if (this.dialogView != null) {
            if (DialogX.onlyOnePopNotification) {
                PopNotification popNotification = null;
                List<PopNotification> list = popNotificationList;
                if (list != null && !list.isEmpty()) {
                    List<PopNotification> list2 = popNotificationList;
                    popNotification = list2.get(list2.size() - 1);
                }
                if (popNotification != null) {
                    popNotification.dismiss();
                }
            }
            if (popNotificationList == null) {
                popNotificationList = new ArrayList();
            }
            popNotificationList.add(this);
            int i2 = isLightTheme() ? R.layout.layout_dialogx_popnotification_material : R.layout.layout_dialogx_popnotification_material_dark;
            if (this.style.popNotificationSettings() != null) {
                if (this.style.popNotificationSettings().layout(isLightTheme()) != 0) {
                    i2 = this.style.popNotificationSettings().layout(isLightTheme());
                }
                DialogXStyle.PopNotificationSettings.ALIGN align = this.style.popNotificationSettings().align();
                this.align = align;
                if (align == null) {
                    this.align = DialogXStyle.PopNotificationSettings.ALIGN.TOP;
                }
                int enterAnimResId = this.style.popNotificationSettings().enterAnimResId(isLightTheme());
                int exitAnimResId = this.style.popNotificationSettings().exitAnimResId(isLightTheme());
                int i3 = this.enterAnimResId;
                if (i3 != 0 || (i3 = overrideEnterAnimRes) != 0) {
                    enterAnimResId = i3;
                } else if (enterAnimResId == 0) {
                    enterAnimResId = R.anim.anim_dialogx_notification_enter;
                }
                this.enterAnimResId = enterAnimResId;
                int i4 = this.exitAnimResId;
                if (i4 != 0 || (i4 = overrideExitAnimRes) != 0) {
                    exitAnimResId = i4;
                } else if (exitAnimResId == 0) {
                    exitAnimResId = R.anim.anim_dialogx_notification_exit;
                }
                this.exitAnimResId = exitAnimResId;
                this.enterAnimDuration = this.enterAnimDuration == -1 ? overrideEnterDuration : this.enterAnimDuration;
                this.exitAnimDuration = this.exitAnimDuration == -1 ? overrideExitDuration : this.exitAnimDuration;
            }
            this.dialogView = createView(i2);
            this.dialogImpl = new DialogImpl(this.dialogView);
            View view = this.dialogView;
            if (view != null) {
                view.setTag(this.f977me);
            }
        }
        show(activity, this.dialogView);
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public String dialogKey() {
        return getClass().getSimpleName() + "(" + Integer.toHexString(hashCode()) + ")";
    }

    public PopNotification autoDismiss(long delay) {
        this.autoDismissDelay = delay;
        Timer timer = this.autoDismissTimer;
        if (timer != null) {
            timer.cancel();
        }
        if (delay < 0) {
            return this;
        }
        Timer timer2 = new Timer();
        this.autoDismissTimer = timer2;
        timer2.schedule(new TimerTask() { // from class: com.kongzue.dialogx.dialogs.PopNotification.1
            @Override // java.util.TimerTask, java.lang.Runnable
            public void run() {
                PopNotification.this.dismiss();
            }
        }, delay);
        return this;
    }

    public void resetAutoDismissTimer() {
        autoDismiss(this.autoDismissDelay);
    }

    public PopNotification showShort() {
        autoDismiss(2000L);
        if (!this.preShow && !this.isShow) {
            show();
        }
        return this;
    }

    public PopNotification showLong() {
        autoDismiss(3500L);
        if (!this.preShow && !this.isShow) {
            show();
        }
        return this;
    }

    public PopNotification showAlways() {
        return noAutoDismiss();
    }

    public PopNotification noAutoDismiss() {
        autoDismiss(-1L);
        return this;
    }

    /* loaded from: classes10.dex */
    public class DialogImpl implements DialogConvertViewInterface {
        public BlurView blurView;
        private ViewGroup boxBody;
        private RelativeLayout boxCustom;
        private DialogXBaseRelativeLayout boxRoot;
        private ImageView imgDialogxPopIcon;
        private TextView txtDialogxButton;
        private TextView txtDialogxPopMessage;
        private TextView txtDialogxPopTitle;

        public DialogImpl(View convertView) {
            if (convertView == null) {
                return;
            }
            this.boxRoot = (DialogXBaseRelativeLayout) convertView.findViewById(R.id.box_root);
            this.boxBody = (ViewGroup) convertView.findViewById(R.id.box_body);
            this.imgDialogxPopIcon = (ImageView) convertView.findViewById(R.id.img_dialogx_pop_icon);
            this.txtDialogxPopTitle = (TextView) convertView.findViewById(R.id.txt_dialogx_pop_title);
            this.txtDialogxPopMessage = (TextView) convertView.findViewById(R.id.txt_dialogx_pop_message);
            this.txtDialogxButton = (TextView) convertView.findViewById(R.id.txt_dialogx_button);
            this.boxCustom = (RelativeLayout) convertView.findViewById(R.id.box_custom);
            init();
            PopNotification.this.dialogImpl = this;
            refreshView();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void init() {
            if (PopNotification.this.titleTextInfo == null) {
                PopNotification.this.titleTextInfo = DialogX.titleTextInfo;
            }
            if (PopNotification.this.messageTextInfo == null) {
                PopNotification.this.messageTextInfo = DialogX.messageTextInfo;
            }
            if (PopNotification.this.buttonTextInfo == null) {
                PopNotification.this.buttonTextInfo = DialogX.buttonTextInfo;
            }
            if (PopNotification.this.backgroundColor == -1) {
                PopNotification.this.backgroundColor = DialogX.backgroundColor;
            }
            if (PopNotification.this.autoDismissTimer == null) {
                PopNotification.this.showShort();
            }
            this.boxRoot.setClickable(false);
            this.boxRoot.setFocusable(false);
            this.boxRoot.setParentDialog(PopNotification.this.f977me);
            this.boxRoot.setAutoUnsafePlacePadding(false);
            this.boxRoot.setOnLifecycleCallBack(new DialogXBaseRelativeLayout.OnLifecycleCallBack() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.1
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onShow() {
                    PopNotification.this.isShow = true;
                    PopNotification.this.preShow = false;
                    PopNotification.this.lifecycle.setCurrentState(Lifecycle.State.CREATED);
                    DialogImpl.this.boxRoot.setAlpha(0.0f);
                    PopNotification.this.onDialogShow();
                    PopNotification.this.getDialogLifecycleCallback().onShow(PopNotification.this.f977me);
                }

                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.OnLifecycleCallBack
                public void onDismiss() {
                    if (PopNotification.popNotificationList != null) {
                        PopNotification.popNotificationList.remove(PopNotification.this);
                    }
                    PopNotification.this.isShow = false;
                    PopNotification.this.getDialogLifecycleCallback().onDismiss(PopNotification.this.f977me);
                    PopNotification.this.dialogImpl = null;
                    PopNotification.this.lifecycle.setCurrentState(Lifecycle.State.DESTROYED);
                    System.gc();
                }
            });
            RelativeLayout.LayoutParams layoutParams = (RelativeLayout.LayoutParams) this.boxBody.getLayoutParams();
            if (PopNotification.this.align == null) {
                PopNotification.this.align = DialogXStyle.PopNotificationSettings.ALIGN.TOP;
            }
            int i2 = AnonymousClass6.$SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[PopNotification.this.align.ordinal()];
            if (i2 == 1) {
                layoutParams.removeRule(13);
                layoutParams.addRule(10);
            } else if (i2 == 2) {
                layoutParams.removeRule(13);
                layoutParams.addRule(12);
                this.boxRoot.setAutoUnsafePlacePadding(true);
            } else if (i2 == 3) {
                layoutParams.removeRule(10);
                layoutParams.removeRule(12);
                layoutParams.addRule(13);
            }
            this.boxBody.setLayoutParams(layoutParams);
            this.boxRoot.setOnSafeInsetsChangeListener(new OnSafeInsetsChangeListener() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.2
                @Override // com.kongzue.dialogx.interfaces.OnSafeInsetsChangeListener
                public void onChange(Rect unsafeRect) {
                    if (PopNotification.this.align == DialogXStyle.PopNotificationSettings.ALIGN.TOP) {
                        DialogImpl.this.boxBody.setY(unsafeRect.top + PopNotification.this.bodyMargin[1]);
                    } else if (PopNotification.this.align == DialogXStyle.PopNotificationSettings.ALIGN.TOP_INSIDE) {
                        DialogImpl.this.boxBody.setPadding(0, unsafeRect.top, 0, 0);
                    }
                }
            });
            this.boxRoot.setOnBackPressedListener(new DialogXBaseRelativeLayout.PrivateBackPressedListener() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.3
                @Override // com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.PrivateBackPressedListener
                public boolean onBackPressed() {
                    return false;
                }
            });
            this.boxRoot.post(new Runnable() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.4
                @Override // java.lang.Runnable
                public void run() {
                    DialogImpl.this.getDialogXAnimImpl().doShowAnim(PopNotification.this.f977me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.4.1
                        @Override // com.kongzue.dialogx.util.ObjectRunnable
                        public void run(Float aFloat) {
                        }
                    });
                    if (!DialogX.onlyOnePopNotification && PopNotification.popNotificationList != null) {
                        for (int i3 = 0; i3 < PopNotification.popNotificationList.size() - 1; i3++) {
                            PopNotification.popNotificationList.get(i3).moveUp(DialogImpl.this.boxBody.getHeight());
                        }
                    }
                    if (PopNotification.this.getStyle().popNotificationSettings() != null && PopNotification.this.getStyle().popNotificationSettings().blurBackgroundSettings() != null && PopNotification.this.getStyle().popNotificationSettings().blurBackgroundSettings().blurBackground()) {
                        MaxRelativeLayout maxRelativeLayout = (MaxRelativeLayout) DialogImpl.this.boxRoot.findViewWithTag("blurBody");
                        int color = PopNotification.this.getResources().getColor(PopNotification.this.getStyle().popNotificationSettings().blurBackgroundSettings().blurForwardColorRes(PopNotification.this.isLightTheme()));
                        DialogImpl.this.blurView = new BlurView(maxRelativeLayout.getContext(), null);
                        RelativeLayout.LayoutParams layoutParams2 = new RelativeLayout.LayoutParams(DialogImpl.this.boxBody.getWidth(), DialogImpl.this.boxBody.getHeight());
                        BlurView blurView = DialogImpl.this.blurView;
                        if (PopNotification.this.backgroundColor != -1) {
                            color = PopNotification.this.backgroundColor;
                        }
                        blurView.setOverlayColor(color);
                        DialogImpl.this.blurView.setTag("blurView");
                        DialogImpl.this.blurView.setRadiusPx(PopNotification.this.getStyle().popNotificationSettings().blurBackgroundSettings().blurBackgroundRoundRadiusPx());
                        maxRelativeLayout.setContentView(DialogImpl.this.boxBody);
                        maxRelativeLayout.addView(DialogImpl.this.blurView, 0, layoutParams2);
                    }
                    PopNotification.this.lifecycle.setCurrentState(Lifecycle.State.RESUMED);
                }
            });
            this.txtDialogxButton.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.5
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (PopNotification.this.onButtonClickListener != null) {
                        if (PopNotification.this.onButtonClickListener.onClick(PopNotification.this.f977me, v)) {
                            return;
                        }
                        DialogImpl.this.doDismiss(v);
                        return;
                    }
                    DialogImpl.this.doDismiss(v);
                }
            });
            PopNotification.this.onDialogInit();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void refreshView() {
            if (this.boxRoot == null || BaseDialog.getTopActivity() == null) {
                return;
            }
            if (PopNotification.this.backgroundColor != -1) {
                PopNotification popNotification = PopNotification.this;
                popNotification.tintColor(this.boxBody, popNotification.backgroundColor);
            }
            if (PopNotification.this.onBindView != null && PopNotification.this.onBindView.getCustomView() != null) {
                PopNotification.this.onBindView.bindParent(this.boxCustom, PopNotification.this.f977me);
                this.boxCustom.setVisibility(0);
            } else {
                this.boxCustom.setVisibility(8);
            }
            if (PopNotification.this.backgroundRadius > -1.0f) {
                GradientDrawable gradientDrawable = (GradientDrawable) this.boxBody.getBackground();
                if (gradientDrawable != null) {
                    gradientDrawable.setCornerRadius(PopNotification.this.backgroundRadius);
                }
                if (Build.VERSION.SDK_INT >= 21) {
                    this.boxBody.setOutlineProvider(new ViewOutlineProvider() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.6
                        @Override // android.view.ViewOutlineProvider
                        public void getOutline(View view, Outline outline) {
                            outline.setRoundRect(0, 0, view.getWidth(), view.getHeight(), PopNotification.this.backgroundRadius);
                        }
                    });
                    this.boxBody.setClipToOutline(true);
                }
            }
            PopNotification popNotification2 = PopNotification.this;
            popNotification2.showText(this.txtDialogxPopTitle, popNotification2.title);
            PopNotification popNotification3 = PopNotification.this;
            popNotification3.showText(this.txtDialogxPopMessage, popNotification3.message);
            PopNotification popNotification4 = PopNotification.this;
            popNotification4.showText(this.txtDialogxButton, popNotification4.buttonText);
            BaseDialog.useTextInfo(this.txtDialogxPopTitle, PopNotification.this.titleTextInfo);
            BaseDialog.useTextInfo(this.txtDialogxPopMessage, PopNotification.this.messageTextInfo);
            BaseDialog.useTextInfo(this.txtDialogxButton, PopNotification.this.buttonTextInfo);
            if (PopNotification.this.iconBitmap != null && !PopNotification.this.iconBitmap.isRecycled()) {
                this.imgDialogxPopIcon.setVisibility(0);
                this.imgDialogxPopIcon.setImageBitmap(PopNotification.this.iconBitmap);
            } else if (PopNotification.this.iconDrawable != null) {
                this.imgDialogxPopIcon.setVisibility(0);
                this.imgDialogxPopIcon.setImageDrawable(PopNotification.this.iconDrawable);
            } else if (PopNotification.this.iconResId != 0) {
                this.imgDialogxPopIcon.setVisibility(0);
                this.imgDialogxPopIcon.setImageResource(PopNotification.this.iconResId);
            } else {
                this.imgDialogxPopIcon.setVisibility(8);
            }
            if (Build.VERSION.SDK_INT >= 21 && PopNotification.this.tintIcon == BaseDialog.BOOLEAN.TRUE) {
                if (PopNotification.this.autoTintIconInLightOrDarkMode) {
                    this.imgDialogxPopIcon.setImageTintList(this.txtDialogxPopTitle.getTextColors());
                } else {
                    this.imgDialogxPopIcon.setImageTintList(null);
                }
            } else if (Build.VERSION.SDK_INT >= 21) {
                this.imgDialogxPopIcon.setImageTintList(null);
            }
            if (PopNotification.this.iconSize > 0) {
                ViewGroup.LayoutParams layoutParams = this.imgDialogxPopIcon.getLayoutParams();
                layoutParams.width = PopNotification.this.iconSize;
                layoutParams.height = PopNotification.this.iconSize;
                this.imgDialogxPopIcon.setLayoutParams(layoutParams);
            }
            this.boxBody.setOnClickListener(new View.OnClickListener() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.7
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (PopNotification.this.onPopNotificationClickListener != null) {
                        if (PopNotification.this.onPopNotificationClickListener.onClick(PopNotification.this.f977me, v)) {
                            return;
                        }
                        PopNotification.this.dismiss();
                        return;
                    }
                    PopNotification.this.dismiss();
                }
            });
            RelativeLayout.LayoutParams layoutParams2 = (RelativeLayout.LayoutParams) this.boxBody.getLayoutParams();
            if (PopNotification.this.bodyMargin[0] != -1) {
                layoutParams2.leftMargin = PopNotification.this.bodyMargin[0];
            }
            if (PopNotification.this.bodyMargin[1] != -1) {
                layoutParams2.topMargin = PopNotification.this.bodyMargin[1];
            }
            if (PopNotification.this.bodyMargin[2] != -1) {
                layoutParams2.rightMargin = PopNotification.this.bodyMargin[2];
            }
            if (PopNotification.this.bodyMargin[3] != -1) {
                layoutParams2.bottomMargin = PopNotification.this.bodyMargin[3];
            }
            this.boxBody.setLayoutParams(layoutParams2);
            PopNotification.this.onDialogRefreshUI();
        }

        @Override // com.kongzue.dialogx.interfaces.DialogConvertViewInterface
        public void doDismiss(final View v) {
            if (v != null) {
                v.setEnabled(false);
            }
            if (PopNotification.this.dismissAnimFlag) {
                return;
            }
            PopNotification.this.dismissAnimFlag = true;
            this.boxRoot.post(new Runnable() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.8
                @Override // java.lang.Runnable
                public void run() {
                    DialogImpl.this.getDialogXAnimImpl().doExitAnim(PopNotification.this.f977me, new ObjectRunnable<Float>() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.8.1
                        @Override // com.kongzue.dialogx.util.ObjectRunnable
                        public void run(Float value) {
                            if (value.floatValue() == 0.0f) {
                                PopNotification.this.waitForDismiss();
                            }
                        }
                    });
                }
            });
        }

        protected DialogXAnimInterface<PopNotification> getDialogXAnimImpl() {
            if (PopNotification.this.dialogXAnimImpl == null) {
                PopNotification.this.dialogXAnimImpl = new DialogXAnimInterface<PopNotification>() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.9
                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doExitAnim(PopNotification dialog, ObjectRunnable animProgress) {
                        doExitAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    @Override // com.kongzue.dialogx.interfaces.DialogXAnimInterface
                    public /* bridge */ /* synthetic */ void doShowAnim(PopNotification dialog, ObjectRunnable animProgress) {
                        doShowAnim2(dialog, (ObjectRunnable<Float>) animProgress);
                    }

                    /* renamed from: doShowAnim  reason: avoid collision after fix types in other method */
                    public void doShowAnim2(PopNotification dialog, ObjectRunnable<Float> animProgress) {
                        Animation loadAnimation = AnimationUtils.loadAnimation(BaseDialog.getTopActivity(), PopNotification.this.enterAnimResId == 0 ? R.anim.anim_dialogx_notification_enter : PopNotification.this.enterAnimResId);
                        loadAnimation.setInterpolator(new DecelerateInterpolator(2.0f));
                        if (PopNotification.this.enterAnimDuration != -1) {
                            loadAnimation.setDuration(PopNotification.this.enterAnimDuration);
                        }
                        loadAnimation.setFillAfter(true);
                        DialogImpl.this.boxBody.startAnimation(loadAnimation);
                        DialogImpl.this.boxRoot.animate().setDuration(PopNotification.this.enterAnimDuration == -1 ? loadAnimation.getDuration() : PopNotification.this.enterAnimDuration).alpha(1.0f).setInterpolator(new DecelerateInterpolator()).setListener(null);
                    }

                    /* renamed from: doExitAnim  reason: avoid collision after fix types in other method */
                    public void doExitAnim2(PopNotification dialog, final ObjectRunnable<Float> animProgress) {
                        Animation loadAnimation = AnimationUtils.loadAnimation(BaseDialog.getTopActivity() == null ? DialogImpl.this.boxRoot.getContext() : BaseDialog.getTopActivity(), PopNotification.this.exitAnimResId == 0 ? R.anim.anim_dialogx_notification_exit : PopNotification.this.exitAnimResId);
                        if (PopNotification.this.exitAnimDuration != -1) {
                            loadAnimation.setDuration(PopNotification.this.exitAnimDuration);
                        }
                        loadAnimation.setFillAfter(true);
                        DialogImpl.this.boxBody.startAnimation(loadAnimation);
                        DialogImpl.this.boxRoot.animate().alpha(0.0f).setInterpolator(new AccelerateInterpolator()).setDuration(PopNotification.this.exitAnimDuration == -1 ? loadAnimation.getDuration() : PopNotification.this.exitAnimDuration);
                        PopNotification.runOnMainDelay(new Runnable() { // from class: com.kongzue.dialogx.dialogs.PopNotification.DialogImpl.9.1
                            @Override // java.lang.Runnable
                            public void run() {
                                animProgress.run(Float.valueOf(0.0f));
                            }
                        }, PopNotification.this.exitAnimDuration == -1 ? loadAnimation.getDuration() : PopNotification.this.exitAnimDuration);
                    }
                };
            }
            return PopNotification.this.dialogXAnimImpl;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.kongzue.dialogx.dialogs.PopNotification$6  reason: invalid class name */
    /* loaded from: classes10.dex */
    public static /* synthetic */ class AnonymousClass6 {
        static final /* synthetic */ int[] $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN;

        static {
            int[] iArr = new int[DialogXStyle.PopNotificationSettings.ALIGN.values().length];
            $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN = iArr;
            try {
                iArr[DialogXStyle.PopNotificationSettings.ALIGN.TOP.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[DialogXStyle.PopNotificationSettings.ALIGN.BOTTOM.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[DialogXStyle.PopNotificationSettings.ALIGN.CENTER.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[DialogXStyle.PopNotificationSettings.ALIGN.TOP_INSIDE.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[DialogXStyle.PopNotificationSettings.ALIGN.BOTTOM_INSIDE.ordinal()] = 5;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void waitForDismiss() {
        this.preRecycle = true;
        List<PopNotification> list = popNotificationList;
        if (list != null) {
            for (PopNotification popNotification : list) {
                if (!popNotification.preRecycle) {
                    return;
                }
            }
            Iterator it = new CopyOnWriteArrayList(popNotificationList).iterator();
            while (it.hasNext()) {
                dismiss(((PopNotification) it.next()).dialogView);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x0078, code lost:
        if (r3 != 5) goto L26;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void moveUp(int newDialogHeight) {
        float f;
        if (getDialogImpl() == null || getDialogImpl().boxBody == null) {
            return;
        }
        ViewGroup viewGroup = getDialogImpl().boxBody;
        if (getDialogImpl() == null || viewGroup == null) {
            return;
        }
        if (this.style.popNotificationSettings() != null) {
            this.align = this.style.popNotificationSettings().align();
        }
        if (this.align == null) {
            this.align = DialogXStyle.PopNotificationSettings.ALIGN.TOP;
        }
        float f2 = 0.0f;
        float y = viewGroup.getY();
        if (viewGroup.getTag() instanceof PopValueAnimator) {
            ((PopValueAnimator) viewGroup.getTag()).end();
            y = ((PopValueAnimator) viewGroup.getTag()).getEndValue();
        }
        int i2 = AnonymousClass6.$SwitchMap$com$kongzue$dialogx$interfaces$DialogXStyle$PopNotificationSettings$ALIGN[this.align.ordinal()];
        if (i2 != 1) {
            if (i2 != 2 && i2 != 3) {
                if (i2 == 4) {
                    y += newDialogHeight;
                    f = viewGroup.getPaddingTop();
                    f2 = y - f;
                }
            }
            f = newDialogHeight * 1.1f;
            f2 = y - f;
        } else {
            f2 = y + (newDialogHeight * 1.1f);
        }
        PopValueAnimator ofFloat = PopValueAnimator.ofFloat(viewGroup.getY(), f2);
        viewGroup.setTag(ofFloat);
        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.dialogs.PopNotification.2
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                if (PopNotification.this.getDialogImpl() != null && PopNotification.this.isShow) {
                    ViewGroup viewGroup2 = PopNotification.this.getDialogImpl().boxBody;
                    if (viewGroup2 == null || !viewGroup2.isAttachedToWindow()) {
                        return;
                    }
                    viewGroup2.setY(((Float) animation.getAnimatedValue()).floatValue());
                    return;
                }
                animation.cancel();
            }
        });
        ofFloat.setDuration(this.enterAnimDuration == -1 ? 300L : this.enterAnimDuration).setInterpolator(new DecelerateInterpolator(2.0f));
        ofFloat.start();
    }

    public void refreshUI() {
        if (getDialogImpl() == null) {
            return;
        }
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.PopNotification.3
            @Override // java.lang.Runnable
            public void run() {
                if (PopNotification.this.dialogImpl != null) {
                    PopNotification.this.dialogImpl.refreshView();
                }
            }
        });
    }

    public void dismiss() {
        runOnMain(new Runnable() { // from class: com.kongzue.dialogx.dialogs.PopNotification.4
            @Override // java.lang.Runnable
            public void run() {
                if (PopNotification.this.dialogImpl == null) {
                    return;
                }
                PopNotification.this.dialogImpl.doDismiss(null);
            }
        });
    }

    public DialogLifecycleCallback<PopNotification> getDialogLifecycleCallback() {
        DialogLifecycleCallback<PopNotification> dialogLifecycleCallback = this.dialogLifecycleCallback;
        return dialogLifecycleCallback == null ? new DialogLifecycleCallback<PopNotification>() { // from class: com.kongzue.dialogx.dialogs.PopNotification.5
        } : dialogLifecycleCallback;
    }

    public PopNotification setDialogLifecycleCallback(DialogLifecycleCallback<PopNotification> dialogLifecycleCallback) {
        this.dialogLifecycleCallback = dialogLifecycleCallback;
        if (this.isShow) {
            dialogLifecycleCallback.onShow(this.f977me);
        }
        return this;
    }

    public PopNotification setStyle(DialogXStyle style) {
        this.style = style;
        return this;
    }

    public PopNotification setTheme(DialogX.THEME theme) {
        this.theme = theme;
        return this;
    }

    public DialogImpl getDialogImpl() {
        return this.dialogImpl;
    }

    public PopNotification setCustomView(OnBindView<PopNotification> onBindView) {
        this.onBindView = onBindView;
        refreshUI();
        return this;
    }

    public View getCustomView() {
        OnBindView<PopNotification> onBindView = this.onBindView;
        if (onBindView == null) {
            return null;
        }
        return onBindView.getCustomView();
    }

    public PopNotification removeCustomView() {
        this.onBindView.clean();
        refreshUI();
        return this;
    }

    public DialogXStyle.PopNotificationSettings.ALIGN getAlign() {
        return this.align;
    }

    public PopNotification setAlign(DialogXStyle.PopNotificationSettings.ALIGN align) {
        this.align = align;
        return this;
    }

    public int getIconResId() {
        return this.iconResId;
    }

    public PopNotification setIconResId(int iconResId) {
        this.iconResId = iconResId;
        refreshUI();
        return this;
    }

    public PopNotification setIcon(Bitmap bitmap) {
        this.iconBitmap = bitmap;
        refreshUI();
        return this;
    }

    public PopNotification setIcon(Drawable iconDrawable) {
        this.iconDrawable = iconDrawable;
        return this;
    }

    public int getIconSize() {
        return this.iconSize;
    }

    public PopNotification setIconSize(int iconSize) {
        this.iconSize = iconSize;
        refreshUI();
        return this;
    }

    public CharSequence getMessage() {
        return this.message;
    }

    public PopNotification setMessage(CharSequence message) {
        this.message = message;
        refreshUI();
        return this;
    }

    public PopNotification setMessage(int messageResId) {
        this.message = getString(messageResId);
        refreshUI();
        return this;
    }

    public CharSequence getButtonText() {
        return this.buttonText;
    }

    public PopNotification setButton(CharSequence buttonText) {
        this.buttonText = buttonText;
        refreshUI();
        return this;
    }

    public PopNotification setButton(int buttonTextResId) {
        this.buttonText = getString(buttonTextResId);
        refreshUI();
        return this;
    }

    public PopNotification setButton(CharSequence buttonText, OnDialogButtonClickListener<PopNotification> onButtonClickListener) {
        this.buttonText = buttonText;
        this.onButtonClickListener = onButtonClickListener;
        refreshUI();
        return this;
    }

    public PopNotification setButton(int buttonTextResId, OnDialogButtonClickListener<PopNotification> onButtonClickListener) {
        this.buttonText = getString(buttonTextResId);
        this.onButtonClickListener = onButtonClickListener;
        refreshUI();
        return this;
    }

    public PopNotification setButton(OnDialogButtonClickListener<PopNotification> onButtonClickListener) {
        this.onButtonClickListener = onButtonClickListener;
        return this;
    }

    public TextInfo getMessageTextInfo() {
        return this.messageTextInfo;
    }

    public PopNotification setMessageTextInfo(TextInfo messageTextInfo) {
        this.messageTextInfo = messageTextInfo;
        refreshUI();
        return this;
    }

    public TextInfo getButtonTextInfo() {
        return this.buttonTextInfo;
    }

    public PopNotification setButtonTextInfo(TextInfo buttonTextInfo) {
        this.buttonTextInfo = buttonTextInfo;
        refreshUI();
        return this;
    }

    public OnDialogButtonClickListener<PopNotification> getOnButtonClickListener() {
        return this.onButtonClickListener;
    }

    public PopNotification setOnButtonClickListener(OnDialogButtonClickListener<PopNotification> onButtonClickListener) {
        this.onButtonClickListener = onButtonClickListener;
        return this;
    }

    public boolean isAutoTintIconInLightOrDarkMode() {
        return this.autoTintIconInLightOrDarkMode;
    }

    public PopNotification setAutoTintIconInLightOrDarkMode(boolean autoTintIconInLightOrDarkMode) {
        this.autoTintIconInLightOrDarkMode = autoTintIconInLightOrDarkMode;
        refreshUI();
        return this;
    }

    public OnDialogButtonClickListener<PopNotification> getOnPopNotificationClickListener() {
        return this.onPopNotificationClickListener;
    }

    public PopNotification setOnPopNotificationClickListener(OnDialogButtonClickListener<PopNotification> onPopNotificationClickListener) {
        this.onPopNotificationClickListener = onPopNotificationClickListener;
        refreshUI();
        return this;
    }

    public int getBackgroundColor() {
        return this.backgroundColor;
    }

    public PopNotification setBackgroundColor(int backgroundColor) {
        this.backgroundColor = backgroundColor;
        refreshUI();
        return this;
    }

    public PopNotification setBackgroundColorRes(int backgroundColorResId) {
        this.backgroundColor = getColor(backgroundColorResId);
        refreshUI();
        return this;
    }

    public long getEnterAnimDuration() {
        return this.enterAnimDuration;
    }

    public PopNotification setEnterAnimDuration(long enterAnimDuration) {
        this.enterAnimDuration = enterAnimDuration;
        return this;
    }

    public long getExitAnimDuration() {
        return this.exitAnimDuration;
    }

    public PopNotification setExitAnimDuration(long exitAnimDuration) {
        this.exitAnimDuration = exitAnimDuration;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    public void restartDialog() {
        View view = this.dialogView;
        if (view != null) {
            dismiss(view);
            this.isShow = false;
        }
        if (getDialogImpl().boxCustom != null) {
            getDialogImpl().boxCustom.removeAllViews();
        }
        if (DialogX.onlyOnePopNotification) {
            PopNotification popNotification = null;
            List<PopNotification> list = popNotificationList;
            if (list != null && !list.isEmpty()) {
                List<PopNotification> list2 = popNotificationList;
                popNotification = list2.get(list2.size() - 1);
            }
            if (popNotification != null) {
                popNotification.dismiss();
            }
        }
        if (popNotificationList == null) {
            popNotificationList = new ArrayList();
        }
        popNotificationList.add(this);
        int i2 = isLightTheme() ? R.layout.layout_dialogx_popnotification_material : R.layout.layout_dialogx_popnotification_material_dark;
        if (this.style.popNotificationSettings() != null) {
            if (this.style.popNotificationSettings().layout(isLightTheme()) != 0) {
                i2 = this.style.popNotificationSettings().layout(isLightTheme());
            }
            DialogXStyle.PopNotificationSettings.ALIGN align = this.style.popNotificationSettings().align();
            this.align = align;
            if (align == null) {
                this.align = DialogXStyle.PopNotificationSettings.ALIGN.TOP;
            }
            int enterAnimResId = this.style.popNotificationSettings().enterAnimResId(isLightTheme());
            int exitAnimResId = this.style.popNotificationSettings().exitAnimResId(isLightTheme());
            int i3 = this.enterAnimResId;
            if (i3 != 0 || (i3 = overrideEnterAnimRes) != 0) {
                enterAnimResId = i3;
            } else if (enterAnimResId == 0) {
                enterAnimResId = R.anim.anim_dialogx_notification_enter;
            }
            this.enterAnimResId = enterAnimResId;
            int i4 = this.exitAnimResId;
            if (i4 != 0 || (i4 = overrideExitAnimRes) != 0) {
                exitAnimResId = i4;
            } else if (exitAnimResId == 0) {
                exitAnimResId = R.anim.anim_dialogx_notification_exit;
            }
            this.exitAnimResId = exitAnimResId;
            this.enterAnimDuration = this.enterAnimDuration == -1 ? overrideEnterDuration : this.enterAnimDuration;
            this.exitAnimDuration = this.exitAnimDuration == -1 ? overrideExitDuration : this.exitAnimDuration;
        }
        this.enterAnimDuration = 0L;
        this.dialogView = createView(i2);
        this.dialogImpl = new DialogImpl(this.dialogView);
        View view2 = this.dialogView;
        if (view2 != null) {
            view2.setTag(this.f977me);
        }
        show(this.dialogView);
    }

    public void hide() {
        this.isHide = true;
        if (getDialogView() != null) {
            getDialogView().setVisibility(8);
        }
    }

    public PopNotification setAnimResId(int enterResId, int exitResId) {
        this.enterAnimResId = enterResId;
        this.exitAnimResId = exitResId;
        return this;
    }

    public PopNotification setEnterAnimResId(int enterResId) {
        this.enterAnimResId = enterResId;
        return this;
    }

    public PopNotification setExitAnimResId(int exitResId) {
        this.exitAnimResId = exitResId;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.BaseDialog
    protected void shutdown() {
        dismiss();
    }

    public PopNotification setDialogImplMode(DialogX.IMPL_MODE dialogImplMode) {
        this.dialogImplMode = dialogImplMode;
        return this;
    }

    public PopNotification setMargin(int left, int top2, int right, int bottom) {
        int[] iArr = this.bodyMargin;
        iArr[0] = left;
        iArr[1] = top2;
        iArr[2] = right;
        iArr[3] = bottom;
        refreshUI();
        return this;
    }

    public PopNotification setMarginLeft(int left) {
        this.bodyMargin[0] = left;
        refreshUI();
        return this;
    }

    public PopNotification setMarginTop(int top2) {
        this.bodyMargin[1] = top2;
        refreshUI();
        return this;
    }

    public PopNotification setMarginRight(int right) {
        this.bodyMargin[2] = right;
        refreshUI();
        return this;
    }

    public PopNotification setMarginBottom(int bottom) {
        this.bodyMargin[3] = bottom;
        refreshUI();
        return this;
    }

    public int getMarginLeft() {
        return this.bodyMargin[0];
    }

    public int getMarginTop() {
        return this.bodyMargin[1];
    }

    public int getMarginRight() {
        return this.bodyMargin[2];
    }

    public int getMarginBottom() {
        return this.bodyMargin[3];
    }

    public PopNotification iconSuccess() {
        setTintIcon(false);
        int i2 = R.mipmap.ico_dialogx_success;
        if (getStyle().popNotificationSettings() != null && getStyle().popNotificationSettings().defaultIconSuccess() != 0) {
            i2 = getStyle().popNotificationSettings().defaultIconSuccess();
        }
        setIconSize(dip2px(26.0f));
        setIconResId(i2);
        return this;
    }

    public PopNotification iconWarning() {
        setTintIcon(false);
        int i2 = R.mipmap.ico_dialogx_warning;
        if (getStyle().popNotificationSettings() != null && getStyle().popNotificationSettings().defaultIconWarning() != 0) {
            i2 = getStyle().popNotificationSettings().defaultIconWarning();
        }
        setIconSize(dip2px(26.0f));
        setIconResId(i2);
        return this;
    }

    public PopNotification iconError() {
        setTintIcon(false);
        int i2 = R.mipmap.ico_dialogx_error;
        if (getStyle().popNotificationSettings() != null && getStyle().popNotificationSettings().defaultIconError() != 0) {
            i2 = getStyle().popNotificationSettings().defaultIconError();
        }
        setIconSize(dip2px(26.0f));
        setIconResId(i2);
        return this;
    }

    public boolean getTintIcon() {
        return this.tintIcon == BaseDialog.BOOLEAN.TRUE;
    }

    public PopNotification setTintIcon(boolean tintIcon) {
        this.tintIcon = tintIcon ? BaseDialog.BOOLEAN.TRUE : BaseDialog.BOOLEAN.FALSE;
        refreshUI();
        return this;
    }

    public Drawable getIconDrawable() {
        return this.iconDrawable;
    }

    public Bitmap getIconBitmap() {
        return this.iconBitmap;
    }

    public CharSequence getTitle() {
        return this.title;
    }

    public PopNotification setTitle(CharSequence title) {
        this.title = title;
        refreshUI();
        return this;
    }

    public TextInfo getTitleTextInfo() {
        return this.titleTextInfo;
    }

    public PopNotification setTitleTextInfo(TextInfo titleTextInfo) {
        this.titleTextInfo = titleTextInfo;
        refreshUI();
        return this;
    }

    public PopNotification setRadius(float radiusPx) {
        this.backgroundRadius = radiusPx;
        refreshUI();
        return this;
    }

    public float getRadius() {
        return this.backgroundRadius;
    }

    public DialogXAnimInterface<PopNotification> getDialogXAnimImpl() {
        return this.dialogXAnimImpl;
    }

    public PopNotification setDialogXAnimImpl(DialogXAnimInterface<PopNotification> dialogXAnimImpl) {
        this.dialogXAnimImpl = dialogXAnimImpl;
        return this;
    }
}
