package com.kongzue.dialogx.interfaces;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowInsets;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.FrameLayout;
import android.widget.TextView;
import androidx.appcompat.app.AppCompatActivity;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import androidx.core.view.ViewCompat;
import androidx.fragment.app.FragmentManager;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleEventObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.impl.ActivityLifecycleImpl;
import com.kongzue.dialogx.impl.DialogFragmentImpl;
import com.kongzue.dialogx.util.ActivityRunnable;
import com.kongzue.dialogx.util.DialogListBuilder;
import com.kongzue.dialogx.util.DialogXFloatingWindowActivity;
import com.kongzue.dialogx.util.TextInfo;
import com.kongzue.dialogx.util.WindowUtil;
import com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;
/* loaded from: classes10.dex */
public abstract class BaseDialog implements LifecycleOwner {
    private static WeakReference<Activity> activityWeakReference;
    static WeakReference<Handler> mMainHandler;
    private static WeakReference<FrameLayout> rootFrameLayout;
    private static List<BaseDialog> runningDialogList;
    private static Thread uiThread;
    private static Map<String, ActivityRunnable> waitRunDialogX;
    protected static WindowInsets windowInsets;
    protected boolean cancelable;
    private WeakReference<DialogListBuilder> dialogListBuilder;
    private WeakReference<View> dialogView;
    protected boolean dismissAnimFlag;
    protected long enterAnimDuration;
    protected long exitAnimDuration;
    protected WeakReference<DialogXFloatingWindowActivity> floatingWindowActivity;
    protected boolean isShow;
    protected int maxWidth;
    protected WeakReference<Activity> ownActivity;
    protected WeakReference<DialogFragmentImpl> ownDialogFragmentImpl;
    protected boolean preShow;
    protected DialogX.IMPL_MODE dialogImplMode = DialogX.implIMPLMode;
    protected LifecycleRegistry lifecycle = new LifecycleRegistry(this);
    protected int backgroundColor = -1;
    protected DialogXStyle style = DialogX.globalStyle;
    protected DialogX.THEME theme = DialogX.globalTheme;
    protected boolean autoShowInputKeyboard = DialogX.autoShowInputKeyboard;

    /* loaded from: classes10.dex */
    public enum BOOLEAN {
        TRUE,
        FALSE
    }

    public abstract String dialogKey();

    public abstract boolean isCancelable();

    /* JADX INFO: Access modifiers changed from: protected */
    public void onDialogInit() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void onDialogRefreshUI() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void onDialogShow() {
    }

    public abstract void restartDialog();

    public abstract <D extends BaseDialog> D show();

    protected abstract void shutdown();

    public static void init(Context context) {
        if (context == null) {
            context = ActivityLifecycleImpl.getTopActivity();
        }
        if (context instanceof Activity) {
            initActivityContext((Activity) context);
        }
        ActivityLifecycleImpl.init(context, new ActivityLifecycleImpl.onActivityResumeCallBack() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.1
            @Override // com.kongzue.dialogx.impl.ActivityLifecycleImpl.onActivityResumeCallBack
            public void getActivity(Activity activity) {
                BaseDialog.initActivityContext(activity);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void initActivityContext(Activity activity) {
        try {
            uiThread = Looper.getMainLooper().getThread();
            activityWeakReference = new WeakReference<>(activity);
            rootFrameLayout = new WeakReference<>((FrameLayout) activity.getWindow().getDecorView());
            if (Build.VERSION.SDK_INT >= 23) {
                publicWindowInsets(rootFrameLayout.get().getRootWindowInsets());
            }
        } catch (Exception e) {
            e.printStackTrace();
            error("DialogX.init: 初始化异常，找不到Activity的根布局");
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void log(Object o) {
        if (DialogX.DEBUGMODE) {
            Log.i(">>>", o.toString());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void error(Object o) {
        if (DialogX.DEBUGMODE) {
            Log.e(">>>", o.toString());
        }
    }

    public static void onActivityResume(Activity activity) {
        if (runningDialogList != null) {
            CopyOnWriteArrayList copyOnWriteArrayList = new CopyOnWriteArrayList(runningDialogList);
            for (int size = copyOnWriteArrayList.size() - 1; size >= 0; size--) {
                BaseDialog baseDialog = (BaseDialog) copyOnWriteArrayList.get(size);
                if (baseDialog.getOwnActivity() == activity && baseDialog.isShow && baseDialog.getDialogView() != null) {
                    View findViewById = baseDialog.getDialogView().findViewById(R.id.box_root);
                    if ((findViewById instanceof DialogXBaseRelativeLayout) && ((DialogXBaseRelativeLayout) findViewById).isBaseFocusable()) {
                        findViewById.requestFocus();
                        return;
                    }
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void requestDialogFocus() {
        if (getTopActivity() instanceof Activity) {
            onActivityResume(getTopActivity());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void show(final View view) {
        BaseDialog baseDialog;
        if (view == null || (baseDialog = (BaseDialog) view.getTag()) == null) {
            return;
        }
        if (baseDialog.isShow) {
            if (baseDialog.getDialogView() != null) {
                baseDialog.getDialogView().setVisibility(0);
                return;
            } else {
                error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
                return;
            }
        }
        baseDialog.ownActivity = new WeakReference<>(getTopActivity());
        baseDialog.dialogView = new WeakReference<>(view);
        log(baseDialog.dialogKey() + ".show");
        addDialogToRunningList(baseDialog);
        int i2 = AnonymousClass8.$SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[baseDialog.dialogImplMode.ordinal()];
        if (i2 == 1) {
            WindowUtil.show(getTopActivity(), view, !(baseDialog instanceof NoTouchInterface));
        } else if (i2 == 2) {
            DialogFragmentImpl dialogFragmentImpl = new DialogFragmentImpl(baseDialog, view);
            dialogFragmentImpl.show(getSupportFragmentManager(getTopActivity()), "DialogX");
            baseDialog.ownDialogFragmentImpl = new WeakReference<>(dialogFragmentImpl);
        } else if (i2 == 3) {
            if (waitRunDialogX == null) {
                waitRunDialogX = new HashMap();
            }
            waitRunDialogX.put(baseDialog.dialogKey(), new ActivityRunnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.2
                @Override // com.kongzue.dialogx.util.ActivityRunnable
                public void run(Activity activity) {
                    BaseDialog.this.floatingWindowActivity = new WeakReference<>((DialogXFloatingWindowActivity) activity);
                    final FrameLayout frameLayout = (FrameLayout) activity.getWindow().getDecorView();
                    if (frameLayout == null) {
                        return;
                    }
                    BaseDialog.runOnMain(new Runnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.2.1
                        @Override // java.lang.Runnable
                        public void run() {
                            if (view.getParent() == BaseDialog.rootFrameLayout.get()) {
                                BaseDialog.error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
                                return;
                            }
                            if (view.getParent() != null) {
                                ((ViewGroup) view.getParent()).removeView(view);
                            }
                            frameLayout.addView(view);
                        }
                    });
                }
            });
            DialogXFloatingWindowActivity dialogXFloatingWindowActivity = DialogXFloatingWindowActivity.getDialogXFloatingWindowActivity();
            if (dialogXFloatingWindowActivity != null && dialogXFloatingWindowActivity.isSameFrom(getTopActivity().hashCode())) {
                dialogXFloatingWindowActivity.showDialogX(baseDialog.dialogKey());
                return;
            }
            Intent intent = new Intent(getContext(), DialogXFloatingWindowActivity.class);
            if (getTopActivity() == null) {
                intent.addFlags(268435456);
            }
            intent.putExtra("dialogXKey", baseDialog.dialogKey());
            intent.putExtra("fromActivityUiStatus", getTopActivity() == null ? 0 : getTopActivity().getWindow().getDecorView().getSystemUiVisibility());
            intent.putExtra(TypedValues.TransitionType.S_FROM, getContext().hashCode());
            getContext().startActivity(intent);
            if (Integer.valueOf(Build.VERSION.SDK_INT).intValue() <= 5 || getTopActivity() == null) {
                return;
            }
            getTopActivity().overridePendingTransition(0, 0);
        } else {
            WeakReference<FrameLayout> weakReference = rootFrameLayout;
            if (weakReference == null || weakReference.get() == null) {
                return;
            }
            runOnMain(new Runnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.3
                @Override // java.lang.Runnable
                public void run() {
                    if (view.getParent() == BaseDialog.rootFrameLayout.get()) {
                        BaseDialog.error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
                        return;
                    }
                    if (view.getParent() != null) {
                        ((ViewGroup) view.getParent()).removeView(view);
                    }
                    ((FrameLayout) BaseDialog.rootFrameLayout.get()).addView(view);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.kongzue.dialogx.interfaces.BaseDialog$8  reason: invalid class name */
    /* loaded from: classes10.dex */
    public static /* synthetic */ class AnonymousClass8 {
        static final /* synthetic */ int[] $SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE;

        static {
            int[] iArr = new int[DialogX.IMPL_MODE.values().length];
            $SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE = iArr;
            try {
                iArr[DialogX.IMPL_MODE.WINDOW.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[DialogX.IMPL_MODE.DIALOG_FRAGMENT.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[DialogX.IMPL_MODE.FLOATING_ACTIVITY.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    private static FragmentManager getSupportFragmentManager(Activity activity) {
        if (activity instanceof AppCompatActivity) {
            return ((AppCompatActivity) activity).getSupportFragmentManager();
        }
        return null;
    }

    public static ActivityRunnable getActivityRunnable(String dialogXKey) {
        if (dialogXKey == null) {
            return null;
        }
        return waitRunDialogX.get(dialogXKey);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void show(final Activity activity, final View view) {
        BaseDialog baseDialog;
        if (activity == null || view == null || (baseDialog = (BaseDialog) view.getTag()) == null) {
            return;
        }
        if (baseDialog.getDialogView() != null) {
            baseDialog.getDialogView().setVisibility(0);
        }
        if (baseDialog.isShow) {
            error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
        } else if (activity.isDestroyed()) {
            error(((BaseDialog) view.getTag()).dialogKey() + ".show ERROR: activity is Destroyed.");
        } else {
            baseDialog.ownActivity = new WeakReference<>(activity);
            baseDialog.dialogView = new WeakReference<>(view);
            log(baseDialog + ".show");
            addDialogToRunningList(baseDialog);
            int i2 = AnonymousClass8.$SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[baseDialog.dialogImplMode.ordinal()];
            if (i2 == 1) {
                WindowUtil.show(activity, view, !(baseDialog instanceof NoTouchInterface));
            } else if (i2 == 2) {
                DialogFragmentImpl dialogFragmentImpl = new DialogFragmentImpl(baseDialog, view);
                dialogFragmentImpl.show(getSupportFragmentManager(activity), "DialogX");
                baseDialog.ownDialogFragmentImpl = new WeakReference<>(dialogFragmentImpl);
            } else if (i2 == 3) {
                if (waitRunDialogX == null) {
                    waitRunDialogX = new HashMap();
                }
                waitRunDialogX.put(baseDialog.dialogKey(), new ActivityRunnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.4
                    @Override // com.kongzue.dialogx.util.ActivityRunnable
                    public void run(Activity activity2) {
                        BaseDialog.this.floatingWindowActivity = new WeakReference<>((DialogXFloatingWindowActivity) activity2);
                        final FrameLayout frameLayout = (FrameLayout) activity2.getWindow().getDecorView();
                        if (frameLayout == null) {
                            return;
                        }
                        BaseDialog.runOnMain(new Runnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.4.1
                            @Override // java.lang.Runnable
                            public void run() {
                                if (view.getParent() == BaseDialog.rootFrameLayout.get()) {
                                    BaseDialog.error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
                                    return;
                                }
                                if (view.getParent() != null) {
                                    ((ViewGroup) view.getParent()).removeView(view);
                                }
                                frameLayout.addView(view);
                            }
                        });
                    }
                });
                DialogXFloatingWindowActivity dialogXFloatingWindowActivity = DialogXFloatingWindowActivity.getDialogXFloatingWindowActivity();
                if (dialogXFloatingWindowActivity != null && dialogXFloatingWindowActivity.isSameFrom(activity.hashCode())) {
                    dialogXFloatingWindowActivity.showDialogX(baseDialog.dialogKey());
                    return;
                }
                Intent intent = new Intent(activity, DialogXFloatingWindowActivity.class);
                intent.putExtra("dialogXKey", baseDialog.dialogKey());
                intent.putExtra(TypedValues.TransitionType.S_FROM, activity.hashCode());
                intent.putExtra("fromActivityUiStatus", activity.getWindow().getDecorView().getSystemUiVisibility());
                activity.startActivity(intent);
                if (Integer.valueOf(Build.VERSION.SDK_INT).intValue() > 5) {
                    activity.overridePendingTransition(0, 0);
                }
            } else {
                final FrameLayout frameLayout = (FrameLayout) activity.getWindow().getDecorView();
                if (frameLayout == null) {
                    return;
                }
                runOnMain(new Runnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.5
                    @Override // java.lang.Runnable
                    public void run() {
                        if (view.getParent() == BaseDialog.rootFrameLayout.get()) {
                            BaseDialog.error(((BaseDialog) view.getTag()).dialogKey() + "已处于显示状态，请勿重复执行 show() 指令。");
                            return;
                        }
                        if (view.getParent() != null) {
                            ((ViewGroup) view.getParent()).removeView(view);
                        }
                        frameLayout.addView(view);
                    }
                });
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void dismiss(final View dialogView) {
        if (dialogView == null) {
            return;
        }
        BaseDialog baseDialog = (BaseDialog) dialogView.getTag();
        log(baseDialog.dialogKey() + ".dismiss");
        removeDialogToRunningList(baseDialog);
        WeakReference<View> weakReference = baseDialog.dialogView;
        if (weakReference != null) {
            weakReference.clear();
        }
        int i2 = AnonymousClass8.$SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[baseDialog.dialogImplMode.ordinal()];
        if (i2 == 1) {
            WindowUtil.dismiss(dialogView);
        } else if (i2 == 2) {
            WeakReference<DialogFragmentImpl> weakReference2 = baseDialog.ownDialogFragmentImpl;
            if (weakReference2 != null && weakReference2.get() != null) {
                baseDialog.ownDialogFragmentImpl.get().dismiss();
            }
        } else if (i2 == 3) {
            WeakReference<DialogXFloatingWindowActivity> weakReference3 = baseDialog.floatingWindowActivity;
            if (weakReference3 != null && weakReference3.get() != null) {
                FrameLayout frameLayout = (FrameLayout) baseDialog.floatingWindowActivity.get().getWindow().getDecorView();
                if (frameLayout != null) {
                    frameLayout.removeView(dialogView);
                }
                baseDialog.floatingWindowActivity.get().finish(baseDialog.dialogKey());
                requestDialogFocus();
            }
        } else {
            runOnMain(new Runnable() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.6
                @Override // java.lang.Runnable
                public void run() {
                    if (dialogView.getParent() == null || !(dialogView.getParent() instanceof ViewGroup)) {
                        if (BaseDialog.rootFrameLayout == null) {
                            return;
                        }
                        ((FrameLayout) BaseDialog.rootFrameLayout.get()).removeView(dialogView);
                    } else {
                        ((ViewGroup) dialogView.getParent()).removeView(dialogView);
                    }
                    BaseDialog.requestDialogFocus();
                }
            }, true);
        }
        if (baseDialog.getDialogListBuilder() == null || baseDialog.getDialogListBuilder().isEmpty()) {
            return;
        }
        baseDialog.getDialogListBuilder().showNext();
    }

    private static void addDialogToRunningList(BaseDialog baseDialog) {
        if (runningDialogList == null) {
            runningDialogList = new CopyOnWriteArrayList();
        }
        runningDialogList.add(baseDialog);
    }

    private static void removeDialogToRunningList(BaseDialog baseDialog) {
        List<BaseDialog> list = runningDialogList;
        if (list != null) {
            list.remove(baseDialog);
        }
    }

    public static Activity getTopActivity() {
        WeakReference<Activity> weakReference = activityWeakReference;
        if (weakReference == null) {
            init(null);
            WeakReference<Activity> weakReference2 = activityWeakReference;
            if (weakReference2 == null) {
                return ActivityLifecycleImpl.getTopActivity();
            }
            return weakReference2.get();
        }
        return weakReference.get();
    }

    public static Context getContext() {
        Activity topActivity = getTopActivity();
        if (topActivity == null) {
            Context applicationContext = getApplicationContext();
            if (applicationContext == null) {
                error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
                return null;
            }
            return applicationContext;
        }
        return topActivity;
    }

    public static Context getApplicationContext() {
        return ActivityLifecycleImpl.getApplicationContext();
    }

    public static void cleanContext() {
        WeakReference<Activity> weakReference = activityWeakReference;
        if (weakReference != null) {
            weakReference.clear();
        }
        activityWeakReference = null;
        System.gc();
    }

    public BaseDialog() {
        this.cancelable = true;
        this.enterAnimDuration = -1L;
        this.exitAnimDuration = -1L;
        this.cancelable = DialogX.cancelable;
        this.enterAnimDuration = DialogX.enterAnimDuration;
        this.exitAnimDuration = DialogX.exitAnimDuration;
    }

    public View createView(int layoutId) {
        if (getApplicationContext() == null) {
            error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
            return null;
        }
        return LayoutInflater.from(getApplicationContext()).inflate(layoutId, (ViewGroup) null);
    }

    public boolean isShow() {
        return this.isShow;
    }

    public DialogXStyle getStyle() {
        return this.style;
    }

    public DialogX.THEME getTheme() {
        return this.theme;
    }

    public static void useTextInfo(TextView textView, TextInfo textInfo) {
        if (textInfo == null || textView == null) {
            return;
        }
        if (textInfo.getFontSize() > 0) {
            textView.setTextSize(textInfo.getFontSizeComplexUnit(), textInfo.getFontSize());
        }
        if (textInfo.getFontColor() != 1) {
            textView.setTextColor(textInfo.getFontColor());
        }
        if (textInfo.getGravity() != -1) {
            textView.setGravity(textInfo.getGravity());
        }
        if (textInfo.isShowEllipsis()) {
            textView.setEllipsize(TextUtils.TruncateAt.END);
        } else {
            textView.setEllipsize(null);
        }
        if (textInfo.getMaxLines() != -1) {
            textView.setMaxLines(textInfo.getMaxLines());
        } else {
            textView.setMaxLines(Integer.MAX_VALUE);
        }
        textView.getPaint().setFakeBoldText(textInfo.isBold());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void showText(TextView textView, CharSequence text) {
        if (textView == null) {
            return;
        }
        if (isNull(text)) {
            textView.setVisibility(8);
            textView.setText("");
            return;
        }
        textView.setVisibility(0);
        textView.setText(text);
    }

    public static boolean isNull(String s) {
        return s == null || s.trim().isEmpty() || "null".equals(s) || "(null)".equals(s);
    }

    public static boolean isNull(CharSequence c) {
        String valueOf = String.valueOf(c);
        return c == null || valueOf.trim().isEmpty() || "null".equals(valueOf) || "(null)".equals(valueOf);
    }

    public Resources getResources() {
        if (getApplicationContext() == null) {
            return Resources.getSystem();
        }
        return getApplicationContext().getResources();
    }

    public int dip2px(float dpValue) {
        return (int) ((dpValue * getResources().getDisplayMetrics().density) + 0.5f);
    }

    public boolean isLightTheme() {
        return this.theme == DialogX.THEME.AUTO ? getApplicationContext() == null ? this.theme == DialogX.THEME.LIGHT : (getResources().getConfiguration().uiMode & 48) == 16 : this.theme == DialogX.THEME.LIGHT;
    }

    public static FrameLayout getRootFrameLayout() {
        WeakReference<FrameLayout> weakReference = rootFrameLayout;
        if (weakReference == null) {
            error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
            return null;
        }
        return weakReference.get();
    }

    public void tintColor(View view, int color) {
        if (view != null && Build.VERSION.SDK_INT >= 21) {
            view.setBackgroundTintList(ColorStateList.valueOf(color));
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void beforeShow() {
        this.preShow = true;
        this.dismissAnimFlag = false;
        if (getTopActivity() == null) {
            init(null);
            if (getTopActivity() == null) {
                error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
                return;
            }
        }
        if (this.dialogImplMode != DialogX.IMPL_MODE.VIEW && (getTopActivity() instanceof LifecycleOwner)) {
            ((LifecycleOwner) getTopActivity()).getLifecycle().addObserver(new LifecycleEventObserver() { // from class: com.kongzue.dialogx.interfaces.BaseDialog.7
                @Override // androidx.lifecycle.LifecycleEventObserver
                public void onStateChanged(LifecycleOwner source, Lifecycle.Event event) {
                    if (event == Lifecycle.Event.ON_DESTROY) {
                        BaseDialog.recycleDialog(BaseDialog.getTopActivity());
                    }
                }
            });
        }
        View currentFocus = getTopActivity().getCurrentFocus();
        if (currentFocus != null) {
            ((InputMethodManager) getTopActivity().getSystemService("input_method")).hideSoftInputFromWindow(currentFocus.getWindowToken(), 2);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public String getString(int titleResId) {
        if (getApplicationContext() == null) {
            error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
            return null;
        }
        return getResources().getString(titleResId);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int getColor(int backgroundRes) {
        if (getApplicationContext() == null) {
            error("DialogX 未初始化。\n请检查是否在启动对话框前进行初始化操作，使用以下代码进行初始化：\nDialogX.init(context);\n\n另外建议您前往查看 DialogX 的文档进行使用：https://github.com/kongzue/DialogX");
            return ViewCompat.MEASURED_STATE_MASK;
        }
        return getResources().getColor(backgroundRes);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void runOnMain(Runnable runnable) {
        if (!DialogX.autoRunOnUIThread || (getUiThread() != null && Thread.currentThread() == getUiThread())) {
            runnable.run();
        } else {
            runOnMain(runnable, true);
        }
    }

    protected static Thread getUiThread() {
        if (uiThread == null) {
            uiThread = Looper.getMainLooper().getThread();
        }
        return uiThread;
    }

    protected static void runOnMain(Runnable runnable, boolean needWaitMainLooper) {
        getMainHandler().post(runnable);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public static void runOnMainDelay(Runnable runnable, long delay) {
        if (delay < 0) {
            return;
        }
        if (!DialogX.autoRunOnUIThread) {
            runnable.run();
        }
        getMainHandler().postDelayed(runnable, delay);
    }

    public View getDialogView() {
        WeakReference<View> weakReference = this.dialogView;
        if (weakReference == null) {
            return null;
        }
        return weakReference.get();
    }

    public Activity getOwnActivity() {
        WeakReference<Activity> weakReference = this.ownActivity;
        if (weakReference == null) {
            return null;
        }
        return weakReference.get();
    }

    protected void cleanActivityContext() {
        WeakReference<Activity> weakReference = this.ownActivity;
        if (weakReference != null) {
            weakReference.clear();
        }
        this.ownActivity = null;
    }

    public static void cleanAll() {
        if (runningDialogList != null) {
            Iterator it = new CopyOnWriteArrayList(runningDialogList).iterator();
            while (it.hasNext()) {
                BaseDialog baseDialog = (BaseDialog) it.next();
                if (baseDialog.isShow()) {
                    baseDialog.shutdown();
                }
                baseDialog.cleanActivityContext();
                runningDialogList.remove(baseDialog);
            }
        }
    }

    public static void recycleDialog(Activity activity) {
        WeakReference<View> weakReference;
        WeakReference<DialogFragmentImpl> weakReference2;
        int i2 = AnonymousClass8.$SwitchMap$com$kongzue$dialogx$DialogX$IMPL_MODE[DialogX.implIMPLMode.ordinal()];
        if (i2 != 1) {
            if (i2 == 2) {
                if (runningDialogList != null) {
                    Iterator it = new CopyOnWriteArrayList(runningDialogList).iterator();
                    while (it.hasNext()) {
                        BaseDialog baseDialog = (BaseDialog) it.next();
                        if (baseDialog.getOwnActivity() == activity && (weakReference2 = baseDialog.ownDialogFragmentImpl) != null && weakReference2.get() != null) {
                            baseDialog.ownDialogFragmentImpl.get().dismiss();
                        }
                    }
                }
            } else if (i2 != 3 && runningDialogList != null) {
                Iterator it2 = new CopyOnWriteArrayList(runningDialogList).iterator();
                while (it2.hasNext()) {
                    BaseDialog baseDialog2 = (BaseDialog) it2.next();
                    if (baseDialog2.getOwnActivity() == activity) {
                        baseDialog2.cleanActivityContext();
                        runningDialogList.remove(baseDialog2);
                    }
                }
            }
        } else if (runningDialogList != null) {
            Iterator it3 = new CopyOnWriteArrayList(runningDialogList).iterator();
            while (it3.hasNext()) {
                BaseDialog baseDialog3 = (BaseDialog) it3.next();
                if (baseDialog3.getOwnActivity() == activity && (weakReference = baseDialog3.dialogView) != null) {
                    WindowUtil.dismiss(weakReference.get());
                }
            }
        }
        if (activity == getTopActivity()) {
            cleanContext();
        }
    }

    public static List<BaseDialog> getRunningDialogList() {
        if (runningDialogList == null) {
            return new ArrayList();
        }
        return new CopyOnWriteArrayList(runningDialogList);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void imeShow(EditText editText, boolean show) {
        if (getTopActivity() == null) {
            return;
        }
        InputMethodManager inputMethodManager = (InputMethodManager) getTopActivity().getSystemService("input_method");
        if (show) {
            inputMethodManager.showSoftInput(editText, 0);
        } else {
            inputMethodManager.hideSoftInputFromWindow(editText.getWindowToken(), 0);
        }
    }

    public int getMaxWidth() {
        int i2 = this.maxWidth;
        return i2 == 0 ? DialogX.dialogMaxWidth : i2;
    }

    public DialogX.IMPL_MODE getDialogImplMode() {
        return this.dialogImplMode;
    }

    public static WindowInsets publicWindowInsets() {
        return windowInsets;
    }

    public static void publicWindowInsets(WindowInsets windowInsets2) {
        if (windowInsets2 != null) {
            windowInsets = windowInsets2;
        }
        if (runningDialogList != null) {
            CopyOnWriteArrayList copyOnWriteArrayList = new CopyOnWriteArrayList(runningDialogList);
            for (int size = copyOnWriteArrayList.size() - 1; size >= 0; size--) {
                BaseDialog baseDialog = (BaseDialog) copyOnWriteArrayList.get(size);
                if (baseDialog.isShow && baseDialog.getDialogView() != null) {
                    View findViewById = baseDialog.getDialogView().findViewById(R.id.box_root);
                    if (findViewById instanceof DialogXBaseRelativeLayout) {
                        log("publicWindowInsets");
                        ((DialogXBaseRelativeLayout) findViewById).paddingView(windowInsets2);
                    }
                }
            }
        }
    }

    protected void bindFloatingActivity(DialogXFloatingWindowActivity activity) {
        this.floatingWindowActivity = new WeakReference<>(activity);
    }

    private static Handler getMainHandler() {
        WeakReference<Handler> weakReference = mMainHandler;
        if (weakReference != null && weakReference.get() != null) {
            return mMainHandler.get();
        }
        WeakReference<Handler> weakReference2 = new WeakReference<>(new Handler(Looper.getMainLooper()));
        mMainHandler = weakReference2;
        return weakReference2.get();
    }

    public DialogListBuilder getDialogListBuilder() {
        WeakReference<DialogListBuilder> weakReference = this.dialogListBuilder;
        if (weakReference == null) {
            return null;
        }
        return weakReference.get();
    }

    public void setDialogListBuilder(DialogListBuilder dialogListBuilder) {
        this.dialogListBuilder = new WeakReference<>(dialogListBuilder);
    }

    public void cleanDialogList() {
        this.dialogListBuilder = null;
    }

    public boolean isPreShow() {
        return this.preShow;
    }

    @Override // androidx.lifecycle.LifecycleOwner
    public Lifecycle getLifecycle() {
        return this.lifecycle;
    }
}
