package com.kongzue.dialogx.interfaces;

import android.app.Activity;
import android.app.FragmentManager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentTransaction;
import com.kongzue.dialogx.DialogX;
import java.util.Random;
/* loaded from: classes10.dex */
public abstract class OnBindView<D> {
    View customView;
    private Fragment fragment;
    private int fragmentParentId = -1;
    int layoutResId;
    private android.app.Fragment supportFragment;
    private Runnable waitBindRunnable;

    public abstract void onBind(D dialog, View v);

    public void onFragmentBind(D dialog, View frameLayout, android.app.Fragment fragment, FragmentManager fragmentManager) {
    }

    public void onFragmentBind(D dialog, View frameLayout, Fragment fragment, androidx.fragment.app.FragmentManager fragmentManager) {
    }

    public OnBindView(int layoutResId) {
        if (BaseDialog.getTopActivity() == null) {
            DialogX.error(DialogX.ERROR_INIT_TIPS);
            return;
        }
        this.layoutResId = layoutResId;
        this.customView = LayoutInflater.from(BaseDialog.getTopActivity()).inflate(layoutResId, (ViewGroup) new RelativeLayout(BaseDialog.getTopActivity()), false);
    }

    /* JADX WARN: Type inference failed for: r4v3, types: [com.kongzue.dialogx.interfaces.OnBindView$1] */
    public OnBindView(final int layoutResId, boolean async) {
        if (BaseDialog.getTopActivity() == null) {
            DialogX.error(DialogX.ERROR_INIT_TIPS);
            return;
        }
        this.layoutResId = layoutResId;
        if (async) {
            new Thread() { // from class: com.kongzue.dialogx.interfaces.OnBindView.1
                @Override // java.lang.Thread, java.lang.Runnable
                public void run() {
                    super.run();
                    synchronized (OnBindView.this) {
                        OnBindView.this.customView = LayoutInflater.from(BaseDialog.getTopActivity()).inflate(layoutResId, (ViewGroup) new RelativeLayout(BaseDialog.getTopActivity()), false);
                        if (OnBindView.this.waitBindRunnable != null) {
                            OnBindView.this.waitBindRunnable.run();
                            OnBindView.this.waitBindRunnable = null;
                        }
                    }
                }
            }.start();
        } else {
            this.customView = LayoutInflater.from(BaseDialog.getTopActivity()).inflate(layoutResId, (ViewGroup) new RelativeLayout(BaseDialog.getTopActivity()), false);
        }
    }

    public OnBindView(View customView) {
        this.customView = customView;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int getFragmentParentId() {
        if (this.fragmentParentId == -1) {
            this.fragmentParentId = createFragmentParentId();
        }
        return this.fragmentParentId;
    }

    private int createFragmentParentId() {
        this.fragmentParentId = new Random().nextInt();
        if (BaseDialog.getTopActivity().findViewById(this.fragmentParentId) != null) {
            return createFragmentParentId();
        }
        return this.fragmentParentId;
    }

    public OnBindView(Fragment fragment) {
        if (BaseDialog.getTopActivity() == null) {
            return;
        }
        FrameLayout frameLayout = new FrameLayout(BaseDialog.getTopActivity());
        this.customView = frameLayout;
        frameLayout.setId(getFragmentParentId());
        this.fragment = fragment;
        this.supportFragment = null;
    }

    public OnBindView(android.app.Fragment supportFragment) {
        if (BaseDialog.getTopActivity() == null) {
            return;
        }
        FrameLayout frameLayout = new FrameLayout(BaseDialog.getTopActivity());
        this.customView = frameLayout;
        frameLayout.setId(getFragmentParentId());
        this.supportFragment = supportFragment;
        this.fragment = null;
    }

    public int getLayoutResId() {
        return this.layoutResId;
    }

    public OnBindView<D> setLayoutResId(int layoutResId) {
        this.layoutResId = layoutResId;
        return this;
    }

    public View getCustomView() {
        if (this.customView == null) {
            this.customView = LayoutInflater.from(BaseDialog.getTopActivity()).inflate(this.layoutResId, (ViewGroup) new RelativeLayout(BaseDialog.getTopActivity()), false);
        }
        return this.customView;
    }

    public OnBindView<D> setCustomView(View customView) {
        this.customView = customView;
        return this;
    }

    public void clean() {
        this.layoutResId = 0;
        this.customView = null;
    }

    @Deprecated
    public void bindParent(ViewGroup parentView) {
        if (getCustomView() == null) {
            waitBind(parentView, null);
            return;
        }
        if (getCustomView().getParent() != null) {
            if (getCustomView().getParent() == parentView) {
                return;
            }
            ((ViewGroup) getCustomView().getParent()).removeView(getCustomView());
        }
        ViewGroup.LayoutParams layoutParams = parentView.getLayoutParams();
        if (layoutParams == null) {
            layoutParams = new RelativeLayout.LayoutParams(-1, -2);
        }
        parentView.addView(getCustomView(), layoutParams);
    }

    /* JADX WARN: Multi-variable type inference failed */
    public void bindParent(ViewGroup parentView, final BaseDialog dialog) {
        if (getCustomView() == null) {
            waitBind(parentView, null);
            return;
        }
        if (getCustomView().getParent() != null) {
            if (getCustomView().getParent() == parentView) {
                return;
            }
            ((ViewGroup) getCustomView().getParent()).removeView(getCustomView());
        }
        ViewGroup.LayoutParams layoutParams = getCustomView().getLayoutParams();
        if (layoutParams == null) {
            layoutParams = new RelativeLayout.LayoutParams(-1, -2);
        }
        parentView.addView(getCustomView(), layoutParams);
        onBind(dialog, getCustomView());
        if (this.fragment == null && this.supportFragment == null) {
            return;
        }
        if (dialog.getDialogImplMode() != DialogX.IMPL_MODE.VIEW) {
            BaseDialog.error(dialog.dialogKey() + "非 VIEW 实现模式不支持 fragment 作为子布局显示。\n其原因为 Window 中不存在 FragmentManager，无法对子布局中的 fragment 进行管理。");
        } else {
            getCustomView().post(new Runnable() { // from class: com.kongzue.dialogx.interfaces.OnBindView.2
                @Override // java.lang.Runnable
                public void run() {
                    if (OnBindView.this.fragment != null && (OnBindView.this.getCustomView() instanceof FrameLayout) && (BaseDialog.getTopActivity() instanceof AppCompatActivity)) {
                        AppCompatActivity appCompatActivity = (AppCompatActivity) BaseDialog.getTopActivity();
                        FragmentTransaction beginTransaction = appCompatActivity.getSupportFragmentManager().beginTransaction();
                        beginTransaction.add(OnBindView.this.getFragmentParentId(), OnBindView.this.fragment);
                        beginTransaction.commit();
                        OnBindView onBindView = OnBindView.this;
                        onBindView.onFragmentBind((OnBindView) dialog, onBindView.getCustomView(), OnBindView.this.fragment, appCompatActivity.getSupportFragmentManager());
                    }
                    if (OnBindView.this.supportFragment != null && (OnBindView.this.getCustomView() instanceof FrameLayout) && (BaseDialog.getTopActivity() instanceof Activity)) {
                        Activity topActivity = BaseDialog.getTopActivity();
                        android.app.FragmentTransaction beginTransaction2 = topActivity.getFragmentManager().beginTransaction();
                        beginTransaction2.add(OnBindView.this.getFragmentParentId(), OnBindView.this.supportFragment);
                        beginTransaction2.commit();
                        OnBindView onBindView2 = OnBindView.this;
                        onBindView2.onFragmentBind((OnBindView) dialog, onBindView2.getCustomView(), OnBindView.this.supportFragment, topActivity.getFragmentManager());
                    }
                }
            });
        }
    }

    private void waitBind(final ViewGroup parentView, final BaseDialog dialog) {
        this.waitBindRunnable = new Runnable() { // from class: com.kongzue.dialogx.interfaces.OnBindView.3
            @Override // java.lang.Runnable
            public void run() {
                if (OnBindView.this.getCustomView() == null) {
                    BaseDialog baseDialog = dialog;
                    if (baseDialog == null) {
                        OnBindView.this.bindParent(parentView);
                    } else {
                        OnBindView.this.bindParent(parentView, baseDialog);
                    }
                }
            }
        };
    }
}
