package com.kongzue.dialogx.style.views;

import android.animation.TimeInterpolator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.LinearInterpolator;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.interfaces.ProgressViewInterface;
import com.kongzue.dialogx.iostheme.R;
/* loaded from: classes2.dex */
public class ProgressView extends View implements ProgressViewInterface {
    public static final int STATUS_ERROR = 3;
    public static final int STATUS_LOADING = 0;
    public static final int STATUS_PROGRESSING = 4;
    public static final int STATUS_SUCCESS = 1;
    public static final int STATUS_WARNING = 2;
    private int color;
    private float currentRotateDegrees;
    private ValueAnimator followAnimator;
    private float followRotateDegrees;
    private float halfSweepA;
    private float halfSweepAMaxValue;
    private float halfSweepAMinValue;
    private TimeInterpolator interpolator;
    private boolean isInited;
    private boolean isLightMode;
    private int line1X;
    private int line1Y;
    private int line2X;
    private int line2Y;
    private float mCenterX;
    private float mCenterY;
    Paint mPaint;
    private float mRadius;
    private boolean noShowLoading;
    protected float oldAnimAngle;
    private RectF oval;
    private Rect ovalInt;
    private ValueAnimator rotateAnimator;
    private int status;
    private int successStep;
    private Runnable tickShowRunnable;
    private int tickStep;
    private Runnable waitProgressingRunnable;
    private int width;

    public ProgressView(Context context) {
        super(context);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.tickStep = 0;
        init(null);
    }

    public ProgressView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.tickStep = 0;
        init(attrs);
    }

    public ProgressView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.tickStep = 0;
        init(attrs);
    }

    public boolean isLightMode() {
        return this.isLightMode;
    }

    public ProgressView setLightMode(boolean lightMode) {
        this.isLightMode = lightMode;
        return this;
    }

    private void init(AttributeSet attrs) {
        synchronized (ProgressView.class) {
            if (this.isInited) {
                return;
            }
            this.isInited = true;
            if (attrs != null) {
                TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attrs, R.styleable.ProgressView);
                this.width = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ProgressView_progressStrokeWidth, dip2px(2.0f));
                this.color = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ProgressView_progressStrokeColor, this.color);
                obtainStyledAttributes.recycle();
            }
            this.mPaint.setAntiAlias(true);
            this.mPaint.setStyle(Paint.Style.STROKE);
            this.mPaint.setStrokeWidth(this.width);
            this.mPaint.setStrokeCap(Paint.Cap.ROUND);
            this.mPaint.setColor(this.color);
            this.isLightMode = this.color != -1;
            if (!isInEditMode()) {
                this.halfSweepA = (this.halfSweepAMaxValue - this.halfSweepAMinValue) / 2.0f;
                ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 8.0f);
                this.rotateAnimator = ofFloat;
                ofFloat.setDuration(1000L);
                this.rotateAnimator.setInterpolator(new LinearInterpolator());
                this.rotateAnimator.setRepeatCount(-1);
                this.rotateAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.style.views.ProgressView.1
                    @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                    public void onAnimationUpdate(ValueAnimator animation) {
                        ProgressView.this.currentRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                        ProgressView.this.invalidate();
                    }
                });
                ValueAnimator ofFloat2 = ValueAnimator.ofFloat(0.0f, 365.0f);
                this.followAnimator = ofFloat2;
                ofFloat2.setDuration(1500L);
                this.followAnimator.setInterpolator(new LinearInterpolator());
                this.followAnimator.setRepeatCount(-1);
                this.followAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.style.views.ProgressView.2
                    @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                    public void onAnimationUpdate(ValueAnimator animation) {
                        ProgressView.this.followRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                    }
                });
                this.followAnimator.start();
                this.rotateAnimator.start();
            }
        }
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        int dip2px = dip2px(30.0f);
        this.mCenterX = (w * 1.0f) / 2.0f;
        this.mCenterY = (h * 1.0f) / 2.0f;
        this.mRadius = (dip2px / 2) - (this.width / 2);
        float f = this.mCenterX;
        float f2 = this.mRadius;
        float f3 = this.mCenterY;
        this.oval = new RectF(f - f2, f3 - f2, f + f2, f3 + f2);
        float f4 = this.mCenterX;
        float f5 = this.mRadius;
        float f6 = this.mCenterY;
        this.ovalInt = new Rect((int) (f4 - f5), (int) (f6 - f5), (int) (f4 + f5), (int) (f6 + f5));
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        Runnable runnable;
        if (isInEditMode()) {
            canvas.drawArc(this.oval, 0.0f, 365.0f, false, this.mPaint);
        } else if (this.noShowLoading) {
            this.successStep = 2;
            drawDoneMark(this.status, canvas);
        } else {
            Math.sin(Math.toRadians(this.followRotateDegrees));
            int i2 = this.status;
            if (i2 == 0) {
                Bitmap loadingBitmap = getLoadingBitmap();
                canvas.drawBitmap(getLoadingBitmap(), new Rect(0, 0, loadingBitmap.getWidth(), loadingBitmap.getHeight()), this.ovalInt, (Paint) null);
            } else if (i2 == 1 || i2 == 2 || i2 == 3) {
                drawDoneMark(i2, canvas);
            } else if (i2 != 4) {
            } else {
                canvas.drawArc(this.oval, -90.0f, this.currentRotateDegrees, false, this.mPaint);
                if (this.currentRotateDegrees != 365.0f || (runnable = this.waitProgressingRunnable) == null) {
                    return;
                }
                runnable.run();
                this.waitProgressingRunnable = null;
            }
        }
    }

    private Bitmap getLoadingBitmap() {
        Bitmap decodeResource = BitmapFactory.decodeResource(getResources(), this.isLightMode ? R.mipmap.img_progress_ios_light : R.mipmap.img_progress_ios_dark);
        Matrix matrix = new Matrix();
        matrix.setRotate(((int) this.currentRotateDegrees) * 45);
        Bitmap createBitmap = Bitmap.createBitmap(decodeResource, 0, 0, decodeResource.getWidth(), decodeResource.getHeight(), matrix, false);
        int width = (createBitmap.getWidth() / 2) - (decodeResource.getWidth() / 2);
        int height = (createBitmap.getHeight() / 2) - (decodeResource.getHeight() / 2);
        int width2 = decodeResource.getWidth();
        int height2 = decodeResource.getHeight();
        int i2 = width < 0 ? 0 : width;
        int i3 = height < 0 ? 0 : height;
        int width3 = i2 + width2 > createBitmap.getWidth() ? createBitmap.getWidth() - i2 : width2;
        if (i3 + height2 > createBitmap.getHeight()) {
            height2 = createBitmap.getHeight() - i3;
        }
        return Bitmap.createBitmap(createBitmap, i2, i3, width3, height2, (Matrix) null, false);
    }

    private void drawDoneMark(int status, Canvas canvas) {
        TimeInterpolator interpolator = this.rotateAnimator.getInterpolator();
        TimeInterpolator timeInterpolator = this.interpolator;
        if (interpolator != timeInterpolator) {
            this.rotateAnimator.setInterpolator(timeInterpolator);
        }
        Runnable runnable = this.tickShowRunnable;
        if (runnable != null) {
            runnable.run();
            if (DialogX.useHaptic) {
                performHapticFeedback(0);
            }
            this.tickShowRunnable = null;
        }
        if (status == 1) {
            showSuccessTick(canvas);
        } else if (status == 2) {
            showWarningTick(canvas);
        } else if (status != 3) {
        } else {
            showErrorTick(canvas);
        }
    }

    private void showSuccessTick(Canvas canvas) {
        int i2;
        float f = this.mCenterX;
        float f2 = this.mRadius;
        int i3 = (int) (f - (((f2 * 1.5d) * 1.0d) / 2.0d));
        int i4 = (int) (f - ((f2 * 1.5d) / 10.0d));
        int i5 = (int) (f2 * 1.5d * 0.9900000095367432d);
        int i6 = this.tickStep;
        if (i6 == 0) {
            int i7 = this.line1X;
            if (i3 + i7 < i4) {
                this.line1X = i7 + 2;
                this.line1Y += 2;
            } else {
                this.line2X = i7;
                this.line2Y = this.line1Y;
                this.tickStep = 1;
            }
        } else if (i6 == 1 && (i2 = this.line2X) < i5) {
            this.line2X = i2 + 4;
            this.line2Y -= 5;
        }
        float f3 = this.mCenterY;
        canvas.drawLine(i3, f3, this.line1X + i3, f3 + this.line1Y, this.mPaint);
        float f4 = this.line1X + i3;
        float f5 = this.mCenterY;
        canvas.drawLine(f4, f5 + this.line1Y, i3 + this.line2X, f5 + this.line2Y, this.mPaint);
        postInvalidateDelayed(1L);
    }

    private void showWarningTick(Canvas canvas) {
        int i2 = (int) this.mCenterX;
        float f = this.mCenterY;
        float f2 = this.mRadius;
        int i3 = (int) (f - (((f2 * 1.5d) * 1.0d) / 2.0d));
        int i4 = (int) (f + (((f2 * 1.5d) * 1.0d) / 8.0d));
        int i5 = (int) (f + (((f2 * 1.5d) * 3.0d) / 7.0d));
        int i6 = this.tickStep;
        if (i6 == 0) {
            int i7 = this.line1Y;
            int i8 = i4 - i3;
            if (i7 < i8) {
                this.line1Y = i7 + 4;
            } else {
                this.line1Y = i8;
                this.tickStep = 1;
            }
        } else if (i6 == 1 && this.line2Y != i5) {
            float f3 = i2;
            canvas.drawLine(f3, i5, f3, i5 + 1, this.mPaint);
        }
        float f4 = i2;
        canvas.drawLine(f4, i3, f4, i3 + this.line1Y, this.mPaint);
        postInvalidateDelayed(this.tickStep == 1 ? 100L : 1L);
    }

    private void showErrorTick(Canvas canvas) {
        float f = this.mCenterX;
        float f2 = this.mRadius;
        int i2 = (int) (f - (((f2 * 1.5d) * 4.0d) / 10.0d));
        int i3 = (int) (f + (((f2 * 1.5d) * 4.0d) / 10.0d));
        int i4 = (int) (this.mCenterY - (((f2 * 1.5d) * 4.0d) / 10.0d));
        int i5 = this.tickStep;
        if (i5 == 0) {
            int i6 = this.line1X;
            if (i3 - i6 > i2) {
                this.line1X = i6 + 4;
                this.line1Y += 4;
            } else {
                this.tickStep = 1;
                canvas.drawLine(i3, i4, i3 - i6, i4 + this.line1Y, this.mPaint);
                postInvalidateDelayed(150L);
                return;
            }
        } else if (i5 == 1) {
            int i7 = this.line2X;
            if (i2 + i7 < i3) {
                this.line2X = i7 + 4;
                this.line2Y += 4;
            }
            canvas.drawLine(i2, i4, i2 + this.line2X, this.line2Y + i4, this.mPaint);
        }
        canvas.drawLine(i3, i4, i3 - this.line1X, i4 + this.line1Y, this.mPaint);
        postInvalidateDelayed(1L);
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void success() {
        this.tickStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.interpolator = new AccelerateDecelerateInterpolator();
        this.status = 1;
        invalidate();
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void warning() {
        this.tickStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.interpolator = new DecelerateInterpolator(2.0f);
        this.status = 2;
        invalidate();
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void error() {
        this.tickStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.interpolator = new DecelerateInterpolator(2.0f);
        this.status = 3;
        invalidate();
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void progress(float progress) {
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        if (this.status != 4) {
            this.currentRotateDegrees = 0.0f;
        }
        ValueAnimator ofFloat = ValueAnimator.ofFloat(this.currentRotateDegrees, progress * 365.0f);
        this.rotateAnimator = ofFloat;
        ofFloat.setDuration(1000L);
        this.rotateAnimator.setInterpolator(new DecelerateInterpolator(2.0f));
        this.rotateAnimator.setRepeatCount(0);
        this.rotateAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.style.views.ProgressView.3
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                ProgressView.this.currentRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                ProgressView.this.invalidate();
            }
        });
        this.rotateAnimator.start();
        this.status = 4;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public ProgressView whenShowTick(Runnable runnable) {
        this.tickShowRunnable = runnable;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void loading() {
        this.noShowLoading = false;
        this.oldAnimAngle = 0.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.status = 0;
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        this.isInited = false;
        init(null);
    }

    public int getStatus() {
        return this.status;
    }

    @Override // android.view.View
    protected void onDetachedFromWindow() {
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        super.onDetachedFromWindow();
    }

    public int getStrokeWidth() {
        return this.width;
    }

    public ProgressView setStrokeWidth(int width) {
        this.width = width;
        Paint paint = this.mPaint;
        if (paint != null) {
            paint.setStrokeWidth(width);
        }
        return this;
    }

    public int getColor() {
        return this.color;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public ProgressView setColor(int color) {
        this.color = color;
        Paint paint = this.mPaint;
        if (paint != null) {
            paint.setColor(color);
        }
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void noLoading() {
        this.noShowLoading = true;
    }

    private int dip2px(float dpValue) {
        return (int) ((dpValue * Resources.getSystem().getDisplayMetrics().density) + 0.5f);
    }
}
