package com.kongzue.dialogx.util;

import android.content.Context;
import android.content.res.ColorStateList;
import android.os.Build;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.Space;
import android.widget.TextView;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.dialogs.PopMenu;
import com.kongzue.dialogx.interfaces.BaseDialog;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes10.dex */
public class PopMenuArrayAdapter extends BaseAdapter {
    public Context context;
    LayoutInflater mInflater;
    public List<CharSequence> menuList;
    private PopMenu popMenu;

    private boolean isHaveProperties(int gravity, int property) {
        return (gravity & property) == property;
    }

    @Override // android.widget.Adapter
    public long getItemId(int position) {
        return position;
    }

    public PopMenuArrayAdapter(PopMenu popMenu, Context context, List<CharSequence> menuList) {
        this.popMenu = popMenu;
        this.menuList = menuList;
        this.context = context;
        this.mInflater = LayoutInflater.from(context);
    }

    public List<CharSequence> getMenuList() {
        return this.menuList;
    }

    @Override // android.widget.Adapter
    public int getCount() {
        if (this.menuList == null) {
            this.menuList = new ArrayList();
        }
        return this.menuList.size();
    }

    @Override // android.widget.Adapter
    public Object getItem(int position) {
        return this.menuList.get(position);
    }

    @Override // android.widget.Adapter
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder;
        int overrideMenuItemLayoutRes;
        if (convertView == null) {
            ViewHolder viewHolder2 = new ViewHolder();
            int i2 = R.layout.item_dialogx_material_context_menu_normal_text;
            if (this.popMenu.getStyle().popMenuSettings() != null && (overrideMenuItemLayoutRes = this.popMenu.getStyle().popMenuSettings().overrideMenuItemLayoutRes(this.popMenu.isLightTheme())) != 0) {
                i2 = overrideMenuItemLayoutRes;
            }
            View inflate = this.mInflater.inflate(i2, (ViewGroup) null);
            viewHolder2.imgDialogxMenuIcon = (ImageView) inflate.findViewById(R.id.img_dialogx_menu_icon);
            viewHolder2.txtDialogxMenuText = (TextView) inflate.findViewById(R.id.txt_dialogx_menu_text);
            viewHolder2.spaceRightPadding = (Space) inflate.findViewById(R.id.space_dialogx_right_padding);
            inflate.setTag(viewHolder2);
            viewHolder = viewHolder2;
            convertView = inflate;
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        int overrideMenuItemBackgroundRes = this.popMenu.getStyle().popMenuSettings() == null ? 0 : this.popMenu.getStyle().popMenuSettings().overrideMenuItemBackgroundRes(this.popMenu.isLightTheme(), position, getCount(), false);
        if (overrideMenuItemBackgroundRes != 0) {
            convertView.setBackgroundResource(overrideMenuItemBackgroundRes);
        }
        viewHolder.imgDialogxMenuIcon.setVisibility(8);
        viewHolder.txtDialogxMenuText.setText(this.menuList.get(position));
        if (this.popMenu.getStyle().popMenuSettings() != null && this.popMenu.getStyle().popMenuSettings().paddingVertical() != 0) {
            if (position == 0) {
                convertView.setPadding(0, this.popMenu.getStyle().popMenuSettings().paddingVertical(), 0, 0);
            } else if (position == getCount() - 1) {
                convertView.setPadding(0, 0, 0, this.popMenu.getStyle().popMenuSettings().paddingVertical());
            } else {
                convertView.setPadding(0, 0, 0, 0);
            }
        }
        if (this.popMenu.getMenuTextInfo() != null) {
            BaseDialog.useTextInfo(viewHolder.txtDialogxMenuText, this.popMenu.getMenuTextInfo());
        }
        int i3 = this.popMenu.isLightTheme() ? R.color.black90 : R.color.white90;
        viewHolder.txtDialogxMenuText.setTextColor(this.context.getResources().getColor(i3));
        if (this.popMenu.getOnIconChangeCallBack() != null) {
            int icon = this.popMenu.getOnIconChangeCallBack().getIcon(this.popMenu, position, this.menuList.get(position).toString());
            boolean isAutoTintIconInLightOrDarkMode = this.popMenu.getOnIconChangeCallBack().isAutoTintIconInLightOrDarkMode();
            if (icon != 0) {
                viewHolder.imgDialogxMenuIcon.setVisibility(0);
                viewHolder.imgDialogxMenuIcon.setImageResource(icon);
                if ((isHaveProperties(viewHolder.txtDialogxMenuText.getGravity(), 17) || isHaveProperties(viewHolder.txtDialogxMenuText.getGravity(), 1)) && viewHolder.spaceRightPadding != null) {
                    viewHolder.spaceRightPadding.setVisibility(0);
                }
                if (Build.VERSION.SDK_INT >= 21 && isAutoTintIconInLightOrDarkMode) {
                    viewHolder.imgDialogxMenuIcon.setImageTintList(ColorStateList.valueOf(this.context.getResources().getColor(i3)));
                }
            } else {
                viewHolder.imgDialogxMenuIcon.setVisibility(8);
                if (viewHolder.spaceRightPadding != null) {
                    viewHolder.spaceRightPadding.setVisibility(8);
                }
            }
        } else {
            viewHolder.imgDialogxMenuIcon.setVisibility(8);
            if (viewHolder.spaceRightPadding != null) {
                viewHolder.spaceRightPadding.setVisibility(8);
            }
        }
        return convertView;
    }

    /* loaded from: classes10.dex */
    class ViewHolder {
        ImageView imgDialogxMenuIcon;
        Space spaceRightPadding;
        TextView txtDialogxMenuText;

        ViewHolder() {
        }
    }
}
