package com.kongzue.dialogx.util;

import android.app.Activity;
import android.content.Intent;
import android.os.Build;
import android.provider.Settings;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.Toast;
import androidx.core.view.PointerIconCompat;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.NoTouchInterface;
/* loaded from: classes10.dex */
public class WindowUtil {
    public static void show(final Activity activity, final View dialogView, final boolean touchEnable) {
        try {
            if (activity.getWindow().getDecorView().isAttachedToWindow()) {
                showNow(activity, dialogView, touchEnable);
            } else {
                activity.getWindow().getDecorView().post(new Runnable() { // from class: com.kongzue.dialogx.util.WindowUtil.1
                    @Override // java.lang.Runnable
                    public void run() {
                        WindowUtil.showNow(activity, dialogView, touchEnable);
                    }
                });
            }
        } catch (Exception unused) {
            if (activity == null || activity.isDestroyed()) {
                return;
            }
            showNow(activity, dialogView, touchEnable);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void showNow(final Activity activity, View dialogView, boolean touchEnable) {
        if (DialogX.globalHoverWindow && Build.VERSION.SDK_INT >= 23 && !Settings.canDrawOverlays(activity)) {
            Toast.makeText(activity, "使用 DialogX.globalHoverWindow 必须开启悬浮窗权限", 1).show();
            Intent intent = new Intent();
            intent.setAction("android.settings.action.MANAGE_OVERLAY_PERMISSION");
            activity.startActivity(intent);
            return;
        }
        FrameLayout frameLayout = new FrameLayout(activity);
        if (dialogView.getParent() != null) {
            ((ViewGroup) dialogView.getParent()).removeView(dialogView);
        }
        frameLayout.addView(dialogView, new FrameLayout.LayoutParams(-1, -1));
        WindowManager windowManager = (WindowManager) activity.getSystemService("window");
        WindowManager.LayoutParams layoutParams = new WindowManager.LayoutParams();
        layoutParams.gravity = 16;
        layoutParams.format = -2;
        if (DialogX.globalHoverWindow) {
            if (Build.VERSION.SDK_INT >= 26) {
                layoutParams.type = 2038;
            } else {
                layoutParams.type = 2002;
            }
        } else {
            layoutParams.type = PointerIconCompat.TYPE_HELP;
        }
        layoutParams.flags = 201327872;
        if (!touchEnable) {
            dialogView.setOnTouchListener(new View.OnTouchListener() { // from class: com.kongzue.dialogx.util.WindowUtil.2
                @Override // android.view.View.OnTouchListener
                public boolean onTouch(View v, MotionEvent event) {
                    for (int size = BaseDialog.getRunningDialogList().size() - 1; size >= 0; size--) {
                        BaseDialog baseDialog = BaseDialog.getRunningDialogList().get(size);
                        if (!(baseDialog instanceof NoTouchInterface) && baseDialog.getOwnActivity() == activity) {
                            if (baseDialog.getDialogView() == null) {
                                return false;
                            }
                            return baseDialog.getOwnActivity().dispatchTouchEvent(event);
                        }
                    }
                    return activity.dispatchTouchEvent(event);
                }
            });
        }
        if (Build.VERSION.SDK_INT >= 28) {
            layoutParams.layoutInDisplayCutoutMode = 1;
        }
        windowManager.addView(frameLayout, layoutParams);
    }

    public static void dismiss(View dialogView) {
        BaseDialog baseDialog = (BaseDialog) dialogView.getTag();
        if (baseDialog == null || baseDialog.getOwnActivity() == null) {
            return;
        }
        ((WindowManager) baseDialog.getOwnActivity().getSystemService("window")).removeViewImmediate((View) dialogView.getParent());
    }
}
