package com.kongzue.dialogx.util.views;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Path;
import android.graphics.Rect;
import android.os.Build;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import androidx.core.view.ViewCompat;
import com.kongzue.dialogx.impl.ActivityLifecycleImpl;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.util.DialogXFloatingWindowActivity;
import java.lang.ref.WeakReference;
/* loaded from: classes10.dex */
public class ActivityScreenShotImageView extends ImageView {
    public static boolean hideContentView;
    private WeakReference<View> contentView;
    float height;
    private boolean inited;
    private boolean isScreenshotSuccess;
    float mRadius;
    private int screenHeight;
    private int screenWidth;
    float width;

    public ActivityScreenShotImageView(Context context) {
        super(context);
        this.inited = false;
        init(null);
    }

    public ActivityScreenShotImageView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.inited = false;
        init(attrs);
    }

    public ActivityScreenShotImageView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.inited = false;
        init(attrs);
    }

    private void init(AttributeSet attrs) {
        if (Build.VERSION.SDK_INT >= 11) {
            setLayerType(2, null);
        }
    }

    public void setRadius(float mRadius) {
        this.mRadius = mRadius;
        invalidate();
    }

    @Override // android.view.View
    protected void onLayout(boolean changed, int left, int top2, int right, int bottom) {
        super.onLayout(changed, left, top2, right, bottom);
        this.width = getWidth();
        this.height = getHeight();
    }

    @Override // android.widget.ImageView, android.view.View
    protected void onDraw(Canvas canvas) {
        float f = this.width;
        float f2 = this.mRadius;
        if (f >= f2 && this.height > f2) {
            if (this.isScreenshotSuccess) {
                canvas.drawColor(ViewCompat.MEASURED_STATE_MASK);
            }
            Path path = new Path();
            path.moveTo(this.mRadius, 0.0f);
            path.lineTo(this.width - this.mRadius, 0.0f);
            float f3 = this.width;
            path.quadTo(f3, 0.0f, f3, this.mRadius);
            path.lineTo(this.width, this.height - this.mRadius);
            float f4 = this.width;
            float f5 = this.height;
            path.quadTo(f4, f5, f4 - this.mRadius, f5);
            path.lineTo(this.mRadius, this.height);
            float f6 = this.height;
            path.quadTo(0.0f, f6, 0.0f, f6 - this.mRadius);
            path.lineTo(0.0f, this.mRadius);
            path.quadTo(0.0f, 0.0f, this.mRadius, 0.0f);
            canvas.clipPath(path);
        }
        try {
            canvas.drawColor(-1);
            super.onDraw(canvas);
        } catch (Exception unused) {
        }
    }

    @Override // android.widget.ImageView, android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        if (!isAttachedToWindow() || this.isScreenshotSuccess) {
            return;
        }
        refreshImage();
    }

    private void refreshImage() {
        if (this.screenWidth == getMeasuredWidth() && this.screenHeight == getMeasuredHeight()) {
            return;
        }
        this.screenWidth = getMeasuredWidth();
        this.screenHeight = getMeasuredHeight();
        doScreenshotActivityAndZoom();
    }

    private void doScreenshotActivityAndZoom() {
        final View contentView = getContentView();
        if (contentView == null) {
            return;
        }
        if (!this.inited) {
            drawViewImage(contentView);
        }
        contentView.post(new Runnable() { // from class: com.kongzue.dialogx.util.views.ActivityScreenShotImageView.1
            @Override // java.lang.Runnable
            public void run() {
                ActivityScreenShotImageView.this.drawViewImage(contentView);
                ActivityScreenShotImageView.this.inited = true;
            }
        });
    }

    private View getContentView() {
        Activity topActivity = ActivityLifecycleImpl.getTopActivity();
        if (topActivity == null) {
            return null;
        }
        if (topActivity instanceof DialogXFloatingWindowActivity) {
            DialogXFloatingWindowActivity dialogXFloatingWindowActivity = (DialogXFloatingWindowActivity) topActivity;
            if (dialogXFloatingWindowActivity.isScreenshot()) {
                return (FrameLayout) topActivity.getWindow().getDecorView();
            }
            dialogXFloatingWindowActivity.setScreenshot(true);
            return BaseDialog.getRootFrameLayout();
        }
        return BaseDialog.getRootFrameLayout();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void drawViewImage(View view) {
        if (view.getWidth() == 0 || view.getHeight() == 0) {
            return;
        }
        view.buildDrawingCache();
        view.getWindowVisibleDisplayFrame(new Rect());
        view.setDrawingCacheEnabled(true);
        setImageBitmap(Bitmap.createBitmap(view.getDrawingCache(), 0, 0, view.getWidth(), view.getHeight()));
        view.destroyDrawingCache();
        if (hideContentView) {
            WeakReference<View> weakReference = this.contentView;
            if (weakReference != null && weakReference.get() != null) {
                this.contentView.get().setVisibility(0);
            }
            View childAt = ((ViewGroup) view).getChildAt(0);
            childAt.setVisibility(8);
            this.contentView = new WeakReference<>(childAt);
        }
        this.isScreenshotSuccess = true;
    }

    @Override // android.widget.ImageView, android.view.View
    protected void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        WeakReference<View> weakReference = this.contentView;
        if (weakReference == null || weakReference.get() == null || !hideContentView) {
            return;
        }
        this.contentView.get().setVisibility(0);
        this.contentView.clear();
    }
}
