package com.kongzue.dialogx.util.views;

import android.content.Context;
import android.content.res.Configuration;
import android.content.res.TypedArray;
import android.graphics.Rect;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewParent;
import android.view.ViewTreeObserver;
import android.view.WindowInsets;
import android.view.inputmethod.InputMethodManager;
import android.widget.RelativeLayout;
import androidx.core.view.ViewCompat;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.interfaces.BaseDialog;
import com.kongzue.dialogx.interfaces.OnSafeInsetsChangeListener;
import java.lang.ref.WeakReference;
/* loaded from: classes10.dex */
public class DialogXBaseRelativeLayout extends RelativeLayout {
    private boolean autoUnsafePlacePadding;
    private ViewTreeObserver.OnGlobalLayoutListener decorViewLayoutListener;
    private boolean focusable;
    private boolean interceptBack;
    private boolean isInited;
    boolean isLightMode;
    float nowBkgAlphaValue;
    private PrivateBackPressedListener onBackPressedListener;
    private OnLifecycleCallBack onLifecycleCallBack;
    private OnSafeInsetsChangeListener onSafeInsetsChangeListener;
    private BaseDialog parentDialog;
    private WeakReference<View> requestFocusView;
    protected Rect unsafePlace;

    /* loaded from: classes10.dex */
    public static abstract class OnLifecycleCallBack {
        public abstract void onDismiss();

        public void onShow() {
        }
    }

    /* loaded from: classes10.dex */
    public interface PrivateBackPressedListener {
        boolean onBackPressed();
    }

    public DialogXBaseRelativeLayout(Context context) {
        super(context);
        this.autoUnsafePlacePadding = true;
        this.focusable = true;
        this.interceptBack = true;
        this.isInited = false;
        this.decorViewLayoutListener = new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.1
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                if (Build.VERSION.SDK_INT >= 23) {
                    DialogXBaseRelativeLayout dialogXBaseRelativeLayout = DialogXBaseRelativeLayout.this;
                    dialogXBaseRelativeLayout.paddingView(dialogXBaseRelativeLayout.getRootWindowInsets());
                } else if (BaseDialog.getTopActivity() == null) {
                } else {
                    DisplayMetrics displayMetrics = new DisplayMetrics();
                    BaseDialog.getTopActivity().getWindowManager().getDefaultDisplay().getRealMetrics(displayMetrics);
                    Rect rect = new Rect();
                    BaseDialog.getTopActivity().getWindow().getDecorView().getWindowVisibleDisplayFrame(rect);
                    DialogXBaseRelativeLayout.this.paddingView(rect.left, rect.top, displayMetrics.widthPixels - rect.right, displayMetrics.heightPixels - rect.bottom);
                }
            }
        };
        this.unsafePlace = new Rect();
        this.isLightMode = true;
        init(null);
    }

    public DialogXBaseRelativeLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.autoUnsafePlacePadding = true;
        this.focusable = true;
        this.interceptBack = true;
        this.isInited = false;
        this.decorViewLayoutListener = new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.1
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                if (Build.VERSION.SDK_INT >= 23) {
                    DialogXBaseRelativeLayout dialogXBaseRelativeLayout = DialogXBaseRelativeLayout.this;
                    dialogXBaseRelativeLayout.paddingView(dialogXBaseRelativeLayout.getRootWindowInsets());
                } else if (BaseDialog.getTopActivity() == null) {
                } else {
                    DisplayMetrics displayMetrics = new DisplayMetrics();
                    BaseDialog.getTopActivity().getWindowManager().getDefaultDisplay().getRealMetrics(displayMetrics);
                    Rect rect = new Rect();
                    BaseDialog.getTopActivity().getWindow().getDecorView().getWindowVisibleDisplayFrame(rect);
                    DialogXBaseRelativeLayout.this.paddingView(rect.left, rect.top, displayMetrics.widthPixels - rect.right, displayMetrics.heightPixels - rect.bottom);
                }
            }
        };
        this.unsafePlace = new Rect();
        this.isLightMode = true;
        init(attrs);
    }

    public DialogXBaseRelativeLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.autoUnsafePlacePadding = true;
        this.focusable = true;
        this.interceptBack = true;
        this.isInited = false;
        this.decorViewLayoutListener = new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.kongzue.dialogx.util.views.DialogXBaseRelativeLayout.1
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                if (Build.VERSION.SDK_INT >= 23) {
                    DialogXBaseRelativeLayout dialogXBaseRelativeLayout = DialogXBaseRelativeLayout.this;
                    dialogXBaseRelativeLayout.paddingView(dialogXBaseRelativeLayout.getRootWindowInsets());
                } else if (BaseDialog.getTopActivity() == null) {
                } else {
                    DisplayMetrics displayMetrics = new DisplayMetrics();
                    BaseDialog.getTopActivity().getWindowManager().getDefaultDisplay().getRealMetrics(displayMetrics);
                    Rect rect = new Rect();
                    BaseDialog.getTopActivity().getWindow().getDecorView().getWindowVisibleDisplayFrame(rect);
                    DialogXBaseRelativeLayout.this.paddingView(rect.left, rect.top, displayMetrics.widthPixels - rect.right, displayMetrics.heightPixels - rect.bottom);
                }
            }
        };
        this.unsafePlace = new Rect();
        this.isLightMode = true;
        init(attrs);
    }

    private void init(AttributeSet attrs) {
        if (Build.VERSION.SDK_INT >= 29) {
            setForceDarkAllowed(false);
        }
        if (this.isInited) {
            return;
        }
        if (attrs != null) {
            TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attrs, R.styleable.DialogXBaseRelativeLayout);
            this.focusable = obtainStyledAttributes.getBoolean(R.styleable.DialogXBaseRelativeLayout_baseFocusable, true);
            this.autoUnsafePlacePadding = obtainStyledAttributes.getBoolean(R.styleable.DialogXBaseRelativeLayout_autoSafeArea, true);
            this.interceptBack = obtainStyledAttributes.getBoolean(R.styleable.DialogXBaseRelativeLayout_interceptBack, true);
            obtainStyledAttributes.recycle();
            this.isInited = true;
        }
        if (this.focusable) {
            setFocusable(true);
            setFocusableInTouchMode(true);
            requestFocus();
        }
        setBkgAlpha(0.0f);
        BaseDialog baseDialog = this.parentDialog;
        if (baseDialog == null || baseDialog.getDialogImplMode() == DialogX.IMPL_MODE.VIEW) {
            return;
        }
        setFitsSystemWindows(true);
    }

    @Override // android.view.View
    protected boolean fitSystemWindows(Rect insets) {
        if (DialogX.useActivityLayoutTranslationNavigationBar || this.parentDialog.getDialogImplMode() != DialogX.IMPL_MODE.VIEW) {
            paddingView(insets.left, insets.top, insets.right, insets.bottom);
        }
        return super.fitSystemWindows(insets);
    }

    @Override // android.view.ViewGroup, android.view.View
    public WindowInsets dispatchApplyWindowInsets(WindowInsets insets) {
        if (Build.VERSION.SDK_INT >= 21 && (DialogX.useActivityLayoutTranslationNavigationBar || this.parentDialog.getDialogImplMode() != DialogX.IMPL_MODE.VIEW)) {
            paddingView(insets.getSystemWindowInsetLeft(), insets.getSystemWindowInsetTop(), insets.getSystemWindowInsetRight(), insets.getSystemWindowInsetBottom());
        }
        return super.dispatchApplyWindowInsets(insets);
    }

    public void paddingView(WindowInsets insets) {
        if (insets == null) {
            if (BaseDialog.publicWindowInsets() == null) {
                return;
            }
            insets = BaseDialog.publicWindowInsets();
        }
        if (Build.VERSION.SDK_INT >= 21) {
            paddingView(insets.getSystemWindowInsetLeft(), insets.getSystemWindowInsetTop(), insets.getSystemWindowInsetRight(), insets.getSystemWindowInsetBottom());
        }
    }

    @Override // android.view.ViewGroup, android.view.View
    public boolean dispatchKeyEvent(KeyEvent event) {
        PrivateBackPressedListener privateBackPressedListener;
        if (isAttachedToWindow() && event.getAction() == 1 && event.getKeyCode() == 4 && this.interceptBack && (privateBackPressedListener = this.onBackPressedListener) != null) {
            return privateBackPressedListener.onBackPressed();
        }
        return super.dispatchKeyEvent(event);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        ((InputMethodManager) getContext().getSystemService("input_method")).hideSoftInputFromWindow(getWindowToken(), 2);
        return super.onTouchEvent(event);
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onAttachedToWindow() {
        super.onAttachedToWindow();
        if (isInEditMode()) {
            return;
        }
        ViewParent parent = getParent();
        if (parent instanceof View) {
            ViewCompat.setFitsSystemWindows(this, ViewCompat.getFitsSystemWindows((View) parent));
        }
        ViewCompat.requestApplyInsets(this);
        if (BaseDialog.getTopActivity() == null) {
            return;
        }
        BaseDialog.getTopActivity().getWindow().getDecorView().getViewTreeObserver().addOnGlobalLayoutListener(this.decorViewLayoutListener);
        this.decorViewLayoutListener.onGlobalLayout();
        OnLifecycleCallBack onLifecycleCallBack = this.onLifecycleCallBack;
        if (onLifecycleCallBack != null) {
            onLifecycleCallBack.onShow();
        }
        this.isLightMode = (getResources().getConfiguration().uiMode & 48) == 16;
    }

    @Override // android.view.ViewGroup, android.view.View
    protected void onDetachedFromWindow() {
        if (this.decorViewLayoutListener != null && BaseDialog.getTopActivity() != null) {
            BaseDialog.getTopActivity().getWindow().getDecorView().getViewTreeObserver().removeOnGlobalLayoutListener(this.decorViewLayoutListener);
        }
        OnLifecycleCallBack onLifecycleCallBack = this.onLifecycleCallBack;
        if (onLifecycleCallBack != null) {
            onLifecycleCallBack.onDismiss();
        }
        this.onSafeInsetsChangeListener = null;
        super.onDetachedFromWindow();
    }

    @Override // android.view.View
    public boolean performClick() {
        if (isEnabled()) {
            return super.performClick();
        }
        return false;
    }

    @Override // android.view.View
    public boolean callOnClick() {
        if (isEnabled()) {
            return super.callOnClick();
        }
        return false;
    }

    public DialogXBaseRelativeLayout setOnLifecycleCallBack(OnLifecycleCallBack onLifecycleCallBack) {
        this.onLifecycleCallBack = onLifecycleCallBack;
        return this;
    }

    public float getSafeHeight() {
        return (getMeasuredHeight() - this.unsafePlace.bottom) - this.unsafePlace.top;
    }

    public void bindFocusView(View view) {
        this.requestFocusView = new WeakReference<>(view);
    }

    @Override // android.view.ViewGroup, android.view.View
    public boolean requestFocus(int direction, Rect previouslyFocusedRect) {
        WeakReference<View> weakReference;
        if (direction == 130 && (weakReference = this.requestFocusView) != null && weakReference.get() != null) {
            return this.requestFocusView.get().requestFocus();
        }
        return super.requestFocus(direction, previouslyFocusedRect);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void paddingView(int left, int top2, int right, int bottom) {
        Rect rect = new Rect(left, top2, right, bottom);
        this.unsafePlace = rect;
        OnSafeInsetsChangeListener onSafeInsetsChangeListener = this.onSafeInsetsChangeListener;
        if (onSafeInsetsChangeListener != null) {
            onSafeInsetsChangeListener.onChange(rect);
        }
        MaxRelativeLayout maxRelativeLayout = (MaxRelativeLayout) findViewById(R.id.bkg);
        if (maxRelativeLayout != null && (maxRelativeLayout.getLayoutParams() instanceof RelativeLayout.LayoutParams) && ((RelativeLayout.LayoutParams) maxRelativeLayout.getLayoutParams()).getRules()[12] == -1 && isAutoUnsafePlacePadding()) {
            maxRelativeLayout.setPadding(0, 0, 0, bottom);
            maxRelativeLayout.setNavBarHeight(bottom);
            setPadding(left, top2, right, 0);
        } else if (isAutoUnsafePlacePadding()) {
            setPadding(left, top2, right, bottom);
        }
    }

    public DialogXBaseRelativeLayout setOnBackPressedListener(PrivateBackPressedListener onBackPressedListener) {
        this.onBackPressedListener = onBackPressedListener;
        return this;
    }

    public OnSafeInsetsChangeListener getOnSafeInsetsChangeListener() {
        return this.onSafeInsetsChangeListener;
    }

    public DialogXBaseRelativeLayout setOnSafeInsetsChangeListener(OnSafeInsetsChangeListener onSafeInsetsChangeListener) {
        this.onSafeInsetsChangeListener = onSafeInsetsChangeListener;
        return this;
    }

    public boolean isAutoUnsafePlacePadding() {
        return this.autoUnsafePlacePadding;
    }

    public Rect getUnsafePlace() {
        return this.unsafePlace;
    }

    public DialogXBaseRelativeLayout setAutoUnsafePlacePadding(boolean autoUnsafePlacePadding) {
        this.autoUnsafePlacePadding = autoUnsafePlacePadding;
        if (!autoUnsafePlacePadding) {
            setPadding(0, 0, 0, 0);
        }
        return this;
    }

    public BaseDialog getParentDialog() {
        return this.parentDialog;
    }

    public DialogXBaseRelativeLayout setParentDialog(BaseDialog parentDialog) {
        this.parentDialog = parentDialog;
        if (parentDialog.getDialogImplMode() != DialogX.IMPL_MODE.VIEW) {
            setFitsSystemWindows(true);
            if (Build.VERSION.SDK_INT >= 23) {
                paddingView(getRootWindowInsets());
            }
        }
        return this;
    }

    @Override // android.view.View
    protected void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (this.isLightMode == ((newConfig.uiMode & 48) == 16) || DialogX.globalTheme != DialogX.THEME.AUTO) {
            return;
        }
        getParentDialog().restartDialog();
    }

    public DialogXBaseRelativeLayout setBkgAlpha(float alpha) {
        this.nowBkgAlphaValue = alpha;
        if (getBackground() != null) {
            getBackground().mutate().setAlpha((int) (alpha * 255.0f));
        }
        return this;
    }

    @Override // android.view.View
    public void setBackground(Drawable background) {
        background.setAlpha((int) (this.nowBkgAlphaValue * 255.0f));
        super.setBackground(background);
    }

    @Override // android.view.View
    public void setBackgroundColor(int color) {
        setBackground(new ColorDrawable(color));
    }

    public boolean isBaseFocusable() {
        return this.focusable;
    }

    public boolean isInterceptBack() {
        return this.interceptBack;
    }

    public DialogXBaseRelativeLayout setInterceptBack(boolean interceptBack) {
        this.interceptBack = interceptBack;
        return this;
    }

    @Override // android.view.View
    public void setVisibility(int visibility) {
        if (visibility == 8 && getAlpha() == 0.0f) {
            setAlpha(0.01f);
        }
        super.setVisibility(visibility);
    }
}
