package com.kongzue.dialogx.util.views;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.kongzue.dialogx.R;
/* loaded from: classes10.dex */
public class MaxLinearLayout extends LinearLayout {
    private int maxHeight;
    private int maxWidth;
    private int minHeight;
    private int minWidth;
    private int preWidth;

    public MaxLinearLayout(Context context) {
        super(context);
        this.preWidth = -1;
        init(context, null);
    }

    public MaxLinearLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.preWidth = -1;
        init(context, attrs);
    }

    public MaxLinearLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.preWidth = -1;
        init(context, attrs);
    }

    private void init(Context context, AttributeSet attrs) {
        if (attrs != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attrs, R.styleable.DialogXMaxLayout);
            this.maxWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_maxLayoutWidth, 0);
            this.maxHeight = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_maxLayoutHeight, 0);
            this.minWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_minLayoutWidth, 0);
            this.minHeight = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_minLayoutHeight, 0);
            obtainStyledAttributes.recycle();
        }
        int i2 = this.minWidth;
        if (i2 == 0) {
            i2 = getMinimumWidth();
        }
        this.minWidth = i2;
        int i3 = this.minHeight;
        if (i3 == 0) {
            i3 = getMinimumHeight();
        }
        this.minHeight = i3;
    }

    public MaxLinearLayout setMaxHeight(int maxHeight) {
        this.maxHeight = maxHeight;
        return this;
    }

    public MaxLinearLayout setMaxWidth(int maxWidth) {
        this.maxWidth = maxWidth;
        return this;
    }

    @Override // android.widget.LinearLayout, android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        int mode = View.MeasureSpec.getMode(heightMeasureSpec);
        int mode2 = View.MeasureSpec.getMode(widthMeasureSpec);
        int size = View.MeasureSpec.getSize(heightMeasureSpec);
        int size2 = View.MeasureSpec.getSize(widthMeasureSpec);
        if (this.preWidth == -1 && size2 != 0) {
            this.preWidth = size2;
        }
        int i2 = this.maxHeight;
        if (i2 > 0) {
            size = Math.max(size, i2);
        }
        int i3 = this.maxWidth;
        if (i3 > 0) {
            size2 = Math.max(size2, i3);
        }
        View findViewWithTag = findViewWithTag("blurView");
        View findViewWithoutTag = findViewWithoutTag("blurView");
        if (findViewWithoutTag != null) {
            int measuredWidth = findViewWithoutTag.getMeasuredWidth() == 0 ? getMeasuredWidth() : findViewWithoutTag.getMeasuredWidth();
            int measuredHeight = findViewWithoutTag.getMeasuredHeight() == 0 ? getMeasuredHeight() : findViewWithoutTag.getMeasuredHeight();
            int i4 = this.minWidth;
            if (measuredWidth < i4) {
                measuredWidth = i4;
            }
            int i5 = this.minHeight;
            if (measuredHeight < i5) {
                measuredHeight = i5;
            }
            if (findViewWithTag != null) {
                if (mode == 1073741824) {
                    measuredHeight = size;
                }
                if (mode2 == 1073741824) {
                    measuredWidth = size2;
                }
                ViewGroup.LayoutParams layoutParams = findViewWithTag.getLayoutParams();
                layoutParams.width = measuredWidth;
                layoutParams.height = measuredHeight;
                findViewWithTag.setLayoutParams(layoutParams);
            }
        } else if (findViewWithTag != null) {
            ViewGroup.LayoutParams layoutParams2 = findViewWithTag.getLayoutParams();
            layoutParams2.width = getMeasuredWidth();
            layoutParams2.height = getMeasuredHeight();
            findViewWithTag.setLayoutParams(layoutParams2);
        }
        super.onMeasure(View.MeasureSpec.makeMeasureSpec(size2, mode2), View.MeasureSpec.makeMeasureSpec(size, mode));
    }

    private View findViewWithoutTag(String tag) {
        for (int i2 = 0; i2 < getChildCount(); i2++) {
            if (!tag.equals(getChildAt(i2).getTag())) {
                return getChildAt(i2);
            }
        }
        return null;
    }

    public int dip2px(float dpValue) {
        return (int) ((dpValue * getResources().getDisplayMetrics().density) + 0.5f);
    }

    @Override // android.view.View
    public void setMinimumHeight(int minHeight) {
        this.minHeight = minHeight;
        super.setMinimumHeight(minHeight);
    }

    @Override // android.view.View
    public void setMinimumWidth(int minWidth) {
        this.minWidth = minWidth;
        super.setMinimumWidth(minWidth);
    }
}
