package com.kongzue.dialogx.util.views;

import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.os.Build;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.RelativeLayout;
import android.widget.ScrollView;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
/* loaded from: classes10.dex */
public class MaxRelativeLayout extends RelativeLayout {
    private ScrollView childScrollView;
    private View contentView;
    private float endAnimValue;
    private boolean interceptTouch;
    private boolean lockWidth;
    private int maxHeight;
    private int maxWidth;
    private int minHeight;
    private int minWidth;
    int navBarHeight;
    Paint navBarPaint;
    private View.OnTouchListener onTouchListener;
    private OnYChanged onYChangedListener;
    private int preWidth;
    boolean reInterceptTouch;
    private float startAnimValue;

    /* loaded from: classes10.dex */
    public interface OnYChanged {
        void y(float y);
    }

    public MaxRelativeLayout(Context context) {
        super(context);
        this.interceptTouch = true;
        this.startAnimValue = 0.0f;
        this.endAnimValue = 0.0f;
        this.preWidth = -1;
        init(context, null);
    }

    public MaxRelativeLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.interceptTouch = true;
        this.startAnimValue = 0.0f;
        this.endAnimValue = 0.0f;
        this.preWidth = -1;
        init(context, attrs);
    }

    public MaxRelativeLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.interceptTouch = true;
        this.startAnimValue = 0.0f;
        this.endAnimValue = 0.0f;
        this.preWidth = -1;
        init(context, attrs);
    }

    private void init(Context context, AttributeSet attrs) {
        if (attrs != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attrs, R.styleable.DialogXMaxLayout);
            this.maxWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_maxLayoutWidth, 0);
            this.maxHeight = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_maxLayoutHeight, 0);
            this.minWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_minLayoutWidth, 0);
            this.minHeight = obtainStyledAttributes.getDimensionPixelSize(R.styleable.DialogXMaxLayout_minLayoutHeight, 0);
            this.lockWidth = obtainStyledAttributes.getBoolean(R.styleable.DialogXMaxLayout_lockWidth, false);
            this.interceptTouch = obtainStyledAttributes.getBoolean(R.styleable.DialogXMaxLayout_interceptTouch, true);
            obtainStyledAttributes.recycle();
        }
        int i2 = this.minWidth;
        if (i2 == 0) {
            i2 = getMinimumWidth();
        }
        this.minWidth = i2;
        int i3 = this.minHeight;
        if (i3 == 0) {
            i3 = getMinimumHeight();
        }
        this.minHeight = i3;
        if (isInEditMode() || Build.VERSION.SDK_INT < 19) {
            return;
        }
        animate().setUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.util.views.MaxRelativeLayout.1
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                long floatValue = MaxRelativeLayout.this.startAnimValue + ((MaxRelativeLayout.this.endAnimValue - MaxRelativeLayout.this.startAnimValue) * ((Float) animation.getAnimatedValue()).floatValue());
                if (MaxRelativeLayout.this.onYChangedListener != null) {
                    MaxRelativeLayout.this.onYChangedListener.y((float) floatValue);
                }
            }
        });
    }

    public MaxRelativeLayout setMaxHeight(int maxHeight) {
        this.maxHeight = maxHeight;
        return this;
    }

    public MaxRelativeLayout setMaxWidth(int maxWidth) {
        if (maxWidth > 0) {
            this.maxWidth = maxWidth;
        }
        return this;
    }

    @Override // android.widget.RelativeLayout, android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        int mode = View.MeasureSpec.getMode(heightMeasureSpec);
        int mode2 = View.MeasureSpec.getMode(widthMeasureSpec);
        int size = View.MeasureSpec.getSize(heightMeasureSpec);
        int size2 = View.MeasureSpec.getSize(widthMeasureSpec);
        if (this.preWidth == -1 && size2 != 0) {
            this.preWidth = size2;
        }
        if (this.lockWidth) {
            this.maxWidth = Math.min(this.maxWidth, Math.min(size2, this.preWidth));
        }
        int i2 = this.maxHeight;
        if (size > i2 && i2 != 0) {
            size = i2;
        }
        int i3 = this.maxWidth;
        if (size2 > i3 && i3 != 0) {
            size2 = i3;
        }
        View findViewWithTag = findViewWithTag("blurView");
        View view = this.contentView;
        if (view == null) {
            view = findViewWithoutTag("blurView");
        }
        if (view != null) {
            int measuredWidth = view.getMeasuredWidth() == 0 ? getMeasuredWidth() : view.getMeasuredWidth();
            int measuredHeight = view.getMeasuredHeight() == 0 ? getMeasuredHeight() : view.getMeasuredHeight();
            int i4 = this.minWidth;
            if (measuredWidth < i4) {
                measuredWidth = i4;
            }
            int i5 = this.minHeight;
            if (measuredHeight < i5) {
                measuredHeight = i5;
            }
            if (findViewWithTag != 0) {
                if (mode == 1073741824) {
                    measuredHeight = size;
                }
                if (mode2 == 1073741824) {
                    measuredWidth = size2;
                }
                RelativeLayout.LayoutParams layoutParams = (RelativeLayout.LayoutParams) findViewWithTag.getLayoutParams();
                layoutParams.width = measuredWidth;
                layoutParams.height = measuredHeight;
                findViewWithTag.setLayoutParams(layoutParams);
            }
        } else if (findViewWithTag != null) {
            RelativeLayout.LayoutParams layoutParams2 = (RelativeLayout.LayoutParams) findViewWithTag.getLayoutParams();
            layoutParams2.width = getMeasuredWidth();
            layoutParams2.height = getMeasuredHeight();
            findViewWithTag.setLayoutParams(layoutParams2);
        }
        super.onMeasure(View.MeasureSpec.makeMeasureSpec(size2, mode2), View.MeasureSpec.makeMeasureSpec(size, mode));
        this.childScrollView = (ScrollView) findViewById(R.id.scrollView);
    }

    private View findViewWithoutTag(String tag) {
        for (int i2 = 0; i2 < getChildCount(); i2++) {
            if (!tag.equals(getChildAt(i2).getTag())) {
                return getChildAt(i2);
            }
        }
        return null;
    }

    @Deprecated
    public boolean isChildScrollViewCanScroll() {
        View childAt;
        ScrollView scrollView = this.childScrollView;
        if (scrollView == null || !scrollView.isEnabled() || (childAt = this.childScrollView.getChildAt(0)) == null) {
            return false;
        }
        return this.childScrollView.getHeight() < childAt.getHeight();
    }

    public int dip2px(float dpValue) {
        return (int) ((dpValue * getResources().getDisplayMetrics().density) + 0.5f);
    }

    public boolean isLockWidth() {
        return this.lockWidth;
    }

    public MaxRelativeLayout setLockWidth(boolean lockWidth) {
        this.lockWidth = lockWidth;
        return this;
    }

    public void setNavBarHeight(int height) {
        this.navBarHeight = height;
        invalidate();
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (this.navBarHeight == 0 || DialogX.bottomDialogNavbarColor == 0) {
            return;
        }
        if (this.navBarPaint == null) {
            Paint paint = new Paint();
            this.navBarPaint = paint;
            paint.setColor(DialogX.bottomDialogNavbarColor);
        }
        canvas.drawRect(0.0f, getHeight() - this.navBarHeight, getWidth(), getHeight(), this.navBarPaint);
    }

    public void setContentView(View contentView) {
        this.contentView = contentView;
    }

    @Override // android.view.View
    public void setY(float y) {
        super.setY(y);
    }

    public OnYChanged getOnYChanged() {
        return this.onYChangedListener;
    }

    public MaxRelativeLayout setOnYChanged(OnYChanged onYChanged) {
        this.onYChangedListener = onYChanged;
        return this;
    }

    @Override // android.view.View
    public void setTranslationY(float translationY) {
        super.setTranslationY(translationY);
        OnYChanged onYChanged = this.onYChangedListener;
        if (onYChanged != null) {
            onYChanged.y(translationY);
        }
    }

    @Override // android.view.View
    public void setOnTouchListener(View.OnTouchListener l) {
        this.onTouchListener = l;
    }

    @Override // android.view.ViewGroup, android.view.View
    public boolean dispatchTouchEvent(MotionEvent ev) {
        View.OnTouchListener onTouchListener = this.onTouchListener;
        if (onTouchListener != null) {
            this.reInterceptTouch = onTouchListener.onTouch(this, ev);
        }
        return super.dispatchTouchEvent(ev);
    }

    @Override // android.view.ViewGroup
    public boolean onInterceptTouchEvent(MotionEvent ev) {
        return this.reInterceptTouch;
    }
}
