package com.kongzue.dialogx.util.views;

import android.animation.TimeInterpolator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.RectF;
import android.os.Handler;
import android.os.Looper;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import com.kongzue.dialogx.DialogX;
import com.kongzue.dialogx.R;
import com.kongzue.dialogx.interfaces.ProgressViewInterface;
/* loaded from: classes10.dex */
public class ProgressView extends View implements ProgressViewInterface {
    public static long PROGRESSING_ANIMATOR_DURATION = 1000;
    public static final int STATUS_ERROR = 3;
    public static final int STATUS_LOADING = 0;
    public static final int STATUS_PROGRESSING = 4;
    public static final int STATUS_SUCCESS = 1;
    public static final int STATUS_WARNING = 2;
    public static long TIP_ANIMATOR_DURATION = 300;
    private int color;
    private float currentRotateDegrees;
    private ValueAnimator followAnimator;
    private float followRotateDegrees;
    private float halfSweepA;
    private float halfSweepAMaxValue;
    private float halfSweepAMinValue;
    private Interpolator interpolator;
    private boolean isInited;
    private int line1X;
    private int line1Y;
    private int line2X;
    private int line2Y;
    private float mCenterX;
    private float mCenterY;
    Paint mPaint;
    private float mRadius;
    private boolean noShowLoading;
    private float nowLoadingProgressEndAngle;
    private float nowLoadingProgressValue;
    private RectF oval;
    private ValueAnimator rotateAnimator;
    private int status;
    private int successStep;
    private ValueAnimator tickAnimator;
    private float tickAnimatorValue;
    private Runnable tickShowRunnable;
    Runnable waitArticulationAnimationRunnable;
    private int width;

    public ProgressView(Context context) {
        super(context);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        init(null);
    }

    public ProgressView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        init(attrs);
    }

    public ProgressView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.status = 0;
        this.width = dip2px(2.0f);
        this.color = -1;
        this.halfSweepAMaxValue = 180.0f;
        this.halfSweepAMinValue = 80.0f;
        this.mPaint = new Paint();
        this.isInited = false;
        this.mRadius = 100.0f;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        init(attrs);
    }

    private void init(AttributeSet attrs) {
        synchronized (ProgressView.class) {
            if (this.isInited) {
                return;
            }
            this.isInited = true;
            if (attrs != null) {
                TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attrs, R.styleable.ProgressView);
                this.width = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ProgressView_progressStrokeWidth, dip2px(2.0f));
                this.color = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ProgressView_progressStrokeColor, this.color);
                obtainStyledAttributes.recycle();
            }
            this.mPaint.setAntiAlias(true);
            this.mPaint.setStyle(Paint.Style.STROKE);
            this.mPaint.setStrokeWidth(this.width);
            this.mPaint.setStrokeCap(Paint.Cap.ROUND);
            this.mPaint.setColor(this.color);
            if (!isInEditMode()) {
                this.halfSweepA = (this.halfSweepAMaxValue - this.halfSweepAMinValue) / 2.0f;
                ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 365.0f);
                this.rotateAnimator = ofFloat;
                ofFloat.setDuration(1000L);
                this.rotateAnimator.setInterpolator(new LinearInterpolator());
                this.rotateAnimator.setRepeatCount(-1);
                this.rotateAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.util.views.ProgressView.1
                    @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                    public void onAnimationUpdate(ValueAnimator animation) {
                        ProgressView.this.currentRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                        ProgressView.this.invalidate();
                    }
                });
                ValueAnimator ofFloat2 = ValueAnimator.ofFloat(0.0f, 365.0f);
                this.followAnimator = ofFloat2;
                ofFloat2.setDuration(1500L);
                this.followAnimator.setInterpolator(new LinearInterpolator());
                this.followAnimator.setRepeatCount(-1);
                this.followAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.util.views.ProgressView.2
                    @Override // android.animation.ValueAnimator.AnimatorUpdateListener
                    public void onAnimationUpdate(ValueAnimator animation) {
                        ProgressView.this.followRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                    }
                });
                this.followAnimator.start();
                this.rotateAnimator.start();
            }
        }
    }

    @Override // android.view.View
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        this.mCenterX = (w * 1.0f) / 2.0f;
        this.mCenterY = (h * 1.0f) / 2.0f;
        this.mRadius = (Math.min(getWidth(), getHeight()) / 2) - (this.width / 2);
        float f = this.mCenterX;
        float f2 = this.mRadius;
        float f3 = this.mCenterY;
        this.oval = new RectF(f - f2, f3 - f2, f + f2, f3 + f2);
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        if (isInEditMode()) {
            canvas.drawArc(this.oval, 0.0f, 365.0f, false, this.mPaint);
        } else if (this.noShowLoading) {
            canvas.drawArc(this.oval, 0.0f, 365.0f, false, this.mPaint);
            this.successStep = 2;
            drawDoneMark(this.status, canvas);
        } else {
            int i2 = this.status;
            if (i2 == 0) {
                float sin = ((float) (this.halfSweepA * Math.sin(Math.toRadians(this.followRotateDegrees)))) + this.halfSweepA + (this.halfSweepAMinValue / 2.0f);
                float f = this.currentRotateDegrees;
                float f2 = f - sin;
                this.nowLoadingProgressValue = f2;
                if (f2 < 0.0f) {
                    this.nowLoadingProgressValue = f2 + 360.0f;
                }
                this.nowLoadingProgressEndAngle = sin;
                canvas.drawArc(this.oval, f, -sin, false, this.mPaint);
            } else if (i2 == 1 || i2 == 2 || i2 == 3) {
                int i3 = this.successStep;
                if (i3 != 0) {
                    if (i3 != 1) {
                        return;
                    }
                    canvas.drawArc(this.oval, 0.0f, 360.0f, false, this.mPaint);
                    drawDoneMark(this.status, canvas);
                    return;
                }
                float f3 = this.nowLoadingProgressEndAngle + 5.0f;
                this.nowLoadingProgressEndAngle = f3;
                canvas.drawArc(this.oval, this.nowLoadingProgressValue, f3, false, this.mPaint);
                if (this.nowLoadingProgressEndAngle - 360.0f >= this.nowLoadingProgressValue) {
                    this.successStep = 1;
                    Runnable runnable = this.waitArticulationAnimationRunnable;
                    if (runnable != null) {
                        runnable.run();
                        this.waitArticulationAnimationRunnable = null;
                    }
                }
            } else if (i2 != 4) {
            } else {
                int i4 = this.successStep;
                if (i4 != 0) {
                    if (i4 != 1) {
                        return;
                    }
                    canvas.drawArc(this.oval, 0.0f, 360.0f, false, this.mPaint);
                    drawDoneMark(this.status, canvas);
                    return;
                }
                canvas.drawArc(this.oval, -90.0f, this.currentRotateDegrees, false, this.mPaint);
                if (this.currentRotateDegrees == 365.0f) {
                    this.successStep = 1;
                    Runnable runnable2 = this.waitArticulationAnimationRunnable;
                    if (runnable2 != null) {
                        runnable2.run();
                        this.waitArticulationAnimationRunnable = null;
                    }
                }
            }
        }
    }

    private void drawDoneMark(int status, Canvas canvas) {
        TimeInterpolator interpolator = this.rotateAnimator.getInterpolator();
        Interpolator interpolator2 = this.interpolator;
        if (interpolator != interpolator2) {
            this.rotateAnimator.setInterpolator(interpolator2);
        }
        Runnable runnable = this.tickShowRunnable;
        if (runnable != null) {
            runnable.run();
            this.tickShowRunnable = null;
            if (DialogX.useHaptic) {
                if (status == 1) {
                    performHapticFeedback(3);
                } else if (status == 2) {
                    new Handler(Looper.getMainLooper()).postDelayed(new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.3
                        @Override // java.lang.Runnable
                        public void run() {
                            ProgressView.this.performHapticFeedback(0);
                        }
                    }, ((float) TIP_ANIMATOR_DURATION) * 0.8f);
                } else if (status == 3) {
                    performHapticFeedback(3);
                    new Handler(Looper.getMainLooper()).postDelayed(new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.4
                        @Override // java.lang.Runnable
                        public void run() {
                            ProgressView.this.performHapticFeedback(3);
                        }
                    }, ((float) TIP_ANIMATOR_DURATION) * 0.5f);
                }
            }
        }
        if (status == 1) {
            showSuccessTick(canvas);
        } else if (status == 2) {
            showWarningTick(canvas);
        } else if (status != 3) {
        } else {
            showErrorTick(canvas);
        }
    }

    private void showSuccessTick(Canvas canvas) {
        float f = this.mRadius;
        float f2 = this.mCenterX;
        float f3 = (int) (f / 20.0f);
        int i2 = (int) ((f2 - (f / 10.0f)) - f3);
        int i3 = (int) (f2 - (f / 2.0f));
        int i4 = (int) (this.mCenterY + f3);
        int i5 = (int) (f2 + (f / 2.0f));
        float f4 = i3;
        int i6 = (int) (((i5 - i3) * this.tickAnimatorValue) + f4);
        Path path = new Path();
        path.moveTo(f4, i4);
        if (i6 < i2) {
            this.line1X = i6;
            int i7 = i4 + (i6 - i3);
            this.line1Y = i7;
            path.lineTo(i6, i7);
        } else {
            this.line1X = i2;
            int i8 = i4 + (i2 - i3);
            this.line1Y = i8;
            path.lineTo(i2, i8);
            this.line2X = i6;
            int i9 = this.line1Y - (i6 - this.line1X);
            this.line2Y = i9;
            path.lineTo(i6, i9);
        }
        canvas.drawPath(path, this.mPaint);
    }

    private void showWarningTick(Canvas canvas) {
        int i2 = (int) this.mCenterX;
        float f = this.mCenterY;
        float f2 = this.mRadius;
        int i3 = (int) (f - ((f2 * 1.0f) / 2.0f));
        int i4 = (int) (((1.0f * f2) / 8.0f) + f);
        int i5 = (int) (f + ((f2 * 3.0f) / 7.0f));
        float f3 = this.tickAnimatorValue;
        if (f3 < 0.9f) {
            float f4 = i2;
            float f5 = i3;
            canvas.drawLine(f4, f5, f4, f5 + ((i4 - i3) * f3), this.mPaint);
            return;
        }
        float f6 = i2;
        canvas.drawLine(f6, i3, f6, i4, this.mPaint);
        canvas.drawLine(f6, i5, f6, i5 + 1, this.mPaint);
    }

    private void showErrorTick(Canvas canvas) {
        float f = this.mCenterY;
        float f2 = this.mRadius;
        int i2 = (int) (f - ((f2 * 4.0f) / 10.0f));
        int i3 = (int) (this.mCenterX + ((f2 * 4.0f) / 10.0f));
        float f3 = this.tickAnimatorValue;
        if (f3 < 0.5f) {
            float f4 = i2;
            float f5 = i3 - i2;
            int i4 = (int) ((f3 * 2.0f * f5) + f4);
            this.line1X = i4;
            int i5 = (int) ((f3 * 2.0f * f5) + f4);
            this.line1Y = i5;
            canvas.drawLine(f4, f4, i4, i5, this.mPaint);
            return;
        }
        float f6 = i2;
        float f7 = i3 - i2;
        this.line1X = (int) ((f3 * 2.0f * f7) + f6);
        this.line1Y = (int) ((f3 * 2.0f * f7) + f6);
        float f8 = i3;
        canvas.drawLine(f6, f6, f8, f8, this.mPaint);
        float f9 = this.tickAnimatorValue;
        int i6 = (int) (f8 - (((f9 - 0.5f) * 2.0f) * f7));
        this.line2X = i6;
        int i7 = (int) (((f9 - 0.5f) * 2.0f * f7) + f6);
        this.line2Y = i7;
        canvas.drawLine(f8, f6, i6, i7, this.mPaint);
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void success() {
        if (this.status == 4) {
            progress(1.0f);
            this.waitArticulationAnimationRunnable = new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.5
                @Override // java.lang.Runnable
                public void run() {
                    ProgressView.this.initTipAnimator(1, new AccelerateDecelerateInterpolator());
                }
            };
            return;
        }
        initTipAnimator(1, new AccelerateDecelerateInterpolator());
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void warning() {
        if (this.status == 4) {
            progress(1.0f);
            this.waitArticulationAnimationRunnable = new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.6
                @Override // java.lang.Runnable
                public void run() {
                    ProgressView.this.initTipAnimator(2, new AccelerateInterpolator(2.0f));
                }
            };
            return;
        }
        initTipAnimator(2, new AccelerateInterpolator(2.0f));
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void error() {
        if (this.status == 4) {
            progress(1.0f);
            this.waitArticulationAnimationRunnable = new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.7
                @Override // java.lang.Runnable
                public void run() {
                    ProgressView.this.initTipAnimator(3, new DecelerateInterpolator(2.0f));
                }
            };
            return;
        }
        initTipAnimator(3, new DecelerateInterpolator(2.0f));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void initTipAnimator(int s, Interpolator i2) {
        this.interpolator = i2;
        this.status = s;
        if (this.successStep == 0) {
            this.waitArticulationAnimationRunnable = new Runnable() { // from class: com.kongzue.dialogx.util.views.ProgressView.8
                @Override // java.lang.Runnable
                public void run() {
                    ProgressView progressView = ProgressView.this;
                    progressView.initTipAnimator(progressView.status, ProgressView.this.interpolator);
                }
            };
            return;
        }
        ValueAnimator valueAnimator = this.tickAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
            this.tickAnimator = null;
        }
        this.tickAnimatorValue = 0.0f;
        ValueAnimator ofFloat = ValueAnimator.ofFloat(0.0f, 1.0f);
        this.tickAnimator = ofFloat;
        ofFloat.setDuration(TIP_ANIMATOR_DURATION);
        this.tickAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.util.views.ProgressView.9
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                ProgressView.this.tickAnimatorValue = ((Float) animation.getAnimatedValue()).floatValue();
                ProgressView.this.invalidate();
            }
        });
        this.tickAnimator.start();
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void progress(float progress) {
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        if (this.status != 4) {
            this.currentRotateDegrees = 0.0f;
        }
        ValueAnimator ofFloat = ValueAnimator.ofFloat(this.currentRotateDegrees, progress * 365.0f);
        this.rotateAnimator = ofFloat;
        ofFloat.setDuration(PROGRESSING_ANIMATOR_DURATION);
        this.rotateAnimator.setInterpolator(new DecelerateInterpolator(2.0f));
        this.rotateAnimator.setRepeatCount(0);
        this.rotateAnimator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() { // from class: com.kongzue.dialogx.util.views.ProgressView.10
            @Override // android.animation.ValueAnimator.AnimatorUpdateListener
            public void onAnimationUpdate(ValueAnimator animation) {
                ProgressView.this.currentRotateDegrees = ((Float) animation.getAnimatedValue()).floatValue();
                ProgressView.this.invalidate();
            }
        });
        this.rotateAnimator.start();
        this.status = 4;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public ProgressView whenShowTick(Runnable runnable) {
        this.tickShowRunnable = runnable;
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void loading() {
        this.noShowLoading = false;
        this.successStep = 0;
        this.line1X = 0;
        this.line1Y = 0;
        this.line2X = 0;
        this.line2Y = 0;
        this.status = 0;
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        this.isInited = false;
        init(null);
    }

    public int getStatus() {
        return this.status;
    }

    @Override // android.view.View
    protected void onDetachedFromWindow() {
        ValueAnimator valueAnimator = this.rotateAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
        }
        ValueAnimator valueAnimator2 = this.followAnimator;
        if (valueAnimator2 != null) {
            valueAnimator2.cancel();
        }
        super.onDetachedFromWindow();
    }

    public int getStrokeWidth() {
        return this.width;
    }

    public ProgressView setStrokeWidth(int width) {
        this.width = width;
        Paint paint = this.mPaint;
        if (paint != null) {
            paint.setStrokeWidth(width);
        }
        return this;
    }

    public int getColor() {
        return this.color;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public ProgressView setColor(int color) {
        this.color = color;
        Paint paint = this.mPaint;
        if (paint != null) {
            paint.setColor(color);
        }
        return this;
    }

    @Override // com.kongzue.dialogx.interfaces.ProgressViewInterface
    public void noLoading() {
        this.noShowLoading = true;
    }

    private int dip2px(float dpValue) {
        return (int) ((dpValue * Resources.getSystem().getDisplayMetrics().density) + 0.5f);
    }
}
