package easypermission.davidinchina.com.easylibrary;

import android.app.Activity;
import easypermission.davidinchina.com.easylibrary.annotation.OnEasyPermissionFailed;
import easypermission.davidinchina.com.easylibrary.annotation.OnEasyPermissionSuccess;
import easypermission.davidinchina.com.easylibrary.util.EasyPermissionUtil;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;
/* loaded from: classes4.dex */
public class EasyPermission {
    private Activity activity;
    private String[] permissions;
    private int requestCode = 101;

    private EasyPermission(Activity activity) {
        this.activity = activity;
    }

    public static EasyPermission with(Activity activity) {
        return new EasyPermission(activity);
    }

    public EasyPermission permissions(String... strArr) {
        this.permissions = strArr;
        return this;
    }

    public EasyPermission code(int i2) {
        this.requestCode = i2;
        return this;
    }

    public void request() {
        Activity activity = this.activity;
        if (activity == null) {
            throw new IllegalArgumentException("null activity is not supported");
        }
        if (this.permissions == null) {
            this.permissions = EasyPermissionUtil.getPermissions(activity);
        }
        requestPermissions(this.activity, this.requestCode, this.permissions);
    }

    private static void requestPermissions(Activity activity, int i2, String[] strArr) {
        if (!EasyPermissionUtil.isOverMarshmallow()) {
            doExecuteSuccess(activity, i2);
            return;
        }
        List<String> findDeniedPermissions = EasyPermissionUtil.findDeniedPermissions(activity, strArr);
        if (findDeniedPermissions.size() > 0) {
            activity.requestPermissions((String[]) findDeniedPermissions.toArray(new String[findDeniedPermissions.size()]), i2);
        } else {
            doExecuteSuccess(activity, i2);
        }
    }

    public static void handleResult(Activity activity, int i2, String[] strArr, int[] iArr) {
        ArrayList arrayList = new ArrayList();
        for (int i3 = 0; i3 < iArr.length; i3++) {
            if (iArr[i3] != 0) {
                arrayList.add(strArr[i3]);
            }
        }
        if (arrayList.size() > 0) {
            doExecuteFail(activity, i2);
        } else {
            doExecuteSuccess(activity, i2);
        }
    }

    private static void doExecuteSuccess(Activity activity, int i2) {
        executeMethod(activity, EasyPermissionUtil.findMethodWithRequestCode(activity.getClass(), OnEasyPermissionSuccess.class, i2));
    }

    private static void doExecuteFail(Activity activity, int i2) {
        executeMethod(activity, EasyPermissionUtil.findMethodWithRequestCode(activity.getClass(), OnEasyPermissionFailed.class, i2));
    }

    private static void executeMethod(Object obj, Method method) {
        executeMethodWithParam(obj, method, new Object[0]);
    }

    private static void executeMethodWithParam(Object obj, Method method, Object... objArr) {
        if (method != null) {
            try {
                if (!method.isAccessible()) {
                    method.setAccessible(true);
                }
                method.invoke(obj, objArr);
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            } catch (InvocationTargetException e2) {
                e2.printStackTrace();
            }
        }
    }
}
