package easypermission.davidinchina.com.easylibrary.util;

import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import easypermission.davidinchina.com.easylibrary.annotation.OnEasyPermissionFailed;
import easypermission.davidinchina.com.easylibrary.annotation.OnEasyPermissionSuccess;
import java.lang.annotation.Annotation;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
/* loaded from: classes4.dex */
public class EasyPermissionUtil {
    private static final String TAG = "EasyPermissionUtil:";

    public static boolean isOverMarshmallow() {
        return Build.VERSION.SDK_INT >= 23;
    }

    public static <A extends Annotation> Method findMethodWithRequestCode(Class cls, Class<A> cls2, int i2) {
        Method[] declaredMethods;
        for (Method method : cls.getDeclaredMethods()) {
            if (method.getAnnotation(cls2) != null && isEqualRequestCodeFromAnnotation(method, cls2, i2)) {
                return method;
            }
        }
        return null;
    }

    public static boolean isEqualRequestCodeFromAnnotation(Method method, Class cls, int i2) {
        return cls.equals(OnEasyPermissionFailed.class) ? i2 == ((OnEasyPermissionFailed) method.getAnnotation(OnEasyPermissionFailed.class)).value() : cls.equals(OnEasyPermissionSuccess.class) && i2 == ((OnEasyPermissionSuccess) method.getAnnotation(OnEasyPermissionSuccess.class)).value();
    }

    public static List<String> findDeniedPermissions(Activity activity, String... strArr) {
        ArrayList arrayList = new ArrayList();
        for (String str : strArr) {
            if (activity.checkSelfPermission(str) != 0) {
                arrayList.add(str);
            }
        }
        return arrayList;
    }

    public static String[] getPermissions(Context context) {
        try {
            String[] strArr = context.getPackageManager().getPackageInfo(context.getPackageName(), 4096).requestedPermissions;
            HashSet hashSet = new HashSet();
            for (String str : strArr) {
                if (checkIsDanderPermission(str)) {
                    hashSet.add(str);
                }
            }
            return (String[]) hashSet.toArray(new String[hashSet.size()]);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
            return new String[0];
        }
    }

    public static boolean checkIsDanderPermission(String str) {
        return str.equals("android.permission.WRITE_CONTACTS") || str.equals("android.permission.GET_ACCOUNTS") || str.equals("android.permission.READ_CONTACTS") || str.equals("android.permission.READ_CALL_LOG") || str.equals("android.permission.READ_PHONE_STATE") || str.equals("android.permission.CALL_PHONE") || str.equals("android.permission.WRITE_CALL_LOG") || str.equals("android.permission.USE_SIP") || str.equals("android.permission.PROCESS_OUTGOING_CALLS") || str.equals("com.android.voicemail.permission.ADD_VOICEMAIL") || str.equals("android.permission.READ_CALENDAR") || str.equals("android.permission.WRITE_CALENDAR") || str.equals("android.permission.CAMERA") || str.equals("android.permission.BODY_SENSORS") || str.equals("android.permission.ACCESS_FINE_LOCATION") || str.equals("android.permission.ACCESS_COARSE_LOCATION") || str.equals("android.permission.READ_EXTERNAL_STORAGE") || str.equals("android.permission.WRITE_EXTERNAL_STORAGE") || str.equals("android.permission.RECORD_AUDIO") || str.equals("android.permission.READ_SMS") || str.equals("android.permission.RECEIVE_WAP_PUSH") || str.equals("android.permission.RECEIVE_MMS") || str.equals("android.permission.RECEIVE_SMS") || str.equals("android.permission.SEND_SMS") || str.equals("android.permission.READ_CELL_BROADCASTS");
    }
}
