package net.lingala.zip4j.core;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.SplitOutputStream;
import net.lingala.zip4j.model.AESExtraDataRecord;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.LocalFileHeader;
import net.lingala.zip4j.model.Zip64EndCentralDirLocator;
import net.lingala.zip4j.model.Zip64EndCentralDirRecord;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Raw;
import net.lingala.zip4j.util.Zip4jUtil;
/* loaded from: classes11.dex */
public class HeaderWriter {
    private final int ZIP64_EXTRA_BUF = 50;

    private byte[] byteArrayListToByteArray(List list) throws ZipException {
        if (list != null) {
            if (list.size() <= 0) {
                return null;
            }
            byte[] bArr = new byte[list.size()];
            for (int i2 = 0; i2 < list.size(); i2++) {
                bArr[i2] = Byte.parseByte((String) list.get(i2));
            }
            return bArr;
        }
        throw new ZipException("input byte array list is null, cannot conver to byte array");
    }

    private void copyByteArrayToArrayList(byte[] bArr, List list) throws ZipException {
        if (list == null || bArr == null) {
            throw new ZipException("one of the input parameters is null, cannot copy byte array to array list");
        }
        for (byte b : bArr) {
            list.add(Byte.toString(b));
        }
    }

    private int countNumberOfFileHeaderEntriesOnDisk(ArrayList arrayList, int i2) throws ZipException {
        if (arrayList != null) {
            int i3 = 0;
            for (int i4 = 0; i4 < arrayList.size(); i4++) {
                if (((FileHeader) arrayList.get(i4)).getDiskNumberStart() == i2) {
                    i3++;
                }
            }
            return i3;
        }
        throw new ZipException("file headers are null, cannot calculate number of entries on this disk");
    }

    private void processHeaderData(ZipModel zipModel, OutputStream outputStream) throws ZipException {
        int i2;
        try {
            if (outputStream instanceof SplitOutputStream) {
                zipModel.getEndCentralDirRecord().setOffsetOfStartOfCentralDir(((SplitOutputStream) outputStream).getFilePointer());
                i2 = ((SplitOutputStream) outputStream).getCurrSplitFileCounter();
            } else {
                i2 = 0;
            }
            if (zipModel.isZip64Format()) {
                if (zipModel.getZip64EndCentralDirRecord() == null) {
                    zipModel.setZip64EndCentralDirRecord(new Zip64EndCentralDirRecord());
                }
                if (zipModel.getZip64EndCentralDirLocator() == null) {
                    zipModel.setZip64EndCentralDirLocator(new Zip64EndCentralDirLocator());
                }
                zipModel.getZip64EndCentralDirLocator().setNoOfDiskStartOfZip64EndOfCentralDirRec(i2);
                zipModel.getZip64EndCentralDirLocator().setTotNumberOfDiscs(i2 + 1);
            }
            zipModel.getEndCentralDirRecord().setNoOfThisDisk(i2);
            zipModel.getEndCentralDirRecord().setNoOfThisDiskStartOfCentralDir(i2);
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    private void updateCompressedSizeInLocalFileHeader(SplitOutputStream splitOutputStream, LocalFileHeader localFileHeader, long j, long j2, byte[] bArr, boolean z) throws ZipException {
        if (splitOutputStream == null) {
            throw new ZipException("invalid output stream, cannot update compressed size for local file header");
        }
        try {
            if (!localFileHeader.isWriteComprSizeInZip64ExtraRecord()) {
                splitOutputStream.seek(j + j2);
            } else if (bArr.length != 8) {
                throw new ZipException("attempting to write a non 8-byte compressed size block for a zip64 file");
            } else {
                long fileNameLength = j + j2 + 4 + 4 + 2 + 2 + localFileHeader.getFileNameLength() + 2 + 2 + 8;
                if (j2 == 22) {
                    fileNameLength += 8;
                }
                splitOutputStream.seek(fileNameLength);
            }
            splitOutputStream.write(bArr);
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    private int writeCentralDirectory(ZipModel zipModel, OutputStream outputStream, List list) throws ZipException {
        if (zipModel == null || outputStream == null) {
            throw new ZipException("input parameters is null, cannot write central directory");
        }
        int i2 = 0;
        if (zipModel.getCentralDirectory() != null && zipModel.getCentralDirectory().getFileHeaders() != null && zipModel.getCentralDirectory().getFileHeaders().size() > 0) {
            for (int i3 = 0; i3 < zipModel.getCentralDirectory().getFileHeaders().size(); i3++) {
                i2 += writeFileHeader(zipModel, (FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3), outputStream, list);
            }
        }
        return i2;
    }

    private void writeEndOfCentralDirectoryRecord(ZipModel zipModel, OutputStream outputStream, int i2, long j, List list) throws ZipException {
        if (zipModel == null || outputStream == null) {
            throw new ZipException("zip model or output stream is null, cannot write end of central directory record");
        }
        try {
            byte[] bArr = new byte[2];
            byte[] bArr2 = new byte[4];
            byte[] bArr3 = new byte[8];
            Raw.writeIntLittleEndian(bArr2, 0, (int) zipModel.getEndCentralDirRecord().getSignature());
            copyByteArrayToArrayList(bArr2, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) zipModel.getEndCentralDirRecord().getNoOfThisDisk());
            copyByteArrayToArrayList(bArr, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) zipModel.getEndCentralDirRecord().getNoOfThisDiskStartOfCentralDir());
            copyByteArrayToArrayList(bArr, list);
            if (zipModel.getCentralDirectory() == null || zipModel.getCentralDirectory().getFileHeaders() == null) {
                throw new ZipException("invalid central directory/file headers, cannot write end of central directory record");
            }
            int size = zipModel.getCentralDirectory().getFileHeaders().size();
            Raw.writeShortLittleEndian(bArr, 0, (short) (zipModel.isSplitArchive() ? countNumberOfFileHeaderEntriesOnDisk(zipModel.getCentralDirectory().getFileHeaders(), zipModel.getEndCentralDirRecord().getNoOfThisDisk()) : size));
            copyByteArrayToArrayList(bArr, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) size);
            copyByteArrayToArrayList(bArr, list);
            Raw.writeIntLittleEndian(bArr2, 0, i2);
            copyByteArrayToArrayList(bArr2, list);
            if (j > InternalZipConstants.ZIP_64_LIMIT) {
                Raw.writeLongLittleEndian(bArr3, 0, InternalZipConstants.ZIP_64_LIMIT);
                System.arraycopy(bArr3, 0, bArr2, 0, 4);
            } else {
                Raw.writeLongLittleEndian(bArr3, 0, j);
                System.arraycopy(bArr3, 0, bArr2, 0, 4);
            }
            copyByteArrayToArrayList(bArr2, list);
            int commentLength = zipModel.getEndCentralDirRecord().getComment() != null ? zipModel.getEndCentralDirRecord().getCommentLength() : 0;
            Raw.writeShortLittleEndian(bArr, 0, (short) commentLength);
            copyByteArrayToArrayList(bArr, list);
            if (commentLength > 0) {
                copyByteArrayToArrayList(zipModel.getEndCentralDirRecord().getCommentBytes(), list);
            }
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x00d4, code lost:
        r13 = 20;
     */
    /* JADX WARN: Removed duplicated region for block: B:15:0x00b8 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:16:0x00c0 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:25:0x00da A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:28:0x00e2 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:31:0x0102 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:32:0x010a A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:35:0x0125 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:36:0x0136 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:39:0x014d A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:42:0x015c  */
    /* JADX WARN: Removed duplicated region for block: B:43:0x015f  */
    /* JADX WARN: Removed duplicated region for block: B:45:0x0162 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:48:0x0170 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:50:0x0189 A[Catch: Exception -> 0x01e6, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:53:0x019b A[Catch: Exception -> 0x01e6, TRY_LEAVE, TryCatch #0 {Exception -> 0x01e6, blocks: (B:6:0x0009, B:8:0x006e, B:11:0x007a, B:13:0x00a3, B:15:0x00b8, B:26:0x00dc, B:28:0x00e2, B:29:0x00e4, B:31:0x0102, B:33:0x0118, B:35:0x0125, B:37:0x0149, B:51:0x0195, B:53:0x019b, B:40:0x014f, B:45:0x0162, B:46:0x0164, B:48:0x0170, B:50:0x0189, B:36:0x0136, B:32:0x010a, B:25:0x00da, B:16:0x00c0, B:12:0x0096), top: B:61:0x0009 }] */
    /* JADX WARN: Removed duplicated region for block: B:63:? A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private int writeFileHeader(ZipModel zipModel, FileHeader fileHeader, OutputStream outputStream, List list) throws ZipException {
        boolean z;
        boolean z2;
        int i2;
        int encodedStringLength;
        int i3;
        if (fileHeader == null || outputStream == null) {
            throw new ZipException("input parameters is null, cannot write local file header");
        }
        try {
            byte[] bArr = new byte[2];
            byte[] bArr2 = new byte[4];
            byte[] bArr3 = new byte[8];
            byte[] bArr4 = {0, 0};
            Raw.writeIntLittleEndian(bArr2, 0, fileHeader.getSignature());
            copyByteArrayToArrayList(bArr2, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getVersionMadeBy());
            copyByteArrayToArrayList(bArr, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getVersionNeededToExtract());
            copyByteArrayToArrayList(bArr, list);
            copyByteArrayToArrayList(fileHeader.getGeneralPurposeFlag(), list);
            Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getCompressionMethod());
            copyByteArrayToArrayList(bArr, list);
            Raw.writeIntLittleEndian(bArr2, 0, fileHeader.getLastModFileTime());
            copyByteArrayToArrayList(bArr2, list);
            Raw.writeIntLittleEndian(bArr2, 0, (int) fileHeader.getCrc32());
            copyByteArrayToArrayList(bArr2, list);
            if (fileHeader.getCompressedSize() < InternalZipConstants.ZIP_64_LIMIT && fileHeader.getUncompressedSize() + 50 < InternalZipConstants.ZIP_64_LIMIT) {
                Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getCompressedSize());
                System.arraycopy(bArr3, 0, bArr2, 0, 4);
                copyByteArrayToArrayList(bArr2, list);
                Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getUncompressedSize());
                System.arraycopy(bArr3, 0, bArr2, 0, 4);
                copyByteArrayToArrayList(bArr2, list);
                z = false;
                Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getFileNameLength());
                copyByteArrayToArrayList(bArr, list);
                byte[] bArr5 = new byte[4];
                if (fileHeader.getOffsetLocalHeader() <= InternalZipConstants.ZIP_64_LIMIT) {
                    Raw.writeLongLittleEndian(bArr3, 0, InternalZipConstants.ZIP_64_LIMIT);
                    System.arraycopy(bArr3, 0, bArr5, 0, 4);
                    z2 = true;
                } else {
                    Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getOffsetLocalHeader());
                    System.arraycopy(bArr3, 0, bArr5, 0, 4);
                    z2 = false;
                }
                if (!z && !z2) {
                    i2 = 0;
                    if (fileHeader.getAesExtraDataRecord() != null) {
                        i2 += 11;
                    }
                    Raw.writeShortLittleEndian(bArr, 0, (short) i2);
                    copyByteArrayToArrayList(bArr, list);
                    copyByteArrayToArrayList(bArr4, list);
                    Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getDiskNumberStart());
                    copyByteArrayToArrayList(bArr, list);
                    copyByteArrayToArrayList(bArr4, list);
                    if (fileHeader.getExternalFileAttr() == null) {
                        copyByteArrayToArrayList(fileHeader.getExternalFileAttr(), list);
                    } else {
                        copyByteArrayToArrayList(new byte[]{0, 0, 0, 0}, list);
                    }
                    copyByteArrayToArrayList(bArr5, list);
                    if (Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getFileNameCharset())) {
                        copyByteArrayToArrayList(Zip4jUtil.convertCharset(fileHeader.getFileName()), list);
                        encodedStringLength = Zip4jUtil.getEncodedStringLength(fileHeader.getFileName());
                    } else {
                        byte[] bytes = fileHeader.getFileName().getBytes(zipModel.getFileNameCharset());
                        copyByteArrayToArrayList(bytes, list);
                        encodedStringLength = bytes.length;
                    }
                    i3 = encodedStringLength + 46;
                    if (!z || z2) {
                        zipModel.setZip64Format(true);
                        Raw.writeShortLittleEndian(bArr, 0, (short) 1);
                        copyByteArrayToArrayList(bArr, list);
                        int i4 = !z ? 16 : 0;
                        if (z2) {
                            i4 += 8;
                        }
                        Raw.writeShortLittleEndian(bArr, 0, (short) i4);
                        copyByteArrayToArrayList(bArr, list);
                        i3 = i3 + 2 + 2;
                        if (z) {
                            Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getUncompressedSize());
                            copyByteArrayToArrayList(bArr3, list);
                            Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getCompressedSize());
                            copyByteArrayToArrayList(bArr3, list);
                            i3 = i3 + 8 + 8;
                        }
                        if (z2) {
                            Raw.writeLongLittleEndian(bArr3, 0, fileHeader.getOffsetLocalHeader());
                            copyByteArrayToArrayList(bArr3, list);
                            i3 += 8;
                        }
                    }
                    if (fileHeader.getAesExtraDataRecord() == null) {
                        AESExtraDataRecord aesExtraDataRecord = fileHeader.getAesExtraDataRecord();
                        Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getSignature());
                        copyByteArrayToArrayList(bArr, list);
                        Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getDataSize());
                        copyByteArrayToArrayList(bArr, list);
                        Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getVersionNumber());
                        copyByteArrayToArrayList(bArr, list);
                        copyByteArrayToArrayList(aesExtraDataRecord.getVendorID().getBytes(), list);
                        copyByteArrayToArrayList(new byte[]{(byte) aesExtraDataRecord.getAesStrength()}, list);
                        Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getCompressionMethod());
                        copyByteArrayToArrayList(bArr, list);
                        return i3 + 11;
                    }
                    return i3;
                }
                i2 = 4;
                if (z2) {
                    i2 += 8;
                }
                if (fileHeader.getAesExtraDataRecord() != null) {
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) i2);
                copyByteArrayToArrayList(bArr, list);
                copyByteArrayToArrayList(bArr4, list);
                Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getDiskNumberStart());
                copyByteArrayToArrayList(bArr, list);
                copyByteArrayToArrayList(bArr4, list);
                if (fileHeader.getExternalFileAttr() == null) {
                }
                copyByteArrayToArrayList(bArr5, list);
                if (Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getFileNameCharset())) {
                }
                i3 = encodedStringLength + 46;
                if (!z) {
                }
                zipModel.setZip64Format(true);
                Raw.writeShortLittleEndian(bArr, 0, (short) 1);
                copyByteArrayToArrayList(bArr, list);
                if (!z) {
                }
                if (z2) {
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) i4);
                copyByteArrayToArrayList(bArr, list);
                i3 = i3 + 2 + 2;
                if (z) {
                }
                if (z2) {
                }
                if (fileHeader.getAesExtraDataRecord() == null) {
                }
            }
            Raw.writeLongLittleEndian(bArr3, 0, InternalZipConstants.ZIP_64_LIMIT);
            System.arraycopy(bArr3, 0, bArr2, 0, 4);
            copyByteArrayToArrayList(bArr2, list);
            copyByteArrayToArrayList(bArr2, list);
            z = true;
            Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getFileNameLength());
            copyByteArrayToArrayList(bArr, list);
            byte[] bArr52 = new byte[4];
            if (fileHeader.getOffsetLocalHeader() <= InternalZipConstants.ZIP_64_LIMIT) {
            }
            if (!z) {
                i2 = 0;
                if (fileHeader.getAesExtraDataRecord() != null) {
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) i2);
                copyByteArrayToArrayList(bArr, list);
                copyByteArrayToArrayList(bArr4, list);
                Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getDiskNumberStart());
                copyByteArrayToArrayList(bArr, list);
                copyByteArrayToArrayList(bArr4, list);
                if (fileHeader.getExternalFileAttr() == null) {
                }
                copyByteArrayToArrayList(bArr52, list);
                if (Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getFileNameCharset())) {
                }
                i3 = encodedStringLength + 46;
                if (!z) {
                }
                zipModel.setZip64Format(true);
                Raw.writeShortLittleEndian(bArr, 0, (short) 1);
                copyByteArrayToArrayList(bArr, list);
                if (!z) {
                }
                if (z2) {
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) i4);
                copyByteArrayToArrayList(bArr, list);
                i3 = i3 + 2 + 2;
                if (z) {
                }
                if (z2) {
                }
                if (fileHeader.getAesExtraDataRecord() == null) {
                }
            }
            i2 = 4;
            if (z2) {
            }
            if (fileHeader.getAesExtraDataRecord() != null) {
            }
            Raw.writeShortLittleEndian(bArr, 0, (short) i2);
            copyByteArrayToArrayList(bArr, list);
            copyByteArrayToArrayList(bArr4, list);
            Raw.writeShortLittleEndian(bArr, 0, (short) fileHeader.getDiskNumberStart());
            copyByteArrayToArrayList(bArr, list);
            copyByteArrayToArrayList(bArr4, list);
            if (fileHeader.getExternalFileAttr() == null) {
            }
            copyByteArrayToArrayList(bArr52, list);
            if (Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getFileNameCharset())) {
            }
            i3 = encodedStringLength + 46;
            if (!z) {
            }
            zipModel.setZip64Format(true);
            Raw.writeShortLittleEndian(bArr, 0, (short) 1);
            copyByteArrayToArrayList(bArr, list);
            if (!z) {
            }
            if (z2) {
            }
            Raw.writeShortLittleEndian(bArr, 0, (short) i4);
            copyByteArrayToArrayList(bArr, list);
            i3 = i3 + 2 + 2;
            if (z) {
            }
            if (z2) {
            }
            if (fileHeader.getAesExtraDataRecord() == null) {
            }
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    private void writeZip64EndOfCentralDirectoryLocator(ZipModel zipModel, OutputStream outputStream, List list) throws ZipException {
        if (zipModel == null || outputStream == null) {
            throw new ZipException("zip model or output stream is null, cannot write zip64 end of central directory locator");
        }
        try {
            byte[] bArr = new byte[4];
            byte[] bArr2 = new byte[8];
            Raw.writeIntLittleEndian(bArr, 0, 117853008);
            copyByteArrayToArrayList(bArr, list);
            Raw.writeIntLittleEndian(bArr, 0, zipModel.getZip64EndCentralDirLocator().getNoOfDiskStartOfZip64EndOfCentralDirRec());
            copyByteArrayToArrayList(bArr, list);
            Raw.writeLongLittleEndian(bArr2, 0, zipModel.getZip64EndCentralDirLocator().getOffsetZip64EndOfCentralDirRec());
            copyByteArrayToArrayList(bArr2, list);
            Raw.writeIntLittleEndian(bArr, 0, zipModel.getZip64EndCentralDirLocator().getTotNumberOfDiscs());
            copyByteArrayToArrayList(bArr, list);
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void writeZip64EndOfCentralDirectoryRecord(ZipModel zipModel, OutputStream outputStream, int i2, long j, List list) throws ZipException {
        int i3;
        if (zipModel == null || outputStream == null) {
            throw new ZipException("zip model or output stream is null, cannot write zip64 end of central directory record");
        }
        try {
            byte[] bArr = new byte[2];
            byte[] bArr2 = {0, 0};
            byte[] bArr3 = new byte[4];
            byte[] bArr4 = new byte[8];
            Raw.writeIntLittleEndian(bArr3, 0, 101075792);
            copyByteArrayToArrayList(bArr3, list);
            Raw.writeLongLittleEndian(bArr4, 0, 44L);
            copyByteArrayToArrayList(bArr4, list);
            if (zipModel.getCentralDirectory() == null || zipModel.getCentralDirectory().getFileHeaders() == null || zipModel.getCentralDirectory().getFileHeaders().size() <= 0) {
                copyByteArrayToArrayList(bArr2, list);
                copyByteArrayToArrayList(bArr2, list);
            } else {
                Raw.writeShortLittleEndian(bArr, 0, (short) ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(0)).getVersionMadeBy());
                copyByteArrayToArrayList(bArr, list);
                Raw.writeShortLittleEndian(bArr, 0, (short) ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(0)).getVersionNeededToExtract());
                copyByteArrayToArrayList(bArr, list);
            }
            Raw.writeIntLittleEndian(bArr3, 0, zipModel.getEndCentralDirRecord().getNoOfThisDisk());
            copyByteArrayToArrayList(bArr3, list);
            Raw.writeIntLittleEndian(bArr3, 0, zipModel.getEndCentralDirRecord().getNoOfThisDiskStartOfCentralDir());
            copyByteArrayToArrayList(bArr3, list);
            if (zipModel.getCentralDirectory() == null || zipModel.getCentralDirectory().getFileHeaders() == null) {
                throw new ZipException("invalid central directory/file headers, cannot write end of central directory record");
            }
            int size = zipModel.getCentralDirectory().getFileHeaders().size();
            if (zipModel.isSplitArchive()) {
                countNumberOfFileHeaderEntriesOnDisk(zipModel.getCentralDirectory().getFileHeaders(), zipModel.getEndCentralDirRecord().getNoOfThisDisk());
                i3 = 0;
            } else {
                i3 = size;
            }
            Raw.writeLongLittleEndian(bArr4, 0, i3);
            copyByteArrayToArrayList(bArr4, list);
            Raw.writeLongLittleEndian(bArr4, 0, size);
            copyByteArrayToArrayList(bArr4, list);
            Raw.writeLongLittleEndian(bArr4, 0, i2);
            copyByteArrayToArrayList(bArr4, list);
            Raw.writeLongLittleEndian(bArr4, 0, j);
            copyByteArrayToArrayList(bArr4, list);
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void writeZipHeaderBytes(ZipModel zipModel, OutputStream outputStream, byte[] bArr) throws ZipException {
        if (bArr == null) {
            throw new ZipException("invalid buff to write as zip headers");
        }
        try {
            if ((outputStream instanceof SplitOutputStream) && ((SplitOutputStream) outputStream).checkBuffSizeAndStartNextSplitFile(bArr.length)) {
                finalizeZipFile(zipModel, outputStream);
            } else {
                outputStream.write(bArr);
            }
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    public void finalizeZipFile(ZipModel zipModel, OutputStream outputStream) throws ZipException {
        if (zipModel == null || outputStream == null) {
            throw new ZipException("input parameters is null, cannot finalize zip file");
        }
        try {
            processHeaderData(zipModel, outputStream);
            long offsetOfStartOfCentralDir = zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir();
            ArrayList arrayList = new ArrayList();
            int writeCentralDirectory = writeCentralDirectory(zipModel, outputStream, arrayList);
            if (zipModel.isZip64Format()) {
                if (zipModel.getZip64EndCentralDirRecord() == null) {
                    zipModel.setZip64EndCentralDirRecord(new Zip64EndCentralDirRecord());
                }
                if (zipModel.getZip64EndCentralDirLocator() == null) {
                    zipModel.setZip64EndCentralDirLocator(new Zip64EndCentralDirLocator());
                }
                zipModel.getZip64EndCentralDirLocator().setOffsetZip64EndOfCentralDirRec(writeCentralDirectory + offsetOfStartOfCentralDir);
                if (outputStream instanceof SplitOutputStream) {
                    zipModel.getZip64EndCentralDirLocator().setNoOfDiskStartOfZip64EndOfCentralDirRec(((SplitOutputStream) outputStream).getCurrSplitFileCounter());
                    zipModel.getZip64EndCentralDirLocator().setTotNumberOfDiscs(((SplitOutputStream) outputStream).getCurrSplitFileCounter() + 1);
                } else {
                    zipModel.getZip64EndCentralDirLocator().setNoOfDiskStartOfZip64EndOfCentralDirRec(0);
                    zipModel.getZip64EndCentralDirLocator().setTotNumberOfDiscs(1);
                }
                writeZip64EndOfCentralDirectoryRecord(zipModel, outputStream, writeCentralDirectory, offsetOfStartOfCentralDir, arrayList);
                writeZip64EndOfCentralDirectoryLocator(zipModel, outputStream, arrayList);
            }
            writeEndOfCentralDirectoryRecord(zipModel, outputStream, writeCentralDirectory, offsetOfStartOfCentralDir, arrayList);
            writeZipHeaderBytes(zipModel, outputStream, byteArrayListToByteArray(arrayList));
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    public void finalizeZipFileWithoutValidations(ZipModel zipModel, OutputStream outputStream) throws ZipException {
        if (zipModel == null || outputStream == null) {
            throw new ZipException("input parameters is null, cannot finalize zip file without validations");
        }
        try {
            ArrayList arrayList = new ArrayList();
            long offsetOfStartOfCentralDir = zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir();
            int writeCentralDirectory = writeCentralDirectory(zipModel, outputStream, arrayList);
            if (zipModel.isZip64Format()) {
                if (zipModel.getZip64EndCentralDirRecord() == null) {
                    zipModel.setZip64EndCentralDirRecord(new Zip64EndCentralDirRecord());
                }
                if (zipModel.getZip64EndCentralDirLocator() == null) {
                    zipModel.setZip64EndCentralDirLocator(new Zip64EndCentralDirLocator());
                }
                zipModel.getZip64EndCentralDirLocator().setOffsetZip64EndOfCentralDirRec(writeCentralDirectory + offsetOfStartOfCentralDir);
                writeZip64EndOfCentralDirectoryRecord(zipModel, outputStream, writeCentralDirectory, offsetOfStartOfCentralDir, arrayList);
                writeZip64EndOfCentralDirectoryLocator(zipModel, outputStream, arrayList);
            }
            writeEndOfCentralDirectoryRecord(zipModel, outputStream, writeCentralDirectory, offsetOfStartOfCentralDir, arrayList);
            writeZipHeaderBytes(zipModel, outputStream, byteArrayListToByteArray(arrayList));
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    public void updateLocalFileHeader(LocalFileHeader localFileHeader, long j, int i2, ZipModel zipModel, byte[] bArr, int i3, SplitOutputStream splitOutputStream) throws ZipException {
        SplitOutputStream splitOutputStream2;
        boolean z;
        if (localFileHeader == null || j < 0 || zipModel == null) {
            throw new ZipException("invalid input parameters, cannot update local file header");
        }
        try {
            if (i3 != splitOutputStream.getCurrSplitFileCounter()) {
                File file = new File(zipModel.getZipFile());
                String parent = file.getParent();
                String zipFileNameWithoutExt = Zip4jUtil.getZipFileNameWithoutExt(file.getName());
                String str = parent + System.getProperty("file.separator");
                splitOutputStream2 = new SplitOutputStream(new File((i3 < 9 ? new StringBuilder().append(str).append(zipFileNameWithoutExt).append(".z0").append(i3 + 1) : new StringBuilder().append(str).append(zipFileNameWithoutExt).append(".z").append(i3 + 1)).toString()));
                z = true;
            } else {
                splitOutputStream2 = splitOutputStream;
                z = false;
            }
            long filePointer = splitOutputStream2.getFilePointer();
            if (i2 == 14) {
                splitOutputStream2.seek(i2 + j);
                splitOutputStream2.write(bArr);
            } else if (i2 == 18 || i2 == 22) {
                updateCompressedSizeInLocalFileHeader(splitOutputStream2, localFileHeader, j, i2, bArr, zipModel.isZip64Format());
            }
            if (z) {
                splitOutputStream2.close();
            } else {
                splitOutputStream.seek(filePointer);
            }
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    public int writeExtendedLocalHeader(LocalFileHeader localFileHeader, OutputStream outputStream) throws ZipException, IOException {
        if (localFileHeader == null || outputStream == null) {
            throw new ZipException("input parameters is null, cannot write extended local header");
        }
        ArrayList arrayList = new ArrayList();
        byte[] bArr = new byte[4];
        Raw.writeIntLittleEndian(bArr, 0, 134695760);
        copyByteArrayToArrayList(bArr, arrayList);
        Raw.writeIntLittleEndian(bArr, 0, (int) localFileHeader.getCrc32());
        copyByteArrayToArrayList(bArr, arrayList);
        long compressedSize = localFileHeader.getCompressedSize();
        if (compressedSize >= 2147483647L) {
            compressedSize = 2147483647L;
        }
        Raw.writeIntLittleEndian(bArr, 0, (int) compressedSize);
        copyByteArrayToArrayList(bArr, arrayList);
        long uncompressedSize = localFileHeader.getUncompressedSize();
        Raw.writeIntLittleEndian(bArr, 0, (int) (uncompressedSize < 2147483647L ? uncompressedSize : 2147483647L));
        copyByteArrayToArrayList(bArr, arrayList);
        byte[] byteArrayListToByteArray = byteArrayListToByteArray(arrayList);
        outputStream.write(byteArrayListToByteArray);
        return byteArrayListToByteArray.length;
    }

    public int writeLocalFileHeader(ZipModel zipModel, LocalFileHeader localFileHeader, OutputStream outputStream) throws ZipException {
        boolean z;
        if (localFileHeader != null) {
            try {
                ArrayList arrayList = new ArrayList();
                byte[] bArr = new byte[2];
                byte[] bArr2 = new byte[4];
                byte[] bArr3 = new byte[8];
                Raw.writeIntLittleEndian(bArr2, 0, localFileHeader.getSignature());
                copyByteArrayToArrayList(bArr2, arrayList);
                Raw.writeShortLittleEndian(bArr, 0, (short) localFileHeader.getVersionNeededToExtract());
                copyByteArrayToArrayList(bArr, arrayList);
                copyByteArrayToArrayList(localFileHeader.getGeneralPurposeFlag(), arrayList);
                Raw.writeShortLittleEndian(bArr, 0, (short) localFileHeader.getCompressionMethod());
                copyByteArrayToArrayList(bArr, arrayList);
                Raw.writeIntLittleEndian(bArr2, 0, localFileHeader.getLastModFileTime());
                copyByteArrayToArrayList(bArr2, arrayList);
                Raw.writeIntLittleEndian(bArr2, 0, (int) localFileHeader.getCrc32());
                copyByteArrayToArrayList(bArr2, arrayList);
                if (localFileHeader.getUncompressedSize() + 50 >= InternalZipConstants.ZIP_64_LIMIT) {
                    Raw.writeLongLittleEndian(bArr3, 0, InternalZipConstants.ZIP_64_LIMIT);
                    System.arraycopy(bArr3, 0, bArr2, 0, 4);
                    copyByteArrayToArrayList(bArr2, arrayList);
                    copyByteArrayToArrayList(bArr2, arrayList);
                    zipModel.setZip64Format(true);
                    localFileHeader.setWriteComprSizeInZip64ExtraRecord(true);
                    z = true;
                } else {
                    Raw.writeLongLittleEndian(bArr3, 0, localFileHeader.getCompressedSize());
                    System.arraycopy(bArr3, 0, bArr2, 0, 4);
                    copyByteArrayToArrayList(bArr2, arrayList);
                    Raw.writeLongLittleEndian(bArr3, 0, localFileHeader.getUncompressedSize());
                    System.arraycopy(bArr3, 0, bArr2, 0, 4);
                    copyByteArrayToArrayList(bArr2, arrayList);
                    localFileHeader.setWriteComprSizeInZip64ExtraRecord(false);
                    z = false;
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) localFileHeader.getFileNameLength());
                copyByteArrayToArrayList(bArr, arrayList);
                int i2 = z ? 20 : 0;
                if (localFileHeader.getAesExtraDataRecord() != null) {
                    i2 += 11;
                }
                Raw.writeShortLittleEndian(bArr, 0, (short) i2);
                copyByteArrayToArrayList(bArr, arrayList);
                if (Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getFileNameCharset())) {
                    copyByteArrayToArrayList(localFileHeader.getFileName().getBytes(zipModel.getFileNameCharset()), arrayList);
                } else {
                    copyByteArrayToArrayList(Zip4jUtil.convertCharset(localFileHeader.getFileName()), arrayList);
                }
                if (z) {
                    Raw.writeShortLittleEndian(bArr, 0, (short) 1);
                    copyByteArrayToArrayList(bArr, arrayList);
                    Raw.writeShortLittleEndian(bArr, 0, (short) 16);
                    copyByteArrayToArrayList(bArr, arrayList);
                    Raw.writeLongLittleEndian(bArr3, 0, localFileHeader.getUncompressedSize());
                    copyByteArrayToArrayList(bArr3, arrayList);
                    copyByteArrayToArrayList(new byte[]{0, 0, 0, 0, 0, 0, 0, 0}, arrayList);
                }
                if (localFileHeader.getAesExtraDataRecord() != null) {
                    AESExtraDataRecord aesExtraDataRecord = localFileHeader.getAesExtraDataRecord();
                    Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getSignature());
                    copyByteArrayToArrayList(bArr, arrayList);
                    Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getDataSize());
                    copyByteArrayToArrayList(bArr, arrayList);
                    Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getVersionNumber());
                    copyByteArrayToArrayList(bArr, arrayList);
                    copyByteArrayToArrayList(aesExtraDataRecord.getVendorID().getBytes(), arrayList);
                    copyByteArrayToArrayList(new byte[]{(byte) aesExtraDataRecord.getAesStrength()}, arrayList);
                    Raw.writeShortLittleEndian(bArr, 0, (short) aesExtraDataRecord.getCompressionMethod());
                    copyByteArrayToArrayList(bArr, arrayList);
                }
                byte[] byteArrayListToByteArray = byteArrayListToByteArray(arrayList);
                outputStream.write(byteArrayListToByteArray);
                return byteArrayListToByteArray.length;
            } catch (ZipException e) {
                throw e;
            } catch (Exception e2) {
                throw new ZipException(e2);
            }
        }
        throw new ZipException("input parameters are null, cannot write local file header");
    }
}
