package net.lingala.zip4j.crypto;

import java.util.Random;
import net.lingala.zip4j.crypto.PBKDF2.MacBasedPRF;
import net.lingala.zip4j.crypto.PBKDF2.PBKDF2Engine;
import net.lingala.zip4j.crypto.PBKDF2.PBKDF2Parameters;
import net.lingala.zip4j.crypto.engine.AESEngine;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.util.Raw;
/* loaded from: classes11.dex */
public class AESEncrpyter implements IEncrypter {
    private int KEY_LENGTH;
    private int MAC_LENGTH;
    private int SALT_LENGTH;
    private AESEngine aesEngine;
    private byte[] aesKey;
    private byte[] counterBlock;
    private byte[] derivedPasswordVerifier;
    private boolean finished;
    private byte[] iv;
    private int keyStrength;
    private MacBasedPRF mac;
    private byte[] macKey;
    private char[] password;
    private byte[] saltBytes;
    private final int PASSWORD_VERIFIER_LENGTH = 2;
    private int nonce = 1;
    private int loopCount = 0;

    public AESEncrpyter(char[] cArr, int i2) throws ZipException {
        if (cArr == null || cArr.length == 0) {
            throw new ZipException("input password is empty or null in AES encrypter constructor");
        }
        if (i2 != 1 && i2 != 3) {
            throw new ZipException("Invalid key strength in AES encrypter constructor");
        }
        this.password = cArr;
        this.keyStrength = i2;
        this.finished = false;
        this.counterBlock = new byte[16];
        this.iv = new byte[16];
        init();
    }

    private byte[] deriveKey(byte[] bArr, char[] cArr) throws ZipException {
        try {
            return new PBKDF2Engine(new PBKDF2Parameters("HmacSHA1", "ISO-8859-1", bArr, 1000)).deriveKey(cArr, this.KEY_LENGTH + this.MAC_LENGTH + 2);
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    private static byte[] generateSalt(int i2) throws ZipException {
        if (i2 == 8 || i2 == 16) {
            int i3 = i2 == 8 ? 2 : 0;
            if (i2 == 16) {
                i3 = 4;
            }
            byte[] bArr = new byte[i2];
            for (int i4 = 0; i4 < i3; i4++) {
                int nextInt = new Random().nextInt();
                int i5 = i4 * 4;
                bArr[i5 + 0] = (byte) (nextInt >> 24);
                bArr[i5 + 1] = (byte) (nextInt >> 16);
                bArr[i5 + 2] = (byte) (nextInt >> 8);
                bArr[i5 + 3] = (byte) nextInt;
            }
            return bArr;
        }
        throw new ZipException("invalid salt size, cannot generate salt");
    }

    private void init() throws ZipException {
        int i2 = this.keyStrength;
        if (i2 == 1) {
            this.KEY_LENGTH = 16;
            this.MAC_LENGTH = 16;
            this.SALT_LENGTH = 8;
        } else if (i2 != 3) {
            throw new ZipException("invalid aes key strength, cannot determine key sizes");
        } else {
            this.KEY_LENGTH = 32;
            this.MAC_LENGTH = 32;
            this.SALT_LENGTH = 16;
        }
        byte[] generateSalt = generateSalt(this.SALT_LENGTH);
        this.saltBytes = generateSalt;
        byte[] deriveKey = deriveKey(generateSalt, this.password);
        if (deriveKey != null) {
            int length = deriveKey.length;
            int i3 = this.KEY_LENGTH;
            int i4 = this.MAC_LENGTH;
            if (length == i3 + i4 + 2) {
                byte[] bArr = new byte[i3];
                this.aesKey = bArr;
                this.macKey = new byte[i4];
                this.derivedPasswordVerifier = new byte[2];
                System.arraycopy(deriveKey, 0, bArr, 0, i3);
                System.arraycopy(deriveKey, this.KEY_LENGTH, this.macKey, 0, this.MAC_LENGTH);
                System.arraycopy(deriveKey, this.KEY_LENGTH + this.MAC_LENGTH, this.derivedPasswordVerifier, 0, 2);
                this.aesEngine = new AESEngine(this.aesKey);
                MacBasedPRF macBasedPRF = new MacBasedPRF("HmacSHA1");
                this.mac = macBasedPRF;
                macBasedPRF.init(this.macKey);
                return;
            }
        }
        throw new ZipException("invalid key generated, cannot decrypt file");
    }

    @Override // net.lingala.zip4j.crypto.IEncrypter
    public int encryptData(byte[] bArr) throws ZipException {
        if (bArr != null) {
            return encryptData(bArr, 0, bArr.length);
        }
        throw new ZipException("input bytes are null, cannot perform AES encrpytion");
    }

    @Override // net.lingala.zip4j.crypto.IEncrypter
    public int encryptData(byte[] bArr, int i2, int i3) throws ZipException {
        int i4;
        int i5;
        if (this.finished) {
            throw new ZipException("AES Encrypter is in finished state (A non 16 byte block has already been passed to encrypter)");
        }
        if (i3 % 16 != 0) {
            this.finished = true;
        }
        int i6 = i2;
        while (true) {
            int i7 = i2 + i3;
            if (i6 >= i7) {
                return i3;
            }
            int i8 = i6 + 16;
            this.loopCount = i8 <= i7 ? 16 : i7 - i6;
            Raw.prepareBuffAESIVBytes(this.iv, this.nonce, 16);
            this.aesEngine.processBlock(this.iv, this.counterBlock);
            int i9 = 0;
            while (true) {
                i4 = this.loopCount;
                if (i9 < i4) {
                    bArr[i6 + i9] = (byte) (bArr[i5] ^ this.counterBlock[i9]);
                    i9++;
                }
            }
            this.mac.update(bArr, i6, i4);
            this.nonce++;
            i6 = i8;
        }
    }

    public byte[] getDerivedPasswordVerifier() {
        return this.derivedPasswordVerifier;
    }

    public byte[] getFinalMac() {
        byte[] bArr = new byte[10];
        System.arraycopy(this.mac.doFinal(), 0, bArr, 0, 10);
        return bArr;
    }

    public int getPasswordVeriifierLength() {
        return 2;
    }

    public byte[] getSaltBytes() {
        return this.saltBytes;
    }

    public int getSaltLength() {
        return this.SALT_LENGTH;
    }

    public void setDerivedPasswordVerifier(byte[] bArr) {
        this.derivedPasswordVerifier = bArr;
    }

    public void setSaltBytes(byte[] bArr) {
        this.saltBytes = bArr;
    }
}
