package net.lingala.zip4j.io;

import java.io.IOException;
import java.io.RandomAccessFile;
import net.lingala.zip4j.crypto.AESDecrypter;
import net.lingala.zip4j.crypto.IDecrypter;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.unzip.UnzipEngine;
/* loaded from: classes11.dex */
public class PartInputStream extends BaseInputStream {
    private IDecrypter decrypter;
    private boolean isAESEncryptedFile;
    private long length;
    private RandomAccessFile raf;
    private UnzipEngine unzipEngine;
    private byte[] oneByteBuff = new byte[1];
    private byte[] aesBlockByte = new byte[16];
    private int aesBytesReturned = 0;
    private int count = -1;
    private long bytesRead = 0;

    public PartInputStream(RandomAccessFile randomAccessFile, long j, long j2, UnzipEngine unzipEngine) {
        boolean z = true;
        this.isAESEncryptedFile = false;
        this.raf = randomAccessFile;
        this.unzipEngine = unzipEngine;
        this.decrypter = unzipEngine.getDecrypter();
        this.length = j2;
        this.isAESEncryptedFile = (unzipEngine.getFileHeader().isEncrypted() && unzipEngine.getFileHeader().getEncryptionMethod() == 99) ? false : false;
    }

    @Override // net.lingala.zip4j.io.BaseInputStream, java.io.InputStream
    public int available() {
        long j = this.length - this.bytesRead;
        if (j > 2147483647L) {
            return Integer.MAX_VALUE;
        }
        return (int) j;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void checkAndReadAESMacBytes() throws IOException {
        IDecrypter iDecrypter;
        if (this.isAESEncryptedFile && (iDecrypter = this.decrypter) != null && (iDecrypter instanceof AESDecrypter) && ((AESDecrypter) iDecrypter).getStoredMac() == null) {
            byte[] bArr = new byte[10];
            int read = this.raf.read(bArr);
            if (read != 10) {
                if (!this.unzipEngine.getZipModel().isSplitArchive()) {
                    throw new IOException("Error occured while reading stored AES authentication bytes");
                }
                this.raf.close();
                RandomAccessFile startNextSplitFile = this.unzipEngine.startNextSplitFile();
                this.raf = startNextSplitFile;
                startNextSplitFile.read(bArr, read, 10 - read);
            }
            ((AESDecrypter) this.unzipEngine.getDecrypter()).setStoredMac(bArr);
        }
    }

    @Override // java.io.InputStream, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this.raf.close();
    }

    @Override // net.lingala.zip4j.io.BaseInputStream
    public UnzipEngine getUnzipEngine() {
        return this.unzipEngine;
    }

    @Override // net.lingala.zip4j.io.BaseInputStream, java.io.InputStream
    public int read() throws IOException {
        byte b;
        if (this.bytesRead >= this.length) {
            return -1;
        }
        if (this.isAESEncryptedFile) {
            int i2 = this.aesBytesReturned;
            if (i2 == 0 || i2 == 16) {
                if (read(this.aesBlockByte) == -1) {
                    return -1;
                }
                this.aesBytesReturned = 0;
            }
            byte[] bArr = this.aesBlockByte;
            int i3 = this.aesBytesReturned;
            this.aesBytesReturned = i3 + 1;
            b = bArr[i3];
        } else if (read(this.oneByteBuff, 0, 1) == -1) {
            return -1;
        } else {
            b = this.oneByteBuff[0];
        }
        return b & 255;
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr) throws IOException {
        return read(bArr, 0, bArr.length);
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) throws IOException {
        int i4;
        long j = this.length;
        long j2 = this.bytesRead;
        if (i3 > j - j2 && (i3 = (int) (j - j2)) == 0) {
            checkAndReadAESMacBytes();
            return -1;
        }
        if ((this.unzipEngine.getDecrypter() instanceof AESDecrypter) && this.bytesRead + i3 < this.length && (i4 = i3 % 16) != 0) {
            i3 -= i4;
        }
        synchronized (this.raf) {
            int read = this.raf.read(bArr, i2, i3);
            this.count = read;
            if (read < i3 && this.unzipEngine.getZipModel().isSplitArchive()) {
                this.raf.close();
                RandomAccessFile startNextSplitFile = this.unzipEngine.startNextSplitFile();
                this.raf = startNextSplitFile;
                if (this.count < 0) {
                    this.count = 0;
                }
                int i5 = this.count;
                int read2 = startNextSplitFile.read(bArr, i5, i3 - i5);
                if (read2 > 0) {
                    this.count = read2 + this.count;
                }
            }
        }
        int i6 = this.count;
        if (i6 > 0) {
            IDecrypter iDecrypter = this.decrypter;
            if (iDecrypter != null) {
                try {
                    iDecrypter.decryptData(bArr, i2, i6);
                } catch (ZipException e) {
                    throw new IOException(e.getMessage());
                }
            }
            this.bytesRead += this.count;
        }
        if (this.bytesRead >= this.length) {
            checkAndReadAESMacBytes();
        }
        return this.count;
    }

    @Override // net.lingala.zip4j.io.BaseInputStream
    public void seek(long j) throws IOException {
        this.raf.seek(j);
    }

    @Override // java.io.InputStream
    public long skip(long j) throws IOException {
        if (j >= 0) {
            long j2 = this.length;
            long j3 = this.bytesRead;
            if (j > j2 - j3) {
                j = j2 - j3;
            }
            this.bytesRead = j3 + j;
            return j;
        }
        throw new IllegalArgumentException();
    }
}
