package net.lingala.zip4j.unzip;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.util.Arrays;
import java.util.zip.CRC32;
import net.lingala.zip4j.core.HeaderReader;
import net.lingala.zip4j.crypto.AESDecrypter;
import net.lingala.zip4j.crypto.IDecrypter;
import net.lingala.zip4j.crypto.StandardDecrypter;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.InflaterInputStream;
import net.lingala.zip4j.io.PartInputStream;
import net.lingala.zip4j.io.ZipInputStream;
import net.lingala.zip4j.model.AESExtraDataRecord;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.LocalFileHeader;
import net.lingala.zip4j.model.UnzipParameters;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.progress.ProgressMonitor;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Raw;
import net.lingala.zip4j.util.Zip4jUtil;
/* loaded from: classes11.dex */
public class UnzipEngine {
    private CRC32 crc;
    private int currSplitFileCounter = 0;
    private IDecrypter decrypter;
    private FileHeader fileHeader;
    private LocalFileHeader localFileHeader;
    private ZipModel zipModel;

    public UnzipEngine(ZipModel zipModel, FileHeader fileHeader) throws ZipException {
        if (zipModel == null || fileHeader == null) {
            throw new ZipException("Invalid parameters passed to StoreUnzip. One or more of the parameters were null");
        }
        this.zipModel = zipModel;
        this.fileHeader = fileHeader;
        this.crc = new CRC32();
    }

    private int calculateAESSaltLength(AESExtraDataRecord aESExtraDataRecord) throws ZipException {
        if (aESExtraDataRecord != null) {
            int aesStrength = aESExtraDataRecord.getAesStrength();
            if (aesStrength != 1) {
                if (aesStrength != 2) {
                    if (aesStrength == 3) {
                        return 16;
                    }
                    throw new ZipException("unable to determine salt length: invalid aes key strength");
                }
                return 12;
            }
            return 8;
        }
        throw new ZipException("unable to determine salt length: AESExtraDataRecord is null");
    }

    /* JADX WARN: Code restructure failed: missing block: B:11:0x0036, code lost:
        if (r0 != null) goto L14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x003d, code lost:
        if (r0 != null) goto L14;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private boolean checkLocalHeader() throws ZipException {
        boolean z;
        RandomAccessFile randomAccessFile = null;
        try {
            try {
                RandomAccessFile checkSplitFile = checkSplitFile();
                if (checkSplitFile == null) {
                    checkSplitFile = new RandomAccessFile(new File(this.zipModel.getZipFile()), InternalZipConstants.READ_MODE);
                }
                LocalFileHeader readLocalFileHeader = new HeaderReader(checkSplitFile).readLocalFileHeader(this.fileHeader);
                this.localFileHeader = readLocalFileHeader;
                if (readLocalFileHeader == null) {
                    throw new ZipException("error reading local file header. Is this a valid zip file?");
                }
                if (readLocalFileHeader.getCompressionMethod() != this.fileHeader.getCompressionMethod()) {
                    z = false;
                } else {
                    z = true;
                }
                try {
                    checkSplitFile.close();
                } catch (IOException | Exception unused) {
                    return z;
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException | Exception unused2) {
                    }
                }
                throw th;
            }
        } catch (FileNotFoundException e) {
            throw new ZipException(e);
        }
    }

    private RandomAccessFile checkSplitFile() throws ZipException {
        StringBuilder append;
        String str;
        String sb;
        if (this.zipModel.isSplitArchive()) {
            int diskNumberStart = this.fileHeader.getDiskNumberStart();
            int i2 = diskNumberStart + 1;
            this.currSplitFileCounter = i2;
            String zipFile = this.zipModel.getZipFile();
            if (diskNumberStart == this.zipModel.getEndCentralDirRecord().getNoOfThisDisk()) {
                sb = this.zipModel.getZipFile();
            } else {
                if (diskNumberStart >= 9) {
                    append = new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf(".")));
                    str = ".z";
                } else {
                    append = new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf(".")));
                    str = ".z0";
                }
                sb = append.append(str).append(i2).toString();
            }
            try {
                RandomAccessFile randomAccessFile = new RandomAccessFile(sb, InternalZipConstants.READ_MODE);
                if (this.currSplitFileCounter == 1) {
                    byte[] bArr = new byte[4];
                    randomAccessFile.read(bArr);
                    if (Raw.readIntLittleEndian(bArr, 0) == 134695760) {
                        return randomAccessFile;
                    }
                    throw new ZipException("invalid first part split file signature");
                }
                return randomAccessFile;
            } catch (FileNotFoundException e) {
                throw new ZipException(e);
            } catch (IOException e2) {
                throw new ZipException(e2);
            }
        }
        return null;
    }

    private void closeStreams(InputStream inputStream, OutputStream outputStream) throws ZipException {
        if (inputStream != null) {
            try {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    if (Zip4jUtil.isStringNotNullAndNotEmpty(e.getMessage()) && e.getMessage().indexOf(" - Wrong Password?") >= 0) {
                        throw new ZipException(e.getMessage());
                    }
                    return;
                }
            } catch (Throwable th) {
                if (outputStream != null) {
                    try {
                        outputStream.close();
                    } catch (IOException unused) {
                    }
                }
                throw th;
            }
        }
        if (outputStream == null) {
            return;
        }
        try {
            outputStream.close();
        } catch (IOException unused2) {
        }
    }

    private RandomAccessFile createFileHandler(String str) throws ZipException {
        ZipModel zipModel = this.zipModel;
        if (zipModel == null || !Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getZipFile())) {
            throw new ZipException("input parameter is null in getFilePointer");
        }
        try {
            return this.zipModel.isSplitArchive() ? checkSplitFile() : new RandomAccessFile(new File(this.zipModel.getZipFile()), str);
        } catch (FileNotFoundException e) {
            throw new ZipException(e);
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private byte[] getAESPasswordVerifier(RandomAccessFile randomAccessFile) throws ZipException {
        try {
            byte[] bArr = new byte[2];
            randomAccessFile.read(bArr);
            return bArr;
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    private byte[] getAESSalt(RandomAccessFile randomAccessFile) throws ZipException {
        if (this.localFileHeader.getAesExtraDataRecord() == null) {
            return null;
        }
        try {
            byte[] bArr = new byte[calculateAESSaltLength(this.localFileHeader.getAesExtraDataRecord())];
            randomAccessFile.seek(this.localFileHeader.getOffsetStartOfData());
            randomAccessFile.read(bArr);
            return bArr;
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    private String getOutputFileNameWithPath(String str, String str2) throws ZipException {
        if (!Zip4jUtil.isStringNotNullAndNotEmpty(str2)) {
            str2 = this.fileHeader.getFileName();
        }
        return str + System.getProperty("file.separator") + str2;
    }

    private FileOutputStream getOutputStream(String str, String str2) throws ZipException {
        if (Zip4jUtil.isStringNotNullAndNotEmpty(str)) {
            try {
                File file = new File(getOutputFileNameWithPath(str, str2));
                if (!file.getParentFile().exists()) {
                    file.getParentFile().mkdirs();
                }
                if (file.exists()) {
                    file.delete();
                }
                return new FileOutputStream(file);
            } catch (FileNotFoundException e) {
                throw new ZipException(e);
            }
        }
        throw new ZipException("invalid output path");
    }

    private byte[] getStandardDecrypterHeaderBytes(RandomAccessFile randomAccessFile) throws ZipException {
        try {
            byte[] bArr = new byte[12];
            randomAccessFile.seek(this.localFileHeader.getOffsetStartOfData());
            randomAccessFile.read(bArr, 0, 12);
            return bArr;
        } catch (IOException e) {
            throw new ZipException(e);
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void init(RandomAccessFile randomAccessFile) throws ZipException {
        if (this.localFileHeader == null) {
            throw new ZipException("local file header is null, cannot initialize input stream");
        }
        try {
            initDecrypter(randomAccessFile);
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void initDecrypter(RandomAccessFile randomAccessFile) throws ZipException {
        IDecrypter aESDecrypter;
        LocalFileHeader localFileHeader = this.localFileHeader;
        if (localFileHeader == null) {
            throw new ZipException("local file header is null, cannot init decrypter");
        }
        if (localFileHeader.isEncrypted()) {
            if (this.localFileHeader.getEncryptionMethod() == 0) {
                aESDecrypter = new StandardDecrypter(this.fileHeader, getStandardDecrypterHeaderBytes(randomAccessFile));
            } else if (this.localFileHeader.getEncryptionMethod() != 99) {
                throw new ZipException("unsupported encryption method");
            } else {
                aESDecrypter = new AESDecrypter(this.localFileHeader, getAESSalt(randomAccessFile), getAESPasswordVerifier(randomAccessFile));
            }
            this.decrypter = aESDecrypter;
        }
    }

    public void checkCRC() throws ZipException {
        FileHeader fileHeader = this.fileHeader;
        if (fileHeader != null) {
            if (fileHeader.getEncryptionMethod() != 99) {
                if ((this.crc.getValue() & InternalZipConstants.ZIP_64_LIMIT) != this.fileHeader.getCrc32()) {
                    String str = "invalid CRC for file: " + this.fileHeader.getFileName();
                    if (this.localFileHeader.isEncrypted() && this.localFileHeader.getEncryptionMethod() == 0) {
                        str = str + " - Wrong Password?";
                    }
                    throw new ZipException(str);
                }
                return;
            }
            IDecrypter iDecrypter = this.decrypter;
            if (iDecrypter == null || !(iDecrypter instanceof AESDecrypter)) {
                return;
            }
            byte[] calculatedAuthenticationBytes = ((AESDecrypter) iDecrypter).getCalculatedAuthenticationBytes();
            byte[] storedMac = ((AESDecrypter) this.decrypter).getStoredMac();
            byte[] bArr = new byte[10];
            if (storedMac == null) {
                throw new ZipException("CRC (MAC) check failed for " + this.fileHeader.getFileName());
            }
            System.arraycopy(calculatedAuthenticationBytes, 0, bArr, 0, 10);
            if (!Arrays.equals(bArr, storedMac)) {
                throw new ZipException("invalid CRC (MAC) for file: " + this.fileHeader.getFileName());
            }
        }
    }

    public IDecrypter getDecrypter() {
        return this.decrypter;
    }

    public FileHeader getFileHeader() {
        return this.fileHeader;
    }

    public ZipInputStream getInputStream() throws ZipException {
        long j;
        IDecrypter iDecrypter;
        if (this.fileHeader != null) {
            RandomAccessFile randomAccessFile = null;
            try {
                RandomAccessFile createFileHandler = createFileHandler(InternalZipConstants.READ_MODE);
                if (checkLocalHeader()) {
                    init(createFileHandler);
                    long compressedSize = this.localFileHeader.getCompressedSize();
                    long offsetStartOfData = this.localFileHeader.getOffsetStartOfData();
                    if (this.localFileHeader.isEncrypted()) {
                        if (this.localFileHeader.getEncryptionMethod() == 99) {
                            if (!(this.decrypter instanceof AESDecrypter)) {
                                throw new ZipException("invalid decryptor when trying to calculate compressed size for AES encrypted file: " + this.fileHeader.getFileName());
                            }
                            compressedSize -= (((AESDecrypter) this.decrypter).getPasswordVerifierLength() + ((AESDecrypter) iDecrypter).getSaltLength()) + 10;
                            j = ((AESDecrypter) this.decrypter).getPasswordVerifierLength() + ((AESDecrypter) this.decrypter).getSaltLength();
                        } else if (this.localFileHeader.getEncryptionMethod() == 0) {
                            j = 12;
                            compressedSize -= 12;
                        }
                        offsetStartOfData += j;
                    }
                    long j2 = compressedSize;
                    long j3 = offsetStartOfData;
                    int compressionMethod = this.fileHeader.getCompressionMethod();
                    if (this.fileHeader.getEncryptionMethod() == 99) {
                        if (this.fileHeader.getAesExtraDataRecord() == null) {
                            throw new ZipException("AESExtraDataRecord does not exist for AES encrypted file: " + this.fileHeader.getFileName());
                        }
                        compressionMethod = this.fileHeader.getAesExtraDataRecord().getCompressionMethod();
                    }
                    createFileHandler.seek(j3);
                    if (compressionMethod != 0) {
                        if (compressionMethod == 8) {
                            return new ZipInputStream(new InflaterInputStream(createFileHandler, j3, j2, this));
                        }
                        throw new ZipException("compression type not supported");
                    }
                    return new ZipInputStream(new PartInputStream(createFileHandler, j3, j2, this));
                }
                throw new ZipException("local header and file header do not match");
            } catch (ZipException e) {
                if (0 != 0) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException unused) {
                    }
                }
                throw e;
            } catch (Exception e2) {
                if (0 != 0) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException unused2) {
                    }
                }
                throw new ZipException(e2);
            }
        }
        throw new ZipException("file header is null, cannot get inputstream");
    }

    public LocalFileHeader getLocalFileHeader() {
        return this.localFileHeader;
    }

    public ZipModel getZipModel() {
        return this.zipModel;
    }

    public RandomAccessFile startNextSplitFile() throws IOException, FileNotFoundException {
        StringBuilder append;
        String str;
        String sb;
        String zipFile = this.zipModel.getZipFile();
        if (this.currSplitFileCounter == this.zipModel.getEndCentralDirRecord().getNoOfThisDisk()) {
            sb = this.zipModel.getZipFile();
        } else {
            if (this.currSplitFileCounter >= 9) {
                append = new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf(".")));
                str = ".z";
            } else {
                append = new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf(".")));
                str = ".z0";
            }
            sb = append.append(str).append(this.currSplitFileCounter + 1).toString();
        }
        this.currSplitFileCounter++;
        try {
            if (Zip4jUtil.checkFileExists(sb)) {
                return new RandomAccessFile(sb, InternalZipConstants.READ_MODE);
            }
            throw new IOException("zip split file does not exist: " + sb);
        } catch (ZipException e) {
            throw new IOException(e.getMessage());
        }
    }

    /* JADX WARN: Not initialized variable reg: 2, insn: 0x004f: MOVE  (r1 I:??[OBJECT, ARRAY]) = (r2 I:??[OBJECT, ARRAY]), block:B:20:0x004e */
    public void unzipFile(ProgressMonitor progressMonitor, String str, String str2, UnzipParameters unzipParameters) throws ZipException {
        OutputStream outputStream;
        InputStream inputStream;
        if (this.zipModel == null || this.fileHeader == null || !Zip4jUtil.isStringNotNullAndNotEmpty(str)) {
            throw new ZipException("Invalid parameters passed during unzipping file. One or more of the parameters were null");
        }
        InputStream inputStream2 = null;
        try {
            try {
                byte[] bArr = new byte[4096];
                ZipInputStream inputStream3 = getInputStream();
                try {
                    FileOutputStream outputStream2 = getOutputStream(str, str2);
                    while (true) {
                        int read = inputStream3.read(bArr);
                        if (read == -1) {
                            closeStreams(inputStream3, outputStream2);
                            UnzipUtil.applyFileAttributes(this.fileHeader, new File(getOutputFileNameWithPath(str, str2)), unzipParameters);
                            break;
                        }
                        outputStream2.write(bArr, 0, read);
                        progressMonitor.updateWorkCompleted(read);
                        if (progressMonitor.isCancelAllTasks()) {
                            progressMonitor.setResult(3);
                            progressMonitor.setState(0);
                            break;
                        }
                    }
                    closeStreams(inputStream3, outputStream2);
                } catch (IOException e) {
                    e = e;
                    throw new ZipException(e);
                } catch (Exception e2) {
                    e = e2;
                    throw new ZipException(e);
                }
            } catch (Throwable th) {
                th = th;
                outputStream = null;
                inputStream2 = inputStream;
                closeStreams(inputStream2, outputStream);
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
        } catch (Exception e4) {
            e = e4;
        } catch (Throwable th2) {
            th = th2;
            outputStream = null;
            closeStreams(inputStream2, outputStream);
            throw th;
        }
    }

    public void updateCRC(int i2) {
        this.crc.update(i2);
    }

    public void updateCRC(byte[] bArr, int i2, int i3) {
        if (bArr != null) {
            this.crc.update(bArr, i2, i3);
        }
    }
}
