package net.lingala.zip4j.util;

import android.support.v4.media.session.PlaybackStateCompat;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.HashMap;
import net.lingala.zip4j.core.HeaderReader;
import net.lingala.zip4j.core.HeaderWriter;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.SplitOutputStream;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.progress.ProgressMonitor;
/* loaded from: classes11.dex */
public class ArchiveMaintainer {
    private long calculateTotalWorkForMergeOp(ZipModel zipModel) throws ZipException {
        long j = 0;
        if (zipModel.isSplitArchive()) {
            int noOfThisDisk = zipModel.getEndCentralDirRecord().getNoOfThisDisk();
            String zipFile = zipModel.getZipFile();
            for (int i2 = 0; i2 <= noOfThisDisk; i2++) {
                j += Zip4jUtil.getFileLengh(new File(zipModel.getEndCentralDirRecord().getNoOfThisDisk() == 0 ? zipModel.getZipFile() : zipFile.substring(0, zipFile.lastIndexOf(".")) + ".z01"));
            }
        }
        return j;
    }

    private long calculateTotalWorkForRemoveOp(ZipModel zipModel, FileHeader fileHeader) throws ZipException {
        return Zip4jUtil.getFileLengh(new File(zipModel.getZipFile())) - fileHeader.getCompressedSize();
    }

    private void copyFile(RandomAccessFile randomAccessFile, OutputStream outputStream, long j, long j2, ProgressMonitor progressMonitor) throws ZipException {
        if (randomAccessFile == null || outputStream == null) {
            throw new ZipException("input or output stream is null, cannot copy file");
        }
        long j3 = 0;
        if (j < 0) {
            throw new ZipException("starting offset is negative, cannot copy file");
        }
        if (j2 < 0) {
            throw new ZipException("end offset is negative, cannot copy file");
        }
        int i2 = (j > j2 ? 1 : (j == j2 ? 0 : -1));
        if (i2 > 0) {
            throw new ZipException("start offset is greater than end offset, cannot copy file");
        }
        if (i2 == 0) {
            return;
        }
        if (progressMonitor.isCancelAllTasks()) {
            progressMonitor.setResult(3);
            progressMonitor.setState(0);
            return;
        }
        try {
            randomAccessFile.seek(j);
            long j4 = j2 - j;
            byte[] bArr = j4 < PlaybackStateCompat.ACTION_SKIP_TO_QUEUE_ITEM ? new byte[(int) j4] : new byte[4096];
            while (true) {
                int read = randomAccessFile.read(bArr);
                if (read == -1) {
                    return;
                }
                outputStream.write(bArr, 0, read);
                long j5 = read;
                progressMonitor.updateWorkCompleted(j5);
                if (progressMonitor.isCancelAllTasks()) {
                    progressMonitor.setResult(3);
                    return;
                }
                j3 += j5;
                if (j3 == j4) {
                    return;
                }
                if (bArr.length + j3 > j4) {
                    bArr = new byte[(int) (j4 - j3)];
                }
            }
        } catch (IOException e) {
            throw new ZipException(e);
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private RandomAccessFile createFileHandler(ZipModel zipModel, String str) throws ZipException {
        if (zipModel == null || !Zip4jUtil.isStringNotNullAndNotEmpty(zipModel.getZipFile())) {
            throw new ZipException("input parameter is null in getFilePointer, cannot create file handler to remove file");
        }
        try {
            return new RandomAccessFile(new File(zipModel.getZipFile()), str);
        } catch (FileNotFoundException e) {
            throw new ZipException(e);
        }
    }

    private RandomAccessFile createSplitZipFileHandler(ZipModel zipModel, int i2) throws ZipException {
        String sb;
        if (zipModel != null) {
            if (i2 >= 0) {
                try {
                    String zipFile = zipModel.getZipFile();
                    if (i2 == zipModel.getEndCentralDirRecord().getNoOfThisDisk()) {
                        sb = zipModel.getZipFile();
                    } else {
                        sb = (i2 >= 9 ? new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf("."))).append(".z").append(i2 + 1) : new StringBuilder().append(zipFile.substring(0, zipFile.lastIndexOf("."))).append(".z0").append(i2 + 1)).toString();
                    }
                    File file = new File(sb);
                    if (Zip4jUtil.checkFileExists(file)) {
                        return new RandomAccessFile(file, InternalZipConstants.READ_MODE);
                    }
                    throw new ZipException("split file does not exist: " + sb);
                } catch (FileNotFoundException e) {
                    throw new ZipException(e);
                } catch (Exception e2) {
                    throw new ZipException(e2);
                }
            }
            throw new ZipException("invlaid part number, cannot create split file handler");
        }
        throw new ZipException("zip model is null, cannot create split file handler");
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Removed duplicated region for block: B:131:0x0184 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:134:0x017d A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:156:0x00be A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:34:0x008c A[Catch: all -> 0x0075, Exception -> 0x0078, IOException -> 0x007e, TRY_LEAVE, TryCatch #22 {IOException -> 0x007e, Exception -> 0x0078, all -> 0x0075, blocks: (B:16:0x003b, B:18:0x0041, B:20:0x004b, B:22:0x0059, B:34:0x008c), top: B:146:0x003b }] */
    /* JADX WARN: Removed duplicated region for block: B:48:0x00d5 A[Catch: all -> 0x00ed, Exception -> 0x00f5, IOException -> 0x00f7, TRY_ENTER, TRY_LEAVE, TryCatch #0 {IOException -> 0x00f7, blocks: (B:38:0x00b1, B:40:0x00be, B:48:0x00d5), top: B:127:0x00b1 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void initMergeSplitZipFile(ZipModel zipModel, File file, ProgressMonitor progressMonitor) throws ZipException {
        RandomAccessFile randomAccessFile;
        RandomAccessFile randomAccessFile2;
        byte[] bArr;
        long j;
        int i2;
        boolean z;
        ArchiveMaintainer archiveMaintainer = this;
        ZipModel zipModel2 = zipModel;
        if (zipModel2 == null) {
            ZipException zipException = new ZipException("one of the input parameters is null, cannot merge split zip file");
            progressMonitor.endProgressMonitorError(zipException);
            throw zipException;
        } else if (!zipModel.isSplitArchive()) {
            ZipException zipException2 = new ZipException("archive not a split zip file");
            progressMonitor.endProgressMonitorError(zipException2);
            throw zipException2;
        } else {
            ArrayList arrayList = new ArrayList();
            RandomAccessFile randomAccessFile3 = null;
            randomAccessFile3 = null;
            OutputStream outputStream = null;
            try {
                try {
                    int noOfThisDisk = zipModel.getEndCentralDirRecord().getNoOfThisDisk();
                    if (noOfThisDisk <= 0) {
                        try {
                            throw new ZipException("corrupt zip model, archive not a split zip file");
                        } catch (IOException e) {
                            e = e;
                            progressMonitor.endProgressMonitorError(e);
                            throw new ZipException(e);
                        } catch (Exception e2) {
                            e = e2;
                            progressMonitor.endProgressMonitorError(e);
                            throw new ZipException(e);
                        } catch (Throwable th) {
                            th = th;
                            randomAccessFile = null;
                            if (outputStream != null) {
                            }
                            if (randomAccessFile != null) {
                            }
                            throw th;
                        }
                    }
                    OutputStream prepareOutputStreamForMerge = archiveMaintainer.prepareOutputStreamForMerge(file);
                    long j2 = 0;
                    long j3 = 0;
                    boolean z2 = false;
                    int i3 = 0;
                    while (i3 <= noOfThisDisk) {
                        try {
                            randomAccessFile = archiveMaintainer.createSplitZipFileHandler(zipModel2, i3);
                            try {
                                Long l = new Long(randomAccessFile.length());
                                try {
                                    try {
                                        if (i3 == 0) {
                                            try {
                                                if (zipModel.getCentralDirectory() != null && zipModel.getCentralDirectory().getFileHeaders() != null && zipModel.getCentralDirectory().getFileHeaders().size() > 0) {
                                                    randomAccessFile.seek(j2);
                                                    randomAccessFile.read(new byte[4]);
                                                    j = j3;
                                                    if (Raw.readIntLittleEndian(bArr, 0) == 134695760) {
                                                        i2 = 4;
                                                        z = true;
                                                        if (i3 == noOfThisDisk) {
                                                            l = new Long(zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
                                                        }
                                                        Long l2 = l;
                                                        long j4 = i2;
                                                        long j5 = j;
                                                        int i4 = i3;
                                                        randomAccessFile2 = randomAccessFile;
                                                        copyFile(randomAccessFile, prepareOutputStreamForMerge, j4, l2.longValue(), progressMonitor);
                                                        long longValue = l2.longValue();
                                                        if (progressMonitor.isCancelAllTasks()) {
                                                            progressMonitor.setResult(3);
                                                            progressMonitor.setState(0);
                                                            if (prepareOutputStreamForMerge != null) {
                                                                try {
                                                                    prepareOutputStreamForMerge.close();
                                                                } catch (IOException unused) {
                                                                }
                                                            }
                                                            if (randomAccessFile2 != null) {
                                                                try {
                                                                    randomAccessFile2.close();
                                                                } catch (IOException unused2) {
                                                                }
                                                            }
                                                            return;
                                                        }
                                                        arrayList.add(l2);
                                                        try {
                                                            randomAccessFile2.close();
                                                        } catch (IOException unused3) {
                                                        }
                                                        i3 = i4 + 1;
                                                        j3 = (longValue - j4) + j5;
                                                        j2 = 0;
                                                        archiveMaintainer = this;
                                                        zipModel2 = zipModel;
                                                        z2 = z;
                                                        randomAccessFile3 = randomAccessFile2;
                                                    }
                                                    z = z2;
                                                    i2 = 0;
                                                    if (i3 == noOfThisDisk) {
                                                    }
                                                    Long l22 = l;
                                                    long j42 = i2;
                                                    long j52 = j;
                                                    int i42 = i3;
                                                    randomAccessFile2 = randomAccessFile;
                                                    copyFile(randomAccessFile, prepareOutputStreamForMerge, j42, l22.longValue(), progressMonitor);
                                                    long longValue2 = l22.longValue();
                                                    if (progressMonitor.isCancelAllTasks()) {
                                                    }
                                                }
                                            } catch (IOException e3) {
                                                e = e3;
                                                progressMonitor.endProgressMonitorError(e);
                                                throw new ZipException(e);
                                            } catch (Exception e4) {
                                                e = e4;
                                                progressMonitor.endProgressMonitorError(e);
                                                throw new ZipException(e);
                                            } catch (Throwable th2) {
                                                th = th2;
                                                outputStream = prepareOutputStreamForMerge;
                                                if (outputStream != null) {
                                                }
                                                if (randomAccessFile != null) {
                                                }
                                                throw th;
                                            }
                                        }
                                        copyFile(randomAccessFile, prepareOutputStreamForMerge, j42, l22.longValue(), progressMonitor);
                                        long longValue22 = l22.longValue();
                                        if (progressMonitor.isCancelAllTasks()) {
                                        }
                                    } catch (IOException e5) {
                                        e = e5;
                                        progressMonitor.endProgressMonitorError(e);
                                        throw new ZipException(e);
                                    }
                                } catch (Exception e6) {
                                    e = e6;
                                    progressMonitor.endProgressMonitorError(e);
                                    throw new ZipException(e);
                                } catch (Throwable th3) {
                                    th = th3;
                                    outputStream = prepareOutputStreamForMerge;
                                    randomAccessFile = randomAccessFile2;
                                    if (outputStream != null) {
                                        try {
                                            outputStream.close();
                                        } catch (IOException unused4) {
                                        }
                                    }
                                    if (randomAccessFile != null) {
                                        try {
                                            randomAccessFile.close();
                                        } catch (IOException unused5) {
                                        }
                                    }
                                    throw th;
                                }
                                j = j3;
                                z = z2;
                                i2 = 0;
                                if (i3 == noOfThisDisk) {
                                }
                                Long l222 = l;
                                long j422 = i2;
                                long j522 = j;
                                int i422 = i3;
                                randomAccessFile2 = randomAccessFile;
                            } catch (IOException e7) {
                                e = e7;
                                randomAccessFile2 = randomAccessFile;
                            } catch (Exception e8) {
                                e = e8;
                                randomAccessFile2 = randomAccessFile;
                            } catch (Throwable th4) {
                                th = th4;
                            }
                        } catch (IOException e9) {
                            e = e9;
                        } catch (Exception e10) {
                            e = e10;
                        } catch (Throwable th5) {
                            th = th5;
                            randomAccessFile = randomAccessFile3;
                            outputStream = prepareOutputStreamForMerge;
                            if (outputStream != null) {
                            }
                            if (randomAccessFile != null) {
                            }
                            throw th;
                        }
                    }
                    long j6 = j3;
                    ZipModel zipModel3 = (ZipModel) zipModel.clone();
                    zipModel3.getEndCentralDirRecord().setOffsetOfStartOfCentralDir(j6);
                    try {
                        updateSplitZipModel(zipModel3, arrayList, z2);
                        new HeaderWriter().finalizeZipFileWithoutValidations(zipModel3, prepareOutputStreamForMerge);
                        progressMonitor.endProgressMonitorSuccess();
                        if (prepareOutputStreamForMerge != null) {
                            try {
                                prepareOutputStreamForMerge.close();
                            } catch (IOException unused6) {
                            }
                        }
                        if (randomAccessFile3 != null) {
                            try {
                                randomAccessFile3.close();
                            } catch (IOException unused7) {
                            }
                        }
                    } catch (IOException e11) {
                        e = e11;
                        progressMonitor.endProgressMonitorError(e);
                        throw new ZipException(e);
                    } catch (Exception e12) {
                        e = e12;
                        progressMonitor.endProgressMonitorError(e);
                        throw new ZipException(e);
                    }
                } catch (Throwable th6) {
                    th = th6;
                }
            } catch (IOException e13) {
                e = e13;
            } catch (Exception e14) {
                e = e14;
            } catch (Throwable th7) {
                th = th7;
            }
        }
    }

    private OutputStream prepareOutputStreamForMerge(File file) throws ZipException {
        if (file != null) {
            try {
                return new FileOutputStream(file);
            } catch (FileNotFoundException e) {
                throw new ZipException(e);
            } catch (Exception e2) {
                throw new ZipException(e2);
            }
        }
        throw new ZipException("outFile is null, cannot create outputstream");
    }

    private void restoreFileName(File file, String str) throws ZipException {
        if (!file.delete()) {
            throw new ZipException("cannot delete old zip file");
        }
        if (!new File(str).renameTo(file)) {
            throw new ZipException("cannot rename modified zip file");
        }
    }

    private void updateSplitEndCentralDirectory(ZipModel zipModel) throws ZipException {
        try {
            if (zipModel == null) {
                throw new ZipException("zip model is null - cannot update end of central directory for split zip model");
            }
            if (zipModel.getCentralDirectory() == null) {
                throw new ZipException("corrupt zip model - getCentralDirectory, cannot update split zip model");
            }
            zipModel.getEndCentralDirRecord().setNoOfThisDisk(0);
            zipModel.getEndCentralDirRecord().setNoOfThisDiskStartOfCentralDir(0);
            zipModel.getEndCentralDirRecord().setTotNoOfEntriesInCentralDir(zipModel.getCentralDirectory().getFileHeaders().size());
            zipModel.getEndCentralDirRecord().setTotNoOfEntriesInCentralDirOnThisDisk(zipModel.getCentralDirectory().getFileHeaders().size());
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void updateSplitFileHeader(ZipModel zipModel, ArrayList arrayList, boolean z) throws ZipException {
        try {
            if (zipModel.getCentralDirectory() == null) {
                throw new ZipException("corrupt zip model - getCentralDirectory, cannot update split zip model");
            }
            int size = zipModel.getCentralDirectory().getFileHeaders().size();
            int i2 = z ? 4 : 0;
            for (int i3 = 0; i3 < size; i3++) {
                long j = 0;
                for (int i4 = 0; i4 < ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getDiskNumberStart(); i4++) {
                    j += ((Long) arrayList.get(i4)).longValue();
                }
                ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).setOffsetLocalHeader((j + ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getOffsetLocalHeader()) - i2);
                ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).setDiskNumberStart(0);
            }
        } catch (ZipException e) {
            throw e;
        } catch (Exception e2) {
            throw new ZipException(e2);
        }
    }

    private void updateSplitZip64EndCentralDirLocator(ZipModel zipModel, ArrayList arrayList) throws ZipException {
        if (zipModel == null) {
            throw new ZipException("zip model is null, cannot update split Zip64 end of central directory locator");
        }
        if (zipModel.getZip64EndCentralDirLocator() == null) {
            return;
        }
        zipModel.getZip64EndCentralDirLocator().setNoOfDiskStartOfZip64EndOfCentralDirRec(0);
        long j = 0;
        for (int i2 = 0; i2 < arrayList.size(); i2++) {
            j += ((Long) arrayList.get(i2)).longValue();
        }
        zipModel.getZip64EndCentralDirLocator().setOffsetZip64EndOfCentralDirRec(zipModel.getZip64EndCentralDirLocator().getOffsetZip64EndOfCentralDirRec() + j);
        zipModel.getZip64EndCentralDirLocator().setTotNumberOfDiscs(1);
    }

    private void updateSplitZip64EndCentralDirRec(ZipModel zipModel, ArrayList arrayList) throws ZipException {
        if (zipModel == null) {
            throw new ZipException("zip model is null, cannot update split Zip64 end of central directory record");
        }
        if (zipModel.getZip64EndCentralDirRecord() == null) {
            return;
        }
        zipModel.getZip64EndCentralDirRecord().setNoOfThisDisk(0);
        zipModel.getZip64EndCentralDirRecord().setNoOfThisDiskStartOfCentralDir(0);
        zipModel.getZip64EndCentralDirRecord().setTotNoOfEntriesInCentralDirOnThisDisk(zipModel.getEndCentralDirRecord().getTotNoOfEntriesInCentralDir());
        long j = 0;
        for (int i2 = 0; i2 < arrayList.size(); i2++) {
            j += ((Long) arrayList.get(i2)).longValue();
        }
        zipModel.getZip64EndCentralDirRecord().setOffsetStartCenDirWRTStartDiskNo(zipModel.getZip64EndCentralDirRecord().getOffsetStartCenDirWRTStartDiskNo() + j);
    }

    private void updateSplitZipModel(ZipModel zipModel, ArrayList arrayList, boolean z) throws ZipException {
        if (zipModel == null) {
            throw new ZipException("zip model is null, cannot update split zip model");
        }
        zipModel.setSplitArchive(false);
        updateSplitFileHeader(zipModel, arrayList, z);
        updateSplitEndCentralDirectory(zipModel);
        if (zipModel.isZip64Format()) {
            updateSplitZip64EndCentralDirLocator(zipModel, arrayList);
            updateSplitZip64EndCentralDirRec(zipModel, arrayList);
        }
    }

    public void initProgressMonitorForMergeOp(ZipModel zipModel, ProgressMonitor progressMonitor) throws ZipException {
        if (zipModel == null) {
            throw new ZipException("zip model is null, cannot calculate total work for merge op");
        }
        progressMonitor.setCurrentOperation(4);
        progressMonitor.setFileName(zipModel.getZipFile());
        progressMonitor.setTotalWork(calculateTotalWorkForMergeOp(zipModel));
        progressMonitor.setState(1);
    }

    public void initProgressMonitorForRemoveOp(ZipModel zipModel, FileHeader fileHeader, ProgressMonitor progressMonitor) throws ZipException {
        if (zipModel == null || fileHeader == null || progressMonitor == null) {
            throw new ZipException("one of the input parameters is null, cannot calculate total work");
        }
        progressMonitor.setCurrentOperation(2);
        progressMonitor.setFileName(fileHeader.getFileName());
        progressMonitor.setTotalWork(calculateTotalWorkForRemoveOp(zipModel, fileHeader));
        progressMonitor.setState(1);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:110:0x01fd  */
    /* JADX WARN: Removed duplicated region for block: B:248:0x0409 A[Catch: IOException -> 0x040d, TRY_LEAVE, TryCatch #22 {IOException -> 0x040d, blocks: (B:246:0x0404, B:248:0x0409), top: B:263:0x0404 }] */
    /* JADX WARN: Removed duplicated region for block: B:253:0x0415  */
    /* JADX WARN: Removed duplicated region for block: B:254:0x0419  */
    /* JADX WARN: Removed duplicated region for block: B:263:0x0404 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:87:0x01b7  */
    /* JADX WARN: Type inference failed for: r2v40 */
    /* JADX WARN: Type inference failed for: r2v41 */
    /* JADX WARN: Type inference failed for: r2v42 */
    /* JADX WARN: Type inference failed for: r2v43 */
    /* JADX WARN: Type inference failed for: r2v45 */
    /* JADX WARN: Type inference failed for: r2v46 */
    /* JADX WARN: Type inference failed for: r2v48, types: [net.lingala.zip4j.model.LocalFileHeader] */
    /* JADX WARN: Type inference failed for: r2v67 */
    /* JADX WARN: Type inference failed for: r2v68 */
    /* JADX WARN: Type inference failed for: r2v72 */
    /* JADX WARN: Type inference failed for: r2v73, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r2v74 */
    /* JADX WARN: Type inference failed for: r2v75 */
    /* JADX WARN: Type inference failed for: r2v76 */
    /* JADX WARN: Type inference failed for: r2v77 */
    /* JADX WARN: Type inference failed for: r2v78 */
    /* JADX WARN: Type inference failed for: r2v79 */
    /* JADX WARN: Type inference failed for: r2v80 */
    /* JADX WARN: Type inference failed for: r2v81 */
    /* JADX WARN: Type inference failed for: r2v82 */
    /* JADX WARN: Type inference failed for: r32v0, types: [net.lingala.zip4j.util.ArchiveMaintainer] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public HashMap initRemoveZipFile(ZipModel zipModel, FileHeader fileHeader, ProgressMonitor progressMonitor) throws ZipException {
        String str;
        File file;
        boolean z;
        RandomAccessFile randomAccessFile;
        SplitOutputStream splitOutputStream;
        RandomAccessFile randomAccessFile2;
        String str2;
        int indexOfFileHeader;
        String str3;
        SplitOutputStream splitOutputStream2;
        String str4;
        String str5;
        String str6;
        File file2;
        RandomAccessFile createFileHandler;
        long offsetLocalHeader;
        File file3;
        String str7;
        String str8;
        int i2;
        if (fileHeader == null || zipModel == null) {
            throw new ZipException("input parameters is null in maintain zip file, cannot remove file from archive");
        }
        HashMap hashMap = new HashMap();
        try {
            indexOfFileHeader = Zip4jUtil.getIndexOfFileHeader(zipModel, fileHeader);
        } catch (ZipException e) {
            e = e;
        } catch (Exception e2) {
            e = e2;
        } catch (Throwable th) {
            th = th;
        }
        try {
        } catch (ZipException e3) {
            e = e3;
            str = null;
            str2 = str;
            file = null;
            z = false;
            splitOutputStream = null;
            randomAccessFile2 = null;
            try {
                progressMonitor.endProgressMonitorError(e);
                throw e;
            } catch (Throwable th2) {
                th = th2;
                str = str2;
                randomAccessFile = randomAccessFile2;
            }
        } catch (Exception e4) {
            e = e4;
            str = null;
            file = null;
            z = false;
            randomAccessFile = null;
            splitOutputStream = null;
            str = str;
            try {
                progressMonitor.endProgressMonitorError(e);
                throw new ZipException(e);
            } catch (Throwable th3) {
                th = th3;
            }
        } catch (Throwable th4) {
            th = th4;
            str = null;
            file = null;
            z = false;
            randomAccessFile = null;
            splitOutputStream = null;
            if (randomAccessFile != null) {
            }
            if (splitOutputStream != null) {
            }
            if (z) {
            }
            throw th;
        }
        if (indexOfFileHeader < 0) {
            throw new ZipException("file header not found in zip model, cannot remove file");
        }
        if (zipModel.isSplitArchive()) {
            throw new ZipException("This is a split archive. Zip file format does not allow updating split/spanned files");
        }
        str = zipModel.getZipFile() + (System.currentTimeMillis() % 1000);
        try {
            file = new File(str);
            str3 = str;
            while (file.exists()) {
                try {
                    str3 = zipModel.getZipFile() + (System.currentTimeMillis() % 1000);
                    try {
                        file = new File(str3);
                    } catch (ZipException e5) {
                        e = e5;
                        str = str3;
                        str2 = str;
                        file = null;
                        z = false;
                        splitOutputStream = null;
                        randomAccessFile2 = null;
                        progressMonitor.endProgressMonitorError(e);
                        throw e;
                    } catch (Exception e6) {
                        e = e6;
                        str = str3;
                        file = null;
                        z = false;
                        randomAccessFile = null;
                        splitOutputStream = null;
                        str = str;
                        progressMonitor.endProgressMonitorError(e);
                        throw new ZipException(e);
                    } catch (Throwable th5) {
                        th = th5;
                        str = str3;
                        file = null;
                        z = false;
                        randomAccessFile = null;
                        splitOutputStream = null;
                        if (randomAccessFile != null) {
                        }
                        if (splitOutputStream != null) {
                        }
                        if (z) {
                        }
                        throw th;
                    }
                } catch (ZipException e7) {
                    e = e7;
                    str = str3;
                } catch (Exception e8) {
                    e = e8;
                    str = str3;
                } catch (Throwable th6) {
                    th = th6;
                    str = str3;
                }
            }
            try {
                splitOutputStream2 = new SplitOutputStream(new File(str3));
                try {
                    file2 = new File(zipModel.getZipFile());
                    try {
                        createFileHandler = createFileHandler(zipModel, InternalZipConstants.READ_MODE);
                    } catch (ZipException e9) {
                        e = e9;
                        file = file2;
                        str5 = str3;
                        splitOutputStream = splitOutputStream2;
                        z = false;
                        randomAccessFile2 = null;
                        str6 = str5;
                        str2 = str6;
                        progressMonitor.endProgressMonitorError(e);
                        throw e;
                    } catch (Exception e10) {
                        e = e10;
                        file = file2;
                        str4 = str3;
                        splitOutputStream = splitOutputStream2;
                        z = false;
                        randomAccessFile = null;
                        str = str4;
                        progressMonitor.endProgressMonitorError(e);
                        throw new ZipException(e);
                    } catch (Throwable th7) {
                        th = th7;
                        file = file2;
                        str = str3;
                        splitOutputStream = splitOutputStream2;
                        z = false;
                        randomAccessFile = null;
                        if (randomAccessFile != null) {
                        }
                        if (splitOutputStream != null) {
                        }
                        if (z) {
                        }
                        throw th;
                    }
                } catch (ZipException e11) {
                    e = e11;
                    str5 = str3;
                    splitOutputStream = splitOutputStream2;
                    file = null;
                } catch (Exception e12) {
                    e = e12;
                    str4 = str3;
                    splitOutputStream = splitOutputStream2;
                    file = null;
                } catch (Throwable th8) {
                    th = th8;
                    str = str3;
                    splitOutputStream = splitOutputStream2;
                    file = null;
                }
            } catch (FileNotFoundException e13) {
                str = str3;
                try {
                    throw new ZipException(e13);
                } catch (ZipException e14) {
                    e = e14;
                    str2 = str;
                    file = null;
                    z = false;
                    splitOutputStream = null;
                    randomAccessFile2 = null;
                    progressMonitor.endProgressMonitorError(e);
                    throw e;
                } catch (Exception e15) {
                    e = e15;
                    file = null;
                    z = false;
                    randomAccessFile = null;
                    splitOutputStream = null;
                    str = str;
                    progressMonitor.endProgressMonitorError(e);
                    throw new ZipException(e);
                } catch (Throwable th9) {
                    th = th9;
                    file = null;
                    z = false;
                    randomAccessFile = null;
                    splitOutputStream = null;
                    if (randomAccessFile != null) {
                    }
                    if (splitOutputStream != null) {
                    }
                    if (z) {
                    }
                    throw th;
                }
            }
        } catch (ZipException e16) {
            e = e16;
        } catch (Exception e17) {
            e = e17;
        } catch (Throwable th10) {
            th = th10;
        }
        try {
            try {
                str = new HeaderReader(createFileHandler).readLocalFileHeader(fileHeader);
                try {
                } catch (ZipException e18) {
                    e = e18;
                } catch (Exception e19) {
                    e = e19;
                } catch (Throwable th11) {
                    th = th11;
                }
            } catch (Throwable th12) {
                th = th12;
                randomAccessFile2 = createFileHandler;
                file = file2;
                str = str3;
            }
            if (str != 0) {
                long offsetLocalHeader2 = fileHeader.getOffsetLocalHeader();
                if (fileHeader.getZip64ExtendedInfo() != null) {
                    try {
                        if (fileHeader.getZip64ExtendedInfo().getOffsetLocalHeader() != -1) {
                            offsetLocalHeader2 = fileHeader.getZip64ExtendedInfo().getOffsetLocalHeader();
                        }
                    } catch (Throwable th13) {
                        th = th13;
                        file = file2;
                        str = str3;
                        splitOutputStream = splitOutputStream2;
                        z = false;
                        randomAccessFile = createFileHandler;
                    }
                }
                long j = offsetLocalHeader2;
                long offsetOfStartOfCentralDir = zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir();
                if (zipModel.isZip64Format() && zipModel.getZip64EndCentralDirRecord() != null) {
                    offsetOfStartOfCentralDir = zipModel.getZip64EndCentralDirRecord().getOffsetStartCenDirWRTStartDiskNo();
                }
                long j2 = offsetOfStartOfCentralDir;
                ArrayList fileHeaders = zipModel.getCentralDirectory().getFileHeaders();
                if (indexOfFileHeader == fileHeaders.size() - 1) {
                    offsetLocalHeader = j2 - 1;
                } else {
                    FileHeader fileHeader2 = (FileHeader) fileHeaders.get(indexOfFileHeader + 1);
                    offsetLocalHeader = fileHeader2 != null ? (fileHeader2.getZip64ExtendedInfo() == null || fileHeader2.getZip64ExtendedInfo().getOffsetLocalHeader() == -1) ? fileHeader2.getOffsetLocalHeader() - 1 : fileHeader2.getZip64ExtendedInfo().getOffsetLocalHeader() - 1 : -1L;
                }
                long j3 = offsetLocalHeader;
                if (j < 0 || j3 < 0) {
                    throw new ZipException("invalid offset for start and end of local file, cannot remove file");
                }
                try {
                    try {
                        if (indexOfFileHeader == 0) {
                            try {
                                if (zipModel.getCentralDirectory().getFileHeaders().size() > 1) {
                                    randomAccessFile2 = createFileHandler;
                                    file3 = file2;
                                    str7 = str3;
                                    i2 = indexOfFileHeader;
                                    copyFile(createFileHandler, splitOutputStream2, j3 + 1, j2, progressMonitor);
                                    if (progressMonitor.isCancelAllTasks()) {
                                        str = str7;
                                        try {
                                            try {
                                                SplitOutputStream splitOutputStream3 = splitOutputStream2;
                                                zipModel.getEndCentralDirRecord().setOffsetOfStartOfCentralDir(splitOutputStream2.getFilePointer());
                                                zipModel.getEndCentralDirRecord().setTotNoOfEntriesInCentralDir(zipModel.getEndCentralDirRecord().getTotNoOfEntriesInCentralDir() - 1);
                                                zipModel.getEndCentralDirRecord().setTotNoOfEntriesInCentralDirOnThisDisk(zipModel.getEndCentralDirRecord().getTotNoOfEntriesInCentralDirOnThisDisk() - 1);
                                                zipModel.getCentralDirectory().getFileHeaders().remove(i2);
                                                for (int i3 = i2; i3 < zipModel.getCentralDirectory().getFileHeaders().size(); i3++) {
                                                    try {
                                                        long offsetLocalHeader3 = ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getOffsetLocalHeader();
                                                        if (((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getZip64ExtendedInfo() != null && ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getZip64ExtendedInfo().getOffsetLocalHeader() != -1) {
                                                            offsetLocalHeader3 = ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).getZip64ExtendedInfo().getOffsetLocalHeader();
                                                        }
                                                        ((FileHeader) zipModel.getCentralDirectory().getFileHeaders().get(i3)).setOffsetLocalHeader((offsetLocalHeader3 - (j3 - j)) - 1);
                                                    } catch (Throwable th14) {
                                                        th = th14;
                                                        splitOutputStream = splitOutputStream2;
                                                        randomAccessFile = randomAccessFile2;
                                                        str8 = str;
                                                        file = file3;
                                                        str = str8;
                                                        z = false;
                                                        if (randomAccessFile != null) {
                                                        }
                                                        if (splitOutputStream != null) {
                                                        }
                                                        if (z) {
                                                        }
                                                        throw th;
                                                    }
                                                }
                                                new HeaderWriter().finalizeZipFile(zipModel, splitOutputStream2);
                                            } catch (Throwable th15) {
                                                th = th15;
                                                file = file3;
                                                splitOutputStream = splitOutputStream2;
                                                randomAccessFile = randomAccessFile2;
                                                str = str;
                                                z = false;
                                                if (randomAccessFile != null) {
                                                }
                                                if (splitOutputStream != null) {
                                                }
                                                if (z) {
                                                }
                                                throw th;
                                            }
                                        } catch (ZipException e20) {
                                            e = e20;
                                            file = file3;
                                            splitOutputStream = splitOutputStream2;
                                            z = false;
                                            str6 = str;
                                            str2 = str6;
                                            progressMonitor.endProgressMonitorError(e);
                                            throw e;
                                        } catch (Exception e21) {
                                            e = e21;
                                            file = file3;
                                            splitOutputStream = splitOutputStream2;
                                            randomAccessFile = randomAccessFile2;
                                            z = false;
                                            str = str;
                                            progressMonitor.endProgressMonitorError(e);
                                            throw new ZipException(e);
                                        }
                                        try {
                                            hashMap.put(InternalZipConstants.OFFSET_CENTRAL_DIR, Long.toString(zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir()));
                                            if (randomAccessFile2 != null) {
                                                try {
                                                    randomAccessFile2.close();
                                                } catch (IOException unused) {
                                                    throw new ZipException("cannot close input stream or output stream when trying to delete a file from zip file");
                                                }
                                            }
                                            splitOutputStream2.close();
                                            restoreFileName(file3, str);
                                            return hashMap;
                                        } catch (ZipException e22) {
                                            e = e22;
                                            file = file3;
                                            splitOutputStream = splitOutputStream2;
                                            z = true;
                                            str6 = str;
                                            str2 = str6;
                                            progressMonitor.endProgressMonitorError(e);
                                            throw e;
                                        } catch (Exception e23) {
                                            e = e23;
                                            file = file3;
                                            splitOutputStream = splitOutputStream2;
                                            randomAccessFile = randomAccessFile2;
                                            z = true;
                                            str = str;
                                            progressMonitor.endProgressMonitorError(e);
                                            throw new ZipException(e);
                                        } catch (Throwable th16) {
                                            th = th16;
                                            file = file3;
                                            splitOutputStream = splitOutputStream2;
                                            randomAccessFile = randomAccessFile2;
                                            z = true;
                                        }
                                    } else {
                                        try {
                                            progressMonitor.setResult(3);
                                            try {
                                                progressMonitor.setState(0);
                                                if (randomAccessFile2 != null) {
                                                    try {
                                                        randomAccessFile2.close();
                                                    } catch (IOException unused2) {
                                                        throw new ZipException("cannot close input stream or output stream when trying to delete a file from zip file");
                                                    }
                                                }
                                                splitOutputStream2.close();
                                                new File(str7).delete();
                                                return null;
                                            } catch (ZipException e24) {
                                                e = e24;
                                                str = str7;
                                                file = file3;
                                                splitOutputStream = splitOutputStream2;
                                                z = false;
                                                str6 = str;
                                                str2 = str6;
                                                progressMonitor.endProgressMonitorError(e);
                                                throw e;
                                            } catch (Exception e25) {
                                                e = e25;
                                                str = str7;
                                                file = file3;
                                                splitOutputStream = splitOutputStream2;
                                                randomAccessFile = randomAccessFile2;
                                                z = false;
                                                str = str;
                                                progressMonitor.endProgressMonitorError(e);
                                                throw new ZipException(e);
                                            } catch (Throwable th17) {
                                                th = th17;
                                                str = str7;
                                                splitOutputStream = splitOutputStream2;
                                                randomAccessFile = randomAccessFile2;
                                                str8 = str;
                                                file = file3;
                                                str = str8;
                                                z = false;
                                                if (randomAccessFile != null) {
                                                }
                                                if (splitOutputStream != null) {
                                                }
                                                if (z) {
                                                }
                                                throw th;
                                            }
                                        } catch (ZipException e26) {
                                            e = e26;
                                            str = str7;
                                        } catch (Exception e27) {
                                            e = e27;
                                            str = str7;
                                        } catch (Throwable th18) {
                                            th = th18;
                                            str = str7;
                                        }
                                    }
                                } else {
                                    randomAccessFile2 = createFileHandler;
                                    file3 = file2;
                                    str7 = str3;
                                    i2 = indexOfFileHeader;
                                    if (progressMonitor.isCancelAllTasks()) {
                                    }
                                }
                            } catch (Throwable th19) {
                                th = th19;
                                randomAccessFile2 = createFileHandler;
                                file3 = file2;
                                str7 = str3;
                                splitOutputStream = splitOutputStream2;
                                randomAccessFile = randomAccessFile2;
                                str8 = str7;
                                file = file3;
                                str = str8;
                                z = false;
                                if (randomAccessFile != null) {
                                }
                                if (splitOutputStream != null) {
                                }
                                if (z) {
                                }
                                throw th;
                            }
                        } else {
                            randomAccessFile2 = createFileHandler;
                            file3 = file2;
                            str7 = str3;
                            i2 = indexOfFileHeader;
                            try {
                                if (i2 == fileHeaders.size() - 1) {
                                    copyFile(randomAccessFile2, splitOutputStream2, 0L, j, progressMonitor);
                                    if (progressMonitor.isCancelAllTasks()) {
                                    }
                                } else {
                                    copyFile(randomAccessFile2, splitOutputStream2, 0L, j, progressMonitor);
                                    copyFile(randomAccessFile2, splitOutputStream2, j3 + 1, j2, progressMonitor);
                                    if (progressMonitor.isCancelAllTasks()) {
                                    }
                                }
                            } catch (Throwable th20) {
                                th = th20;
                                str = str7;
                                file = file3;
                                splitOutputStream = splitOutputStream2;
                                randomAccessFile = randomAccessFile2;
                                str = str;
                                z = false;
                                if (randomAccessFile != null) {
                                }
                                if (splitOutputStream != null) {
                                }
                                if (z) {
                                }
                                throw th;
                            }
                        }
                    } catch (Throwable th21) {
                        th = th21;
                    }
                } catch (ZipException e28) {
                    e = e28;
                    str = str7;
                    file = file3;
                    splitOutputStream = splitOutputStream2;
                    z = false;
                    str6 = str;
                    str2 = str6;
                    progressMonitor.endProgressMonitorError(e);
                    throw e;
                } catch (Exception e29) {
                    e = e29;
                    str = str7;
                    file = file3;
                    splitOutputStream = splitOutputStream2;
                    randomAccessFile = randomAccessFile2;
                    z = false;
                    str = str;
                    progressMonitor.endProgressMonitorError(e);
                    throw new ZipException(e);
                }
                z = false;
                if (randomAccessFile != null) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException unused3) {
                        throw new ZipException("cannot close input stream or output stream when trying to delete a file from zip file");
                    }
                }
                if (splitOutputStream != null) {
                    splitOutputStream.close();
                }
                if (z) {
                    new File(str).delete();
                } else {
                    restoreFileName(file, str);
                }
                throw th;
            }
            throw new ZipException("invalid local file header, cannot remove file from archive");
        } catch (ZipException e30) {
            e = e30;
            randomAccessFile2 = createFileHandler;
            file = file2;
            str = str3;
        } catch (Exception e31) {
            e = e31;
            randomAccessFile2 = createFileHandler;
            file = file2;
            str = str3;
        }
    }

    public void mergeSplitZipFiles(final ZipModel zipModel, final File file, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        if (z) {
            new Thread(InternalZipConstants.THREAD_NAME) { // from class: net.lingala.zip4j.util.ArchiveMaintainer.2
                @Override // java.lang.Thread, java.lang.Runnable
                public void run() {
                    try {
                        ArchiveMaintainer.this.initMergeSplitZipFile(zipModel, file, progressMonitor);
                    } catch (ZipException unused) {
                    }
                }
            }.start();
        } else {
            initMergeSplitZipFile(zipModel, file, progressMonitor);
        }
    }

    public HashMap removeZipFile(final ZipModel zipModel, final FileHeader fileHeader, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        if (z) {
            new Thread(InternalZipConstants.THREAD_NAME) { // from class: net.lingala.zip4j.util.ArchiveMaintainer.1
                @Override // java.lang.Thread, java.lang.Runnable
                public void run() {
                    try {
                        ArchiveMaintainer.this.initRemoveZipFile(zipModel, fileHeader, progressMonitor);
                        progressMonitor.endProgressMonitorSuccess();
                    } catch (ZipException unused) {
                    }
                }
            }.start();
            return null;
        }
        HashMap initRemoveZipFile = initRemoveZipFile(zipModel, fileHeader, progressMonitor);
        progressMonitor.endProgressMonitorSuccess();
        return initRemoveZipFile;
    }

    public void setComment(ZipModel zipModel, String str) throws ZipException {
        HeaderWriter headerWriter;
        SplitOutputStream splitOutputStream;
        if (str == null) {
            throw new ZipException("comment is null, cannot update Zip file with comment");
        }
        if (zipModel == null) {
            throw new ZipException("zipModel is null, cannot update Zip file with comment");
        }
        byte[] bytes = str.getBytes();
        int length = str.length();
        if (Zip4jUtil.isSupportedCharset(InternalZipConstants.CHARSET_COMMENTS_DEFAULT)) {
            try {
                String str2 = new String(str.getBytes(InternalZipConstants.CHARSET_COMMENTS_DEFAULT), InternalZipConstants.CHARSET_COMMENTS_DEFAULT);
                byte[] bytes2 = str2.getBytes(InternalZipConstants.CHARSET_COMMENTS_DEFAULT);
                length = str2.length();
                str = str2;
                bytes = bytes2;
            } catch (UnsupportedEncodingException unused) {
                bytes = str.getBytes();
                length = str.length();
            }
        }
        if (length > 65535) {
            throw new ZipException("comment length exceeds maximum length");
        }
        zipModel.getEndCentralDirRecord().setComment(str);
        zipModel.getEndCentralDirRecord().setCommentBytes(bytes);
        zipModel.getEndCentralDirRecord().setCommentLength(length);
        SplitOutputStream splitOutputStream2 = null;
        try {
            try {
                headerWriter = new HeaderWriter();
                splitOutputStream = new SplitOutputStream(zipModel.getZipFile());
            } catch (Throwable th) {
                th = th;
            }
        } catch (FileNotFoundException e) {
            e = e;
        } catch (IOException e2) {
            e = e2;
        }
        try {
            splitOutputStream.seek(zipModel.isZip64Format() ? zipModel.getZip64EndCentralDirRecord().getOffsetStartCenDirWRTStartDiskNo() : zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
            headerWriter.finalizeZipFileWithoutValidations(zipModel, splitOutputStream);
            try {
                splitOutputStream.close();
            } catch (IOException unused2) {
            }
        } catch (FileNotFoundException e3) {
            e = e3;
            throw new ZipException(e);
        } catch (IOException e4) {
            e = e4;
            throw new ZipException(e);
        } catch (Throwable th2) {
            th = th2;
            splitOutputStream2 = splitOutputStream;
            if (splitOutputStream2 != null) {
                try {
                    splitOutputStream2.close();
                } catch (IOException unused3) {
                }
            }
            throw th;
        }
    }
}
