package net.lingala.zip4j.util;

import java.io.DataInput;
import java.io.IOException;
import java.util.Objects;
import net.lingala.zip4j.exception.ZipException;
/* loaded from: classes11.dex */
public class Raw {
    public static byte bitArrayToByte(int[] iArr) throws ZipException {
        if (iArr != null) {
            if (iArr.length == 8) {
                if (checkBits(iArr)) {
                    int i2 = 0;
                    for (int i3 = 0; i3 < iArr.length; i3++) {
                        i2 = (int) (i2 + (Math.pow(2.0d, i3) * iArr[i3]));
                    }
                    return (byte) i2;
                }
                throw new ZipException("invalid bits provided, bits contain other values than 0 or 1");
            }
            throw new ZipException("invalid bit array length, cannot calculate byte");
        }
        throw new ZipException("bit array is null, cannot calculate byte from bits");
    }

    private static boolean checkBits(int[] iArr) {
        for (int i2 = 0; i2 < iArr.length; i2++) {
            if (iArr[i2] != 0 && iArr[i2] != 1) {
                return false;
            }
        }
        return true;
    }

    public static byte[] convertCharArrayToByteArray(char[] cArr) {
        Objects.requireNonNull(cArr);
        byte[] bArr = new byte[cArr.length];
        for (int i2 = 0; i2 < cArr.length; i2++) {
            bArr[i2] = (byte) cArr[i2];
        }
        return bArr;
    }

    public static void prepareBuffAESIVBytes(byte[] bArr, int i2, int i3) {
        bArr[0] = (byte) i2;
        bArr[1] = (byte) (i2 >> 8);
        bArr[2] = (byte) (i2 >> 16);
        bArr[3] = (byte) (i2 >> 24);
        byte b = (byte) 0;
        bArr[4] = b;
        bArr[5] = b;
        bArr[6] = b;
        bArr[7] = b;
        bArr[8] = b;
        bArr[9] = b;
        bArr[10] = b;
        bArr[11] = b;
        bArr[12] = b;
        bArr[13] = b;
        bArr[14] = b;
        bArr[15] = b;
    }

    public static int readIntLittleEndian(byte[] bArr, int i2) {
        return ((((bArr[i2 + 3] & 255) << 8) | (bArr[i2 + 2] & 255)) << 16) | (bArr[i2] & 255) | ((bArr[i2 + 1] & 255) << 8);
    }

    public static int readLeInt(DataInput dataInput, byte[] bArr) throws ZipException {
        try {
            dataInput.readFully(bArr, 0, 4);
            return (bArr[0] & 255) | ((bArr[1] & 255) << 8) | ((((bArr[3] & 255) << 8) | (bArr[2] & 255)) << 16);
        } catch (IOException e) {
            throw new ZipException(e);
        }
    }

    public static long readLongLittleEndian(byte[] bArr, int i2) {
        return (bArr[i2] & 255) | (((((((((((((((bArr[i2 + 7] & 255) | 0) << 8) | (bArr[i2 + 6] & 255)) << 8) | (bArr[i2 + 5] & 255)) << 8) | (bArr[i2 + 4] & 255)) << 8) | (bArr[i2 + 3] & 255)) << 8) | (bArr[i2 + 2] & 255)) << 8) | (bArr[i2 + 1] & 255)) << 8);
    }

    public static final short readShortBigEndian(byte[] bArr, int i2) {
        return (short) ((bArr[i2 + 1] & 255) | ((short) (((short) ((bArr[i2] & 255) | 0)) << 8)));
    }

    public static int readShortLittleEndian(byte[] bArr, int i2) {
        return ((bArr[i2 + 1] & 255) << 8) | (bArr[i2] & 255);
    }

    public static byte[] toByteArray(int i2) {
        return new byte[]{(byte) i2, (byte) (i2 >> 8), (byte) (i2 >> 16), (byte) (i2 >> 24)};
    }

    public static byte[] toByteArray(int i2, int i3) {
        byte[] bArr = new byte[i3];
        byte[] byteArray = toByteArray(i2);
        for (int i4 = 0; i4 < byteArray.length && i4 < i3; i4++) {
            bArr[i4] = byteArray[i4];
        }
        return bArr;
    }

    public static final void writeIntLittleEndian(byte[] bArr, int i2, int i3) {
        bArr[i2 + 3] = (byte) (i3 >>> 24);
        bArr[i2 + 2] = (byte) (i3 >>> 16);
        bArr[i2 + 1] = (byte) (i3 >>> 8);
        bArr[i2] = (byte) (i3 & 255);
    }

    public static void writeLongLittleEndian(byte[] bArr, int i2, long j) {
        bArr[i2 + 7] = (byte) (j >>> 56);
        bArr[i2 + 6] = (byte) (j >>> 48);
        bArr[i2 + 5] = (byte) (j >>> 40);
        bArr[i2 + 4] = (byte) (j >>> 32);
        bArr[i2 + 3] = (byte) (j >>> 24);
        bArr[i2 + 2] = (byte) (j >>> 16);
        bArr[i2 + 1] = (byte) (j >>> 8);
        bArr[i2] = (byte) (j & 255);
    }

    public static final void writeShortLittleEndian(byte[] bArr, int i2, short s) {
        bArr[i2 + 1] = (byte) (s >>> 8);
        bArr[i2] = (byte) (s & 255);
    }
}
