package net.lingala.zip4j.util;

import java.io.File;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.List;
import java.util.TimeZone;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.ZipModel;
/* loaded from: classes11.dex */
public class Zip4jUtil {
    public static boolean checkArrayListTypes(ArrayList arrayList, int i2) throws ZipException {
        boolean z;
        if (arrayList != null) {
            if (arrayList.size() > 0) {
                if (i2 != 1) {
                    if (i2 == 2) {
                        for (int i3 = 0; i3 < arrayList.size(); i3++) {
                            if (!(arrayList.get(i3) instanceof String)) {
                                z = true;
                                break;
                            }
                        }
                    }
                    z = false;
                } else {
                    for (int i4 = 0; i4 < arrayList.size(); i4++) {
                        if (!(arrayList.get(i4) instanceof File)) {
                            z = true;
                            break;
                        }
                    }
                    z = false;
                }
                if (z) {
                    return false;
                }
            }
            return true;
        }
        throw new ZipException("input arraylist is null, cannot check types");
    }

    public static boolean checkFileExists(File file) throws ZipException {
        if (file != null) {
            return file.exists();
        }
        throw new ZipException("cannot check if file exists: input file is null");
    }

    public static boolean checkFileExists(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            return checkFileExists(new File(str));
        }
        throw new ZipException("path is null");
    }

    public static boolean checkFileReadAccess(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            if (checkFileExists(str)) {
                try {
                    return new File(str).canRead();
                } catch (Exception unused) {
                    throw new ZipException("cannot read zip file");
                }
            }
            throw new ZipException("file does not exist: " + str);
        }
        throw new ZipException("path is null");
    }

    public static boolean checkFileWriteAccess(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            if (checkFileExists(str)) {
                try {
                    return new File(str).canWrite();
                } catch (Exception unused) {
                    throw new ZipException("cannot read zip file");
                }
            }
            throw new ZipException("file does not exist: " + str);
        }
        throw new ZipException("path is null");
    }

    public static boolean checkOutputFolder(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            File file = new File(str);
            if (file.exists()) {
                if (file.isDirectory()) {
                    if (file.canWrite()) {
                        return true;
                    }
                    throw new ZipException("no write access to output folder");
                }
                throw new ZipException("output folder is not valid");
            }
            try {
                file.mkdirs();
                if (file.isDirectory()) {
                    if (file.canWrite()) {
                        return true;
                    }
                    throw new ZipException("no write access to destination folder");
                }
                throw new ZipException("output folder is not valid");
            } catch (Exception unused) {
                throw new ZipException("Cannot create destination folder");
            }
        }
        throw new ZipException(new NullPointerException("output path is null"));
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v10 */
    /* JADX WARN: Type inference failed for: r4v6, types: [byte[]] */
    /* JADX WARN: Type inference failed for: r4v8 */
    /* JADX WARN: Type inference failed for: r4v9 */
    public static byte[] convertCharset(String str) throws ZipException {
        try {
            String detectCharSet = detectCharSet(str);
            str = detectCharSet.equals(InternalZipConstants.CHARSET_CP850) ? str.getBytes(InternalZipConstants.CHARSET_CP850) : detectCharSet.equals(InternalZipConstants.CHARSET_UTF8) ? str.getBytes(InternalZipConstants.CHARSET_UTF8) : str.getBytes();
            return str;
        } catch (UnsupportedEncodingException unused) {
            return str.getBytes();
        } catch (Exception e) {
            throw new ZipException(e);
        }
    }

    public static String decodeFileName(byte[] bArr, boolean z) {
        if (z) {
            try {
                return new String(bArr, InternalZipConstants.CHARSET_UTF8);
            } catch (UnsupportedEncodingException unused) {
                return new String(bArr);
            }
        }
        return getCp850EncodedString(bArr);
    }

    public static String detectCharSet(String str) throws ZipException {
        if (str != null) {
            try {
                return str.equals(new String(str.getBytes(InternalZipConstants.CHARSET_CP850), InternalZipConstants.CHARSET_CP850)) ? InternalZipConstants.CHARSET_CP850 : str.equals(new String(str.getBytes(InternalZipConstants.CHARSET_UTF8), InternalZipConstants.CHARSET_UTF8)) ? InternalZipConstants.CHARSET_UTF8 : InternalZipConstants.CHARSET_DEFAULT;
            } catch (UnsupportedEncodingException | Exception unused) {
                return InternalZipConstants.CHARSET_DEFAULT;
            }
        }
        throw new ZipException("input string is null, cannot detect charset");
    }

    public static long dosToJavaTme(int i2) {
        Calendar calendar = Calendar.getInstance();
        calendar.set(((i2 >> 25) & 127) + 1980, ((i2 >> 21) & 15) - 1, (i2 >> 16) & 31, (i2 >> 11) & 31, (i2 >> 5) & 63, (i2 & 31) * 2);
        calendar.set(14, 0);
        return calendar.getTime().getTime();
    }

    public static String getAbsoluteFilePath(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            return new File(str).getAbsolutePath();
        }
        throw new ZipException("filePath is null or empty, cannot get absolute file path");
    }

    public static long[] getAllHeaderSignatures() {
        return new long[]{InternalZipConstants.LOCSIG, 134695760, InternalZipConstants.CENSIG, InternalZipConstants.ENDSIG, InternalZipConstants.DIGSIG, InternalZipConstants.ARCEXTDATREC, 134695760, InternalZipConstants.ZIP64ENDCENDIRLOC, InternalZipConstants.ZIP64ENDCENDIRREC, 1, 39169};
    }

    public static String getCp850EncodedString(byte[] bArr) {
        try {
            return new String(bArr, InternalZipConstants.CHARSET_CP850);
        } catch (UnsupportedEncodingException unused) {
            return new String(bArr);
        }
    }

    public static int getEncodedStringLength(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            return getEncodedStringLength(str, detectCharSet(str));
        }
        throw new ZipException("input string is null, cannot calculate encoded String length");
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v0, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r3v10 */
    /* JADX WARN: Type inference failed for: r3v13 */
    /* JADX WARN: Type inference failed for: r3v14 */
    /* JADX WARN: Type inference failed for: r3v15 */
    /* JADX WARN: Type inference failed for: r3v3, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r3v5, types: [java.nio.ByteBuffer] */
    /* JADX WARN: Type inference failed for: r3v6, types: [java.nio.ByteBuffer] */
    public static int getEncodedStringLength(String str, String str2) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            if (isStringNotNullAndNotEmpty(str2)) {
                try {
                    str = str2.equals(InternalZipConstants.CHARSET_CP850) ? ByteBuffer.wrap(str.getBytes(InternalZipConstants.CHARSET_CP850)) : str2.equals(InternalZipConstants.CHARSET_UTF8) ? ByteBuffer.wrap(str.getBytes(InternalZipConstants.CHARSET_UTF8)) : ByteBuffer.wrap(str.getBytes(str2));
                } catch (UnsupportedEncodingException unused) {
                    str = ByteBuffer.wrap(str.getBytes());
                } catch (Exception e) {
                    throw new ZipException(e);
                }
                return str.limit();
            }
            throw new ZipException("encoding is not defined, cannot calculate string length");
        }
        throw new ZipException("input string is null, cannot calculate encoded String length");
    }

    public static FileHeader getFileHeader(ZipModel zipModel, String str) throws ZipException {
        if (zipModel != null) {
            if (isStringNotNullAndNotEmpty(str)) {
                FileHeader fileHeaderWithExactMatch = getFileHeaderWithExactMatch(zipModel, str);
                if (fileHeaderWithExactMatch == null) {
                    String replaceAll = str.replaceAll("\\\\", InternalZipConstants.ZIP_FILE_SEPARATOR);
                    FileHeader fileHeaderWithExactMatch2 = getFileHeaderWithExactMatch(zipModel, replaceAll);
                    return fileHeaderWithExactMatch2 == null ? getFileHeaderWithExactMatch(zipModel, replaceAll.replaceAll(InternalZipConstants.ZIP_FILE_SEPARATOR, "\\\\")) : fileHeaderWithExactMatch2;
                }
                return fileHeaderWithExactMatch;
            }
            throw new ZipException("file name is null, cannot determine file header for fileName: " + str);
        }
        throw new ZipException("zip model is null, cannot determine file header for fileName: " + str);
    }

    public static FileHeader getFileHeaderWithExactMatch(ZipModel zipModel, String str) throws ZipException {
        if (zipModel != null) {
            if (isStringNotNullAndNotEmpty(str)) {
                if (zipModel.getCentralDirectory() != null) {
                    if (zipModel.getCentralDirectory().getFileHeaders() != null) {
                        if (zipModel.getCentralDirectory().getFileHeaders().size() <= 0) {
                            return null;
                        }
                        ArrayList fileHeaders = zipModel.getCentralDirectory().getFileHeaders();
                        for (int i2 = 0; i2 < fileHeaders.size(); i2++) {
                            FileHeader fileHeader = (FileHeader) fileHeaders.get(i2);
                            String fileName = fileHeader.getFileName();
                            if (isStringNotNullAndNotEmpty(fileName) && str.equalsIgnoreCase(fileName)) {
                                return fileHeader;
                            }
                        }
                        return null;
                    }
                    throw new ZipException("file Headers are null, cannot determine file header with exact match for fileName: " + str);
                }
                throw new ZipException("central directory is null, cannot determine file header with exact match for fileName: " + str);
            }
            throw new ZipException("file name is null, cannot determine file header with exact match for fileName: " + str);
        }
        throw new ZipException("zip model is null, cannot determine file header with exact match for fileName: " + str);
    }

    public static long getFileLengh(File file) throws ZipException {
        if (file != null) {
            if (file.isDirectory()) {
                return -1L;
            }
            return file.length();
        }
        throw new ZipException("input file is null, cannot calculate file length");
    }

    public static long getFileLengh(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            return getFileLengh(new File(str));
        }
        throw new ZipException("invalid file name");
    }

    public static String getFileNameFromFilePath(File file) throws ZipException {
        if (file != null) {
            if (file.isDirectory()) {
                return null;
            }
            return file.getName();
        }
        throw new ZipException("input file is null, cannot get file name");
    }

    public static ArrayList getFilesInDirectoryRec(File file, boolean z) throws ZipException {
        if (file != null) {
            ArrayList arrayList = new ArrayList();
            List asList = Arrays.asList(file.listFiles());
            if (file.canRead()) {
                for (int i2 = 0; i2 < asList.size(); i2++) {
                    File file2 = (File) asList.get(i2);
                    if (file2.isHidden() && !z) {
                        break;
                    }
                    arrayList.add(file2);
                    if (file2.isDirectory()) {
                        arrayList.addAll(getFilesInDirectoryRec(file2, z));
                    }
                }
            }
            return arrayList;
        }
        throw new ZipException("input path is null, cannot read files in the directory");
    }

    public static int getIndexOfFileHeader(ZipModel zipModel, FileHeader fileHeader) throws ZipException {
        if (zipModel == null || fileHeader == null) {
            throw new ZipException("input parameters is null, cannot determine index of file header");
        }
        if (zipModel.getCentralDirectory() != null) {
            if (zipModel.getCentralDirectory().getFileHeaders() != null) {
                if (zipModel.getCentralDirectory().getFileHeaders().size() <= 0) {
                    return -1;
                }
                String fileName = fileHeader.getFileName();
                if (isStringNotNullAndNotEmpty(fileName)) {
                    ArrayList fileHeaders = zipModel.getCentralDirectory().getFileHeaders();
                    for (int i2 = 0; i2 < fileHeaders.size(); i2++) {
                        String fileName2 = ((FileHeader) fileHeaders.get(i2)).getFileName();
                        if (isStringNotNullAndNotEmpty(fileName2) && fileName.equalsIgnoreCase(fileName2)) {
                            return i2;
                        }
                    }
                    return -1;
                }
                throw new ZipException("file name in file header is empty or null, cannot determine index of file header");
            }
            throw new ZipException("file Headers are null, cannot determine index of file header");
        }
        throw new ZipException("central directory is null, ccannot determine index of file header");
    }

    public static long getLastModifiedFileTime(File file, TimeZone timeZone) throws ZipException {
        if (file != null) {
            if (file.exists()) {
                return file.lastModified();
            }
            throw new ZipException("input file does not exist, cannot read last modified file time");
        }
        throw new ZipException("input file is null, cannot read last modified file time");
    }

    /* JADX WARN: Removed duplicated region for block: B:24:0x00b9  */
    /* JADX WARN: Removed duplicated region for block: B:27:0x00d0 A[RETURN] */
    /* JADX WARN: Removed duplicated region for block: B:28:0x00d1  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static String getRelativeFileName(String str, String str2, String str3) throws ZipException {
        String fileNameFromFilePath;
        StringBuilder append;
        StringBuilder sb;
        if (!isStringNotNullAndNotEmpty(str)) {
            throw new ZipException("input file path/name is empty, cannot calculate relative file name");
        }
        if (isStringNotNullAndNotEmpty(str3)) {
            String path = new File(str3).getPath();
            if (!path.endsWith(InternalZipConstants.FILE_SEPARATOR)) {
                path = path + InternalZipConstants.FILE_SEPARATOR;
            }
            String substring = str.substring(path.length());
            if (substring.startsWith(System.getProperty("file.separator"))) {
                substring = substring.substring(1);
            }
            File file = new File(str);
            if (!file.isDirectory()) {
                sb = new StringBuilder().append(substring.substring(0, substring.lastIndexOf(file.getName())).replaceAll("\\\\", InternalZipConstants.ZIP_FILE_SEPARATOR)).append(file.getName());
                fileNameFromFilePath = sb.toString();
                if (isStringNotNullAndNotEmpty(str2)) {
                    fileNameFromFilePath = str2 + fileNameFromFilePath;
                }
                if (isStringNotNullAndNotEmpty(fileNameFromFilePath)) {
                    return fileNameFromFilePath;
                }
                throw new ZipException("Error determining file name");
            }
            append = new StringBuilder().append(substring.replaceAll("\\\\", InternalZipConstants.ZIP_FILE_SEPARATOR));
        } else {
            File file2 = new File(str);
            if (file2.isDirectory()) {
                append = new StringBuilder().append(file2.getName());
            } else {
                fileNameFromFilePath = getFileNameFromFilePath(new File(str));
                if (isStringNotNullAndNotEmpty(str2)) {
                }
                if (isStringNotNullAndNotEmpty(fileNameFromFilePath)) {
                }
            }
        }
        sb = append.append(InternalZipConstants.ZIP_FILE_SEPARATOR);
        fileNameFromFilePath = sb.toString();
        if (isStringNotNullAndNotEmpty(str2)) {
        }
        if (isStringNotNullAndNotEmpty(fileNameFromFilePath)) {
        }
    }

    public static ArrayList getSplitZipFiles(ZipModel zipModel) throws ZipException {
        int noOfThisDisk;
        String str;
        if (zipModel != null) {
            if (zipModel.getEndCentralDirRecord() == null) {
                return null;
            }
            ArrayList arrayList = new ArrayList();
            String zipFile = zipModel.getZipFile();
            String name = new File(zipFile).getName();
            if (isStringNotNullAndNotEmpty(zipFile)) {
                if (zipModel.isSplitArchive() && (noOfThisDisk = zipModel.getEndCentralDirRecord().getNoOfThisDisk()) != 0) {
                    int i2 = 0;
                    while (i2 <= noOfThisDisk) {
                        if (i2 == noOfThisDisk) {
                            str = zipModel.getZipFile();
                        } else {
                            str = (name.indexOf(".") >= 0 ? zipFile.substring(0, zipFile.lastIndexOf(".")) : zipFile) + (i2 > 9 ? ".z" : ".z0") + (i2 + 1);
                        }
                        arrayList.add(str);
                        i2++;
                    }
                } else {
                    arrayList.add(zipFile);
                }
                return arrayList;
            }
            throw new ZipException("cannot get split zip files: zipfile is null");
        }
        throw new ZipException("cannot get split zip files: zipmodel is null");
    }

    public static String getZipFileNameWithoutExt(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            if (str.indexOf(System.getProperty("file.separator")) >= 0) {
                str = str.substring(str.lastIndexOf(System.getProperty("file.separator")));
            }
            return str.indexOf(".") > 0 ? str.substring(0, str.lastIndexOf(".")) : str;
        }
        throw new ZipException("zip file name is empty or null, cannot determine zip file name");
    }

    public static boolean isStringNotNullAndNotEmpty(String str) {
        return str != null && str.trim().length() > 0;
    }

    public static boolean isSupportedCharset(String str) throws ZipException {
        if (isStringNotNullAndNotEmpty(str)) {
            try {
                new String("a".getBytes(), str);
                return true;
            } catch (UnsupportedEncodingException unused) {
                return false;
            } catch (Exception e) {
                throw new ZipException(e);
            }
        }
        throw new ZipException("charset is null or empty, cannot check if it is supported");
    }

    public static boolean isWindows() {
        return System.getProperty("os.name").toLowerCase().indexOf("win") >= 0;
    }

    public static long javaToDosTime(long j) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTimeInMillis(j);
        int i2 = calendar.get(1);
        if (i2 < 1980) {
            return 2162688L;
        }
        int i3 = calendar.get(2);
        int i4 = (i3 + 1) << 21;
        return i4 | ((i2 - 1980) << 25) | (calendar.get(5) << 16) | (calendar.get(11) << 11) | (calendar.get(12) << 5) | (calendar.get(13) >> 1);
    }

    public static void setFileArchive(File file) throws ZipException {
    }

    public static void setFileHidden(File file) throws ZipException {
    }

    public static void setFileReadOnly(File file) throws ZipException {
        if (file == null) {
            throw new ZipException("input file is null. cannot set read only file attribute");
        }
        if (file.exists()) {
            file.setReadOnly();
        }
    }

    public static void setFileSystemMode(File file) throws ZipException {
    }
}
