package net.lingala.zip4j.zip;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.HashMap;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.SplitOutputStream;
import net.lingala.zip4j.io.ZipOutputStream;
import net.lingala.zip4j.model.EndCentralDirRecord;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.model.ZipParameters;
import net.lingala.zip4j.progress.ProgressMonitor;
import net.lingala.zip4j.util.ArchiveMaintainer;
import net.lingala.zip4j.util.CRCUtil;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Zip4jUtil;
/* loaded from: classes11.dex */
public class ZipEngine {
    private ZipModel zipModel;

    public ZipEngine(ZipModel zipModel) throws ZipException {
        if (zipModel == null) {
            throw new ZipException("zip model is null in ZipEngine constructor");
        }
        this.zipModel = zipModel;
    }

    private long calculateTotalWork(ArrayList arrayList, ZipParameters zipParameters) throws ZipException {
        if (arrayList != null) {
            long j = 0;
            for (int i2 = 0; i2 < arrayList.size(); i2++) {
                if ((arrayList.get(i2) instanceof File) && ((File) arrayList.get(i2)).exists()) {
                    j += (zipParameters.isEncryptFiles() && zipParameters.getEncryptionMethod() == 0) ? Zip4jUtil.getFileLengh((File) arrayList.get(i2)) * 2 : Zip4jUtil.getFileLengh((File) arrayList.get(i2));
                    if (this.zipModel.getCentralDirectory() != null && this.zipModel.getCentralDirectory().getFileHeaders() != null && this.zipModel.getCentralDirectory().getFileHeaders().size() > 0) {
                        FileHeader fileHeader = Zip4jUtil.getFileHeader(this.zipModel, Zip4jUtil.getRelativeFileName(((File) arrayList.get(i2)).getAbsolutePath(), zipParameters.getRootFolderInZip(), zipParameters.getDefaultFolderPath()));
                        if (fileHeader != null) {
                            j += Zip4jUtil.getFileLengh(new File(this.zipModel.getZipFile())) - fileHeader.getCompressedSize();
                        }
                    }
                }
            }
            return j;
        }
        throw new ZipException("file list is null, cannot calculate total work");
    }

    private void checkParameters(ZipParameters zipParameters) throws ZipException {
        if (zipParameters == null) {
            throw new ZipException("cannot validate zip parameters");
        }
        if (zipParameters.getCompressionMethod() != 0 && zipParameters.getCompressionMethod() != 8) {
            throw new ZipException("unsupported compression type");
        }
        if (zipParameters.getCompressionMethod() == 8 && zipParameters.getCompressionLevel() < 0 && zipParameters.getCompressionLevel() > 9) {
            throw new ZipException("invalid compression level. compression level dor deflate should be in the range of 0-9");
        }
        if (!zipParameters.isEncryptFiles()) {
            zipParameters.setAesKeyStrength(-1);
            zipParameters.setEncryptionMethod(-1);
        } else if (zipParameters.getEncryptionMethod() != 0 && zipParameters.getEncryptionMethod() != 99) {
            throw new ZipException("unsupported encryption method");
        } else {
            if (zipParameters.getPassword() == null || zipParameters.getPassword().length <= 0) {
                throw new ZipException("input password is empty or null");
            }
        }
    }

    private EndCentralDirRecord createEndOfCentralDirectoryRecord() {
        EndCentralDirRecord endCentralDirRecord = new EndCentralDirRecord();
        endCentralDirRecord.setSignature(InternalZipConstants.ENDSIG);
        endCentralDirRecord.setNoOfThisDisk(0);
        endCentralDirRecord.setTotNoOfEntriesInCentralDir(0);
        endCentralDirRecord.setTotNoOfEntriesInCentralDirOnThisDisk(0);
        endCentralDirRecord.setOffsetOfStartOfCentralDir(0L);
        return endCentralDirRecord;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x0082, code lost:
        if (r0 != null) goto L30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x0084, code lost:
        r0.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x0122, code lost:
        r15.setResult(3);
        r15.setState(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:50:0x0128, code lost:
        r5.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x014f, code lost:
        if (r0 != null) goto L30;
     */
    /* JADX WARN: Not initialized variable reg: 3, insn: 0x0168: MOVE  (r0 I:??[OBJECT, ARRAY]) = (r3 I:??[OBJECT, ARRAY]), block:B:77:0x0167 */
    /* JADX WARN: Removed duplicated region for block: B:104:0x017c A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:96:0x0175 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:94:0x0087 -> B:98:0x0087). Please submit an issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void initAddFiles(ArrayList arrayList, ZipParameters zipParameters, ProgressMonitor progressMonitor) throws ZipException {
        ZipOutputStream zipOutputStream;
        ZipOutputStream zipOutputStream2;
        if (arrayList == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null when adding files");
        }
        if (arrayList.size() <= 0) {
            throw new ZipException("no files to add");
        }
        if (this.zipModel.getEndCentralDirRecord() == null) {
            this.zipModel.setEndCentralDirRecord(createEndOfCentralDirectoryRecord());
        }
        FileInputStream fileInputStream = null;
        try {
            try {
                checkParameters(zipParameters);
                removeFilesIfExists(arrayList, zipParameters, progressMonitor);
                boolean checkFileExists = Zip4jUtil.checkFileExists(this.zipModel.getZipFile());
                SplitOutputStream splitOutputStream = new SplitOutputStream(new File(this.zipModel.getZipFile()), this.zipModel.getSplitLength());
                zipOutputStream = new ZipOutputStream(splitOutputStream, this.zipModel);
                if (checkFileExists) {
                    try {
                        if (this.zipModel.getEndCentralDirRecord() == null) {
                            throw new ZipException("invalid end of central directory record");
                        }
                        splitOutputStream.seek(this.zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
                    } catch (ZipException e) {
                        e = e;
                        try {
                            progressMonitor.endProgressMonitorError(e);
                            throw e;
                        } catch (Throwable th) {
                            th = th;
                            if (fileInputStream != null) {
                                try {
                                    fileInputStream.close();
                                } catch (IOException unused) {
                                }
                            }
                            if (zipOutputStream != null) {
                                try {
                                    zipOutputStream.close();
                                } catch (IOException unused2) {
                                }
                            }
                            throw th;
                        }
                    } catch (Exception e2) {
                        e = e2;
                        progressMonitor.endProgressMonitorError(e);
                        throw new ZipException(e);
                    }
                }
                byte[] bArr = new byte[4096];
                int i2 = 0;
                loop0: while (true) {
                    try {
                        if (i2 >= arrayList.size()) {
                            zipOutputStream.finish();
                            progressMonitor.endProgressMonitorSuccess();
                        } else if (progressMonitor.isCancelAllTasks()) {
                            progressMonitor.setResult(3);
                            progressMonitor.setState(0);
                        } else {
                            ZipParameters zipParameters2 = (ZipParameters) zipParameters.clone();
                            progressMonitor.setFileName(((File) arrayList.get(i2)).getAbsolutePath());
                            if (!((File) arrayList.get(i2)).isDirectory()) {
                                if (zipParameters2.isEncryptFiles() && zipParameters2.getEncryptionMethod() == 0) {
                                    progressMonitor.setCurrentOperation(3);
                                    zipParameters2.setSourceFileCRC((int) CRCUtil.computeFileCRC(((File) arrayList.get(i2)).getAbsolutePath(), progressMonitor));
                                    progressMonitor.setCurrentOperation(0);
                                    if (progressMonitor.isCancelAllTasks()) {
                                        progressMonitor.setResult(3);
                                        progressMonitor.setState(0);
                                        if (fileInputStream != null) {
                                        }
                                    }
                                }
                                if (Zip4jUtil.getFileLengh((File) arrayList.get(i2)) == 0) {
                                    zipParameters2.setCompressionMethod(0);
                                }
                            }
                            zipOutputStream.putNextEntry((File) arrayList.get(i2), zipParameters2);
                            if (((File) arrayList.get(i2)).isDirectory()) {
                                zipOutputStream.closeEntry();
                            } else {
                                FileInputStream fileInputStream2 = new FileInputStream((File) arrayList.get(i2));
                                while (true) {
                                    try {
                                        int read = fileInputStream2.read(bArr);
                                        if (read == -1) {
                                            zipOutputStream.closeEntry();
                                            fileInputStream2.close();
                                            fileInputStream = fileInputStream2;
                                            break;
                                        } else if (progressMonitor.isCancelAllTasks()) {
                                            break loop0;
                                        } else {
                                            zipOutputStream.write(bArr, 0, read);
                                            progressMonitor.updateWorkCompleted(read);
                                        }
                                    } catch (ZipException e3) {
                                        e = e3;
                                        fileInputStream = fileInputStream2;
                                        progressMonitor.endProgressMonitorError(e);
                                        throw e;
                                    } catch (Exception e4) {
                                        e = e4;
                                        progressMonitor.endProgressMonitorError(e);
                                        throw new ZipException(e);
                                    } catch (Throwable th2) {
                                        th = th2;
                                        fileInputStream = fileInputStream2;
                                        if (fileInputStream != null) {
                                        }
                                        if (zipOutputStream != null) {
                                        }
                                        throw th;
                                    }
                                }
                            }
                            i2++;
                        }
                    } catch (IOException unused3) {
                    }
                }
                try {
                    zipOutputStream.close();
                } catch (IOException unused4) {
                }
            } catch (Throwable th3) {
                th = th3;
                zipOutputStream = zipOutputStream2;
                fileInputStream = null;
            }
        } catch (ZipException e5) {
            e = e5;
            zipOutputStream = null;
        } catch (Exception e6) {
            e = e6;
        } catch (Throwable th4) {
            th = th4;
            zipOutputStream = null;
        }
    }

    private RandomAccessFile prepareFileOutputStream() throws ZipException {
        String zipFile = this.zipModel.getZipFile();
        if (Zip4jUtil.isStringNotNullAndNotEmpty(zipFile)) {
            try {
                File file = new File(zipFile);
                if (!file.getParentFile().exists()) {
                    file.getParentFile().mkdirs();
                }
                return new RandomAccessFile(file, InternalZipConstants.WRITE_MODE);
            } catch (FileNotFoundException e) {
                throw new ZipException(e);
            }
        }
        throw new ZipException("invalid output path");
    }

    private void removeFilesIfExists(ArrayList arrayList, ZipParameters zipParameters, ProgressMonitor progressMonitor) throws ZipException {
        ZipModel zipModel = this.zipModel;
        if (zipModel == null || zipModel.getCentralDirectory() == null || this.zipModel.getCentralDirectory().getFileHeaders() == null || this.zipModel.getCentralDirectory().getFileHeaders().size() <= 0) {
            return;
        }
        RandomAccessFile randomAccessFile = null;
        int i2 = 0;
        while (true) {
            try {
                try {
                    if (i2 < arrayList.size()) {
                        FileHeader fileHeader = Zip4jUtil.getFileHeader(this.zipModel, Zip4jUtil.getRelativeFileName(((File) arrayList.get(i2)).getAbsolutePath(), zipParameters.getRootFolderInZip(), zipParameters.getDefaultFolderPath()));
                        if (fileHeader != null) {
                            if (randomAccessFile != null) {
                                randomAccessFile.close();
                                randomAccessFile = null;
                            }
                            ArchiveMaintainer archiveMaintainer = new ArchiveMaintainer();
                            progressMonitor.setCurrentOperation(2);
                            HashMap initRemoveZipFile = archiveMaintainer.initRemoveZipFile(this.zipModel, fileHeader, progressMonitor);
                            if (progressMonitor.isCancelAllTasks()) {
                                progressMonitor.setResult(3);
                                progressMonitor.setState(0);
                                if (randomAccessFile == null) {
                                    return;
                                }
                            } else {
                                progressMonitor.setCurrentOperation(0);
                                if (randomAccessFile == null) {
                                    randomAccessFile = prepareFileOutputStream();
                                    if (initRemoveZipFile != null && initRemoveZipFile.get(InternalZipConstants.OFFSET_CENTRAL_DIR) != null) {
                                        try {
                                            long parseLong = Long.parseLong((String) initRemoveZipFile.get(InternalZipConstants.OFFSET_CENTRAL_DIR));
                                            if (parseLong >= 0) {
                                                randomAccessFile.seek(parseLong);
                                            }
                                        } catch (NumberFormatException unused) {
                                            throw new ZipException("NumberFormatException while parsing offset central directory. Cannot update already existing file header");
                                        } catch (Exception unused2) {
                                            throw new ZipException("Error while parsing offset central directory. Cannot update already existing file header");
                                        }
                                    }
                                } else {
                                    continue;
                                }
                            }
                        }
                        i2++;
                    } else if (randomAccessFile == null) {
                        return;
                    }
                } catch (IOException e) {
                    throw new ZipException(e);
                }
            } catch (Throwable th) {
                if (randomAccessFile != null) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException unused3) {
                    }
                }
                throw th;
            }
        }
        try {
            randomAccessFile.close();
        } catch (IOException unused4) {
        }
    }

    public void addFiles(final ArrayList arrayList, final ZipParameters zipParameters, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        if (arrayList == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null when adding files");
        }
        if (arrayList.size() <= 0) {
            throw new ZipException("no files to add");
        }
        progressMonitor.setCurrentOperation(0);
        progressMonitor.setState(1);
        progressMonitor.setResult(1);
        if (!z) {
            initAddFiles(arrayList, zipParameters, progressMonitor);
            return;
        }
        progressMonitor.setTotalWork(calculateTotalWork(arrayList, zipParameters));
        progressMonitor.setFileName(((File) arrayList.get(0)).getAbsolutePath());
        new Thread(InternalZipConstants.THREAD_NAME) { // from class: net.lingala.zip4j.zip.ZipEngine.1
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    ZipEngine.this.initAddFiles(arrayList, zipParameters, progressMonitor);
                } catch (ZipException unused) {
                }
            }
        }.start();
    }

    public void addFolderToZip(File file, ZipParameters zipParameters, ProgressMonitor progressMonitor, boolean z) throws ZipException {
        File parentFile;
        if (file == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null, cannot add folder to zip");
        }
        if (!Zip4jUtil.checkFileExists(file.getAbsolutePath())) {
            throw new ZipException("input folder does not exist");
        }
        if (!file.isDirectory()) {
            throw new ZipException("input file is not a folder, user addFileToZip method to add files");
        }
        if (!Zip4jUtil.checkFileReadAccess(file.getAbsolutePath())) {
            throw new ZipException("cannot read folder: " + file.getAbsolutePath());
        }
        String str = "";
        if (!zipParameters.isIncludeRootFolder()) {
            str = file.getAbsolutePath();
        } else if (file.getAbsolutePath() != null) {
            if (file.getAbsoluteFile().getParentFile() != null) {
                parentFile = file.getAbsoluteFile().getParentFile();
                str = parentFile.getAbsolutePath();
            }
        } else if (file.getParentFile() != null) {
            parentFile = file.getParentFile();
            str = parentFile.getAbsolutePath();
        }
        zipParameters.setDefaultFolderPath(str);
        ArrayList filesInDirectoryRec = Zip4jUtil.getFilesInDirectoryRec(file, zipParameters.isReadHiddenFiles());
        if (zipParameters.isIncludeRootFolder()) {
            if (filesInDirectoryRec == null) {
                filesInDirectoryRec = new ArrayList();
            }
            filesInDirectoryRec.add(file);
        }
        addFiles(filesInDirectoryRec, zipParameters, progressMonitor, z);
    }

    public void addStreamToZip(InputStream inputStream, ZipParameters zipParameters) throws ZipException {
        if (inputStream == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null, cannot add stream to zip");
        }
        ZipOutputStream zipOutputStream = null;
        try {
            try {
                checkParameters(zipParameters);
                boolean checkFileExists = Zip4jUtil.checkFileExists(this.zipModel.getZipFile());
                SplitOutputStream splitOutputStream = new SplitOutputStream(new File(this.zipModel.getZipFile()), this.zipModel.getSplitLength());
                ZipOutputStream zipOutputStream2 = new ZipOutputStream(splitOutputStream, this.zipModel);
                if (checkFileExists) {
                    try {
                        if (this.zipModel.getEndCentralDirRecord() == null) {
                            throw new ZipException("invalid end of central directory record");
                        }
                        splitOutputStream.seek(this.zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
                    } catch (ZipException e) {
                        throw e;
                    } catch (Exception e2) {
                        e = e2;
                        throw new ZipException(e);
                    } catch (Throwable th) {
                        th = th;
                        zipOutputStream = zipOutputStream2;
                        if (zipOutputStream != null) {
                            try {
                                zipOutputStream.close();
                            } catch (IOException unused) {
                            }
                        }
                        throw th;
                    }
                }
                byte[] bArr = new byte[4096];
                zipOutputStream2.putNextEntry(null, zipParameters);
                if (!zipParameters.getFileNameInZip().endsWith(InternalZipConstants.ZIP_FILE_SEPARATOR) && !zipParameters.getFileNameInZip().endsWith("\\")) {
                    while (true) {
                        int read = inputStream.read(bArr);
                        if (read == -1) {
                            break;
                        }
                        zipOutputStream2.write(bArr, 0, read);
                    }
                }
                zipOutputStream2.closeEntry();
                zipOutputStream2.finish();
                try {
                    zipOutputStream2.close();
                } catch (IOException unused2) {
                }
            } catch (Throwable th2) {
                th = th2;
            }
        } catch (ZipException e3) {
            throw e3;
        } catch (Exception e4) {
            e = e4;
        }
    }
}
